@@ -201,7 +201,7 @@ BEGIN_EVENT_TABLE(wxVTKRenderWindowInteractor, wxWindow)
 
   //Bind the events to the event converters
   EVT_LEFT_DOWN   (wxVTKRenderWindowInteractor::OnButtonDown)
-  EVT_LEFT_DCLICK (wxVTKRenderWindowInteractor::OnMouseDoubleCilck)
+  EVT_LEFT_DCLICK (wxVTKRenderWindowInteractor::OnMouseDoubleClick)
   EVT_MIDDLE_DOWN (wxVTKRenderWindowInteractor::OnButtonDown)
   EVT_RIGHT_DOWN  (wxVTKRenderWindowInteractor::OnButtonDown)
   EVT_LEFT_UP     (wxVTKRenderWindowInteractor::OnButtonUp)
@@ -1295,7 +1295,7 @@ const char* wx_key_to_key_sym(int i)
 
 
 //---------------------------------------------------------------------------
-void wxVTKRenderWindowInteractor::OnMouseDoubleCilck(wxMouseEvent &event)
+void wxVTKRenderWindowInteractor::OnMouseDoubleClick(wxMouseEvent &event)
 {
   if (!Enabled || (ActiveButton != wxEVT_NULL))
   {
