@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ipacscontroller.h 4477 2011-12-13 11:16:56Z tovar $
+ *  $Id: ipacscontroller.h 4848 2012-04-18 09:43:41Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -12,9 +12,10 @@
  */
 #pragma once
 
+#include <ostream>
 #include <string>
 #include <exception>
-#include <ostream>
+#include <vector>
 #include <list>
 #include <map>
 
@@ -41,6 +42,41 @@ namespace GIL {
 			}
 		};
 
+		class EXTAPI ICustomAssociation {
+			
+		protected:
+
+			ICustomAssociation();
+
+		public:
+			virtual ~ICustomAssociation();
+
+		public:
+
+			virtual bool Connect(const std::string& serverId, const std::string& local_aet) = 0;
+
+			virtual bool createRQ( const std::string& sopclassUID, const std::string& sopinstanceUID, const GIL::DICOM::TipoJerarquia& attributeListIn,  int& status, GnkPtr<GIL::DICOM::TipoJerarquia>& attributeListOut) = 0;
+			virtual bool setRQ(    const std::string& sopclassUID, const std::string& sopinstanceUID, const GIL::DICOM::TipoJerarquia& modificationList, int& status, GnkPtr<GIL::DICOM::TipoJerarquia>& attributeListOut) = 0;
+			virtual bool getRQ(    const std::string& sopclassUID, const std::string& sopinstanceUID, const int *attributeIdentifierList, unsigned long numShorts, int& status,  GnkPtr<GIL::DICOM::TipoJerarquia>& attributeListOut) = 0;
+			virtual bool actionRQ( const std::string& sopclassUID, const std::string& sopinstanceUID, int actionTypeID, const GIL::DICOM::TipoJerarquia& actionInformation, int& status,  GnkPtr<GIL::DICOM::TipoJerarquia>& attributeListOut) = 0;
+			virtual bool deleteRQ( const std::string& sopclassUID, const std::string& sopinstanceUID, int& status) = 0;
+
+			virtual bool releaseAssociation() = 0;
+			virtual bool abortAssociation() = 0;
+
+		public:
+
+			void addPresentationContext(const std::string& sopClass, const std::list<std::string>& transferSyntaxes);
+			void mapClassForPresentationContext(const std::string& src, const std::string& dest);
+			const std::string& getErrorMessage() const;
+
+		protected:
+
+			std::string errorMsg;		
+			std::list< std::map<std::string, std::list<std::string> > > presentationContexts;
+			std::map<std::string, std::string> presentationContextMap;
+		};
+
 		typedef struct ContextoResultado {
 			bool error;
 			std::string UIDPaciente;
@@ -147,6 +183,34 @@ namespace GIL {
 				const GIL::DICOM::TipoJerarquia& base,
 				GNC::IProxyNotificadorProgreso* pNotificador
 			) = 0;
+			
+			virtual bool Print(
+				void* connectionKey,
+				const std::string& serverId,
+				const GIL::DICOM::TipoJerarquia& film,
+				const GIL::DICOM::TipoJerarquia& layout,
+				const GIL::DICOM::TipoJerarquia& job,
+				const std::vector<std::string> files,
+				GNC::IProxyNotificadorProgreso* pNotificador
+			) = 0;
+
+			/** Gets the current server ID list */
+			virtual void GetServerList(std::list<std::string>& list) = 0;
+
+			/** Perform query */
+			virtual bool Query(
+				void* connectionKey,
+				const std::string& abstractSyntax,
+				const std::list<std::string>& transferSyntaxes,
+				const GIL::DICOM::TipoJerarquia& query,
+				int maxResultTagLen,
+				std::list< GnkPtr<GIL::DICOM::TipoJerarquia> >& resultsWraper,
+				const std::string& serverId,
+				GNC::IProxyNotificadorProgreso* pNotificador
+			) = 0;
+
+			virtual GIL::DICOM::ICustomAssociation* CreateCustomAssociation(void* connectionKey, const std::string& ambitolog, GNC::IProxyNotificadorProgreso* pNotificador = NULL) = 0;
+			virtual void DestroyCustomAssociation(GIL::DICOM::ICustomAssociation* assoc) = 0;
 
 			virtual void SubirArchivos(void* connectionKey, const std::string& serverId, const std::vector<std::string>& pathsSubida, GNC::IProxyNotificadorProgreso * pNotificador, TipoTransferSyntaxEnvio transferSyntax) =0;
 
@@ -158,10 +222,13 @@ namespace GIL {
 
 			virtual bool findAndGetTagFromFile(const std::string& ruta, unsigned short group, unsigned short element, std::string& value) = 0;
 
-			virtual bool EsDICOM(const std::string& path, bool accept_dicomdir, bool accept_dicomfile) = 0;
+			virtual bool EsDICOM(const std::string& path, bool accept_dicomdir, bool accept_dicomfile) const = 0;
+			
+			virtual bool EsPDF(const std::string& path) const = 0;
 
 			/* Devuelve la ruta en disco (asignada a la variable ruta pasada por referencia) en base a los IDs unicos de estudio y serie de una serie de imagenes obtenida*/
-			virtual bool GetRutaImagen(const std::string& uidPaciente, const std::string& uidEstudio, const std::string& uidSerie, const std::string& uidImagen, std::string& ruta, bool crearDirectorios = true) = 0;
+			virtual bool GetRutaImagen(const std::string& uidPaciente, const std::string& uidEstudio, const std::string& uidSerie, const std::string& uidImagen, const std::string& dicomDirPath, std::string& ruta, bool crearDirectorios = true) = 0;
+			virtual bool GetRutaImagenTemp(const std::string& uidPaciente, const std::string& uidEstudio, const std::string& uidSerie, const std::string& uidImagen, const std::string& dicomDirPath, std::string& ruta, bool crearDirectorios = true) = 0;
 
 			void DumpFileElements(const std::string& rutaFichero, IInspectCallBack* callback);
 
