@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: imodelodicom.h 3834 2011-05-10 07:42:57Z carlos $
+ *  $Id: imodelodicom.h 4687 2012-02-10 13:35:07Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -25,9 +25,9 @@ class IModeloPaciente;
 
 namespace GIL {
 	namespace DICOM {
-		class ModelException : public std::exception {
+		class ModelException : public GNC::GCS::IException {
 		public:
-			ModelException(const std::string& msg, const std::string& componente="GIL/DICOM/Model", bool fatal = true) throw()
+			ModelException(const std::string& msg, const std::string& componente="GIL/DICOM/Model", bool fatal = true) : GNC::GCS::IException(msg, componente, fatal)
 			{
 				this->cause = msg;
 				this->component = componente;
