@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: iconfiguracion.h 3066 2010-12-21 10:10:14Z carlos $
+ *  $Id: iconfiguracion.h 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -15,7 +15,6 @@
 #include <list>
 
 class wxWindow;
-class wxXmlNode;
 
 class IDialogoConfiguracion {
 public:
@@ -56,8 +55,4 @@ public:
 	virtual bool Validar() = 0;
 
 	virtual bool Guardar() = 0;
-
-	virtual void Exportar(wxXmlNode* pNodo) = 0;
-
-	virtual void Importar(wxXmlNode* pNodo) = 0;
 };
