@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: icontextoestudio.cpp 4575 2012-01-20 14:21:44Z tovar $
+ *  $Id: icontextoestudio.cpp 4694 2012-02-13 12:30:11Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -20,13 +20,12 @@
 #include <api/ientorno.h>
 #include <api/ivista.h>
 #include <api/icontextoestudio.h>
-#include <api/imodelointegracion.h>
 
 #include <api/dicom/idicomizador.h>
 #include <api/dicom/idicommanager.h>
 
 #include <api/controllers/ipacscontroller.h>
-#include <api/icontroladorhistorial.h>
+#include <main/controllers/controladorhistorial.h>
 #include <api/icontroladorherramientas.h>
 #include <api/icontroladorlog.h>
 
@@ -116,8 +115,6 @@ GnkPtr<GNC::GCS::IContextoEstudioReferido> GNC::GCS::IContextoEstudio::NewRef(co
 
 	reference->Ficheros              = parent->Ficheros;
 
-	reference->ModeloIntegracion     = parent->ModeloIntegracion;
-
 	reference->IgnorarModificaciones = parent->IgnorarModificaciones;
 
 	reference->ModoFuncionamiento    = parent->ModoFuncionamiento;
@@ -146,8 +143,6 @@ GNC::GCS::IContextoEstudio& GNC::GCS::IContextoEstudio::operator = (const GNC::G
 
 	Ficheros              = o.Ficheros;
 
-	ModeloIntegracion     = o.ModeloIntegracion;
-
 	IgnorarModificaciones = o.IgnorarModificaciones;
 
 	ModoFuncionamiento    = o.ModoFuncionamiento;
@@ -266,16 +261,6 @@ std::list<std::string> GNC::GCS::IContextoEstudio::GetListaFicherosYDiagnosticos
 	return resultado;
 }
 
-void GNC::GCS::IContextoEstudio::SetModeloIntegracion(GnkPtr<GIL::IModeloIntegracion> modeloIntegracion)
-{
-	ModeloIntegracion = modeloIntegracion;
-}
-
-GnkPtr<GIL::IModeloIntegracion>& GNC::GCS::IContextoEstudio::GetModeloIntegracion()
-{
-	return ModeloIntegracion;
-}
-
 const std::string& GNC::GCS::IContextoEstudio::GetRutaDeImagenActiva()
 {
 	return GetRutaDeImagen(IndiceFicheroActivo);
@@ -552,13 +537,7 @@ int GNC::GCS::IContextoEstudio::GetTSizeActiva()
 const std::string GNC::GCS::IContextoEstudio::GetNombreMedico()
 {
 	std::string nombre ("");
-	if(ModeloIntegracion.IsValid()) {
-		std::ostringstream ostr;
-		ostr<<ModeloIntegracion->Medico.apellido1 << ' ' << ModeloIntegracion->Medico.apellido2 << '^' << ModeloIntegracion->Medico.nombre;
-		nombre = ostr.str();
-	} else {
-		GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Estacion","NombreMedico",nombre);
-	}
+	GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Estacion","NombreMedico",nombre);
 	return nombre;
 }
 
@@ -566,11 +545,7 @@ const std::string GNC::GCS::IContextoEstudio::GetNombreMedico()
 const std::string GNC::GCS::IContextoEstudio::GetNombreCentro()
 {
 	std::string nombre ("");
-	if(ModeloIntegracion.IsValid()) {
-		nombre = ModeloIntegracion->Medico.nombreCentro;
-	} else {
-		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","CentroNombre",nombre);
-	}
+	GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","CentroNombre",nombre);
 	return nombre;
 }
 
@@ -652,10 +627,14 @@ void GNC::GCS::IContextoEstudio::SetModificado(const int indice)
 
 bool GNC::GCS::IContextoEstudio::Guardar()
 {
-	if (ModoFuncionamiento == TMF_NDiagnosticos) {
-		return GuardarNDiagnosticos();
+	if (!GNC::GCS::ControladorHistorial::Instance()->IsReadOnly()) {
+		if (ModoFuncionamiento == TMF_NDiagnosticos) {
+			return GuardarNDiagnosticos();
+		} else {
+			return GuardarUnDiagnostico();
+		}
 	} else {
-		return GuardarUnDiagnostico();
+		return false;
 	}
 }
 
@@ -743,7 +722,7 @@ bool GNC::GCS::IContextoEstudio::GuardarUnDiagnostico()
 		pTagDiagnostico->getTag(std::string("0020|000e"),uidSerie);
 		pTagDiagnostico->getTag(std::string("0008|0018"),uidImagen);
 
-		Entorno->GetPACSController()->GetRutaImagen(uidPaciente,UIDEstudioDiagnostico,uidSerie,uidImagen,Ficheros[0]->RutaDiagnostico);
+		Entorno->GetPACSController()->GetRutaImagen(uidPaciente,UIDEstudioDiagnostico,uidSerie,uidImagen, GNC::GCS::ControladorHistorial::Instance()->GetGinkgoDicomDir(),Ficheros[0]->RutaDiagnostico);
 
 		if (!wxCopyFile(pathTmp,FROMPATH( Ficheros[0]->RutaDiagnostico ))) {
 			LOG_ERROR("IContextoEstudio", "error copying file " << stdPathTmp << " TO " << Ficheros[0]->RutaDiagnostico);
@@ -820,13 +799,9 @@ bool GNC::GCS::IContextoEstudio::GuardarNDiagnosticos()
 
 		//institucion
 		std::string strTmp;
-		if(ModeloIntegracion.IsValid()) {
-			pTagDiagnostico->tags[std::string("0008|0080")] = ModeloIntegracion->Medico.nombreCentro;
-		} else {
-			GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","CentroNombre",strTmp);
-			if(strTmp.size() != 0){
-				pTagDiagnostico->tags[std::string("0008|0080")] = strTmp;
-			}
+		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","CentroNombre",strTmp);
+		if(strTmp.size() != 0){
+			pTagDiagnostico->tags[std::string("0008|0080")] = strTmp;
 		}
 
 		//nombre del medico responsable de la institucion
@@ -878,7 +853,7 @@ bool GNC::GCS::IContextoEstudio::GuardarNDiagnosticos()
 			pTagDiagnostico->getTag(std::string("0020|000e"),uidSerie);
 			pTagDiagnostico->getTag(std::string("0008|0018"),uidImagen);
 
-			Entorno->GetPACSController()->GetRutaImagen(uidPaciente,UIDEstudioDiagnostico,uidSerie,uidImagen,Ficheros[i]->RutaDiagnostico);
+			Entorno->GetPACSController()->GetRutaImagen(uidPaciente,UIDEstudioDiagnostico,uidSerie,uidImagen, GNC::GCS::ControladorHistorial::Instance()->GetGinkgoDicomDir(),Ficheros[i]->RutaDiagnostico);
 
 			if (!wxCopyFile(pathTmp,FROMPATH( Ficheros[i]->RutaDiagnostico ))) {
 				LOG_ERROR("IContextoEstudio", "error copying file " << stdPathTmp << " TO " << Ficheros[0]->RutaDiagnostico);
@@ -1141,7 +1116,7 @@ void GNC::GCS::IContextoEstudio::CargarTagsImagen(const int indice)
 			//se  busca el diagnostico que apunte a este fichero
 			modelo = Entorno->GetControladorHistorial()->GetDiagnostico(Ficheros[indice]->RutaImagen,UIDEstudioDiagnostico);
 		}
-		std::string pathAbsoluto = Entorno->GetPathAbsolutoFichero(modelo.m_pathRelativo);
+		std::string pathAbsoluto = GNC::GCS::ControladorHistorial::Instance()->GetPathAbsolutoFichero(modelo.m_pathRelativo);
 		if(wxFileExists(FROMPATH(pathAbsoluto)))
 		{
 			//leemos los tags privados del diagnostico
