@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: icontextoestudio.h 4446 2011-11-25 09:18:18Z tovar $
+ *  $Id: icontextoestudio.h 4582 2012-01-24 09:39:52Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -38,10 +38,6 @@ namespace GNC {
 	}
 }
 
-namespace GIL {
-	class IModeloIntegracion;
-}
-
 namespace GIL {
 	namespace DICOM {
 		struct TipoJerarquia;
@@ -96,8 +92,7 @@ namespace GNC {
 			int                                               IndiceFicheroActivo;
 			std::list<std::string>                            ListaUIDsSerie;
 		protected:
-			TVectorFicherosEstudio			                  Ficheros;
-			GnkPtr<GIL::IModeloIntegracion>                   ModeloIntegracion;
+			TVectorFicherosEstudio										Ficheros;
 			bool                                              IgnorarModificaciones;
 			TModoFuncionamiento                               ModoFuncionamiento;
 
@@ -140,9 +135,6 @@ namespace GNC {
 
 			std::list<std::string> GetListaFicherosYDiagnosticos();
 
-			void SetModeloIntegracion(GnkPtr<GIL::IModeloIntegracion> modeloIntegracion);
-			GnkPtr<GIL::IModeloIntegracion>& GetModeloIntegracion();
-
 			const std::string& GetRutaDeImagenActiva();
 			const std::string& GetRutaDeImagen(const int indice);
 			const std::string& GetRutaDeDiagnosticoActivo();
