@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: icontroladorhistorial.h 3827 2011-05-05 12:19:42Z tovar $
+ *  $Id: icontroladorhistorial.h 4404 2011-11-15 09:41:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -35,6 +35,8 @@ namespace GNC {
 				std::string m_descripcionEstudio;
 				std::string m_uidImportador;
 				std::string m_nombreMedico;
+				std::string m_accessionNumber;
+				std::string m_studyId;
 			}ModeloEstudio;
 
 			typedef struct ModeloDCM
@@ -59,6 +61,9 @@ namespace GNC {
 				std::string m_uidImportador;
 				std::string m_uidImagen;
 				std::string m_nombreMedico;
+				std::string m_studyId;
+				std::string m_seriesNumber;
+				std::string m_accessionNumber;
 				char	m_orientacion;
 				double		m_patientPosition[3];
 				std::string m_contentDate;
@@ -69,6 +74,7 @@ namespace GNC {
 				double m_instanceNumber;
 				std::list<std::string> m_listaReferencias;
 				std::string m_uidTransferSyntax;
+				std::string m_sopClassUID;
 				char m_sexo;
 			}ModeloDCM;
 
@@ -93,6 +99,9 @@ namespace GNC {
 					m_numeroSlices = 1;
 					m_sexo = otro.m_sexo;
 					m_uidTransferSyntax = otro.m_uidTransferSyntax;
+					m_accessionNumber = otro.m_accessionNumber;
+					m_studyId = otro.m_studyId;
+					m_seriesNumber = otro.m_seriesNumber;
 				}
 
 				std::string m_idPaciente;
@@ -109,6 +118,9 @@ namespace GNC {
 				std::string m_modalidad;
 				std::string m_uidImportador;
 				std::string m_uidTransferSyntax;
+				std::string m_studyId;
+				std::string m_accessionNumber;
+				std::string m_seriesNumber;
 				int m_numeroSlices;
 				char m_sexo;
 			}ModeloSerie;			
