@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: iexception.cpp 3911 2011-07-04 07:58:00Z carlos $
+ *  $Id: iexception.cpp 4782 2012-03-08 11:01:25Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -33,6 +33,11 @@ const std::string& GNC::GCS::IException::GetCause() const {
 	return cause;
 }
 
+const char* GNC::GCS::IException::what() const throw()
+{
+	return cause.c_str();
+}
+
 std::string GNC::GCS::IException::GetFullCause() const {
 	return *this;
 }
