@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: iexception.h 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: iexception.h 4782 2012-03-08 11:01:25Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -25,12 +25,14 @@ namespace GNC {
 		public:
 			IException(const std::string& msg, const std::string& component="GNC", bool fatal = true) throw();
 
-			~IException() throw();
+			virtual ~IException() throw();
 
 			const std::string& GetComponent() const;
 
 			const std::string& GetCause() const;
 
+			virtual const char* what() const throw();
+
 			std::string GetFullCause() const;
 
 			bool IsFatal()  const;
