@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: imodelohl7.h 3518 2011-03-16 13:53:24Z carlos $
+ *  $Id: imodelohl7.h 4687 2012-02-10 13:35:07Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -29,118 +29,14 @@ namespace GIL {
 
 		/* Este namespace contiene una implementación completa de mensajeria HL7 generica */
 
-		class HL7Exception : public std::exception {
+		class HL7Exception : public GNC::GCS::IException {
 		public:
-			HL7Exception(const std::string& msg, const std::string& componente="Modelo", bool fatal = true) throw()
-			{
-				this->cause = msg;
-				this->component = componente;
-				this->fatal = fatal;
-			}
-			~HL7Exception() throw()
-			{
-			}
-
-			const std::string& GetComponent() const
-			{
-				return component;
-			}
-
-			const std::string& GetCause() const {
-				return cause;
-			}
-
-			std::string GetFullCause() const {
-				return *this;
-			}
-
-			bool IsFatal()  const {
-				return fatal;
-			}
-
-			operator std::string () const {
-				return std::string("Excepcion en componente ") + GetComponent() + std::string(": ")  + GetCause();
-			}
-
-			friend std::ostream& operator<<(std::ostream& out, const HL7Exception& ex)
-			{
-				out << (const std::string&) ex;
-				return out;
-			}
-
-			friend std::ostream& operator<<(std::ostream& out, const HL7Exception* ex)
-			{
-				if (ex != NULL) {
-					out << *ex;
-				}
-				else {
-					out << "(NULL)";
-				}
-				return out;
-			}
-
-		protected:
-			std::string cause;
-			std::string component;
-			bool fatal;
+			HL7Exception(const std::string& msg, const std::string& component="HL7", bool fatal = true) throw() : GNC::GCS::IException(msg ,component, fatal) {}
 		};
 
-		class HL7XMLException : public std::exception {
+		class HL7XMLException : public GNC::GCS::IException {
 		public:
-			HL7XMLException(const std::string& msg, const std::string& xml, const std::string& componente="XMLIntegration", bool fatal = true) throw()
-			{
-				this->cause = msg;
-				this->xml = xml;
-				this->component = componente;
-				this->fatal = fatal;
-			}
-			~HL7XMLException() throw()
-			{
-			}
-
-			const std::string& GetComponent() const
-			{
-				return component;
-			}
-
-			const std::string& GetCause() const {
-				return cause;
-			}
-
-			std::string GetFullCause() const {
-				return *this;
-			}
-
-			bool IsFatal()  const {
-				return fatal;
-			}
-
-			operator std::string () const {
-				return std::string("Excepcion en componente ") + GetComponent() + std::string(": ")  + GetCause() + std::string(" XML dump:\n") + xml.c_str();
-			}
-
-			friend std::ostream& operator<<(std::ostream& out, const HL7XMLException& ex)
-			{
-				out << (const std::string&) ex;
-				return out;
-			}
-
-			friend std::ostream& operator<<(std::ostream& out, const HL7XMLException* ex)
-			{
-				if (ex != NULL) {
-					out << *ex;
-				}
-				else {
-					out << "(NULL)";
-				}
-				return out;
-			}
-
-		protected:
-			std::string cause;
-			std::string xml;
-			std::string component;
-			bool fatal;
+			HL7XMLException(const std::string& msg, const std::string& component="XMLIntegration", bool fatal = true) throw() : GNC::GCS::IException(msg ,component, fatal) {}			
 		};
 
 		namespace Util {
@@ -285,7 +181,7 @@ namespace GIL {
 			}
 		};
 
-		class Field : protected std::map<unsigned int, Component> {
+		class Field : public std::map<unsigned int, Component> {
 
 		private:
 			typedef std::map<unsigned int, Component> Base;
@@ -664,14 +560,14 @@ namespace GIL {
 				return out << *s;
 			}
 
-			Field& ParseField (unsigned int fieldNum, const std::string& record, bool unscape = true);
+			EXTAPI Field& ParseField (unsigned int fieldNum, const std::string& record, bool unscape = true);
 
-			const std::string EscapeER7(const std::string& str) const;
-			const std::string UnEscapeER7(const std::string& str) const;
+			EXTAPI const std::string EscapeER7(const std::string& str) const;
+			EXTAPI const std::string UnEscapeER7(const std::string& str) const;
 
 		};
 
-		class Message : protected std::list<Segment> {
+		class Message : public std::list<Segment> {
 
 		private:
 
@@ -861,8 +757,8 @@ namespace GIL {
 
 		public:
 
-			const std::string EscapeER7(const std::string& str) const;
-			const std::string UnEscapeER7(const std::string& str) const;
+			EXTAPI const std::string EscapeER7(const std::string& str) const;
+			EXTAPI const std::string UnEscapeER7(const std::string& str) const;
 
 			void Clear()
 			{
