@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: initwx.cpp 4491 2011-12-14 10:17:03Z tovar $
+ *  $Id: initwx.cpp 4851 2012-04-18 11:59:41Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -74,6 +74,7 @@
 #include <main/licencia.h>
 #include <api/globals.h>
 #include <api/imodulo.h>
+#include <api/integration/template.h>
 #include <api/icontroladormodulo.h>
 #include <api/dicom/idicomconformance.h>
 #include <eventos/eventosginkgo.h>
@@ -95,11 +96,13 @@
 #include <main/controllers/controladorlog.h>
 #include <main/controllers/controladorbbddhl7.h>
 #include <main/controllers/controladoracciones.h>
+#include <main/controllers/integrationcontroller.h>
 #include <main/controllers/dcmtk/dicomservers.h>
 #include <main/controllers/controladorinternacionalizacion.h>
 #include <main/controllers/controladorautenticacion.h>
 #include <main/tools/herramientascore.h>
 #include <main/controllers/xmlrpccontroller.h>
+#include <main/controllers/inactivitycontroller.h>
 #include <main/controllers/configurationcontroller.h>
 
 #include <main/gui/mainwindow/ventanaprincipal.h>
@@ -180,6 +183,20 @@ void Ginkgo::ProcesarEvento(GNC::GCS::Eventos::IEvento* evt)
 	}
 }
 
+int Ginkgo::FilterEvent(wxEvent &event)
+{
+    // Automaticlly logout when the user is Away From Keyboard (AFK) for too long
+
+	if (wxEVT_MOTION == event.GetEventType() || wxEVT_CHAR == event.GetEventType())
+    {
+        // User has done something, so stop the AFK timer
+		 GNC::GCS::InactivityController::Instance()->ResetsInactivity();
+    }
+	 const int FILTER_EVENT_PROCESS_NORMALLY = -1;
+
+    return FILTER_EVENT_PROCESS_NORMALLY;
+}
+
 /* Carga las extensiones de plugins Ginkgo (Bibliotecas externas .plugin) */
 void Ginkgo::LoadPlugins()
 {
@@ -318,7 +335,10 @@ bool Ginkgo::OnInit()
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "anonymous_history", _Std("Anonymous mode (history is cleaned)"), false, "", false);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "max_tabs", _Std("Max number of tabs opened"), false, "2", false);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "inactivity_time", _Std("Max seconds of Ginkgo CADx application inactivity"), false, "600", false);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "auto_close", _Std("Close automatically Ginkgo CADx after dicomize"), false, "", false);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "export", _Std("Export images"), false, "", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "acquire", _Std("Acquire DICOM files"), false, "", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "import", _Std("Import files to DICOM format"), false, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Online manual"), "url_manual", _Std("URL of online manual"), true, "http://doc.ginkgo-cadx.com/", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Online support"), "url_support", _Std("URL of online support"), true, _Std("http://ginkgo-cadx.com/en/services/"), true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Extensions Support"), "extensions_support_1", _Std("URL for new extensions"), true, _Std("http://ginkgo-cadx.com/"), true);
@@ -329,7 +349,6 @@ bool Ginkgo::OnInit()
 	
 	
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.menu",_Std("Tools"),"configuracion",_Std("Settings menu"), false, "", true);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.menu",_Std("Tools"),"filtrado",_Std("Filter menu"), true, "", false);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.menu",_Std("Tools"),"licencia",_Std("License menu"), true, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"),"pacs_upload",_Std("Upload images to a PACS server"), false, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "pacs_acquisition", _Std("Acquire images from PACS"),false, "", true);
@@ -345,6 +364,7 @@ bool Ginkgo::OnInit()
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.hl7", _Std("HL7 Service"), "autostart", _Std("Automatically start HL7 Sender service"), false, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.integracion", _Std("XML dicomization"), "send_message", _Std("Send Hl7 message when importing"), false, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.integracion", _Std("XML dicomization"), "upload_pacs", _Std("Send study to PACS when importing"), false, "", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.integracion",_Std("XML dicomization"), "integration_template",_Std("Default ORU template"),false, DEFAULT_INTEGRATION_MESSAGE_TEMPLATE, true);
 
 
 	std::string modalidades[20] = {"CR","CT","DR","DX","IO","MG","MR","NM","OT","PT","RF","RG","SC","SR","US","XA","XC","ES","ECG","HD"};
@@ -357,6 +377,8 @@ bool Ginkgo::OnInit()
 	wxString texto = _("Download all modalities");
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.download",_Std("PACS"),"all",std::string(texto.ToUTF8()),false, "", true);
 
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.opengl", _Std("OpenGL"), "enable_shaders", _Std("Enable shaders"), false, "", true);
+
 	//
 
 	/*
@@ -452,7 +474,10 @@ bool Ginkgo::OnInit()
 			cH->RegistrarHerramienta(new GNC::HerramientaMarcado());
 			cH->RegistrarHerramienta(new GNC::HerramientaNota());
 			cH->RegistrarHerramienta(new GNC::HerramientaElevacion());
+// BROKEN
+#if 0
 			cH->RegistrarHerramienta(new GNC::HerramientaLupa());
+#endif
 			cH->RegistrarHerramienta(new GNC::HerramientaRejillaMetrica());
 			cH->RegistrarHerramienta(new GNC::HerramientaLayoutVentana());
 
@@ -462,24 +487,20 @@ bool Ginkgo::OnInit()
 			cH->RegistrarHerramienta(new GNC::HerramientaDesencajar());
 			cH->RegistrarHerramienta(new GNC::HerramientaDeshacer());
 			cH->RegistrarHerramienta(new GNC::HerramientaInterpolate());
-			
+						
 
 			//especial
 			cH->RegistrarHerramienta(new GNC::HerramientaReset());
 			//cH->RegistrarHerramienta(new GNC::HerramientaLazo());
 		}
 		catch (GNC::GCS::ControladorHerramientasException& e) {
-			std::cerr << e.getCause().c_str() << std::endl;
+			std::cerr << e << std::endl;
 		}
 		
 
 		DoProgress(wxString(_("Configuring environment ...")));
-		//FUNDAMENTAL LOS PERMISOS DESPUES DE LOADPLUGINS, PORQUE SI NO NO ESTAN CARGADAS LAS DEFINICIONES DE PERMISOS
-		std::string permisos(PERMISOS_DIST);
-		try{
-			//carga de permisos definidos en licencia (privados)
-			GNC::GCS::ControladorPermisos::Instance()->CargarXMLPermisos(permisos,true);
 
+		try{
 			GNC::GCS::ConfigurationController::TListGroups profiles;
 			GNC::GCS::ConfigurationController::Instance()->readGroupGeneral("/GinkgoCore/Profiles", profiles);
 
@@ -508,7 +529,7 @@ bool Ginkgo::OnInit()
 			(*it).second->RegistrarVistas();
 		}
 
-		m_pVentanaPrincipal->CargarHistorial();			
+		m_pVentanaPrincipal->CargarHistorial();	
 
 		DoProgress(wxString(_("Interpreting parameters ...")));
 
@@ -686,14 +707,16 @@ int Ginkgo::OnExit()
 		}
 	}
 	catch (GNC::GCS::ControladorHerramientasException& ex) {
-		std::cerr << "Error al registrar herramientas de Derma: No se pudo subscribir la herramienta: " << ex.getCause() << std::endl;
+		std::cerr << "Error al registrar herramientas de Derma: No se pudo subscribir la herramienta: " << ex << std::endl;
 	}
 
 
 	GNC::GCS::ControladorVistas::FreeInstance();
 	GIL::XMLRPC::XMLRPCController::FreeInstance();
+	GIL::IntegrationController::FreeInstance();
 	GIL::HL7::ControladorEnvioHl7::FreeInstance();
 	GNC::GCS::ControladorAcciones::FreeInstance();
+	GNC::GCS::InactivityController::FreeInstance();
 	GNC::GCS::ControladorComandos::FreeInstance();
 	GIL::DICOM::PACSController::FreeInstance();
 	GNC::ControladorExtensiones::FreeInstance();
