@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: iproxynotificadorprogreso.h 3483 2011-03-10 14:56:55Z carlos $
+ *  $Id: iproxynotificadorprogreso.h 3830 2011-05-06 13:30:18Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -11,7 +11,7 @@
  *
  */
 #pragma once
-#include "api.h"
+#include <api/api.h>
 #include <string>
 namespace GNC {
 	class EXTAPI IProxyNotificadorProgreso {
