@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ivista.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: ivista.cpp 4687 2012-02-10 13:35:07Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -21,55 +21,6 @@
 
 #include "ivista.h"
 
-GNC::GCS::VistaException::VistaException(const std::string& msg, const std::string& componente, bool fatal) throw()
-{
-	this->cause = msg;
-	this->component = componente;
-	this->fatal = fatal;
-}
-GNC::GCS::VistaException::~VistaException() throw()
-{
-}
-
-const std::string& GNC::GCS::VistaException::GetComponent() const
-{
-	return component;
-}
-
-const std::string& GNC::GCS::VistaException::GetCause() const {
-	return cause;
-}
-
-std::string GNC::GCS::VistaException::GetFullCause() const {
-	return *this;
-}
-
-bool GNC::GCS::VistaException::IsFatal()  const {
-	return fatal;
-}
-
-GNC::GCS::VistaException::operator const std::string () const {
-	return std::string("Excepcion en componente ") + GetComponent() + std::string(": ")  + GetCause();
-}
-
-std::ostream& operator << (std::ostream& out, const GNC::GCS::VistaException& ex)
-{
-	out << (const std::string&) ex;
-	return out;
-}
-
-std::ostream& operator << (std::ostream& out, const GNC::GCS::VistaException* ex)
-{
-	if (ex != NULL) {
-		out << ((const std::string)(*ex)).c_str();
-	}
-	else {
-		out << "(NULL)";
-	}
-	return out;
-}
-
-
 /* Constructor */
 GNC::GCS::IVista::IVista(const GnkPtr<GNC::GCS::IContextoEstudio>& estudio) : Estudio(new GnkPtr<GNC::GCS::IContextoEstudio>(estudio) )
 {
