@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: iwidgets.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: iwidgets.cpp 4478 2011-12-13 11:55:00Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -58,8 +58,9 @@ wxXmlNode* GNC::GCS::Nodo::Serializar()
 
 //endregion
 
-GNC::GCS::Widgets::IWidgetBuilder::IWidgetBuilder(GNC::GCS::IWidgetsManager* pManager, long gid, bool activar)
+GNC::GCS::Widgets::IWidgetBuilder::IWidgetBuilder(GNC::GCS::IWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask, long gid, bool activar)
 {
+	m_ButtonMask = buttonMask;
 	m_GID = gid;
 	m_pManager = pManager;
 	if(activar) {
@@ -69,9 +70,7 @@ GNC::GCS::Widgets::IWidgetBuilder::IWidgetBuilder(GNC::GCS::IWidgetsManager* pMa
 
 GNC::GCS::Widgets::IWidgetBuilder::~IWidgetBuilder()
 {
-	if (m_pManager->GetBuilder() == this) {
-		m_pManager->SetBuilder(NULL);
-	}
+	m_pManager->UnRegisterBuilder(this);
 }
 
 /* Obtiene el id de grupo de los widget construidos (tipo) */
@@ -82,12 +81,12 @@ long GNC::GCS::Widgets::IWidgetBuilder::GetGID()
 
 void GNC::GCS::Widgets::IWidgetBuilder::Activar()
 {
-	m_pManager->SetBuilder(this);
+	m_pManager->RegisterBuilder(this);
 }
 
 void GNC::GCS::Widgets::IWidgetBuilder::Desactivar()
 {
-	m_pManager->SetBuilder(NULL);
+	m_pManager->UnRegisterBuilder(this);
 }
 
 void GNC::GCS::Widgets::IWidgetBuilder::LanzarEventoCreacion(IWidget* w)
