@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: iwizard.h 4171 2011-09-22 12:34:58Z tovar $
+ *  $Id: iwizard.h 4403 2011-11-14 10:59:24Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -15,7 +15,7 @@
 #include <string>
 #include <list>
 
-class IWizard{
+class IWizard {
 public:
 	virtual void SiguientePaso() = 0;
 	virtual void EnableSiguiente(bool enable) = 0;
@@ -39,13 +39,22 @@ public:
 		m_pWizard = pWizard;
 	};
 
-	virtual void Attach(wxSizer *sizer)=0;
+	virtual bool Attach()
+	{
+		return true;
+	}
 
-	virtual void Detach(wxSizer *sizer)=0;
+	virtual bool Detach()
+	{
+		return true;
+	}
 
 	virtual std::string GetTitle()=0;
 
-	virtual std::string GetSubTitle()=0;
+	virtual std::string GetSubTitle()
+	{
+		return "";
+	}
 
 	virtual bool Siguiente()=0;
 
