@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: comandoactualizaciones.h 3521 2011-03-16 14:54:22Z carlos $
+*  $Id: comandoactualizaciones.h 4410 2011-11-18 08:34:07Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -19,18 +19,19 @@ namespace GNC {
 		class IVista;
 	}
 }
-
+class wxHTTPBuilder;
 namespace GNC {
 	class ComandoComprobarActualizaciones;
 
 	class ComandoComprobarActualizacionesParams : public GNC::GCS::IComandoParams {
 	public:
-		ComandoComprobarActualizacionesParams(const std::string& url, bool informar = false) : m_URL(url), m_Informar(informar) {}
+		ComandoComprobarActualizacionesParams(const std::string& url, bool informar = false);
 
-		virtual ~ComandoComprobarActualizacionesParams() {}
+		virtual ~ComandoComprobarActualizacionesParams();
 
 		std::string                     m_URL;
 		bool                            m_Informar;
+		wxHTTPBuilder*						  m_pBuilder;
 
 	};
 
@@ -43,6 +44,7 @@ namespace GNC {
 
 		virtual void Execute();
 		virtual void Update();
+		virtual void OnAbort();
 
 	protected:
 
