@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: comandocarga.h 3521 2011-03-16 14:54:22Z carlos $
+*  $Id: comandocarga.h 4158 2011-09-19 13:25:20Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -26,7 +26,7 @@ namespace GADAPI {
 
 	class ComandoCargaParams : public GNC::GCS::IComandoParams, public GNC::GCS::IObservadorVistas {
 	public:
-		ComandoCargaParams(GNC::GCS::IVista* pVista, GnkPtr<GIL::IModeloIntegracion>& modeloIntegracion, const std::string& uidEstudioDiagnostico);
+		ComandoCargaParams(GNC::GCS::IVista* pVista, GnkPtr<GIL::IModeloIntegracion>& modeloIntegracion, const std::string& uidEstudioDiagnostico, const bool loadFirst);
 
 		virtual ~ComandoCargaParams();
 
@@ -36,6 +36,7 @@ namespace GADAPI {
 		GnkPtr<GIL::IModeloIntegracion> ModeloIntegracion;
 		std::string                     UIDEstudioDiagnostico;
 		ComandoCarga*                   Padre;
+		bool									  LoadFirst;
 
 	};
 
