@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: comandogenerarthumbnails.cpp 4516 2012-01-12 12:18:40Z tovar $
+*  $Id: comandogenerarthumbnails.cpp 4706 2012-02-16 07:59:43Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -57,8 +57,8 @@
 #include <itkLinearInterpolateImageFunction.h>
 #include <itkImageDuplicator.h>
 
-#define UID_MPEG2MainProfileAtMainLevelTransferSyntax "1.2.840.10008.1.2.4.100"
-#define UID_MPEG2MainProfileAtHighLevelTransferSyntax "1.2.840.10008.1.2.4.101"
+#define UID_VideoPhotographicImageStorage  "1.2.840.10008.5.1.4.1.1.77.1.4.1"
+#define UID_EncapsulatedPDFStorage          "1.2.840.10008.5.1.4.1.1.104.1"
 
 #define IDC_GENERAR_THUMBNAILS       81
 #define IDC_CARGA       91
@@ -109,16 +109,11 @@ namespace GADAPI {
 		//pillamos el uid
 		m_pThumbParams->m_modeloDCM = GNC::GCS::ControladorHistorial::Instance()->GetModeloDCM(m_pThumbParams->m_ruta);
 		if(m_pThumbParams->m_modeloDCM.m_uidImagen == "") {
-			GTRACE("Saliendo generar thumbnails salida1  " << m_pThumbParams->m_ruta);
-			if (m_pThumbParams->m_modeloDCM.m_uidTransferSyntax == UID_MPEG2MainProfileAtMainLevelTransferSyntax || 
-				m_pThumbParams->m_modeloDCM.m_uidTransferSyntax == UID_MPEG2MainProfileAtHighLevelTransferSyntax) 
-			{
-				wxBitmap bmp = GinkgoResourcesManager::PanelHistorial::GetMoviePreview();
-				m_pThumbParams->m_wxImg = new wxImage();
-				(*m_pThumbParams->m_wxImg) = bmp.ConvertToImage();
-				m_Error = false;
-				return;
-			}
+			wxBitmap bmp = GinkgoResourcesManager::PanelHistorial::GetIcoUnknownFile();
+			m_pThumbParams->m_wxImg = new wxImage();
+			(*m_pThumbParams->m_wxImg) = bmp.ConvertToImage();
+			GuardarImagen();
+			m_Error = false;
 			return;
 		}
 		//comprobar si el thumbnail ya estaba generado
@@ -129,9 +124,7 @@ namespace GADAPI {
 			m_Error = false;
 			return;
 		} else {
-			//TODO special case video preview...
-			if (m_pThumbParams->m_modeloDCM.m_uidTransferSyntax == UID_MPEG2MainProfileAtMainLevelTransferSyntax || 
-				m_pThumbParams->m_modeloDCM.m_uidTransferSyntax == UID_MPEG2MainProfileAtHighLevelTransferSyntax) 
+			if (m_pThumbParams->m_modeloDCM.m_sopClassUID == UID_VideoPhotographicImageStorage) 
 			{
 				wxBitmap bmp = GinkgoResourcesManager::PanelHistorial::GetMoviePreview();
 				m_pThumbParams->m_wxImg = new wxImage();
@@ -140,6 +133,14 @@ namespace GADAPI {
 				m_Error = false;
 				return;
 			}
+			if (m_pThumbParams->m_modeloDCM.m_sopClassUID == UID_EncapsulatedPDFStorage) 
+			{
+				wxBitmap bmp = GinkgoResourcesManager::PanelHistorial::GetPDFPreview();
+				m_pThumbParams->m_wxImg = new wxImage();
+				(*m_pThumbParams->m_wxImg) = bmp.ConvertToImage();
+				m_Error = false;
+				return;
+			}
 
 			double size[2]   = {0.0, 0.0};
 			unsigned int dimensions[3] = {0, 0, 0};
@@ -306,17 +307,24 @@ namespace GADAPI {
 						pImageMap->SetOutputFormatToRGB();
 
 						if (timg->GetScalarType() != VTK_UNSIGNED_CHAR) {
-							timg->Update();
-							double range[2];
-							timg->GetScalarRange(range);
+							double window, level;
+							if (loader.GetDefaultWindowLevel(window,level)) {
+								pImageMap->SetWindow(window);
+								pImageMap->SetLevel(level);
+							} else {
+								timg->Update();
+								double range[2];
+								timg->GetScalarRange(range);
 
-							double diff = range[1]-range[0];
+								double diff = range[1]-range[0];
 
-							if (diff > std::numeric_limits<double>::epsilon()) {
-								pImageMap->GetLookupTable()->SetRange(range);
+								window = range[1]-range[0];
+								level = 0.5*(range[1]+range[0]);
 
-								pImageMap->SetWindow(range[1] - range[0]);
-								pImageMap->SetLevel(0.5f * (range[0] + range[1]));
+								if (diff > std::numeric_limits<double>::epsilon()) {
+									pImageMap->SetWindow(window);
+									pImageMap->SetLevel(level);
+								}
 							}
 						}
 
