@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: comandomergediagnosticwithimage.cpp 4404 2011-11-15 09:41:03Z tovar $
+*  $Id: comandomergediagnosticwithimage.cpp 4682 2012-02-09 14:25:47Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -93,7 +93,6 @@ namespace GADAPI {
 		}
 		m_uidDiagnosticStudy = pStudyContext->GetUIDEstudioDiagnostico();
 		m_diagnosticMode = pStudyContext->GetModoFuncionamiento();
-		m_pModeloIntegracion = pStudyContext->GetModeloIntegracion();
 
 		pStudyContext->Vista->GetModulo()->GetTagsPrivadosReplace(m_mapTagsPrivadosReplace);
 
@@ -236,7 +235,7 @@ namespace GADAPI {
 					//read diagnostic file
 					GNC::GCS::IControladorHistorial::ModeloDCM diagnosticModel;
 					diagnosticModel = GNC::GCS::ControladorHistorial::Instance()->GetDiagnosticoSerie((*itOld).m_seriesInstance,m_pMergeParams->m_uidDiagnosticStudy);
-					pathDiagnostic = GNC::Entorno::Instance()->GetPathAbsolutoFichero(diagnosticModel.m_pathRelativo);
+					pathDiagnostic = GNC::GCS::ControladorHistorial::Instance()->GetPathAbsolutoFichero(diagnosticModel.m_pathRelativo);
 					pDicomManager->CargarFichero(pathDiagnostic, baseDiagnostic);
 					for (GNC::GCS::IControladorModulo::TMapaTagsPrivados::iterator itModulos = m_pMergeParams->m_mapTagsPrivadosReplace.begin(); itModulos != m_pMergeParams->m_mapTagsPrivadosReplace.end(); ++itModulos)
 					{
@@ -305,7 +304,7 @@ namespace GADAPI {
 				//read diagnostic file
 				GNC::GCS::IControladorHistorial::ModeloDCM diagnosticModel;
 				diagnosticModel = GNC::GCS::ControladorHistorial::Instance()->GetDiagnostico((*itOld).m_path,m_pMergeParams->m_uidDiagnosticStudy);
-				std::string pathDiagnostic = GNC::Entorno::Instance()->GetPathAbsolutoFichero(diagnosticModel.m_pathRelativo);
+				std::string pathDiagnostic = GNC::GCS::ControladorHistorial::Instance()->GetPathAbsolutoFichero(diagnosticModel.m_pathRelativo);
 				pDicomManager->CargarFichero(pathDiagnostic, baseDiagnostic);
 
 				for (GNC::GCS::IControladorModulo::TMapaTagsPrivados::iterator itModulos = m_pMergeParams->m_mapTagsPrivadosReplace.begin(); itModulos != m_pMergeParams->m_mapTagsPrivadosReplace.end(); ++itModulos)
