@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: comandopacs.h 3834 2011-05-10 07:42:57Z carlos $
+*  $Id: comandopacs.h 4477 2011-12-13 11:16:56Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -118,31 +118,6 @@ namespace GADAPI {
 			GTRACE("<< ComandoPACSParams::ComandoPACSParams(): " << this);
 		}
 
-		ComandoPACSParams(const std::string& serverSeleccionado, const std::string uid, TipoAmbito tAm)
-		{
-			m_pModelo = GnkPtr<IModeloDicom>(new IModeloDicom());
-			m_listaUID.push_back(uid);
-
-			m_Ambito = tAm;
-
-			if(serverSeleccionado == "") {
-				//usaremos el primer servidor (por defecto)
-				if(DicomServerList::Instance()->GetFirst() !=NULL) {
-					m_serverSeleccionado = DicomServerList::Instance()->GetDefaultServer()->ID;
-				} else {
-					throw GIL::DICOM::PACSException(_Std("There is not any Remote PACS configured"));
-				}
-			} else {
-				m_serverSeleccionado = serverSeleccionado;
-			}
-			m_pNotificador = NULL;
-			m_informar = false;
-			m_error = "";
-
-			m_TipoAccion = GADAPI::PACS::TAC_Descargar;
-			GTRACE("<< ComandoPACSParams::ComandoPACSParams(): " << this);
-		}
-
 		ComandoPACSParams(const std::string& serverSeleccionado, const std::vector<std::string>& rutas, GnkPtr<GIL::IModeloIntegracion> pModeloIntegracion,GIL::DICOM::TipoTransferSyntaxEnvio transferSyntax = GIL::DICOM::SendDefault)
 		{
 			if(serverSeleccionado == "") {
