@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: commandsynchronizewithgui.h 3655 2011-04-06 12:26:00Z tovar $
+*  $Id: commandsynchronizewithgui.h 4078 2011-08-16 10:19:52Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -20,21 +20,30 @@
 #include <api/imodelointegracion.h>
 
 namespace GADAPI {
+	class EXTAPI ISynchronizedData {
+	public:
+		ISynchronizedData(){}
+		virtual ~ISynchronizedData(){}
+	};
+
 	class EXTAPI ISynchronizedWithGUI
 	{
 	public:
-		virtual void ExecuteSynchronized() = 0;
+		virtual void ExecuteSynchronized(GADAPI::ISynchronizedData* pData) = 0;
 	};
 
 	class EXTAPI CommandSynchronizeWithGUI : public GNC::GCS::IComando {
 	public:
-		CommandSynchronizeWithGUI(ISynchronizedWithGUI* pParam);
+		CommandSynchronizeWithGUI(ISynchronizedWithGUI* pParam, ISynchronizedData * pData = NULL, bool clearData = false);
+		virtual ~CommandSynchronizeWithGUI();
 
 	 protected:
 		virtual void Execute();
-		virtual void Update();;
+		virtual void Update();
 
 	protected:
 		ISynchronizedWithGUI* m_pListener;
+		ISynchronizedData * m_pData;
+		bool m_clearData;
 	};
 }
