@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: exporttodicomdircommand.cpp 4575 2012-01-20 14:21:44Z tovar $
+*  $Id: exporttodicomdircommand.cpp 4706 2012-02-16 07:59:43Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -26,7 +26,7 @@
 #include <wx/dir.h>
 #include <main/controllers/configurationcontroller.h>
 #include <main/controllers/controladorhistorial.h>
-#include <main/controllers/dcmtk/dicommanager.h>
+#include <main/controllers/dicommanager.h>
 #include <main/controllers/controladorlog.h>
 #include <main/entorno.h>
 
@@ -272,7 +272,7 @@ namespace GADAPI {
 					}
 
 					wxString pathOfImageWx = fullPathWx + wxFileName::GetPathSeparator() + wxString::FromUTF8(pathOfImage.c_str());
-					std::string absolutepathFile = GNC::Entorno::Instance()->GetPathAbsolutoFichero((*itDCMModels).m_pathRelativo);
+					std::string absolutepathFile = GNC::GCS::ControladorHistorial::Instance()->GetPathAbsolutoFichero((*itDCMModels).m_pathRelativo);
 					if (!wxCopyFile(FROMPATH(absolutepathFile),  pathOfImageWx)) {
 						LOG_ERROR("ExportToDicomDirCommand", "Error copying file " << absolutepathFile << " TO " << pathOfImageWx.ToUTF8());
 						m_pExportacionParams->m_Error = _Std("There was an error writing file");
