@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: incomingdicomassociationcommand.cpp 4305 2011-10-18 11:28:18Z carlos $
+*  $Id: incomingdicomassociationcommand.cpp 4682 2012-02-09 14:25:47Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -31,6 +31,7 @@
 #endif
 
 #include <main/controllers/pacscontroller.h>
+#include <main/controllers/controladorhistorial.h>
 struct StoreCallbackData
 {
   char* imageFileName;
@@ -127,7 +128,7 @@ static void storeSCPCallback( void * callbackData, T_DIMSE_StoreProgress * progr
 		}
 
 		std::string rutaStd;
-		if (!GIL::DICOM::PACSController::Instance()->GetRutaImagenTemp(PacienteUId,EstudioUId,SerieUId,ImagenUId,rutaStd)) {
+		if (!GIL::DICOM::PACSController::Instance()->GetRutaImagenTemp(PacienteUId,EstudioUId,SerieUId,ImagenUId, GNC::GCS::ControladorHistorial::Instance()->GetGinkgoDicomDir(),rutaStd)) {
 			LOG_ERROR(ambitoLog, "could not create subdirectory for study: " << rutaStd);
         rsp->DimseStatus = STATUS_STORE_Error_CannotUnderstand;
         return;
