@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: sendhl7command.cpp 4319 2011-10-20 06:57:50Z carlos $
+*  $Id: sendhl7command.cpp 4670 2012-02-08 07:11:51Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -17,8 +17,9 @@
 #include <endpoint/endpoint.h>
 #include "sendhl7command.h"
 #include <main/controllers/controladorlog.h>
+#include <main/controllers/controladorhl7.h>
 #include <api/imodelohl7.h>
-#include <api/iguiasmensajeriasacyl.h>
+#include <api/ihl7parser.h>
 
 #define IDC_SEND_HL7								117
 
@@ -62,7 +63,7 @@ namespace GADAPI
 
 				try {
 					switch((*it).m_protocolo) {
-						case GIL::HL7::IControladorHL7::TP_MLLP:
+						case GIL::HL7::ControladorHL7::TP_MLLP:
 							EnviarMensajeMLLP((*it).m_mensaje,(*it).m_destino,(*it).m_procesarACK,(*it).m_msgControlId);
 							GIL::HL7::ControladorBBDDHl7::Instance()->ActualizarEstadoMensaje((*it).m_id,GIL::HL7::MensajeHL7::TE_Enviado,"");
 							LOG_DEBUG("Core/HL7", _Std("Message successfully sent"))
@@ -246,7 +247,7 @@ namespace GADAPI
 			if (i != msgNum || !pending) {
 				//std::cout << "Mensaje :\n" << s << std::endl;
 				try {
-					GIL::Sacyl::Messages::ACKInterpreter ai(GIL::HL7::Message::FromER7(s));
+					GIL::Hl7Parser::Messages::ACKInterpreter ai(GIL::HL7::Message::FromER7(s));
 					if (msgControlId != ai.GetReferralMessageControlId()) {
 						throw GIL::HL7::HL7Exception(_Std("Error in the logic of confirmation. The control of the message ID does not match recognized"));
 					}
