@@ -685,6 +685,92 @@ int Endpoint::Read(int bytes_to_read, std::string& data)
 }
 
 
+// Read bytes_to_read bytes into data, return FALSE if end-of-file
+// bytes_to_read=x can be either:
+// x>0 - read AT LEAST x bytes, blocking
+// x<0 - read AT MOST -x bytes, blocking
+// x=0 - Non-blocking I/O (not supported)
+// (This is copied almost verbatim from my own IPv4-only Socket)
+int Endpoint::Read(int bytes_to_read, char* buffer)
+{
+    int bytes_left      = bytes_to_read;
+	int bytes_read      = 0;
+    int bytes_just_read = 0;
+    //bool eof            = false;
+    bool read_all       = true;
+    //bool ret            = true;
+
+    if (bytes_to_read == 0) {            // Non-blocking I/O (not supported)
+#ifdef _EP_DEBUG
+        std::cout << "Error, can't read 0 bytes" << std::endl;
+#endif
+    }
+
+    if (bytes_to_read < 0)       // Negatives = don't read all, do one call
+    {
+         bytes_left = -bytes_to_read;
+         read_all = false;
+    }
+
+    do
+    {
+        char* buf = new char[bytes_left];
+        if (!buf)
+        {
+#ifdef _EP_DEBUG
+           std::cout << "OUT OF MEMORY!" << std::endl;
+#endif
+           // force-close connection and return 0
+           m_bool = false;
+           m_error_cat = EP_ERROR_RECV;
+           m_error_code = 0;
+           m_error_str = "";
+           Close();
+           CloseServer();
+           return 0;
+        }
+
+        bytes_just_read = recv(m_sockfd, (char*)buf, bytes_left, 0);
+        if (bytes_just_read > 0)
+        {
+           bytes_read += bytes_just_read;
+			  memcpy(buffer, buf, bytes_just_read);
+        }
+        delete[] buf;      // TODO: Less inefficient
+
+        // Check for conditions that may terminate reading prematurely
+        if (bytes_just_read == -1)        // -1  is error or EWOULDBLOCK
+        {
+           // Check if caller wanted non-blocking, and we got it
+           if (/*!m_blocking && */errno == EAGAIN)
+               return bytes_read;
+
+           // Otherwise, this is an error
+           m_bool = false;
+           m_error_cat = EP_ERROR_RECV;
+           SetLastError();
+           return -bytes_read;   // Error condition
+           break;
+        }
+        else if (bytes_just_read == 0)    // 0 is EOF
+           return bytes_read;
+
+        bytes_left -= bytes_just_read;
+
+        // If read_all is set (the default, for + values), loop again.
+        // If not set (for - bytes_to_read values), don't loop anymore
+        if (!read_all)
+           break;
+    } while(bytes_left != 0);
+
+    //m_bytes_recv += data.length();
+    //Endpoint::g_bytes_recv += data.length();
+    AddBytesRecv(bytes_read);
+
+    return bytes_read;
+}
+
+
 bool Endpoint::g_initialized = false;
 
 int Endpoint::g_raw_sockfd = 0;        // create new raw socket fd for each instance by default
@@ -830,6 +916,22 @@ void Endpoint::Shutdown(EP_Mode mode)
 	}
 }
 
+void Endpoint::ShutdownSocket(int socketID, EP_Mode mode)
+{
+	switch(mode)
+	{
+	case INPUT:
+		shutdown(socketID, 0);
+		break;
+	case OUTPUT:
+		shutdown(socketID, 1);
+		break;
+	case BOTH:
+		shutdown(socketID, 2);
+		break;
+	}
+}
+
 bool Endpoint::CloseServer()
 {
   if( m_servfd > 0 )
