@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: eventosginkgo.h 3666 2011-04-11 07:39:10Z tovar $
+*  $Id: eventosginkgo.h 4742 2012-02-23 10:57:03Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -51,9 +51,14 @@
 #include "views.h"
 
 #define ginkgoEVT_Core_DeleteFile			 13
-#include "deletefilehistory.h"
+#define ginkgoEVT_Core_UpdateFile			 14
+#include "filehistory.h"
 
-#define ginkgoEVT_Core_HideSplashWindow	 14
+#define ginkgoEVT_Core_HideSplashWindow	 15
 #include "hidesplashwindow.h"
+
+#define ginkgoEVT_Core_Integration     16
+#define ginkgoEVT_Core_HL7SendRequest  17
+#include "integration.h"
 ///el rango 100-199 esta reservado para el historial
 
