@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: iherramientalupa.h 3696 2011-04-14 08:40:28Z carlos $
+*  $Id: iherramientalupa.h 4475 2011-12-13 07:24:02Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -24,7 +24,7 @@ namespace GNC {
 			typedef GNC::GCS::IContratable<TContratoWidgets> TContratableWidgets;
 
 			static const IHerramienta::UID ID = HCore_Lupa;
-			IHerramientaLupa() : IHerramienta(HCore_Lupa,TFamiliaVisualizacion,"CoreLupa") {};
+			IHerramientaLupa() : IHerramienta(HCore_Lupa,TFamiliaVision,"CoreLupa") {};
 			virtual ~IHerramientaLupa() {};
 
 			virtual void SetVistaActiva(GNC::GCS::IVista* pVista) = 0;
