@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: iherramientapuntero.h 3696 2011-04-14 08:40:28Z carlos $
+*  $Id: iherramientapuntero.h 4478 2011-12-13 11:55:00Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -25,7 +25,7 @@ namespace GNC {
 			typedef IContratable<TContratoWidgets> TContratableWidgets;
 
 			static const IHerramienta::UID ID = HCore_Puntero;
-			IHerramientaPuntero() : IHerramienta(HCore_Puntero,TFamiliaVisualizacion, "CorePuntero") {};
+			IHerramientaPuntero() : IHerramienta(HCore_Puntero, TFamiliaGlobal, "CorePuntero") {};
 			virtual ~IHerramientaPuntero() {};
 
 			virtual void SetVistaActiva(GNC::GCS::IVista* pVista) = 0;
