@@ -45,8 +45,14 @@ namespace GNC {
 
 		void ConfigurationController::Flush()
 		{
-			m_pUserConfig->Flush();
-			m_pGeneralConfig->Flush();
+			wxFileName user(m_pathUserConfig);
+			if (user.IsFileWritable()) {
+				m_pUserConfig->Flush();
+			} 
+			wxFileName global(m_pathGlobalConfig);
+			if (global.IsFileWritable()) {
+				m_pGeneralConfig->Flush();
+			}
 		}
 
 		bool ConfigurationController::deleteEntryGeneral(const std::string& scope, const std::string&key)
@@ -84,6 +90,16 @@ namespace GNC {
 			return writeInt(TC_General, scope, key, value);
 		}
 
+		bool ConfigurationController::readDoubleGeneral(const std::string& scope, const std::string& key, double& value, double defaultValue)
+		{
+			return readDouble(TC_General, scope, key, value, defaultValue);
+		}
+
+		bool ConfigurationController::writeDoubleGeneral(const std::string& scope, const std::string& key, double value)
+		{
+			return writeDouble(TC_General, scope, key, value);
+		}
+
 		bool ConfigurationController::writeGroupGeneral(const std::string& scope, const TListGroups& listOfGroups, const std::string& prefix)
 		{
 			return writeGroup(TC_General, scope, listOfGroups, prefix);
@@ -106,12 +122,20 @@ namespace GNC {
 
       bool ConfigurationController::readStringUser(const std::string& scope, const std::string& key, std::string& value, const std::string& defaultValue)
 		{
-			return readString(TC_User, scope, key, value, defaultValue);
+			if (!readString(TC_General, scope, key, value, defaultValue)) {
+				return readString(TC_User, scope, key, value, defaultValue);
+			} else {
+				return true;
+			}
 		}
 
 		bool ConfigurationController::readBoolUser(const std::string& scope, const std::string& key, bool& value, bool defaultValue)
 		{
-			return readBool(TC_User, scope, key, value, defaultValue);
+			if (!readBool(TC_General, scope, key, value, defaultValue)) {
+				return readBool(TC_User, scope, key, value, defaultValue);
+			} else {
+				return true;
+			}
 		}
 
 		bool ConfigurationController::writeBoolUser(const std::string& scope, const std::string& key, bool value)
@@ -121,7 +145,11 @@ namespace GNC {
 
 		bool ConfigurationController::readIntUser(const std::string& scope, const std::string& key, int& value, int defaultValue)
 		{
-			return readInt(TC_User, scope, key, value, defaultValue);
+			if (!readInt(TC_General, scope, key, value, defaultValue)) {
+				return readInt(TC_User, scope, key, value, defaultValue);
+			} else {
+				return true;
+			}
 		}
 
 		bool ConfigurationController::writeIntUser(const std::string& scope, const std::string& key, int value)
@@ -129,6 +157,20 @@ namespace GNC {
 			return writeInt(TC_User, scope, key, value);
 		}
 
+		bool ConfigurationController::readDoubleUser(const std::string& scope, const std::string& key, double& value, double defaultValue)
+		{
+			if (!readDouble(TC_General, scope, key, value, defaultValue)) {
+				return readDouble(TC_User, scope, key, value, defaultValue);
+			} else {
+				return true;
+			}
+		}
+
+		bool ConfigurationController::writeDoubleUser(const std::string& scope, const std::string& key, double value)
+		{
+			return writeDouble(TC_User, scope, key, value);
+		}
+
 		bool ConfigurationController::writeGroupUser(const std::string& scope, const TListGroups& listOfGroups, const std::string& prefix)
 		{
 			return writeGroup(TC_User, scope, listOfGroups, prefix);
@@ -136,7 +178,11 @@ namespace GNC {
 
 		bool ConfigurationController::readGroupUser(const std::string& scope, TListGroups& listOfGroups) 
 		{
-			return readGroup(TC_User, scope, listOfGroups);
+			if (!readGroup(TC_General, scope, listOfGroups)) {
+				return readGroup(TC_User, scope, listOfGroups);
+			} else {
+				return true;
+			}
 		}
 
 		bool ConfigurationController::saveGlobalConfigurationFile(const std::string& path)
@@ -190,7 +236,7 @@ namespace GNC {
 			config->SetPath(wxString::FromUTF8(scope.c_str()));
 
 			bool result = config->Write(wxString::FromUTF8(key.c_str()),wxString::FromUTF8(value.c_str()));
-			config->Flush();    
+			Flush();   
 			return result;
 		}
 
@@ -222,7 +268,7 @@ namespace GNC {
 			config->SetPath(wxString::FromUTF8(scope.c_str()));
 
 			bool result = config->Write(wxString::FromUTF8(key.c_str()),value);
-			config->Flush();    
+			Flush();    
 			return result;
 		}
 
@@ -270,7 +316,39 @@ namespace GNC {
 			config->SetPath(wxString::FromUTF8(scope.c_str()));
 
 			bool result = config->Write(wxString::FromUTF8(key.c_str()),value);
-			config->Flush();    
+			Flush();    
+			return result;
+		}
+
+		bool ConfigurationController::readDouble(TConfig type, const std::string& scope, const std::string& key, double& value, double defaultValue)
+		{
+			wxCriticalSectionLocker locker(m_criticalSection);
+			wxConfigBase * config;
+			if (type==TC_General) {
+				config = m_pGeneralConfig;
+			} else {
+				config = m_pUserConfig;
+			}
+			config->SetPath(wxString::FromUTF8(scope.c_str()));
+			
+			bool result = config->Read(wxString::FromUTF8(key.c_str()),&value,defaultValue);
+			
+			return result;
+		}
+
+		bool ConfigurationController::writeDouble(TConfig type, const std::string& scope, const std::string& key, double value) 
+		{
+			wxCriticalSectionLocker locker(m_criticalSection);
+			wxConfigBase * config;
+			if (type==TC_General) {
+				config = m_pGeneralConfig;
+			} else {
+				config = m_pUserConfig;
+			}
+			config->SetPath(wxString::FromUTF8(scope.c_str()));
+
+			bool result = config->Write(wxString::FromUTF8(key.c_str()),value);
+			Flush();    
 			return result;
 		}
 
@@ -287,14 +365,15 @@ namespace GNC {
 			config->SetPath(wxString::FromUTF8(scope.c_str()));
 
 			int i=0;
+			bool ok = true;
 			for (TListGroups::const_iterator itGroups = listOfGroups.begin(); itGroups != listOfGroups.end(); ++itGroups, ++i) {
 				for (TMapValues::const_iterator itValues = (*itGroups).begin(); itValues != (*itGroups).end(); ++itValues) {
 					std::ostringstream ostrKey;
 					ostrKey << prefix << i << "/" << (*itValues).first;
-					config->Write(wxString::FromUTF8(ostrKey.str().c_str()), wxString::FromUTF8((*itValues).second.c_str()));
+					ok &= config->Write(wxString::FromUTF8(ostrKey.str().c_str()), wxString::FromUTF8((*itValues).second.c_str()));
 				}
 			}
-			return true;
+			return ok;
 		}
 
 		bool ConfigurationController::readGroup(TConfig type, const std::string& scope, TListGroups& listOfGroups)
@@ -360,9 +439,8 @@ namespace GNC {
 		}
 
 		ConfigurationController::~ConfigurationController() {
-			m_pUserConfig->Flush();
+			Flush();
 			delete m_pUserConfig;
-			m_pGeneralConfig->Flush();
 			delete m_pGeneralConfig;
 		}  
 
