@@ -42,6 +42,8 @@ namespace GNC {
 			virtual bool readBoolGeneral(const std::string& scope, const std::string& key, bool& value, bool defaultValue = true);
 			virtual bool readIntGeneral(const std::string& scope, const std::string& key, int& value, int defaultValue = 0);
 			virtual bool writeIntGeneral(const std::string& scope, const std::string& key, int value);
+			virtual bool readDoubleGeneral(const std::string& scope, const std::string& key, double& value, double defaultValue = 0.0);
+			virtual bool writeDoubleGeneral(const std::string& scope, const std::string& key, double value);
 			virtual bool writeGroupGeneral(const std::string& scope, const TListGroups& listOfGroups, const std::string& prefix = "");
 			virtual bool readGroupGeneral(const std::string& scope, TListGroups& listOfGroups);
 
@@ -52,6 +54,8 @@ namespace GNC {
 			virtual bool writeBoolUser(const std::string& scope, const std::string& key, bool value);
 			virtual bool readIntUser(const std::string& scope, const std::string& key, int& value, int defaultValue = 0);
 			virtual bool writeIntUser(const std::string& scope, const std::string& key, int value);
+			virtual bool readDoubleUser(const std::string& scope, const std::string& key, double& value, double defaultValue = 0.0);
+			virtual bool writeDoubleUser(const std::string& scope, const std::string& key, double value);
 			virtual bool writeGroupUser(const std::string& scope, const TListGroups& listOfGroups, const std::string& prefix = "");
 			virtual bool readGroupUser(const std::string& scope, TListGroups& listOfGroups);
 
@@ -69,6 +73,8 @@ namespace GNC {
 			bool writeBool(TConfig type, const std::string& scope, const std::string& key, bool value);
 			bool writeInt(TConfig type, const std::string& scope, const std::string& key, int value);
 			bool readInt(TConfig type, const std::string& scope, const std::string& key, int& value, int defaultValue = 0);
+			bool writeDouble(TConfig type, const std::string& scope, const std::string& key, double value);
+			bool readDouble(TConfig type, const std::string& scope, const std::string& key, double& value, double defaultValue = 0.0);
 			bool writeGroup(TConfig type, const std::string& scope, const TListGroups& listOfGroups, const std::string& prefix = "");
 			bool readGroup(TConfig type, const std::string& scope, TListGroups& listOfGroups);
 
