@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: controladorcarga.cpp 3834 2011-05-10 07:42:57Z carlos $
+ *  $Id: controladorcarga.cpp 4158 2011-09-19 13:25:20Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -851,11 +851,11 @@ vtkSmartPointer<vtkImageData> GNC::GCS::ControladorCarga::CargarITKMultidimensio
 
 }
 
-void GNC::GCS::ControladorCarga::CargaAsincrona(GNC::GCS::IVista* pVista, GnkPtr<GIL::IModeloIntegracion>& ModeloIntegracion, const std::string& uidEstudioDiagnostico)
+void GNC::GCS::ControladorCarga::CargaAsincrona(GNC::GCS::IVista* pVista, GnkPtr<GIL::IModeloIntegracion>& ModeloIntegracion, const std::string& uidEstudioDiagnostico, bool loadFirst)
 {
 	wxCriticalSectionLocker locker(*m_pCriticalSection);
 	GNC::GCS::ControladorVistas::Instance()->SolicitarActivarVista(pVista);
-	GADAPI::ComandoCarga* pCmd = new GADAPI::ComandoCarga(new GADAPI::ComandoCargaParams(pVista, ModeloIntegracion, uidEstudioDiagnostico));
+	GADAPI::ComandoCarga* pCmd = new GADAPI::ComandoCarga(new GADAPI::ComandoCargaParams(pVista, ModeloIntegracion, uidEstudioDiagnostico,loadFirst));
 	GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("load"), pCmd, pVista);
 }
 
