@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: controladorhistorial.h 3963 2011-07-11 14:03:51Z tovar $
+ *  $Id: controladorhistorial.h 4742 2012-02-23 10:57:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -44,18 +44,41 @@ namespace GNC {
 			} TAddError;
 			typedef std::list<TAddError> TAddErrorList;
 
-			void RecargarHistorial();
+			typedef enum TAddAction {
+				TAA_MOVE,
+				TAA_COPY,
+				TAA_LINK,
+				TAA_IGNORE
+			} TAddAction;
+
+			void RecargarHistorial(const std::string& pathDicomDir = "", bool tryTemp = true);
 
 	//region "Patron singleton"
 		public:
 			static ControladorHistorial* Instance();
 			static void FreeInstance();
+			
+			/* Constructor*/
+			ControladorHistorial();
+			ControladorHistorial(const std::string& pathOfDataBase);
+		protected:
+			void InitController(const std::string& pathOfDataBase);
+		public:
+			~ControladorHistorial();
+
+			bool IsOk();
+			bool IsReadOnly();
+			virtual std::string GetGinkgoDicomDir(bool barraAlFinal = false);
+			void ReadFromConfigDicomDir();
+			virtual std::string GetPathAbsolutoFichero(const std::string& pathRelativo);
+			virtual std::string GetPathRelativoFichero(const std::string& pathAbsoluto);
 
 			static ControladorHistorial* m_pInstance;
 	//endregion
 
 			//region "metodos propios del historial"
-			bool AddFiles(const ListaPaths& listaPaths,ListaModelosDCM& listaModelos, ListaPaths& listaSobreescritos, TAddErrorList& errorList, bool forzarSobreescribir, GNC::IProxyNotificadorProgreso* pNotificador = NULL, bool soloLeer = false, bool mover = false);
+			bool AddFiles(const ListaPaths& listaPaths,ListaModelosDCM& listaModelos, ListaPaths& listaSobreescritos, TAddErrorList& errorList, bool forzarSobreescribir, GNC::IProxyNotificadorProgreso* pNotificador = NULL, TAddAction action = TAA_COPY);
+			bool UpdateFiles(const ListaStrings& sopInstanceList,ListaModelosDCM& listaModelos, TAddErrorList& errorList);
 
 			bool EliminarFichero(const std::string& pathAbsolutoFichero, bool eliminarDelDisco);
 			bool EliminarPaciente(const std::string& idPaciente, bool eliminarDelDisco);
@@ -72,6 +95,7 @@ namespace GNC {
 			bool ReferenciaResuelta(const std::string& uidFichero);
 
 			ModeloDCM GetModeloDCM(const std::string& pathAbsoluto);
+			void GetAllModelosDCMSeries(const std::string& uidSeries, ListaModelosDCM& models);
 			//trhows exception
 			void GetDCMModelSql(const std::string& sql, ListaModelosDCM& dcmList);
 
@@ -135,6 +159,8 @@ namespace GNC {
 
 			virtual char GetSeriesOrientation(const std::string& uidSerie);
 
+			unsigned long GetNumberOfFiles();
+
 			virtual VectorPaths GetPathsSerieOrdenados(const std::string& uidSerie);
 			
 			virtual VectorPaths GetPathsStudyOfSeries(const std::string& uidSeries);
@@ -148,22 +174,18 @@ namespace GNC {
 			void GetThumbnail(const std::string& pathRelativo, int& ancho, int& alto, unsigned char*& imagen);
 			//
 		protected:
-			/* Constructor*/
-			ControladorHistorial();
-			~ControladorHistorial();
-
 			//region "helpers"
 			//devuelve false si !copia y no esta donde deberia
-			bool RellenaDCM(ModeloDCM& modelo,const std::string& pathAbsoluto,ListaPaths& listaSobreescritos, TAddErrorList& errorList, bool forzarSobreescribir = false, bool copia = false, bool mover = false);
+			bool RellenaDCM(ModeloDCM& modelo,const std::string& pathAbsoluto,ListaPaths& listaSobreescritos, TAddErrorList& errorList, bool forzarSobreescribir = false, TAddAction action = TAA_COPY);
 
 			bool EliminarFicheros(const std::list<std::string>& pathsRelativosFicheros, bool eliminarDeDisco);
 			bool QuitarFicheros(const std::list<std::string>& pathsFicheros);
 
 			bool InsertarPaciente(const std::string& idPaciente, const std::string& nombre, const std::string& fechaNacimento,const char& sexo);
-			bool InsertarEstudio(const std::string& uidEstudio, const std::string& descripcion, const std::string& m_nombreMedico, const std::string& fecha,const std::string& hora,const std::string& idPaciente);
-			bool InsertarSerie(const std::string& uidSerie, const std::string& descripcion, const std::string& fecha,const std::string& hora,const std::string& uidEstudio);
+			bool InsertarEstudio(const std::string& uidEstudio, const std::string& descripcion, const std::string& m_nombreMedico, const std::string& fecha,const std::string& hora,const std::string& idPaciente, const std::string& studyId, const std::string& accessionNumber);
+			bool InsertarSerie(const std::string& uidSerie, const std::string& descripcion, const std::string& fecha,const std::string& hora,const std::string& uidEstudio,const std::string& seriesNumber);
 			bool InsertarFichero(const std::string& pathRelativo, const std::string& uidFichero, const std::string& modalidad,const std::string& descripcion,
-				const std::string& uidImportador, const std::string& fecha,const std::string& hora, const std::string& transferSyntax, const std::string& uidSerie);
+				const std::string& uidImportador, const std::string& fecha,const std::string& hora, const std::string& transferSyntax, const std::string& uidSerie, const std::string& sopClassUID);
 			bool InsertarTagsOrdenacion(const std::string& pathRelativo, const char orientacion, double posicion[3], double sliceLocation, const std::string& height,
 				const std::string& width, double instanceNumber, const std::string& fecha,const std::string& hora);
 			void InstertarReferencias(const std::string& uidOrigen, const std::string& uidDestino);
@@ -173,6 +195,7 @@ namespace GNC {
 			bool ActualizarFichero(const std::string& pathRelativo,const std::string& descripcion,
 				const std::string& uidImportador, const std::string& fecha,const std::string& hora);
 			void ActualizarReferencias(const std::string& uidOrigen, const std::string& uidDestino);
+		protected:
 
 			//sincrono con la interfaz
 			void PurgarHistorial();
@@ -184,6 +207,8 @@ namespace GNC {
 			wxSQLite3Database* m_pConexion;
 			wxSQLite3Database* m_pConexionThumbnails;
 			wxCriticalSection* m_pCriticalSection;
+			bool m_readOnly;
+			std::string m_GinkgoDicomDir;
 		};
 	}
 }
