@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: controladorpermisos.cpp 4602 2012-01-26 07:23:02Z tovar $
+ *  $Id: controladorpermisos.cpp 4641 2012-02-01 13:04:38Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -64,10 +64,6 @@ namespace GNC {
 			if(!doc.IsOk() || doc.GetRoot()->GetName() != wxT("permisos")) {
 				throw ControladorPermisosException("xml mal formado");
 			}
-
-			if (privados) {
-				LimpiarPermisos();
-			}
 						
 			wxString wxNamespace;
 			wxString wxId;
@@ -91,10 +87,21 @@ namespace GNC {
 						permiso->GetPropVal(wxT("namespace"), &wxNamespace) &&
 						permiso->GetPropVal(wxT("id"), &wxId) &&
 						permiso->GetPropVal(wxT("accion"), &wxAccion) &&
-						permiso->GetPropVal(wxT("activopordefecto"), &wxActivoPorDefecto) &&
-						permiso->GetPropVal(wxT("valorpordefecto"), &wxValorPorDefecto) &&
-						permiso->GetPropVal(wxT("valor"), &wxValor) )
+						permiso->GetPropVal(wxT("activopordefecto"), &wxActivoPorDefecto) )
 					{
+						if (!permiso->GetPropVal(wxT("valorpordefecto"), &wxValorPorDefecto) || !permiso->GetPropVal(wxT("valor"), &wxValor) ) {
+							for (wxXmlNode* child = permiso->GetChildren(); child != NULL; child = child->GetNext()) {
+								if (child->GetChildren() == NULL) {
+									continue;
+								}
+								if (child->GetName() == wxT("default_value")) {
+									wxValorPorDefecto = child->GetChildren()->GetContent().Trim();
+								} else if (child->GetName() == wxT("value")) {
+									wxValor = child->GetChildren()->GetContent().Trim();
+								}
+							}							
+						}	
+
 						stdNamespace = wxNamespace.ToUTF8();
 						stdId = wxId.ToUTF8();
 						stdAccion = wxAccion.ToUTF8();
@@ -248,10 +255,21 @@ namespace GNC {
 						permiso->GetPropVal(wxT("namespace"), &wxNamespace) &&
 						permiso->GetPropVal(wxT("id"), &wxId) &&
 						permiso->GetPropVal(wxT("accion"), &wxAccion) &&
-						permiso->GetPropVal(wxT("activopordefecto"), &wxActivoPorDefecto) &&
-						permiso->GetPropVal(wxT("valorpordefecto"), &wxValorPorDefecto) &&
-						permiso->GetPropVal(wxT("valor"), &wxValor) )
+						permiso->GetPropVal(wxT("activopordefecto"), &wxActivoPorDefecto) )
 					{
+						if (!permiso->GetPropVal(wxT("valorpordefecto"), &wxValorPorDefecto) || !permiso->GetPropVal(wxT("valor"), &wxValor) ) {
+							for (wxXmlNode* child = permiso->GetChildren(); child != NULL; child = child->GetNext()) {
+								if (child->GetChildren() == NULL) {
+									continue;
+								}
+								if (child->GetName() == wxT("default_value")) {
+									wxValorPorDefecto = child->GetChildren()->GetContent().Trim();
+								} else if (child->GetName() == wxT("value")) {
+									wxValor = child->GetChildren()->GetContent().Trim();
+								}
+							}							
+						}						
+
 						stdNamespace = wxNamespace.ToUTF8();
 						stdId = wxId.ToUTF8();
 						stdAccion = wxAccion.ToUTF8();
