@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: controladorvistas.cpp 4044 2011-07-22 12:21:07Z tovar $
+ *  $Id: controladorvistas.cpp 4701 2012-02-14 13:00:19Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -30,6 +30,7 @@
 #include <main/entorno.h>
 
 #include <main/controllers/controladorcomandos.h>
+#include <main/controllers/inactivitycontroller.h>
 #include <main/controllers/controladorlog.h>
 #include <main/controllers/controladorpermisos.h>
 #include <main/gui/countdownmessage/countdownmessage.h>
@@ -42,57 +43,6 @@
 #include <main/panelgrid.h>
 #include <api/icontextoestudio.h>
 
-//this timer is to controlate user inactivity
-namespace GNC {
-	namespace GCS {
-		class TimerInactivity: public wxTimer {
-		public:
-			TimerInactivity() 
-			{
-				GNC::GCS::Permisos::EstadoPermiso estado = GNC::GCS::ControladorPermisos::Instance()->Get("core.restrictions", "inactivity_time");
-				if (estado) {
-					m_maxInactivity = estado.ObtenerValor<long>() * 1000;
-					this->Start(m_maxInactivity, true);
-				} else {
-					m_maxInactivity = -1;
-				}
-			}
-
-			~TimerInactivity() 
-			{
-			}
-			
-			virtual void Notify()
-			{
-				if (m_maxInactivity > 0) {
-					GNC::GUI::CountdownMessage countdown(GNC::Entorno::Instance()->GetVentanaRaiz());
-					countdown.ShowModal();
-					if (countdown.Cancel()) {
-						this->Start(m_maxInactivity, true);
-						return;
-					}
-					GNC::Entorno::Instance()->GetVentanaPrincipal()->Close();
-				}
-			}
-
-			virtual void Reset() 
-			{
-				if (IsRunning()) {
-					Stop();
-				}
-				if (m_maxInactivity > 0) {
-					this->Start(m_maxInactivity, true);
-				}
-			}
-
-		protected:
-			long m_maxInactivity;	
-		};
-	}
-}
-//
-
-
 //region "Patron singleton"
 
 GNC::GCS::ControladorVistas* GNC::GCS::ControladorVistas::m_pInstance = 0;
@@ -104,17 +54,10 @@ GNC::GCS::ControladorVistas::ControladorVistas()
 	//se conecta el evento Ginkgo
 	GNC::GCS::Eventos::EventoModificacionFichero evtModificado;
 	GNC::Entorno::Instance()->GetControladorEventos()->Registrar(this, evtModificado);
-
-	m_pTimerInactivity = new TimerInactivity;
 }
 
 GNC::GCS::ControladorVistas::~ControladorVistas()
 {
-	if (m_pTimerInactivity != NULL) {
-		delete m_pTimerInactivity;
-		m_pTimerInactivity = NULL;
-	}
-	//DestruirTabs();
 }
 
 GNC::GCS::ControladorVistas* GNC::GCS::ControladorVistas::Instance()
@@ -167,7 +110,7 @@ void GNC::GCS::ControladorVistas::Thaw()
 
 void GNC::GCS::ControladorVistas::SetTitulo(GNC::GCS::IVista* pVista, const std::string& tituloNuevo) {
 	//resets inactivity
-	ResetsInactivity();
+	GNC::GCS::InactivityController::Instance()->ResetsInactivity();
 	//
 	wxWindow* pVentana = NULL;
 	int numConteo = 0;
@@ -282,7 +225,7 @@ void GNC::GCS::ControladorVistas::SetTitulo(GNC::GCS::IVista* pVista, const std:
 std::string GNC::GCS::ControladorVistas::GetTitulo(GNC::GCS::IVista* pVista)
 {
 	//resets inactivity
-	ResetsInactivity();
+	GNC::GCS::InactivityController::Instance()->ResetsInactivity();
 	//
 
 	wxWindow* pVentana = NULL;
@@ -333,17 +276,10 @@ void GNC::GCS::ControladorVistas::PropagarConfiguracionCambiada()
 	UnLock(GLOC());
 }
 
-void GNC::GCS::ControladorVistas::ResetsInactivity()
-{
-	//resets inactivity
-	m_pTimerInactivity->Reset();
-	//
-}
-
 void GNC::GCS::ControladorVistas::Registrar(GNC::GCS::IVista* pVista)
 {
 	//resets inactivity
-	ResetsInactivity();
+	GNC::GCS::InactivityController::Instance()->ResetsInactivity();
 	//
 
 	Lock(GLOC());
@@ -371,7 +307,7 @@ void GNC::GCS::ControladorVistas::Registrar(GNC::GCS::IVista* pVista)
 void GNC::GCS::ControladorVistas::Destruir(GNC::GCS::IVista* pVista)
 {
 	//resets inactivity
-	ResetsInactivity();
+	GNC::GCS::InactivityController::Instance()->ResetsInactivity();
 	//
 
 	Lock(GLOC());
@@ -395,7 +331,7 @@ void GNC::GCS::ControladorVistas::Destruir(GNC::GCS::IVista* pVista)
 void GNC::GCS::ControladorVistas::Destruir(wxWindow* pVentana)
 {
 	//resets inactivity
-	ResetsInactivity();
+	GNC::GCS::InactivityController::Instance()->ResetsInactivity();
 	//
 
 	Lock(GLOC());
@@ -420,7 +356,7 @@ void GNC::GCS::ControladorVistas::Destruir(wxWindow* pVentana)
 
 void GNC::GCS::ControladorVistas::SolicitarActivarVista(GNC::GCS::IVista* pVista) {
 	//resets inactivity
-	ResetsInactivity();
+	GNC::GCS::InactivityController::Instance()->ResetsInactivity();
 	//
 
 	if (pVista == m_pVistaActiva) {
@@ -462,7 +398,7 @@ void GNC::GCS::ControladorVistas::SolicitarActivarVista(GNC::GCS::IVista* pVista
 void GNC::GCS::ControladorVistas::PropagarVistaCreada(GNC::GCS::IVista* pVista)
 {
 	//resets inactivity
-	ResetsInactivity();
+	GNC::GCS::InactivityController::Instance()->ResetsInactivity();
 	//
 
 	GNC::Entorno* pEntorno = GNC::Entorno::Instance();
@@ -481,7 +417,7 @@ inline bool my_isnan(double x)
 void GNC::GCS::ControladorVistas::PropagarVistaDestruida(GNC::GCS::IVista* pVista)
 {
 	//resets inactivity
-	ResetsInactivity();
+	GNC::GCS::InactivityController::Instance()->ResetsInactivity();
 	//
 
 	if (pVista == NULL) {
@@ -655,7 +591,7 @@ void GNC::GCS::ControladorVistas::OcultarPanel(wxWindow* win)
 }
 GNC::GCS::ControladorVistas::TipoListaVistas GNC::GCS::ControladorVistas::GetVistas(){
 	//resets inactivity
-	ResetsInactivity();
+	GNC::GCS::InactivityController::Instance()->ResetsInactivity();
 	//
 
 	GNC::GCS::ControladorVistas::TipoListaVistas result;
