@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: controladorvistas.h 4044 2011-07-22 12:21:07Z tovar $
+ *  $Id: controladorvistas.h 4701 2012-02-14 13:00:19Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -26,7 +26,6 @@ class wxAuiNotebook;
 namespace GNC {
 
 	namespace GCS {
-		class TimerInactivity;
 		class ControladorVistas : public IControladorVistas, public GNC::GCS::IObservador, public GNC::GCS::ILockable {
 
 //region "Patron singleton"
@@ -57,8 +56,6 @@ namespace GNC {
 			virtual void Destruir(wxWindow* pVentana);
 
 			virtual void PropagarConfiguracionCambiada();
-
-			virtual void ResetsInactivity();
 //endregion
 
 //region "Getters de vistas activas"
@@ -113,7 +110,6 @@ namespace GNC {
 			MapaVentanas           m_MapaVentanas;
 			MapaConteoTitulos      m_MapaConteoTitulos;
 			MapaTitulosRegistrados m_MapaTitulosRegistrados;
-			TimerInactivity*		  m_pTimerInactivity;
 
 		protected:
 			/* Constructor. Se mantiene una referencia a la ventana principal por ser ella la responsable de crear "tabs" */
