@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: dicomechoassociation.cpp 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: dicomechoassociation.cpp 3847 2011-05-11 13:35:43Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -12,9 +12,10 @@
  *
  */
 #include <api/icontroladorlog.h>
+#include <api/dicom/idicomconformance.h>
 #include <main/controllers/controladorlog.h>
 #include "dicomechoassociation.h"
-#include <api/internacionalizacion.h>
+
 
 #ifdef verify
 #define MACRO_QUE_ESTORBA verify
@@ -27,14 +28,18 @@
 #endif
 
 EchoAssociation::EchoAssociation(const std::string& ambitolog) : Association(ambitolog) {
-	m_abstractSyntax = UID_VerificationSOPClass;
+	m_abstractSyntax = GIL::DICOM::Conformance::GetScpSOPClasses().GetSOPClassUID("VerificationSOPClass");
 }
 
 EchoAssociation::~EchoAssociation() {
 }
 
 void EchoAssociation::OnAddPresentationContext(T_ASC_Parameters* params) {
-	CONDITION cond = ASC_addPresentationContext(params, 1, m_abstractSyntax, AllTransferSyntaxes, 3);
+	GIL::DICOM::ArrayHelper transfersyntaxes;
+	transfersyntaxes.copyFrom(GIL::DICOM::Conformance::GetScuSOPClasses().GetSupportedTransferSyntaxUIDs("VerificationSOPClass"));
+	
+	
+	CONDITION cond = ASC_addPresentationContext(params, 1, m_abstractSyntax.c_str(), transfersyntaxes.array, transfersyntaxes.size);
 	if (cond.bad()) {
 		LOG_ERROR(ambitolog, "Unable to add default presentation context");
 	}
