@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: dicomfindassociation.h 3834 2011-05-10 07:42:57Z carlos $
+ *  $Id: dicomfindassociation.h 4572 2012-01-19 14:21:13Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -63,6 +63,11 @@ public:
 				throw std::exception();
 		}
 	}
+
+	void SetAbstractSyntax(const std::string& abstractSyntax)
+	{
+		Association::m_abstractSyntax = abstractSyntax.c_str();
+	}
 	
 	
 	/**
