@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: dicomimg2dcm.cpp 4057 2011-08-03 10:06:14Z tovar $
+ *  $Id: dicomimg2dcm.cpp 4819 2012-04-09 07:15:32Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -14,6 +14,7 @@
 //#define _GINKGO_TRACE
 #include <api/globals.h>
 #include <main/controllers/controladorlog.h>
+#include <main/controllers/configurationcontroller.h>
 #include <api/icontextoestudio.h>
 #ifdef verify
 #define MACRO_QUE_ESTORBA verify
@@ -23,11 +24,13 @@
 #include <wx/image.h>
 
 #include <dcmtk/config/osconfig.h>
-#include "libi2d/i2d.h"
+#include "libi2d/document2dcm.h"
 #include "libi2d/i2djpgs.h"
+#include "libi2d/pdf2dsource.h"
 #include "libi2d/i2dles.h"
 #include "libi2d/i2dplsc.h"
 #include "libi2d/i2dplvlp.h"
+#include "libi2d/foooutpl.h"
 #include "libi2d/i2dplnsc.h"
 #include "dicomimg2dcm.h"
 #include "dcmtk/dcmdata/dcdict.h"
@@ -37,6 +40,7 @@
 #include <dcmtk/dcmdata/dcfilefo.h>
 
 #include <main/controllers/controladorpermisos.h>
+#include <main/controllers/pacscontroller.h>
 
 
 
@@ -108,7 +112,7 @@ namespace GIL {
 				return NULL;
 			}
 			if (valStr.length() > 0) {
-				if (elem->putString(valStr.c_str()).bad()) {
+				if (elem->putString( wxString( valStr.c_str(), wxConvUTF8).mb_str(*m_pConv) ).bad()) {
 					std::cerr << "No se pudo asignar el valor al elemento: (" <<
 					std::hex << std::setw(4) << std::setfill('0') << g << "|" <<
 					std::hex << std::setw(4) << std::setfill('0') << e << ")=" << valStr.c_str() << std::endl;
@@ -120,6 +124,74 @@ namespace GIL {
 
 		}
 
+		DICOMImg2DCM::DICOMImg2DCM() {
+				i2d = NULL;
+				outputPlug = NULL;
+				inputPlug = NULL;
+				resultObject = NULL;
+				writeXfer = EXS_Unknown;
+
+				std::string Charset;
+				GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","DefaultCharset",Charset,"ISO_IR 192");
+				if (Charset == "ISO_IR 192" || Charset == "ISO_IR 6") {
+					m_pConv = new wxCSConv(wxFONTENCODING_UTF8);
+				}
+				else if (Charset == "ISO_IR 100") {
+					m_pConv = new wxCSConv(wxFONTENCODING_ISO8859_1);
+				}
+				else if (Charset == "ISO_IR 101") {
+					m_pConv = new wxCSConv(wxFONTENCODING_ISO8859_2);
+				}
+				else if (Charset == "ISO_IR 109") {
+					m_pConv = new wxCSConv(wxFONTENCODING_ISO8859_3);
+				}
+				else if (Charset == "ISO_IR 110") {
+					m_pConv = new wxCSConv(wxFONTENCODING_ISO8859_4);
+				}
+				else if (Charset == "ISO_IR 148") {
+					m_pConv = new wxCSConv(wxFONTENCODING_ISO8859_9);
+				}
+				else if (Charset == "ISO_IR 144") {
+					m_pConv = new wxCSConv(wxFONTENCODING_ISO8859_5);
+				}
+				else if (Charset == "ISO_IR 127") {
+					m_pConv = new wxCSConv(wxFONTENCODING_ISO8859_6);
+				}
+				else if (Charset == "ISO_IR 126") {
+					m_pConv = new wxCSConv(wxFONTENCODING_ISO8859_7);
+				}
+				else if (Charset == "ISO_IR 138") {
+					m_pConv = new wxCSConv(wxFONTENCODING_ISO8859_8);
+				}
+				else {
+					m_pConv = new wxCSConv(wxFONTENCODING_UTF8);
+				}
+			};
+		DICOMImg2DCM::~DICOMImg2DCM() {
+				LiberarMemoria();
+				delete m_pConv;
+			}
+			
+		void DICOMImg2DCM::LiberarMemoria() {
+				if (resultObject != NULL) {
+					delete resultObject;
+					resultObject = NULL;
+				}
+				if (inputPlug != NULL) {
+					delete inputPlug;
+					inputPlug = NULL;
+				}
+				if (outputPlug != NULL) {
+					delete outputPlug;
+					outputPlug = NULL;
+				}
+				if (i2d != NULL) {
+					delete i2d;
+					i2d = NULL;
+				}
+			};
+			
+
 //endregion
 
 
@@ -131,33 +203,55 @@ namespace GIL {
 				throw I2DException("No se ha especificado el fichero de entrada");
 			}
 
-			GNC::GCS::Permisos::EstadoPermiso mantenerCodificacion = GNC::GCS::ControladorPermisos::Instance()->Get("core.importacion", "mantener");
-
-			if (mantenerCodificacion.Activo()) {
-				//probamos a ver si nos vale cn un JPEG source
-				I2DJpegSource *jpgSource = new I2DJpegSource();
-				if (jpgSource == NULL) {
-					throw I2DException("No se pudo reservar memoria para realizar la conversion");
-				}
-				// Set JPEG Options
-				// Enable/Disable support for progressive JPEG
-				jpgSource->setProgrSupport(OFTrue);
-				// Enable/Disable support for extended sequential JPEG
-				jpgSource->setExtSeqSupport(OFTrue);
-				jpgSource->setImageFile(inputFile.c_str());
-				Inicializar(jpgSource, pICallback, debug, outputFormat);
-			} else {
-				wxString nombreImagen = FROMPATH(inputFile);
-				wxImage img(nombreImagen);
-				if(!img.Ok())
-				{
-					throw I2DException(_Std("Image format not supported"));
+			if (GIL::DICOM::PACSController::Instance()->EsPDF(inputFile)) { // Special PDF Dicomization
+				//pdf => foo not need output plug
+				if (outputFormat == TDOF_AUTO) {
+					outputFormat = TDOF_FOO;
 				}
 
-				unsigned char* imgData = img.GetData();
-				TImageFile rgbLittleEndian(imgData, img.GetWidth(), img.GetHeight());
-				Inicializar(rgbLittleEndian, pICallback, debug, outputFormat);
-			} 
+				PDF2DSource* pdfSource = new PDF2DSource();
+				if (pdfSource == NULL) {
+					throw I2DException(_Std("Unable to reserve memory for PDF dicomization"));
+				}
+				pdfSource->setPDFFile(inputFile.c_str());
+				Inicializar(pdfSource, pICallback, debug, outputFormat);
+			}
+			else 
+			{ // Traditional Image dicomization
+				
+				//image => vlp
+				if (outputFormat == TDOF_AUTO) {
+					outputFormat = TDOF_VLP;
+				}
+
+				GNC::GCS::Permisos::EstadoPermiso mantenerCodificacion = GNC::GCS::ControladorPermisos::Instance()->Get("core.importacion", "mantener");
+
+				if (mantenerCodificacion.Activo()) {
+					//probamos a ver si nos vale cn un JPEG source
+					I2DJpegSource *jpgSource = new I2DJpegSource();
+					if (jpgSource == NULL) {
+						throw I2DException(_Std("Unable to reserve memory for image Dicomization"));
+					}
+					// Set JPEG Options
+					// Enable/Disable support for progressive JPEG
+					jpgSource->setProgrSupport(OFTrue);
+					// Enable/Disable support for extended sequential JPEG
+					jpgSource->setExtSeqSupport(OFTrue);
+					jpgSource->setImageFile(inputFile.c_str());
+					Inicializar(jpgSource, pICallback, debug, outputFormat);
+				} else {
+					wxString nombreImagen = FROMPATH(inputFile);
+					wxImage img(nombreImagen);
+					if(!img.Ok())
+					{
+						throw I2DException(_Std("Image format not supported"));
+					}
+
+					unsigned char* imgData = img.GetData();
+					TImageFile rgbLittleEndian(imgData, img.GetWidth(), img.GetHeight());
+					Inicializar(rgbLittleEndian, pICallback, debug, outputFormat);
+				}
+			}
 		}
 
 		void DICOMImg2DCM::Inicializar(TImageFile& fileDefinition, IInspectCallBack* pICallback, bool debug, TDICOMOutputFormat outputFormat)
@@ -166,13 +260,13 @@ namespace GIL {
 			Inicializar(littleEndianSource, pICallback, debug, outputFormat);
 		}
 
-		void DICOMImg2DCM::Inicializar(I2DImgSource* plugEntrada, IInspectCallBack* pICallback, bool debug, TDICOMOutputFormat outputFormat)
+		void DICOMImg2DCM::Inicializar(D2DSource* plugEntrada, IInspectCallBack* pICallback, bool debug, TDICOMOutputFormat outputFormat)
 		{
 			LiberarMemoria();
 
 			inputPlug = plugEntrada;
 
-			i2d = new Image2Dcm();
+			i2d = new Document2Dcm();
 			if (i2d == NULL) {
 				throw I2DException("No se pudo reservar memoria para realizar la conversion");
 			}
@@ -190,12 +284,14 @@ namespace GIL {
 			if (vMode)
 				std::cout << inputPlug->inputFormat() << std::endl;
 
-			if (outputFormat == TDOF_VLP) {
+			if (outputFormat == TDOF_VLP || outputFormat == TDOF_AUTO) {
 				outputPlug = new I2DOutputPlugVLP();
 			} else if (outputFormat == TDOF_SC) {
 				outputPlug = new I2DOutputPlugSC();
 			} else if (outputFormat == TDOF_NSC) {
 				outputPlug = new I2DOutputPlugNewSC();
+			} else if (outputFormat == TDOF_FOO){
+				outputPlug = new FooOutputPlug();
 			} else {
 				throw I2DException("No existe ningun plugin para el formato de salida especificado");
 			}
@@ -354,7 +450,8 @@ namespace GIL {
 				throw I2DException("El conversor no se ha inicializado previamente");
 			}
 
-			return InsertarJerarquia(base,i2d->getOverrideKeys(), NULL, NULL);
+			int val = InsertarJerarquia(base,i2d->getOverrideKeys(), NULL, NULL);
+			return val;
 		};
 
 		int DICOMImg2DCM::InsertarJerarquia(TipoJerarquia& base,DcmDataset* dcmDataSet, DcmItem* itemPadre, DcmSequenceOfItems* seqPadre)
@@ -365,13 +462,11 @@ namespace GIL {
 			int numItemsInsertados = 0;
 			int numSeqsInsertadas  = 0;
 
-
-
 			// Insertamos todos los tags correspondientes a este nivel en la raiz (de haberla, si no: en el dataset).
 			for (ListaTags::iterator it = base.tags.begin(); it != base.tags.end(); it++) {
 				DcmElement* e = this->CrearElementoConValor((*it).first.c_str());
 				if (e != NULL) {
-					e->putString((*it).second.c_str());
+					e->putString( wxString( (*it).second.c_str(), wxConvUTF8).mb_str(*m_pConv) );
 
 					OFCondition cond;
 					if (itemPadre == NULL) {
@@ -559,6 +654,15 @@ namespace GIL {
 			OFCondition cond;
 
 			i2d->updateOverrideKeys(resultObject);
+			//overrride charset
+			{
+				std::string strTmp;
+				GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","DefaultCharset",strTmp,"ISO_IR 192");
+				cond = resultObject->putAndInsertString(DCM_SpecificCharacterSet, strTmp.c_str());
+				if (cond.bad()) {
+					throw I2DException(cond.text());
+				}
+			}
 
 			DcmFileFormat dcmff(resultObject);
 			cond = dcmff.saveFile(outputFile.c_str(), writeXfer, lengthEnc, grpLengthEnc, padEnc, filepad, itempad);
@@ -669,10 +773,13 @@ namespace GIL {
 			DSRDocument *doc = new DSRDocument();
 			if (doc != NULL)
 			{
-
+				{
+					std::string strTmp;
+					GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","DefaultCharset",strTmp,"ISO_IR 192");
+					doc->setSpecificCharacterSet(strTmp.c_str());
+				}
 				doc->createNewDocument(DSRTypes::DT_BasicTextSR);
 				doc->setSpecificCharacterSetType(DSRTypes::CS_UTF8);
-				doc->setSpecificCharacterSet("ISO_IR 192");
 
 				doc->setManufacturer("Ginkgo");
 				doc->setPatientName("Last Name^First Name");
@@ -694,9 +801,9 @@ namespace GIL {
 					cond = doc->write(*dataset);
 					if (cond.good()){
 						//utf-8
-						if( dataset->putAndInsertOFStringArray(DCM_SpecificCharacterSet, "ISO_IR 192").bad()) {
+						/*if( dataset->putAndInsertOFStringArray(DCM_SpecificCharacterSet, "ISO_IR 192").bad()) {
 							LOG_ERROR("Dicomizacion", "Error al establecer la codificacion en el fichero DICOM");
-						}
+						}*/
 						InsertarJerarquia(base,dataset,NULL,NULL);
 						for(std::list<GnkPtr<TipoPrivateTags> >::iterator it = tagsPrivados.begin(); it!= tagsPrivados.end(); it++){
 							InsertarTagsPrivados(*(*it),dataset);
