@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: dicomnetclient.h 4468 2011-12-09 10:02:00Z carlos $
+ *  $Id: dicomnetclient.h 4818 2012-04-04 13:25:18Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -16,6 +16,7 @@
 #include <api/icontroladorlog.h>
 #include <api/iproxynotificadorprogreso.h>
 #include <main/controllers/controladorlog.h>
+#include <main/controllers/dcmtk/dicomservers.h>
 #include "dicomnetwork.h"
 #include "helpers.h"
 
@@ -72,13 +73,13 @@ public:
 		this->m_pNotificadorProgreso = pNotificadorProgreso;
 		this->ambitolog = ambitolog;
 	};
-
-	bool QueryServer(DcmDataset* query, DicomServer* server, IModeloDicom* pModelo, const std::string& local_aet, CallbackType callbackType) {
-		if (server == NULL || pModelo == NULL) {
+	
+	bool QueryServer(DicomServer* server, const std::string& local_aet) {
+		if (server == NULL) {
 			return false;
 		}
-
 		if (!Net->Initiallized()) {
+		
 			Net->InitializeNetwork(T::GetTimeout(), T::GetRole(), T::GetAcceptorPort());
 		}
 
@@ -97,7 +98,56 @@ public:
 		CONDITION c = ECC_Normal;
 
 		if (r.good() == true) {
-			LOG_TRACE(ambitolog, "Enviando Objeto:" << std::endl << DumpDataset(query));
+			c = T::SendObject();
+		}
+		else {
+			LOG_ERROR(ambitolog, "Error al conectar:" << r.text());
+			T::Drop();
+			T::Destroy();
+			throw GIL::DICOM::PACSException(r.text());
+		}
+
+		if (!c.good()) {
+			LOG_ERROR(ambitolog, "Error al enviar objeto: " << c.text());
+			T::Drop();
+			T::Destroy();
+			throw GIL::DICOM::PACSException(c.text());
+		}
+
+		LOG_DEBUG(ambitolog, "Cerrando asociación");
+		T::Drop();
+		
+	}
+
+	bool QueryServer(DcmDataset* query, DicomServer* server, IModeloDicom* pModelo, const std::string& local_aet, CallbackType callbackType) {
+		if (pModelo == NULL && callbackType != CT_None)  {
+			return false;
+		}
+		if (server == NULL) {
+			return false;
+		}
+
+		if (!Net->Initiallized()) {
+		
+			Net->InitializeNetwork(T::GetTimeout(), T::GetRole(), T::GetAcceptorPort());
+		}
+
+		T::Create(
+			server->AET,
+			server->HostName,
+			server->Port,
+			local_aet
+		);
+
+		T::SetNotificadorProgreso(m_pNotificadorProgreso);
+
+		LOG_DEBUG(ambitolog, "Conectando: AET = " << server->AET << ", Host = " << server->HostName << ", Puerto = " << server->Port << ", Local AET = " << local_aet << ", PDU = " << server->PDU);
+		CONDITION r = T::Connect(Net, server->PDU);
+
+		CONDITION c = ECC_Normal;
+
+		if (r.good() == true) {
+			LOG_DEBUG(ambitolog, "Enviando Objeto:" << std::endl << DumpDataset(query));
 			c = T::SendObject(query);
 		}
 		else {
