@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: dicomstoreassociation.cpp 3921 2011-07-06 11:36:02Z tovar $
+ *  $Id: dicomstoreassociation.cpp 4825 2012-04-10 13:40:21Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -16,6 +16,7 @@
 #include <api/icontroladorlog.h>
 #include <main/controllers/controladorlog.h>
 #include <api/icontextoestudio.h>
+#include <main/controllers/dcmtk/ginkgouid.h>
 #include "helpers.h"
 
 #ifdef verify
@@ -351,12 +352,6 @@ namespace GIL {
 			return cond;
 		}
 
-		static int secondsSince1970()
-		{
-			time_t t = time(NULL);
-			return (int)t;
-		}
-
 		static OFString intToString(int i)
 		{
 			char numbuf[32];
@@ -364,12 +359,10 @@ namespace GIL {
 			return numbuf;
 		}
 
-		static OFString makeUID(OFString basePrefix, int counter)
+		static int secondsSince1970()
 		{
-			OFString prefix = basePrefix + "." + intToString(counter);
-			char uidbuf[65];
-			OFString uid = dcmGenerateUniqueIdentifier(uidbuf, prefix.c_str());
-			return uid;
+			time_t t = time(NULL);
+			return (int)t;
 		}
 
 		static OFBool updateStringAttributeValue(DcmItem* dataset, const DcmTagKey& key, OFString& value)
@@ -415,9 +408,9 @@ namespace GIL {
 			static OFString patientID;
 			static OFString patientName;
 
-			if (seriesInstanceUID.length() == 0) seriesInstanceUID=makeUID(SITE_SERIES_UID_ROOT, (int)seriesCounter);
+			if (seriesInstanceUID.length() == 0) seriesInstanceUID = GIL::DICOM::MakeUID(GIL::DICOM::GUID_SeriesRoot, (int)seriesCounter).c_str();
 			if (seriesNumber.length() == 0) seriesNumber = intToString((int)seriesCounter);
-			if (studyInstanceUID.length() == 0) studyInstanceUID = makeUID(SITE_STUDY_UID_ROOT, (int)studyCounter);
+			if (studyInstanceUID.length() == 0) studyInstanceUID = GIL::DICOM::MakeUID(GIL::DICOM::GUID_StudyRoot, (int)studyCounter).c_str();
 			if (studyID.length() == 0) studyID = studyIDPrefix + intToString((int)secondsSince1970()) + intToString((int)studyCounter);
 			if (accessionNumber.length() == 0) accessionNumber = accessionNumberPrefix + intToString(secondsSince1970()) + intToString((int)studyCounter);
 			if (patientID.length() == 0) patientID = patientIDPrefix + intToString(secondsSince1970()) + intToString((int)patientCounter);
@@ -426,13 +419,13 @@ namespace GIL {
 			if (imageCounter >= opt_inventSeriesCount) {
 				imageCounter = 0;
 				seriesCounter++;
-				seriesInstanceUID = makeUID(SITE_SERIES_UID_ROOT, (int)seriesCounter);
+				seriesInstanceUID = GIL::DICOM::MakeUID(GIL::DICOM::GUID_SeriesRoot, (int)seriesCounter).c_str();
 				seriesNumber = intToString((int)seriesCounter);
 			}
 			if (seriesCounter >= opt_inventStudyCount) {
 				seriesCounter = 0;
-				studyCounter++;
-				studyInstanceUID = makeUID(SITE_STUDY_UID_ROOT, (int)studyCounter);
+				studyCounter++;				
+				studyInstanceUID = GIL::DICOM::MakeUID(GIL::DICOM::GUID_StudyRoot, (int)studyCounter).c_str();
 				studyID = studyIDPrefix + intToString(secondsSince1970()) + intToString((int)studyCounter);
 				accessionNumber = accessionNumberPrefix + intToString(secondsSince1970()) + intToString((int)studyCounter);
 			}
@@ -444,7 +437,7 @@ namespace GIL {
 				patientName = patientNamePrefix + intToString(secondsSince1970()) + intToString((int)patientCounter);
 			}
 
-			OFString sopInstanceUID = makeUID(SITE_INSTANCE_UID_ROOT, (int)imageCounter);
+			OFString sopInstanceUID = GIL::DICOM::MakeUID(GIL::DICOM::GUID_InstanceRoot, (int)imageCounter).c_str();
 			OFString imageNumber = intToString((int)imageCounter);
 
 			if (opt_debug) {
@@ -483,7 +476,7 @@ namespace GIL {
 			if (filexfer.getXfer() == EXS_JPEG2000LosslessOnly || filexfer.getXfer() == EXS_JPEG2000)
 			{
 				status = DecompressJPEG2000(fname, outfname);
-				LOG_WARN(LOGGER,"Se ha descomprimido desde JPEG2000, podrían perderse algunos tags");
+				LOG_WARN(LOGGER,"The file is being uncompressed from JPG2000. Some tags could be lost");
 			}
 			else {
 
@@ -880,8 +873,8 @@ namespace GIL {
 			opt_maxReceivePDULength = server->PDU;
 			std::string host = server->HostName;
 			unsigned int puerto = server->Port;
-			//TIMEOUT 15 SEGUNDOS
-			unsigned int dicomtimeout = 15;
+			//TIMEOUT 60 SEGUNDOS
+			unsigned int dicomtimeout = 60;
 			bool _shouldAbort=false;
 			DcmFileFormat fileformat;
 			errorEncontrado ="";
