@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: istorecallback.h 3066 2010-12-21 10:10:14Z carlos $
+ *  $Id: istorecallback.h 4392 2011-11-10 14:51:21Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -34,6 +34,6 @@ class IStoreCallBack {
 public:
     IStoreCallBack() {};
 
-    virtual void Store(DcmDataset* dset) = 0;
+	 virtual void Store(const std::string& fileName, DcmDataset* dset) = 0;
 };
 
