@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: pacscontroller.cpp 4516 2012-01-12 12:18:40Z tovar $
+*  $Id: pacscontroller.cpp 4848 2012-04-18 09:43:41Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -16,7 +16,6 @@
 
 #include "pacscontroller.h"
 #include "dcmtk/dicomimg2dcm.h"
-#include "dcmtk/dicommanager.h"
 #include "dcmtk/dicomservers.h"
 #include "dcmtk/dicomservice.h"
 #include "dcmtk/dicomnetclient.h"
@@ -24,6 +23,8 @@
 #include "dcmtk/dicommoveassociation.h"
 #include "dcmtk/dicomgetassociation.h"
 #include "dcmtk/dicomstoreassociation.h"
+#include "dcmtk/dicomprintassociation.h"
+#include "dcmtk/dicomcustomassociation.h"
 #include <dcmtk/dcmdata/dcrledrg.h>
 #include <dcmtk/dcmjpeg/djdecode.h>
 #include <dcmtk/dcmdata/dcdicdir.h>
@@ -35,7 +36,8 @@
 #include <wx/file.h>
 #include <wx/tokenzr.h>
 #include <main/controllers/configurationcontroller.h>
-#include <main/controllers/dcmtk/dicommanager.h>
+#include <main/controllers/controladorhistorial.h>
+#include <main/controllers/dicommanager.h>
 
 #include <api/icontextoestudio.h>
 
@@ -131,7 +133,7 @@ namespace GIL {
 			//std::cout << "ImagenUId = " << ImagenUId << std::endl;
 
 			std::string rutaStd;
-			GetRutaImagenTemp(PacienteUId,EstudioUId,SerieUId,ImagenUId,rutaStd);
+			GetRutaImagenTemp(PacienteUId,EstudioUId,SerieUId,ImagenUId, GNC::GCS::ControladorHistorial::Instance()->GetGinkgoDicomDir(),rutaStd);
 
 			if (!wxRenameFile(FROMPATH(fileName), FROMPATH(rutaStd))) {
 				LOG_ERROR("PACSCONTROLLER-STORE", "Error writting file to temp dir");
@@ -165,20 +167,30 @@ namespace GIL {
 
 			e = newDicomElement(DCM_PatientID);
 			e->putString(idPaciente.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_PatientName);
 			e->putString(nombrePaciente.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_PatientBirthDate);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_PatientSex);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_ReferringPhysicianName);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			NetClient<FindAssociation> a(GIL::DICOM::DCMTK::Network::Instance(connectionKey), "C-FIND", pNotificador);
 
@@ -245,7 +257,6 @@ namespace GIL {
 				time = timeFrom;
 			}
 
-
 			std::string station;
 			DcmDataset query;
 			DcmElement* e = NULL;
@@ -260,53 +271,79 @@ namespace GIL {
 
 			e = newDicomElement(DCM_PatientName);
 			e->putString(nombrePaciente.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_PatientID);
 			e->putString(idPaciente.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_ModalitiesInStudy);
 			if (modality != "*" && modality != "") {
 				e->putString(modality.c_str());
 			}
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_PatientBirthDate);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_PatientSex);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_StudyDate);
 			e->putString(date.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_StudyTime);
 			e->putString(time.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_StudyID);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_StudyInstanceUID);
 			e->putString(idEstudio.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_StudyDescription);
 			e->putString(description.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_AccessionNumber);
 			e->putString(AccNumber.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_StationName);
 			e->putString(station.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_ReferringPhysicianName);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			NetClient<FindAssociation> a(connectionKey, "C-FIND", pNotificador);
 
@@ -359,29 +396,45 @@ namespace GIL {
 
 			e = newDicomElement(DCM_StudyInstanceUID);
 			e->putString(estudioId.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_SeriesInstanceUID);
 			e->putString(serieId.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_Modality);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_SeriesDescription);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_SeriesDate);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_SeriesTime);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_NumberOfSeriesRelatedInstances);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_ReferringPhysicianName);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			NetClient<FindAssociation> a(connectionKey, "C-FIND", pNotificador);
 
@@ -435,19 +488,29 @@ namespace GIL {
 
 			e = newDicomElement(DCM_SeriesInstanceUID);
 			e->putString(serieId.c_str());
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_SOPInstanceUID);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_ImageID);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_ImageIndex);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_ReferringPhysicianName);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			NetClient<FindAssociation> a(connectionKey, "C-FIND", pNotificador);
 
@@ -526,9 +589,9 @@ namespace GIL {
 									{
 										OFString uidImagen;
 										FileRecord->findAndGetOFString(DCM_ReferencedSOPInstanceUIDInFile, uidImagen);
-										
+
 										wxString currentPath = FROMPATH(basePath);
-										
+
 										wxString wxStr = FROMPATH(tmpString);
 										wxString separador = wxFileName::GetPathSeparator();
 										wxString barra = wxT('\\');
@@ -543,11 +606,11 @@ namespace GIL {
 											// recase: Get case insensitive path (if needed)
 											wxStringTokenizer tokenizer(wxStr, separador);
 											bool validPath = true; // When false, "recase" will do nothing more
-											
+
 											while (validPath && tokenizer.HasMoreTokens() )
 											{
 												wxString relPathPart = tokenizer.GetNextToken();
-												
+
 												if (tokenizer.HasMoreTokens()) { // Scanning subdirectories
 													wxString entry;
 													if (validPath && !wxDir::Exists(currentPath + separador + relPathPart)) {
@@ -575,12 +638,12 @@ namespace GIL {
 													else {
 														currentPath += separador + relPathPart; // Assign case sentitive subdir to current path (Could be non-existing if validPath == false)
 													}
-													
+
 												}
 												else { // Scanning end file
-													
+
 													wxString entry;
-													
+
 													if (validPath && !wxFile::Access(currentPath + separador + relPathPart, wxFile::read)) {
 														wxDir dir;
 														bool cont = dir.Open(currentPath) && dir.GetFirst(&entry, wxEmptyString, wxDIR_FILES | wxDIR_HIDDEN );
@@ -607,10 +670,10 @@ namespace GIL {
 														currentPath += separador + relPathPart; // Assign case sentitive filename to current path (Could be non-existing if validPath == false)
 													}
 												}
-												
+
 											}
 										}//end recase
-										
+
 										pModelo->InsertarImagen(uidSerie.c_str(), uidImagen.c_str(), std::string(TOPATH(currentPath)));
 									}
 								}
@@ -642,7 +705,7 @@ namespace GIL {
 			return found;
 		}
 
-		bool PACSController::EsDICOM(const std::string& path, bool accept_dicomdir, bool accept_dicomfile)
+		bool PACSController::EsDICOM(const std::string& path, bool accept_dicomdir, bool accept_dicomfile) const
 		{
 			bool valido = false;
 			char magic[5] = { 'X', 'X', 'X', 'X', 0 };
@@ -690,23 +753,104 @@ namespace GIL {
 			return valido;
 		}
 
+		bool PACSController::EsPDF(const std::string& path) const
+		{
+			bool valido = false;
+			char magic[4] = { 'X', 'X', 'X', 'X' }; // %PDF
+			std::string emptystr;
+			std::fstream pdffile;
+
+			pdffile.open (path.c_str(), std::ios::in | std::ios::binary);
+
+			if (!pdffile.eof() && pdffile.good() ) {
+				pdffile.read (magic, 4);
+			}
+			if (!pdffile.eof() && pdffile.good()) {
+				if ( magic[0] == '%' && magic[1] == 'P' && magic[2] == 'D' && magic[3] == 'F' ) {
+					valido = true;
+				}
+			}
+			pdffile.close();
+
+			return valido;
+		}
+
 		void PACSController::FillInQuery(const GIL::DICOM::TipoJerarquia& base, DcmDataset* query)
 		{
+			OFCondition cond;
+
+			typedef GIL::DICOM::TipoJerarquia TJerarquia;
+
 			for (ListaTags::const_iterator it = base.tags.begin(); it != base.tags.end(); it++) {
 				DcmElement* e = GIL::DICOM::DICOMManager::CrearElementoConValor((*it).first.c_str());
 
 				if (e != NULL) {
-					e->putString( (*it).second.c_str() );
-					OFCondition cond;
+					const std::string& val = (*it).second;
+					if (val.size() > 0) {
+						e->putString( (*it).second.c_str() );
+					}					
 					cond = query->insert(e, true, false);
-					
+
 					if (cond.bad()) {
 						LOG_ERROR("PACSCONTROLLER", "No se pudo insertar el elemento: (" << e->getTag().toString().c_str() << "): " << cond.text());
 					}
 				}
+
+				for (TJerarquia::ListaJerarquias::const_iterator it2 = base.secuencias.begin(); it2 != base.secuencias.end(); it2++) {
+					const TJerarquia& seq = (*it2);
+					DcmElement* es = GIL::DICOM::DICOMManager::CrearElementoConValor(seq.tagName.c_str());			
+
+					for (TJerarquia::ListaJerarquias::const_iterator it3 = seq.items.begin(); it3 != seq.items.end(); it3++) {
+						const TJerarquia& item = (*it3);
+						DcmItem* di = new DcmItem();
+
+						for (ListaTags::const_iterator it4 = item.tags.begin(); it4 != item.tags.end(); it4++) {
+							DcmElement* ei = GIL::DICOM::DICOMManager::CrearElementoConValor((*it4).first.c_str());
+							if (ei != NULL) {
+								const std::string& val = (*it4).second;
+								if (val.size() > 0) {
+									ei->putString( (*it4).second.c_str() );
+								}					
+								cond = di->insert(ei, true, false);
+
+								if (cond.bad()) {
+									LOG_ERROR("PACSCONTROLLER", "No se pudo insertar el elemento: (" << ei->getTag().toString().c_str() << "): " << cond.text());
+								}
+							}
+
+						}
+
+						query->insertSequenceItem(es->getTag(), di);
+					}					
+				}
 			}
 		}
 
+		bool PACSController::Print(void* connectionKey, const std::string& serverId, const GIL::DICOM::TipoJerarquia& film, const GIL::DICOM::TipoJerarquia& layout, const GIL::DICOM::TipoJerarquia& job, const std::vector<std::string> files, GNC::IProxyNotificadorProgreso* pNotificador)
+		{
+			DicomServerList* listaServidores = DicomServerList::Instance();
+			DicomServer* server = listaServidores->GetServer(serverId);
+			if (!server->GetReuseConnection()) {
+				ReleaseConnection(connectionKey);
+				GetConnection(connectionKey);
+			}
+			try {
+				PrintAssociation f(connectionKey, "C-PRINT", pNotificador);
+				CONDITION cond = f.Print(server, GNC::Entorno::Instance()->GetDicomLocalAET(), film, layout, job, files);
+				if (cond.bad()) {
+					throw GIL::DICOM::PACSException(cond.text(), "GIL/DICOM/Print");
+				}
+			}
+			catch(std::exception& ex) {
+				std::ostringstream os;
+				os << "Internal error: " << ex.what();
+				throw GIL::DICOM::PACSException(os.str(), "GIL/DICOM/Print");
+			}
+
+			return true;
+		}
+
+
 		bool PACSController::ObtenerEstudio(void* connectionKey, const std::string& serverId, const GIL::DICOM::TipoJerarquia& base, IModeloDicom* pModelo, GNC::IProxyNotificadorProgreso* pNotificador)
 		{
 			DicomServerList* listaServidores = DicomServerList::Instance();
@@ -728,20 +872,29 @@ namespace GIL {
 			query.insert(e);
 
 			e = newDicomElement(DCM_PatientID);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_PatientName);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_StudyDate);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_StudyTime);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_StudyID);
-			query.insert(e);
-
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			FillInQuery(base, &query);
 
@@ -755,10 +908,14 @@ namespace GIL {
 				query.insert(e, true);
 
 				e = newDicomElement(DCM_SeriesInstanceUID);
-				query.insert(e, true);
+				if (query.insert(e).bad()) {
+					delete e;
+				}
 
 				e = newDicomElement(DCM_Modality);
-				query.insert(e, true);
+				if (query.insert(e).bad()) {
+					delete e;
+				}
 
 				std::list<std::string> listOfUIDS;
 				std::list<std::string> listOfModalities;
@@ -785,7 +942,7 @@ namespace GIL {
 					unsigned int numResults = 0;
 
 					numResults = stack->card();
-					
+
 
 					for (unsigned int i = 0; i < numResults; i++) {
 
@@ -807,14 +964,14 @@ namespace GIL {
 						}
 					}
 				}
-				
+
 				for (std::list<std::string>::iterator itUIDS = listOfUIDS.begin(), itModalities = listOfModalities.begin();
 					itUIDS != listOfUIDS.end(); itUIDS++, itModalities++) 
 				{
-					if (!server->GetReuseConnection()) {
-						ReleaseConnection(connectionKey);
-						GetConnection(connectionKey);
-					}
+					//it's mandatory to release connection here to start one connection for each series	
+					ReleaseConnection(connectionKey);
+					GetConnection(connectionKey);
+
 					GIL::DICOM::TipoJerarquia baseAux = base;
 					baseAux.tags["0020|000e"] = (*itUIDS);
 					baseAux.tags["0008|0060"] = (*itModalities);
@@ -862,12 +1019,16 @@ namespace GIL {
 				e = newDicomElement(DCM_QueryRetrieveLevel);
 				e->putString("SERIES");
 				query.insert(e, true);
-								
+
 				e = newDicomElement(DCM_SeriesInstanceUID);
-				query.insert(e);
+				if (query.insert(e).bad()) {
+					delete e;
+				}
 
 				e = newDicomElement(DCM_Modality);
-				query.insert(e);
+				if (query.insert(e).bad()) {
+					delete e;
+				}
 
 				NetClient<FindAssociation> f(connectionKey, "C-GET/FIND", pNotificador);
 				f.SetMaxResults(-1);
@@ -954,15 +1115,21 @@ namespace GIL {
 				e = newDicomElement(DCM_QueryRetrieveLevel);
 				e->putString("SERIES");
 				query.insert(e, true);
-				
+
 				e = newDicomElement(DCM_StudyInstanceUID);
-				query.insert(e);
+				if (query.insert(e).bad()) {
+					delete e;
+				}
 
 				e = newDicomElement(DCM_SeriesInstanceUID);
-				query.insert(e);
+				if (query.insert(e).bad()) {
+					delete e;
+				}
 
 				e = newDicomElement(DCM_Modality);
-				query.insert(e);
+				if (query.insert(e).bad()) {
+					delete e;
+				}
 
 				NetClient<FindAssociation> f(connectionKey, "C-GET/FIND", pNotificador);
 				f.SetMaxResults(-1);
@@ -1022,13 +1189,19 @@ namespace GIL {
 			query.insert(e, true);
 
 			e = newDicomElement(DCM_SeriesInstanceUID);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_Modality);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			e = newDicomElement(DCM_SeriesNumber);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
@@ -1085,7 +1258,7 @@ namespace GIL {
 					return false;
 				}
 			}
-
+			query.clear();
 			return true;
 
 		}
@@ -1112,7 +1285,9 @@ namespace GIL {
 			query.insert(e, true);
 
 			e = newDicomElement(DCM_InstanceNumber);
-			query.insert(e);
+			if (query.insert(e).bad()) {
+				delete e;
+			}
 
 			std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
@@ -1158,6 +1333,77 @@ namespace GIL {
 			return true;
 		}
 
+		/** Gets the current server ID list */
+		void PACSController::GetServerList(std::list<std::string>& /*list*/)
+		{
+			//TODO
+		}
+
+		/** Perform query */
+		bool PACSController::Query(
+			void* connectionKey,
+			const std::string& abstractSyntax,
+			const std::list<std::string>& /*transferSyntaxes*/,
+			const GIL::DICOM::TipoJerarquia& queryWrapper,
+			int maxResultTagLen,
+			std::list< GnkPtr<GIL::DICOM::TipoJerarquia> >& resultsWrapper,				
+			const std::string& serverId,
+			GNC::IProxyNotificadorProgreso* pNotificador
+			)
+		{
+
+			resultsWrapper.clear();
+
+			DicomServerList* listaServidores = DicomServerList::Instance();
+			DicomServer* server = listaServidores->GetServer(serverId);
+
+			DcmDataset query;
+			DcmElement* e = NULL;
+
+			e = newDicomElement(DCM_SpecificCharacterSet);
+			e->putString("ISO_IR 192");
+			query.insert(e);
+
+			DICOMManager* dm = new DICOMManager(&query);
+			dm->InsertarJerarquia(queryWrapper, NULL, NULL);
+			delete dm;
+
+			std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
+
+			NetClient<FindAssociation> a(connectionKey, "C-FIND", pNotificador);
+
+			a.SetAbstractSyntax(abstractSyntax);
+
+			if (server->useTLS) {
+				a.SetTLS(server->GetCertificate(), server->GetPrivateKey(), server->GetverifyCredentials());
+			}
+			if (server->GetPACSUser() != "") {
+				a.SetUserPass(server->GetPACSUser(), server->GetPACSPass());
+			}
+			if (a.QueryServer(&query, server, NULL, localAET, CT_None)) {
+				DcmStack* stack = a.GetResultStack();
+				if (stack != NULL)
+				{
+
+					for (unsigned int i = 0; i < stack->card(); i++) {
+
+						if (stack->elem(i)->ident() == EVR_dataset) {
+							GIL::DICOM::DICOMManager mgr( (DcmDataset*)(stack->elem(i)) );
+							GnkPtr<GIL::DICOM::TipoJerarquia> base = new GIL::DICOM::TipoJerarquia();							
+							mgr.CargarJerarquia((*base), maxResultTagLen);
+							resultsWrapper.push_back(base);
+						}
+					}
+				}
+				return true;
+			}
+			else {
+				return false;
+			}
+
+		}
+
+
 		bool PACSController::QueryRetrieve(
 			void* connectionKey,
 			const std::string& serverId,
@@ -1198,6 +1444,18 @@ namespace GIL {
 			return true;
 		}
 
+		GIL::DICOM::ICustomAssociation* PACSController::CreateCustomAssociation(void* connectionKey, const std::string& ambitolog, GNC::IProxyNotificadorProgreso* pNotificador)
+		{
+			return new CustomAssociation(connectionKey, ambitolog, pNotificador);
+		}
+		
+		void PACSController::DestroyCustomAssociation(GIL::DICOM::ICustomAssociation* assoc)
+		{
+			if (assoc != NULL) {
+				delete assoc;
+			}
+		}
+
 		void PACSController::StartService()
 		{
 			StopService();
@@ -1271,7 +1529,7 @@ namespace GIL {
 			return cadenaMD5.str();
 		}
 
-		bool PACSController::GetRutaSerie(const std::string& uidPaciente, const std::string& uidEstudio, const std::string& uidSerie, std::string& ruta, bool crearDirectorios,bool temporal)
+		bool PACSController::GetRutaSerie(const std::string& uidPaciente, const std::string& uidEstudio, const std::string& uidSerie, const std::string& dicomDirPath, std::string& ruta, bool crearDirectorios,bool temporal)
 		{
 			bool correcto = true;
 			//md5 de uidpaciente, estudio y serie
@@ -1292,7 +1550,7 @@ namespace GIL {
 			std::string resumen = GetMD5(cadena);
 
 			wxString dirRaiz, dirSerie;
-			dirRaiz = FROMPATH(GNC::Entorno::Instance()->GetGinkgoDicomDir());
+			dirRaiz = FROMPATH(dicomDirPath);
 			if (!wxDir::Exists(dirRaiz) && crearDirectorios) {
 				correcto = correcto && wxFileName::Mkdir(dirRaiz, 0700);
 			}
@@ -1313,18 +1571,18 @@ namespace GIL {
 			return correcto;
 		}
 
-		bool PACSController::GetRutaImagen(const std::string& uidPaciente, const std::string& uidEstudio, const std::string& uidSerie, const std::string& uidImagen, std::string& ruta, bool crearDirectorios)
+		bool PACSController::GetRutaImagen(const std::string& uidPaciente, const std::string& uidEstudio, const std::string& uidSerie, const std::string& uidImagen, const std::string& dicomDirPath, std::string& ruta, bool crearDirectorios)
 		{
-			bool correcto = GetRutaSerie(uidPaciente,uidEstudio,uidSerie,ruta, crearDirectorios, false);
+			bool correcto = GetRutaSerie(uidPaciente,uidEstudio,uidSerie, dicomDirPath,ruta, crearDirectorios, false);
 			std::ostringstream ostr;
 			ostr << ruta << (char)wxFileName::GetPathSeparator(wxPATH_NATIVE)<<GetMD5(uidImagen)<<".dcm";
 			ruta = ostr.str();
 			return correcto;
 		}
 
-		bool PACSController::GetRutaImagenTemp(const std::string& uidPaciente, const std::string& uidEstudio, const std::string& uidSerie, const std::string& uidImagen, std::string& ruta, bool crearDirectorios)
+		bool PACSController::GetRutaImagenTemp(const std::string& uidPaciente, const std::string& uidEstudio, const std::string& uidSerie, const std::string& uidImagen, const std::string& dicomDirPath, std::string& ruta, bool crearDirectorios)
 		{
-			bool correcto = GetRutaSerie(uidPaciente,uidEstudio,uidSerie,ruta, crearDirectorios, true);
+			bool correcto = GetRutaSerie(uidPaciente,uidEstudio,uidSerie, dicomDirPath,ruta, crearDirectorios, true);
 			std::ostringstream ostr;
 			ostr << ruta << (char)wxFileName::GetPathSeparator(wxPATH_NATIVE)<<GetMD5(uidImagen)<<".dcm";
 			ruta = ostr.str();
@@ -1369,16 +1627,16 @@ namespace GIL {
 		/*
 		void PACSController::CrearInstanciaDeImportacion(void* ref) {
 		m_ListaInstanciasDicomImg2DCM[ref] = new IDICOMImg2DCM();
-	 }
+		}
 
-	 void PACSController::LiberarInstanciaDeImportacion(void* ref) {
-	 ListaInstanciasImg2DCMType::iterator it = m_ListaInstanciasDicomImg2DCM.find(ref);
-	 if (it != m_ListaInstanciasDicomImg2DCM.end()) {
-	 delete (*it).second;
-	 m_ListaInstanciasDicomImg2DCM.erase(it);
-	 }
-	 }
-	 */
+		void PACSController::LiberarInstanciaDeImportacion(void* ref) {
+		ListaInstanciasImg2DCMType::iterator it = m_ListaInstanciasDicomImg2DCM.find(ref);
+		if (it != m_ListaInstanciasDicomImg2DCM.end()) {
+		delete (*it).second;
+		m_ListaInstanciasDicomImg2DCM.erase(it);
+		}
+		}
+		*/
 
 		IDICOMImg2DCM* PACSController::CrearInstanciaDeImportacion() {
 			return new DICOMImg2DCM();
@@ -1432,7 +1690,7 @@ namespace GIL {
 		void PACSController::PurgarDirectorioTemporal()
 		{
 			wxString dirTemp;
-			dirTemp = FROMPATH(GNC::Entorno::Instance()->GetGinkgoDicomDir());
+			dirTemp = FROMPATH(GNC::GCS::ControladorHistorial::Instance()->GetGinkgoDicomDir());
 			if (!wxDir::Exists(dirTemp)) {
 				return;
 			}
