@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: parserxmlenglish.cpp 4477 2011-12-13 11:16:56Z tovar $
+ *  $Id: parserxmlenglish.cpp 4670 2012-02-08 07:11:51Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -20,6 +20,7 @@
 
 #include <wx/xml/xml.h>
 #include <wx/file.h>
+#include <wx/filename.h>
 #include <wx/sstream.h>
 #include <wx/msgdlg.h>
 #ifndef _WIN32
@@ -34,8 +35,7 @@
 #include <api/globals.h>
 #include <api/imodelohl7.h>
 #include <api/icontroladormodulo.h>
-#include <api/icontroladorhl7.h>
-#include <api/iguiasmensajeriasacyl.h>
+#include <api/integration/dict.h>
 #include <api/aetwildcards.h>
 #include <main/controllers/controladorextensiones.h>
 #include <main/controllers/controladorlog.h>
@@ -43,17 +43,17 @@
 #include "dcmtk/dicomservers.h"
 
 //creacion de la base de datos de mensajes
-GIL::HL7::ParserXMLEnglish::ParserXMLEnglish()
+GIL::ParserXMLEnglish::ParserXMLEnglish()
 {
 }
 
-GIL::HL7::ParserXMLEnglish::~ParserXMLEnglish()
+GIL::ParserXMLEnglish::~ParserXMLEnglish()
 {
 }
 
 //region "Interfaz generica"
 
-std::list<std::string> GIL::HL7::ParserXMLEnglish::GetKeys()
+std::list<std::string> GIL::ParserXMLEnglish::GetKeys()
 {
 	std::list<std::string> list;
 	list.push_back("gnkworkflows");
@@ -62,7 +62,7 @@ std::list<std::string> GIL::HL7::ParserXMLEnglish::GetKeys()
 }
 
 /* Parsea la cadena XML y construye el modelo de integracion. Los parametros no encontrados se asignan por defecto segun lo especificado en la configuracion global */
-void GIL::HL7::ParserXMLEnglish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaModelosIntegracion& models, wxXmlNode* pRoot) 
+void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& models, wxXmlNode* pRoot) 
 {
 	MapaServers servers;
 	std::string xpp; // XML Pretty Printed for extended information info.
@@ -92,7 +92,7 @@ void GIL::HL7::ParserXMLEnglish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 					pacsServer.sid = propVal.ToUTF8();
 				}
 				else {
-					throw HL7XMLException(_Std("Omitted Identificator"), xpp, "CONF/pacs");
+					throw IntegrationException(_Std("Omitted Identificator"), xpp, "CONF/pacs");
 				}
 
 				propVal = nodo->GetPropVal(wxT("aet"), wxEmptyString);
@@ -100,7 +100,7 @@ void GIL::HL7::ParserXMLEnglish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 					pacsServer.AET = propVal.ToUTF8();
 				}
 				else {
-					throw HL7XMLException(_Std("Omitted AET"), xpp, "CONF/pacs");
+					throw IntegrationException(_Std("Omitted AET"), xpp, "CONF/pacs");
 				}
 
 				propVal = nodo->GetPropVal(wxT("hostname"), wxEmptyString);
@@ -108,7 +108,7 @@ void GIL::HL7::ParserXMLEnglish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 					pacsServer.hostname = propVal.ToUTF8();
 				}
 				else {
-					throw HL7XMLException(_Std("Hostname missing"), xpp, "CONF/pacs");
+					throw IntegrationException(_Std("Hostname missing"), xpp, "CONF/pacs");
 				}
 
 				propVal = nodo->GetPropVal(wxT("port"), wxEmptyString);
@@ -116,7 +116,7 @@ void GIL::HL7::ParserXMLEnglish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 					pacsServer.puerto = propVal.ToUTF8();
 				}
 				else {
-					throw HL7XMLException(_Std("Omitted port"), xpp, "CONF/pacs");
+					throw IntegrationException(_Std("Omitted port"), xpp, "CONF/pacs");
 				}
 				
 				propVal = nodo->GetPropVal(wxT("tls"), wxEmptyString);
@@ -186,13 +186,13 @@ void GIL::HL7::ParserXMLEnglish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 					long puerto;
 					long pdu;
 					if(!wxString::FromUTF8(pacsServer.pdu.c_str()).ToLong(&pdu)) {
-						throw HL7XMLException(_Std("The pdu size is not a valid number"), xpp, "CONF/pacs");
+						throw IntegrationException(_Std("The pdu size is not a valid number"), xpp, "CONF/pacs");
 					}
 					server->PDU = pdu;
 					if(wxString::FromUTF8(pacsServer.puerto.c_str()).ToLong(&puerto)) {
 						server->Port = puerto;
 					} else {
-						throw HL7XMLException(_Std("Port is not a valid number"), xpp, "CONF/pacs");
+						throw IntegrationException(_Std("Port is not a valid number"), xpp, "CONF/pacs");
 					}
 					if (pacsServer.metodo == GIL::IModeloPACSServer::IMPS_GET) {
 						server->retrieveWithMove = false;
@@ -214,12 +214,12 @@ void GIL::HL7::ParserXMLEnglish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 					long puerto;
 					long pdu;
 					if(!wxString::FromUTF8(pacsServer.pdu.c_str()).ToLong(&pdu)) {
-						throw HL7XMLException(_Std("The pdu size is not a valid number"), xpp, "CONF/pacs");
+						throw IntegrationException(_Std("The pdu size is not a valid number"), xpp, "CONF/pacs");
 					}
 					if(wxString::FromUTF8(pacsServer.puerto.c_str()).ToLong(&puerto)) {
 						DicomServerList::Instance()->AddServer( DicomServer(pacsServer.sid, pacsServer.AET, pacsServer.hostname, (int)puerto, 0, true, pdu, pacsServer.tls, pacsServer.user, pacsServer.password, pacsServer.metodo == GIL::IModeloPACSServer::IMPS_MOVE, wxString::FromUTF8(pacsServer.retrieveLevel.c_str()).Upper() == wxT("SERIES"), false, pacsServer.verify, pacsServer.cert, pacsServer.key), true );
 					} else {
-						throw HL7XMLException(_Std("The port is not a valid number"), xpp, "CONF/pacs");
+						throw IntegrationException(_Std("The port is not a valid number"), xpp, "CONF/pacs");
 					}
 				}
 			}
@@ -228,7 +228,7 @@ void GIL::HL7::ParserXMLEnglish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 		// Parseamos las gnkworkflows
 		for (wxXmlNode* nodo = pRoot->GetChildren(); nodo != NULL; nodo = nodo->GetNext()) {
 			if (nodo->GetName().CmpNoCase(wxT("gnkworkflow") ) == 0)  { // gnkworkflow
-				GIL::IModeloIntegracion* modelo = ParseGnkWorkflow(nodo, servers);				
+				GIL::IModeloIntegracion* modelo = ParseGnkWorkflow(nodo, servers);
 				models.push_back(modelo);
 			} //fin gnkworkflow
 		} //fin de parseo de gnkworkflows
@@ -236,16 +236,12 @@ void GIL::HL7::ParserXMLEnglish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 		GIL::IModeloIntegracion* modelo = ParseGnkWorkflow(pRoot, servers);
 		models.push_back(modelo);
 	} else {
-		throw HL7XMLException(_Std("Setting not found"), xpp, "CONF");
+		throw IntegrationException(_Std("Setting not found"), xpp, "CONF");
 	}
 }
 
-GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo, GIL::HL7::ParserXMLEnglish::MapaServers& servers)
+GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo, GIL::ParserXMLEnglish::MapaServers& servers)
 {	
-	std::string codigoAplicacion;
-	//se extrae de la configuracion el codigo de aplicacion
-	GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE","CodigoAplicacion", codigoAplicacion);
-
 	std::string xpp; // XML Pretty Printed for extended information info.
 	wxString propVal;
 	GIL::IModeloIntegracion* modelo = new IModeloIntegracion();
@@ -283,47 +279,41 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 			modelo->accion = GIL::IModeloIntegracion::TA_Open;
 		}
 		else {
-			throw HL7XMLException(_Std("\"action\" attribute invalid at \"gnkworkflow\" scope" ), xpp, "CONF/template");
+			throw IntegrationException(_Std("\"action\" attribute invalid at \"gnkworkflow\" scope" ), xpp, "CONF/template");
 		}
 	}
 	else {
-		throw HL7XMLException(_Std("\"action\" attribute expected at \"gnkworkflow\" scope"), xpp, "CONF/template");
+		throw IntegrationException(_Std("\"action\" attribute expected at \"gnkworkflow\" scope"), xpp, "CONF/template");
 	}
 
 	propVal = nodo->GetPropVal(wxT("petition-id"), wxEmptyString);
 	if( !propVal.empty() ) {
-		modelo->idPeticion = propVal.ToUTF8();
-	}
-	else {
-		modelo->idPeticion = "";
+		modelo->GlobalVariables.InsertVariable(GKDI_HCE_PETITION_ID, std::string(propVal.ToUTF8()));
 	}
 
 	propVal = nodo->GetPropVal(wxT("scope"), wxEmptyString);
 	if( !propVal.empty() ) {
-		modelo->idAmbitoPeticion = propVal.ToUTF8();
-	}
-	else {
-		modelo->idAmbitoPeticion = "";
+		modelo->GlobalVariables.InsertVariable(GKDI_JIMENA_AMBITO_PETICION,std::string(propVal.ToUTF8()));
 	}
 
 	if( nodo->HasProp(wxT("pacs-retrieve-sid")) ) {
 		propVal = nodo->GetPropVal(wxT("pacs-retrieve-sid"), wxEmptyString);
 		if (!propVal.IsEmpty()) {
-			modelo->PACSObtencion = propVal.ToUTF8();
-		}
+			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_RETRIEVE_SID, std::string(propVal.ToUTF8()));
+		}	
 		else {
-			throw HL7XMLException(_Std("\"pacs-retrieve-sid\" attribute empty at \"gnkworkflow\" scope"), xpp, "CONF/template");
-		}					
+			throw IntegrationException(_Std("\"pacs-retrieve-sid\" attribute empty at \"gnkworkflow\" scope"), xpp, "CONF/template");
+		}		
 	}
 
 	if( nodo->HasProp(wxT("pacs-store-sid")) ) {
 		propVal = nodo->GetPropVal(wxT("pacs-store-sid"), wxEmptyString);
 		if (!propVal.IsEmpty()) {
-			modelo->PACSAlmacenamiento = propVal.ToUTF8();
-		}
+			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_STORE_SID, std::string(propVal.ToUTF8()));
+		}	
 		else {
-			throw HL7XMLException(_Std("\"pacs-store-sid\" attribute empty at \"gnkworkflow\" scope"), xpp, "CONF/template");
-		}					
+			throw IntegrationException(_Std("\"pacs-store-sid\" attribute empty at \"gnkworkflow\" scope"), xpp, "CONF/template");
+		}		
 	}
 
 	//recorremos los hijos de las gnkworkflows
@@ -336,10 +326,10 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 		if(hijo->GetName().CmpNoCase(wxT("query-retrieve-level")) == 0){
 			propVal = hijo->GetPropVal(wxT("value"), wxEmptyString);
 			if ( !propVal.empty() ) {
-				modelo->ambitoDIMSE = propVal.Upper().ToUTF8();
+				modelo->TagsDICOMOverwrite.tags["0008|0052"] = std::string(propVal.Upper().ToUTF8());
 			}
 			else {
-				throw HL7XMLException(_Std("\"value\" attribute expected at \"query-retrieve-level\" scope"), xpp, "CONF/template");
+				throw IntegrationException(_Std("\"value\" attribute expected at \"query-retrieve-level\" scope"), xpp, "CONF/template");
 			}
 		}
 
@@ -348,19 +338,19 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 			for (wxXmlNode* hijosPaciente = hijo->GetChildren(); hijosPaciente != NULL; hijosPaciente = hijosPaciente->GetNext()) {
 				if(hijosPaciente->GetName().CmpNoCase(wxT("name")) == 0) {
 					if(hijosPaciente->GetChildren() != NULL){
-						modelo->Paciente.nombre = hijosPaciente->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_PATIENT_NAME, std::string(hijosPaciente->GetChildren()->GetContent().ToUTF8()));
 					}
 				} else if(hijosPaciente->GetName().CmpNoCase(wxT("first-surname")) == 0) {
 					if(hijosPaciente->GetChildren() != NULL){
-						modelo->Paciente.apellido1 = hijosPaciente->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_PATIENT_FAMILY_NAME, std::string(hijosPaciente->GetChildren()->GetContent().ToUTF8()));
 					}
 				} else if(hijosPaciente->GetName().CmpNoCase(wxT("second-surname")) == 0) {
 					if(hijosPaciente->GetChildren() != NULL){
-						modelo->Paciente.apellido2 = hijosPaciente->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_PATIENT_SECOND_FAMILY_NAME, std::string(hijosPaciente->GetChildren()->GetContent().ToUTF8()));
 					}
 				} else if(hijosPaciente->GetName().CmpNoCase(wxT("episode-number")) == 0) {
 					if(hijosPaciente->GetChildren() != NULL){
-						modelo->Paciente.numEpisodio = hijosPaciente->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_HCE_EPISODE_NUMBER, std::string(hijosPaciente->GetChildren()->GetContent().ToUTF8()));
 					}
 				}else if(hijosPaciente->GetName().CmpNoCase(wxT("id")) == 0) {
 					std::string codigo(propVal.ToUTF8());
@@ -370,12 +360,14 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 						codigo =  propVal.ToUTF8();
 					}
 					else {
-						throw HL7Exception(_Std("\"code\" attribute expected at \"patient\" scope"), xpp, "CONF/template");
+						throw IntegrationException(_Std("\"code\" attribute expected at \"patient\" scope"), xpp, "CONF/template");
 					}
 					propVal = hijosPaciente->GetPropVal(wxT("value"), wxEmptyString);
 					if ( !propVal.empty() ) {
 						valor =  propVal.ToUTF8();
-						modelo->Paciente.listaIdentificadores.push_back(IModeloIdentificador(codigo,valor));
+						if (!modelo->GlobalVariables.Contains(GKDI_PATIENT_ID)) {
+							modelo->GlobalVariables.InsertVariable(GKDI_PATIENT_ID, valor);
+						}
 					}								
 				}
 			}
@@ -386,15 +378,15 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 			for (wxXmlNode* hijosMedico = hijo->GetChildren(); hijosMedico != NULL; hijosMedico = hijosMedico->GetNext()) {
 				if(hijosMedico->GetName().CmpNoCase(wxT("name")) == 0) {
 					if(hijosMedico->GetChildren() != NULL){
-						modelo->Medico.nombre = hijosMedico->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_NAME, std::string(hijosMedico->GetChildren()->GetContent().ToUTF8()));
 					}
 				} else if(hijosMedico->GetName().CmpNoCase(wxT("first-surname")) == 0) {
 					if(hijosMedico->GetChildren() != NULL){
-						modelo->Medico.apellido1 = hijosMedico->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_FAMILY_NAME, std::string(hijosMedico->GetChildren()->GetContent().ToUTF8()));
 					}
 				} else if(hijosMedico->GetName().CmpNoCase(wxT("second-surname")) == 0) {
 					if(hijosMedico->GetChildren() != NULL){
-						modelo->Medico.apellido2 = hijosMedico->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_SECOND_FAMILY_NAME, std::string(hijosMedico->GetChildren()->GetContent().ToUTF8()));
 					}
 				} else if(hijosMedico->GetName().CmpNoCase(wxT("id")) == 0) {
 					std::string codigo(propVal.ToUTF8());
@@ -404,27 +396,29 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 						codigo =  propVal.ToUTF8();
 					}
 					else {
-						throw HL7XMLException(_Std("\"code\" attribute expected at \"physician\" scope"), xpp, "CONF/template");
+						throw IntegrationException(_Std("\"code\" attribute expected at \"physician\" scope"), xpp, "CONF/template");
 					}
 					propVal = hijosMedico->GetPropVal(wxT("value"), wxEmptyString);
 					if ( !propVal.empty() ) {
 						valor =  propVal.ToUTF8();
 					}
 					else {
-						throw HL7XMLException(_Std("\"value\" attribute expected at \"physician\" scope"), xpp, "CONF/template");
+						throw IntegrationException(_Std("\"value\" attribute expected at \"physician\" scope"), xpp, "CONF/template");
+					}
+					if (!modelo->GlobalVariables.Contains(GKDI_REFERRING_PHISICIAN_ID)) {
+						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_ID, valor);
 					}
-					modelo->Medico.listaIdentificadores.push_back(IModeloIdentificador(codigo,valor));
 				} else if(hijosMedico->GetName() == wxT("institution")) {
 					propVal = hijosMedico->GetPropVal(wxT("iid"), wxEmptyString);
 					if ( !propVal.empty() ) {
-						modelo->Medico.idCentro =  propVal.ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_INSTITUTION_ID, std::string(propVal.ToUTF8()));
 					}
 					else {
-						throw HL7XMLException(_Std("\"iid\" atribute expected at \"institution\" scope"), xpp, "CONF/template");
+						throw IntegrationException(_Std("\"iid\" atribute expected at \"institution\" scope"), xpp, "CONF/template");
 					}
 
 					if(hijosMedico->GetChildren() != NULL){
-						modelo->Medico.nombreCentro = hijosMedico->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_INSTITUTION_NAME, std::string(hijosMedico->GetChildren()->GetContent().ToUTF8()));
 					}
 				}
 			}
@@ -433,10 +427,10 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 		if(hijo->GetName().CmpNoCase(wxT("hce")) == 0) {
 			propVal = hijo->GetPropVal(wxT("aid"), wxEmptyString);
 			if ( !propVal.empty() ) {
-				modelo->HCE.Sid =  propVal.ToUTF8();
+				modelo->GlobalVariables.InsertVariable(GKDI_HCE_ID, std::string(propVal.ToUTF8()));
 			}
 			else {
-				throw HL7XMLException(_Std("\"aid\" attribute expected at \"hce\" scope"), xpp, "CONF/template");
+				throw IntegrationException(_Std("\"aid\" attribute expected at \"hce\" scope"), xpp, "CONF/template");
 			}
 		}
 
@@ -450,14 +444,14 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 			if ( !propVal.empty() ) {
 				codigo = propVal.Upper().ToUTF8();
 			}else {
-				throw HL7XMLException(_Std("\"code\" attribute expected at \"metadata\" scope"), xpp, "CONF/template");
+				throw IntegrationException(_Std("\"code\" attribute expected at \"metadata\" scope"), xpp, "CONF/template");
 			}
 
 			propVal = hijo->GetPropVal(wxT("key"), wxEmptyString);
 			if ( !propVal.empty() ) {
 				clave = propVal.Lower().ToUTF8();
 			}else {
-				throw HL7XMLException(_Std("\"key\" attribute expected at \"metadata\" scope"), xpp, "CONF/template");
+				throw IntegrationException(_Std("\"key\" attribute expected at \"metadata\" scope"), xpp, "CONF/template");
 			}
 
 			propVal = hijo->GetPropVal(wxT("value"), wxEmptyString);
@@ -470,56 +464,84 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 				descripcion = propVal.ToUTF8();
 			}
 
-			IModeloTupla tupla(codigo,clave, valor,descripcion);
-			modelo->Metadatos.push_back(tupla);
+			if (codigo == "DICOM") {
+				modelo->TagsDICOMOverwrite.tags[clave] = valor;
+			} else {
+				modelo->GlobalVariables.InsertVariable(clave, valor, descripcion);
+			}
 		}
 
 		if (hijo->GetName().CmpNoCase(wxT("observations")) == 0) {
 			if(hijo->GetChildren() != NULL) {
-				modelo->observaciones = hijo->GetChildren()->GetContent().ToUTF8();
+				modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_OBSERVATIONS, std::string(hijo->GetChildren()->GetContent().ToUTF8()));
+			}
+		}
+
+		if (hijo->GetName().CmpNoCase(wxT("message_template")) == 0) {
+			if(hijo->GetChildren() != NULL) {
+				modelo->messageTemplate = std::string(hijo->GetChildren()->GetContent().ToUTF8());
 			}
 		}
 	}//fin hijos gnkworkflow
-	if (modelo->accion == GIL::IModeloIntegracion::TA_Obtener && modelo->Paciente.listaIdentificadores.size() != 0)
-	{
-		modelo->Metadatos.push_back(IModeloTupla("DICOM","0010|0020", modelo->Paciente.GetIdentificadorPreferido().valor,""));
-	}
+
+	//insert tags dicom...
 	if (modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
-		if (modelo->idAmbitoPeticion == "") {
-			throw HL7XMLException(_Std("\"scope\" attribute expected at \"gnkworkflow\" scope"), xpp, "CONF/template");
+		//only overwrite en dicomize no en obtain....
+		if (modelo->GlobalVariables.Contains(GKDI_PATIENT_ID)) {
+			modelo->TagsDICOMOverwrite.tags["0010|0020"] = modelo->GlobalVariables.GetValue(GKDI_PATIENT_ID);
 		}
-		if (modelo->idPeticion == "") {
-			throw HL7XMLException(_Std("\"petition-id\" attribute expected at \"gnkworkflow\" scope"), xpp, "CONF/template");
+		if (modelo->GlobalVariables.Contains(GKDI_PATIENT_NAME)) {
+			std::ostringstream ostr;
+			ostr << modelo->GlobalVariables.GetValue(GKDI_PATIENT_FAMILY_NAME);
+			if (modelo->GlobalVariables.Contains(GKDI_PATIENT_SECOND_FAMILY_NAME)) {
+				ostr << " " << modelo->GlobalVariables.GetValue(GKDI_PATIENT_SECOND_FAMILY_NAME);
+			}
+			ostr << "^" << modelo->GlobalVariables.GetValue(GKDI_PATIENT_NAME);
+			modelo->TagsDICOMOverwrite.tags["0010|0010"] = ostr.str();
 		}
-		if(modelo->Medico.listaIdentificadores.size() == 0) {
-			throw HL7XMLException(_Std("It has been read a \"medico\" tag without identifiers"), xpp, "CONF/template");
+		if (modelo->GlobalVariables.Contains(GKDI_REFERRING_PHISICIAN_NAME)) {
+			std::ostringstream ostr;
+			ostr << modelo->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_FAMILY_NAME);
+			if (modelo->GlobalVariables.Contains(GKDI_REFERRING_PHISICIAN_SECOND_FAMILY_NAME)) {
+				ostr << " " << modelo->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_SECOND_FAMILY_NAME);
+			}
+			ostr << "^" << modelo->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_NAME);
+			modelo->TagsDICOMOverwrite.tags["0008|0090"] = ostr.str();
+		}
+		if (modelo->GlobalVariables.Contains(GKDI_REFERRING_PHISICIAN_INSTITUTION_NAME)) {
+			modelo->TagsDICOMOverwrite.tags["0008|0080"] = modelo->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_INSTITUTION_NAME);
+		}
+		if (!modelo->GlobalVariables.Contains(GKDI_HCE_PETITION_ID)) {
+			throw IntegrationException(_Std("\"petition-id\" attribute expected at \"gnkworkflow\" scope"), xpp, "CONF/template");
 		}
 	} else if (modelo->accion == GIL::IModeloIntegracion::TA_Obtener) {
-		if (modelo->Metadatos.size() == 0) {
-			throw HL7XMLException(_Std("You must specify attributes you want to use in the query"), xpp, "CONF/template");
+		if (modelo->TagsDICOMOverwrite.tags.empty()) {
+			throw IntegrationException(_Std("You must specify attributes you want to use in the query"), xpp, "CONF/template");
 		}
 	}
-	if(modelo->HCE.Sid == "") {
-		throw HL7XMLException(_Std("id_application expected"), xpp, "CONF/template");
+	if(!modelo->GlobalVariables.Contains(GKDI_HCE_ID)) {
+		throw IntegrationException(_Std("id_application expected"), xpp, "CONF/template");
 	}
-	if(modelo->Paciente.listaIdentificadores.size() == 0 && modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
-		throw HL7XMLException(_Std("It has been read a \"patient\" tag without identifiers"), xpp, "CONF/template");
+	if (!modelo->GlobalVariables.Contains(GKDI_PATIENT_ID) && modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
+		throw IntegrationException(_Std("It has been read a \"patient\" tag without identifiers"), xpp, "CONF/template");
 	}
 	//se pone el codigo de aplicacion y el primer PACS de la configuracion si no nos ha venido  ninguno
-	modelo->CodigoAplicacion = codigoAplicacion;
+	std::string codigoAplicacion;
+	GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE","CodigoAplicacion", codigoAplicacion);
+	modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_APPLICATION_CODE, codigoAplicacion);
 	if(servers.size() > 0) {
 		DicomServer* pServer = DicomServerList::Instance()->GetDefaultServer();
-		if (modelo->PACSObtencion.size() == 0 && pServer != NULL) {
-			modelo->PACSObtencion = pServer->ID;
+		if (!modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_STORE_SID) && pServer != NULL) {
+			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_STORE_SID, pServer->ID);
 		}
-		if (modelo->PACSAlmacenamiento.size() == 0 && pServer != NULL) {
-			modelo->PACSAlmacenamiento = pServer->ID;
+		if (!modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_RETRIEVE_SID) && pServer != NULL) {
+			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_RETRIEVE_SID, pServer->ID);
 		}
 	}
-	if ( (modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar && modelo->PACSAlmacenamiento.size() == 0) || 
-		(modelo->accion == GIL::IModeloIntegracion::TA_Obtener && modelo->PACSObtencion.size() == 0) ) 
+	if ( (modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar && !modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_STORE_SID)) || 
+		(modelo->accion == GIL::IModeloIntegracion::TA_Obtener && !modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_RETRIEVE_SID)) ) 
 	{
-		throw HL7XMLException(_Std("You must define a default PACS in the integration XML or in the settings menu"), xpp, "CONF/template");
+		throw IntegrationException(_Std("You must define a default PACS in the integration XML or in the settings menu"), xpp, "CONF/template");
 	}
 	return modelo;
 }
