@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: parserxmlspanish.cpp 4477 2011-12-13 11:16:56Z tovar $
+ *  $Id: parserxmlspanish.cpp 4670 2012-02-08 07:11:51Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -33,9 +33,8 @@
 #include "parserxmlspanish.h"
 #include <api/globals.h>
 #include <api/imodelohl7.h>
+#include <api/integration/dict.h>
 #include <api/icontroladormodulo.h>
-#include <api/icontroladorhl7.h>
-#include <api/iguiasmensajeriasacyl.h>
 #include <api/aetwildcards.h>
 #include <main/controllers/controladorextensiones.h>
 #include <main/controllers/controladorlog.h>
@@ -43,17 +42,17 @@
 #include "dcmtk/dicomservers.h"
 
 //creacion de la base de datos de mensajes
-GIL::HL7::ParserXMLSpanish::ParserXMLSpanish()
+GIL::ParserXMLSpanish::ParserXMLSpanish()
 {
 }
 
-GIL::HL7::ParserXMLSpanish::~ParserXMLSpanish()
+GIL::ParserXMLSpanish::~ParserXMLSpanish()
 {
 }
 
 //region "Interfaz generica"
 
-std::list<std::string> GIL::HL7::ParserXMLSpanish::GetKeys()
+std::list<std::string> GIL::ParserXMLSpanish::GetKeys()
 {
 	std::list<std::string> list;
 	list.push_back("getcontextresult");
@@ -62,7 +61,7 @@ std::list<std::string> GIL::HL7::ParserXMLSpanish::GetKeys()
 }
 
 /* Parsea la cadena XML y construye el modelo de integracion. Los parametros no encontrados se asignan por defecto segun lo especificado en la configuracion global */
-void GIL::HL7::ParserXMLSpanish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaModelosIntegracion& models, wxXmlNode* pRoot) 
+void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& models, wxXmlNode* pRoot) 
 {
 	MapaServers servers;
 	std::string xpp; // XML Pretty Printed for extended information info.
@@ -90,7 +89,7 @@ void GIL::HL7::ParserXMLSpanish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 					pacsServer.sid = propVal.ToUTF8();
 				}
 				else {
-					throw HL7XMLException(_Std("Omitted Identificator"), xpp, "CONF/pacs");
+					throw IntegrationException(_Std("Omitted Identificator"), xpp, "CONF/pacs");
 				}
 
 				propVal = nodo->GetPropVal(wxT("aet"), wxEmptyString);
@@ -98,7 +97,7 @@ void GIL::HL7::ParserXMLSpanish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 					pacsServer.AET = propVal.ToUTF8();
 				}
 				else {
-					throw HL7XMLException(_Std("Omitted AET"), xpp, "CONF/pacs");
+					throw IntegrationException(_Std("Omitted AET"), xpp, "CONF/pacs");
 				}
 
 				propVal = nodo->GetPropVal(wxT("hostname"), wxEmptyString);
@@ -106,7 +105,7 @@ void GIL::HL7::ParserXMLSpanish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 					pacsServer.hostname = propVal.ToUTF8();
 				}
 				else {
-					throw HL7XMLException(_Std("Hostname missing"), xpp, "CONF/pacs");
+					throw IntegrationException(_Std("Hostname missing"), xpp, "CONF/pacs");
 				}
 
 				propVal = nodo->GetPropVal(wxT("puerto"), wxEmptyString);
@@ -114,7 +113,7 @@ void GIL::HL7::ParserXMLSpanish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 					pacsServer.puerto = propVal.ToUTF8();
 				}
 				else {
-					throw HL7XMLException(_Std("Omitted port"), xpp, "CONF/pacs");
+					throw IntegrationException(_Std("Omitted port"), xpp, "CONF/pacs");
 				}
 				
 				propVal = nodo->GetPropVal(wxT("tls"), wxEmptyString);
@@ -184,13 +183,13 @@ void GIL::HL7::ParserXMLSpanish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 					long puerto;
 					long pdu;
 					if(!wxString::FromUTF8(pacsServer.pdu.c_str()).ToLong(&pdu)) {
-						throw HL7XMLException(_Std("The pdu size is not a valid number"), xpp, "CONF/pacs");
+						throw IntegrationException(_Std("The pdu size is not a valid number"), xpp, "CONF/pacs");
 					}
 					server->PDU = pdu;
 					if(wxString::FromUTF8(pacsServer.puerto.c_str()).ToLong(&puerto)) {
 						server->Port = puerto;
 					} else {
-						throw HL7XMLException(_Std("Port is not a valid number"), xpp, "CONF/pacs");
+						throw IntegrationException(_Std("Port is not a valid number"), xpp, "CONF/pacs");
 					}
 					if (pacsServer.metodo == GIL::IModeloPACSServer::IMPS_GET) {
 						server->retrieveWithMove = false;
@@ -215,12 +214,12 @@ void GIL::HL7::ParserXMLSpanish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 					long puerto;
 					long pdu;
 					if(!wxString::FromUTF8(pacsServer.pdu.c_str()).ToLong(&pdu)) {
-						throw HL7XMLException(_Std("The pdu size is not a valid number"), xpp, "CONF/pacs");
+						throw IntegrationException(_Std("The pdu size is not a valid number"), xpp, "CONF/pacs");
 					}
 					if(wxString::FromUTF8(pacsServer.puerto.c_str()).ToLong(&puerto)) {
 						DicomServerList::Instance()->AddServer( DicomServer(pacsServer.sid, pacsServer.AET, pacsServer.hostname, (int)puerto, 0, true, pdu, pacsServer.tls, pacsServer.user, pacsServer.password, pacsServer.metodo == GIL::IModeloPACSServer::IMPS_MOVE, wxString::FromUTF8(pacsServer.retrieveLevel.c_str()).Upper() == wxT("SERIES"), false, pacsServer.verify, pacsServer.cert, pacsServer.key), true );
 					} else {
-						throw HL7XMLException(_Std("The port is not a valid number"), xpp, "CONF/pacs");
+						throw IntegrationException(_Std("The port is not a valid number"), xpp, "CONF/pacs");
 					}
 				}
 			}
@@ -238,11 +237,11 @@ void GIL::HL7::ParserXMLSpanish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 		GIL::IModeloIntegracion* modelo = ParsePlantilla(pRoot, servers);
 		models.push_back(modelo);
 	} else {
-		throw HL7XMLException(_Std("Setting not found"), xpp, "CONF");
+		throw IntegrationException(_Std("Setting not found"), xpp, "CONF");
 	}
 }
 
-GIL::IModeloIntegracion* GIL::HL7::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo, MapaServers& servers)
+GIL::IModeloIntegracion* GIL::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo, MapaServers& servers)
 {
 	std::string codigoAplicacion;
 	//se extrae de la configuracion el codigo de aplicacion
@@ -282,46 +281,40 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLSpanish::ParsePlantilla(wxXmlNode* n
 			modelo->accion = GIL::IModeloIntegracion::TA_Imprimir;
 		}
 		else {
-			throw HL7XMLException(_Std("\"accion\" attribute invalid at \"plantilla\" scope" ), xpp, "CONF/template");
+			throw IntegrationException(_Std("\"accion\" attribute invalid at \"plantilla\" scope" ), xpp, "CONF/template");
 		}
 	}
 	else {
-		throw HL7XMLException(_Std("\"accion\" attribute expected at \"plantilla\" scope"), xpp, "CONF/template");
+		throw IntegrationException(_Std("\"accion\" attribute expected at \"plantilla\" scope"), xpp, "CONF/template");
 	}
 
 	propVal = nodo->GetPropVal(wxT("id_peticion"), wxEmptyString);
 	if( !propVal.empty() ) {
-		modelo->idPeticion = propVal.ToUTF8();
-	}
-	else {
-		throw HL7XMLException(_Std("\"id_peticion\" attribute expected at \"plantilla\" scope"), xpp, "CONF/template");
+		modelo->GlobalVariables.InsertVariable(GKDI_HCE_PETITION_ID, std::string(propVal.ToUTF8()), "Id de peticion");
 	}
 
 	propVal = nodo->GetPropVal(wxT("ambito"), wxEmptyString);
 	if( !propVal.empty() ) {
-		modelo->idAmbitoPeticion = propVal.ToUTF8();
-	}
-	else {
-		throw HL7XMLException(_Std("\"ambito\" attribute expected at \"plantilla\" scope"), xpp, "CONF/template");
+		modelo->GlobalVariables.InsertVariable(GKDI_JIMENA_AMBITO_PETICION, std::string(propVal.ToUTF8()), "Ambito de la peticion");		
 	}
 
 	if( nodo->HasProp(wxT("pacs_retrieve_sid")) ) {
 		propVal = nodo->GetPropVal(wxT("pacs_retrieve_sid"), wxEmptyString);
 		if (!propVal.IsEmpty()) {
-			modelo->PACSObtencion = propVal.ToUTF8();
+			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_RETRIEVE_SID, std::string(propVal.ToUTF8()), "String Id del pacs de obtencion");
 		}
 		else {
-			throw HL7XMLException(_Std("\"pacs_retrieve_sid\" attribute empty at \"plantilla\" scope"), xpp, "CONF/template");
+			throw IntegrationException(_Std("\"pacs_retrieve_sid\" attribute empty at \"plantilla\" scope"), xpp, "CONF/template");
 		}					
 	}
 
 	if( nodo->HasProp(wxT("pacs_store_sid")) ) {
 		propVal = nodo->GetPropVal(wxT("pacs_store_sid"), wxEmptyString);
 		if (!propVal.IsEmpty()) {
-			modelo->PACSAlmacenamiento = propVal.ToUTF8();
+			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_STORE_SID, std::string(propVal.ToUTF8()), "String Id del pacs de almacenamiento");
 		}
 		else {
-			throw HL7XMLException(_Std("\"pacs_store_sid\" attribute empty at \"plantilla\" scope"), xpp, "CONF/template");
+			throw IntegrationException(_Std("\"pacs_store_sid\" attribute empty at \"plantilla\" scope"), xpp, "CONF/template");
 		}					
 	}
 
@@ -338,35 +331,36 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLSpanish::ParsePlantilla(wxXmlNode* n
 			else {
 				uid = "";
 				if(modelo->accion != GIL::IModeloIntegracion::TA_Dicomizar) {
-					throw HL7XMLException(_Std("\"uid\" attribute expected at \"dimse\" scope"), xpp, "CONF/template");
+					throw IntegrationException(_Std("\"uid\" attribute expected at \"dimse\" scope"), xpp, "CONF/template");
 				}
 			}
 
 			propVal = hijo->GetPropVal(wxT("ambito"), wxEmptyString).Lower();
 			if ( !propVal.empty() ) {
 				if (propVal.CmpNoCase(wxT("study")) == 0){
-					modelo->ambitoDIMSE = "STUDY";
+					modelo->TagsDICOMOverwrite.tags["0008|0052"] = "STUDY";
 					//study instance uid
-					modelo->Metadatos.push_back(IModeloTupla("DICOM","0020|000d", uid,""));
+					modelo->TagsDICOMOverwrite.tags["0020|000d"] = uid;
 				}
 				else if (propVal.CmpNoCase(wxT("series")) == 0) {
-					modelo->ambitoDIMSE = "SERIES";
+					modelo->TagsDICOMOverwrite.tags["0008|0052"] = "SERIES";
 					//series instance uid
-					modelo->Metadatos.push_back(IModeloTupla("DICOM","0020|000e", uid,""));
+					modelo->TagsDICOMOverwrite.tags["0020|000e"] = uid;
 				}
 				else if (propVal.CmpNoCase(wxT("image")) == 0) {
+					modelo->TagsDICOMOverwrite.tags["0008|0052"] = "IMAGE";
+					//sop instance
+					modelo->TagsDICOMOverwrite.tags["0008|0018"] = uid;
 					//sop instance uid
-					modelo->Metadatos.push_back(IModeloTupla("DICOM","0008|0018", uid,""));
-					modelo->ambitoDIMSE = "IMAGE";
 				}
 				else {
-					throw HL7XMLException(_Std("\"ambito\" attribute invalid at \"dimse\" scope"), xpp, "CONF/template");
+					throw IntegrationException(_Std("\"ambito\" attribute invalid at \"dimse\" scope"), xpp, "CONF/template");
 				}
 			}
 			else {
-				modelo->ambitoDIMSE = "STUDY";
+				modelo->TagsDICOMOverwrite.tags["0020|000d"] = "STUDY";
 				if(modelo->accion != GIL::IModeloIntegracion::TA_Dicomizar) {
-					throw HL7XMLException(_Std("\"ambito\" attribute expected at \"dimse\" scope"), xpp, "CONF/template");
+					throw IntegrationException(_Std("\"ambito\" attribute expected at \"dimse\" scope"), xpp, "CONF/template");
 				}
 			}
 			
@@ -377,19 +371,19 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLSpanish::ParsePlantilla(wxXmlNode* n
 			for (wxXmlNode* hijosPaciente = hijo->GetChildren(); hijosPaciente != NULL; hijosPaciente = hijosPaciente->GetNext()) {
 				if(hijosPaciente->GetName().CmpNoCase(wxT("nombre")) == 0) {
 					if(hijosPaciente->GetChildren() != NULL){
-						modelo->Paciente.nombre = hijosPaciente->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_PATIENT_NAME,  std::string(hijosPaciente->GetChildren()->GetContent().ToUTF8()), "Patient Name");
 					}
 				} else if(hijosPaciente->GetName().CmpNoCase(wxT("apellido1")) == 0) {
 					if(hijosPaciente->GetChildren() != NULL){
-						modelo->Paciente.apellido1 = hijosPaciente->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_PATIENT_FAMILY_NAME,  std::string(hijosPaciente->GetChildren()->GetContent().ToUTF8()), "Patient Surname");
 					}
 				} else if(hijosPaciente->GetName().CmpNoCase(wxT("apellido2")) == 0) {
 					if(hijosPaciente->GetChildren() != NULL){
-						modelo->Paciente.apellido2 = hijosPaciente->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_PATIENT_SECOND_FAMILY_NAME,  std::string(hijosPaciente->GetChildren()->GetContent().ToUTF8()), "Patient Second Surname");
 					}
 				} else if(hijosPaciente->GetName().CmpNoCase(wxT("numero_episodio")) == 0) {
 					if(hijosPaciente->GetChildren() != NULL){
-						modelo->Paciente.numEpisodio = hijosPaciente->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_HCE_EPISODE_NUMBER,  std::string(hijosPaciente->GetChildren()->GetContent().ToUTF8()), "Episode Number");
 					}
 				}else if(hijosPaciente->GetName().CmpNoCase(wxT("id")) == 0) {
 					std::string codigo(propVal.ToUTF8());
@@ -399,12 +393,14 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLSpanish::ParsePlantilla(wxXmlNode* n
 						codigo =  propVal.ToUTF8();
 					}
 					else {
-						throw HL7Exception(_Std("\"codigo\" attribute expected at \"paciente\" scope"), xpp, "CONF/template");
+						throw IntegrationException(_Std("\"codigo\" attribute expected at \"paciente\" scope"), xpp, "CONF/template");
 					}
 					propVal = hijosPaciente->GetPropVal(wxT("valor"), wxEmptyString);
 					if ( !propVal.empty() ) {
 						valor =  propVal.ToUTF8();
-						modelo->Paciente.listaIdentificadores.push_back(IModeloIdentificador(codigo,valor));
+						if (!modelo->GlobalVariables.Contains(GKDI_PATIENT_ID) || codigo=="PI") {
+							modelo->GlobalVariables.InsertVariable(GKDI_PATIENT_ID,  valor, "Patient Id");
+						}
 					}								
 				}
 			}
@@ -415,15 +411,15 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLSpanish::ParsePlantilla(wxXmlNode* n
 			for (wxXmlNode* hijosMedico = hijo->GetChildren(); hijosMedico != NULL; hijosMedico = hijosMedico->GetNext()) {
 				if(hijosMedico->GetName().CmpNoCase(wxT("nombre")) == 0) {
 					if(hijosMedico->GetChildren() != NULL){
-						modelo->Medico.nombre = hijosMedico->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_NAME,  std::string(hijosMedico->GetChildren()->GetContent().ToUTF8()), "Referring Physician Name");
 					}
 				} else if(hijosMedico->GetName().CmpNoCase(wxT("apellido1")) == 0) {
 					if(hijosMedico->GetChildren() != NULL){
-						modelo->Medico.apellido1 = hijosMedico->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_FAMILY_NAME,  std::string(hijosMedico->GetChildren()->GetContent().ToUTF8()), "Referring Physician Family Name");
 					}
 				} else if(hijosMedico->GetName().CmpNoCase(wxT("apellido2")) == 0) {
 					if(hijosMedico->GetChildren() != NULL){
-						modelo->Medico.apellido2 = hijosMedico->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_SECOND_FAMILY_NAME,  std::string(hijosMedico->GetChildren()->GetContent().ToUTF8()), "Referring Physician Second Family Name");
 					}
 				} else if(hijosMedico->GetName().CmpNoCase(wxT("id")) == 0) {
 					std::string codigo(propVal.ToUTF8());
@@ -433,27 +429,29 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLSpanish::ParsePlantilla(wxXmlNode* n
 						codigo =  propVal.ToUTF8();
 					}
 					else {
-						throw HL7XMLException(_Std("\"codigo\" attribute expected at \"medico\" scope"), xpp, "CONF/template");
+						throw IntegrationException(_Std("\"codigo\" attribute expected at \"medico\" scope"), xpp, "CONF/template");
 					}
-					propVal = hijosMedico->GetPropVal(wxT("valor"), wxEmptyString);
+					propVal = hijosMedico->GetPropVal(wxT("valor"), wxEmptyString);					
 					if ( !propVal.empty() ) {
 						valor =  propVal.ToUTF8();
 					}
 					else {
-						throw HL7XMLException(_Std("\"valor\" attribute expected at \"medico\" scope"), xpp, "CONF/template");
+						throw IntegrationException(_Std("\"valor\" attribute expected at \"medico\" scope"), xpp, "CONF/template");
+					}
+					if (!modelo->GlobalVariables.Contains(GKDI_REFERRING_PHISICIAN_ID) || codigo=="NNESP") {
+						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_ID,  valor, "Referring Physician Id");
 					}
-					modelo->Medico.listaIdentificadores.push_back(IModeloIdentificador(codigo,valor));
 				} else if(hijosMedico->GetName().CmpNoCase(wxT("centro")) == 0) {
 					propVal = hijosMedico->GetPropVal(wxT("cid"), wxEmptyString);
 					if ( !propVal.empty() ) {
-						modelo->Medico.idCentro =  propVal.ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_INSTITUTION_ID, std::string(propVal.ToUTF8()));
 					}
 					else {
-						throw HL7XMLException(_Std("\"cid\" atribute expected at \"centro\" scope"), xpp, "CONF/template");
+						throw IntegrationException(_Std("\"cid\" atribute expected at \"centro\" scope"), xpp, "CONF/template");
 					}
 
 					if(hijosMedico->GetChildren() != NULL){
-						modelo->Medico.nombreCentro = hijosMedico->GetChildren()->GetContent().ToUTF8();
+						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_INSTITUTION_NAME, std::string(hijosMedico->GetChildren()->GetContent().ToUTF8()));
 					}
 				}
 			}
@@ -462,10 +460,10 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLSpanish::ParsePlantilla(wxXmlNode* n
 		if(hijo->GetName().CmpNoCase(wxT("hce")) == 0) {
 			propVal = hijo->GetPropVal(wxT("aid"), wxEmptyString);
 			if ( !propVal.empty() ) {
-				modelo->HCE.Sid =  propVal.ToUTF8();
+				modelo->GlobalVariables.InsertVariable(GKDI_HCE_ID, std::string(propVal.ToUTF8()));
 			}
 			else {
-				throw HL7XMLException(_Std("\"aid\" attribute expected at \"hce\" scope"), xpp, "CONF/template");
+				throw IntegrationException(_Std("\"aid\" attribute expected at \"hce\" scope"), xpp, "CONF/template");
 			}
 		}
 
@@ -477,19 +475,20 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLSpanish::ParsePlantilla(wxXmlNode* n
 
 			propVal = hijo->GetPropVal(wxT("codigo"), wxEmptyString);
 			if ( !propVal.empty() ) {
-				codigo = propVal.ToUTF8();
+				codigo = propVal.Upper().ToUTF8();
 			}else {
-				throw HL7XMLException(_Std("\"codigo\" attribute expected at \"metadato\" scope"), xpp, "CONF/template");
+				throw IntegrationException(_Std("\"codigo\" attribute expected at \"metadato\" scope"), xpp, "CONF/template");
 			}
 
 			propVal = hijo->GetPropVal(wxT("clave"), wxEmptyString);
 			if ( !propVal.empty() ) {
-				clave = propVal.ToUTF8();
+				clave = propVal.Lower().ToUTF8();
 			}else {
-				throw HL7XMLException(_Std("\"clave\" attribute expected at \"metadato\" scope"), xpp, "CONF/template");
+				throw IntegrationException(_Std("\"clave\" attribute expected at \"metadato\" scope"), xpp, "CONF/template");
 			}
 
 			propVal = hijo->GetPropVal(wxT("valor"), wxEmptyString);
+
 			if ( !propVal.empty() ) {
 				valor = propVal.ToUTF8();
 			}
@@ -499,49 +498,78 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLSpanish::ParsePlantilla(wxXmlNode* n
 				descripcion = propVal.ToUTF8();
 			}
 
-			IModeloTupla tupla(codigo,clave, valor,descripcion);
-			modelo->Metadatos.push_back(tupla);
+			if (codigo == "DICOM") {
+				modelo->TagsDICOMOverwrite.tags[clave] = valor;
+			} else {
+				modelo->GlobalVariables.InsertVariable(clave, valor, descripcion);
+			}
 		}
 
 		if (hijo->GetName().CmpNoCase(wxT("observaciones")) == 0) {
 			if(hijo->GetChildren() != NULL) {
-				modelo->observaciones = hijo->GetChildren()->GetContent().ToUTF8();
+				modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_OBSERVATIONS, std::string(hijo->GetChildren()->GetContent().ToUTF8()));
 			}
 		}
 	}//fin hijos plantilla
-	if (modelo->accion == GIL::IModeloIntegracion::TA_Obtener && modelo->Paciente.listaIdentificadores.size() != 0)
-	{
-		modelo->Metadatos.push_back(IModeloTupla("DICOM","0010|0020", modelo->Paciente.GetIdentificadorPreferido().valor,""));
+//insert tags dicom...
+	if (modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
+		//solo se sobreescribe en dicomizacion
+		if (!modelo->GlobalVariables.Contains(GKDI_HCE_PETITION_ID)) {
+			throw IntegrationException(_Std("\"id_peticion\" attribute expected at \"gnkworkflow\" scope"), xpp, "CONF/template");
+		}
+		if (!modelo->GlobalVariables.Contains(GKDI_JIMENA_AMBITO_PETICION)) {
+			throw IntegrationException(_Std("\"ambito\" attribute expected at \"plantilla\" scope"), xpp, "CONF/template");
+		}
+		if (modelo->GlobalVariables.Contains(GKDI_PATIENT_ID)) {
+			modelo->TagsDICOMOverwrite.tags["0010|0020"] = modelo->GlobalVariables.GetValue(GKDI_PATIENT_ID);
+		}
+		if (modelo->GlobalVariables.Contains(GKDI_PATIENT_NAME)) {
+			std::ostringstream ostr;
+			ostr << modelo->GlobalVariables.GetValue(GKDI_PATIENT_FAMILY_NAME);
+			if (modelo->GlobalVariables.Contains(GKDI_PATIENT_SECOND_FAMILY_NAME)) {
+				ostr << " " << modelo->GlobalVariables.GetValue(GKDI_PATIENT_SECOND_FAMILY_NAME);
+			}
+			ostr << "^" << modelo->GlobalVariables.GetValue(GKDI_PATIENT_NAME);
+			modelo->TagsDICOMOverwrite.tags["0010|0010"] = ostr.str();
+		}
+		if (modelo->GlobalVariables.Contains(GKDI_REFERRING_PHISICIAN_NAME)) {
+			std::ostringstream ostr;
+			ostr << modelo->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_FAMILY_NAME);
+			if (modelo->GlobalVariables.Contains(GKDI_REFERRING_PHISICIAN_SECOND_FAMILY_NAME)) {
+				ostr << " " << modelo->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_SECOND_FAMILY_NAME);
+			}
+			ostr << "^" << modelo->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_NAME);
+			modelo->TagsDICOMOverwrite.tags["0008|0090"] = ostr.str();
+		}
+		if (modelo->GlobalVariables.Contains(GKDI_REFERRING_PHISICIAN_INSTITUTION_NAME)) {
+			modelo->TagsDICOMOverwrite.tags["0008|0080"] = modelo->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_INSTITUTION_NAME);
+		}
+	} else if (modelo->accion == GIL::IModeloIntegracion::TA_Obtener) {
+		if (modelo->TagsDICOMOverwrite.tags.empty()) {
+			throw IntegrationException(_Std("You must specify attributes you want to use in the query"), xpp, "CONF/template");
+		}
 	}
-	if(modelo->HCE.Sid == "") {
-		throw HL7XMLException(_Std("id_application expected"), xpp, "CONF/template");
+	if(!modelo->GlobalVariables.Contains(GKDI_HCE_ID)) {
+		throw IntegrationException(_Std("id_application expected"), xpp, "CONF/template");
 	}
-	if(modelo->Medico.listaIdentificadores.size() == 0) {
-		throw HL7XMLException(_Std("It has been read a \"medico\" tag without identifiers"), xpp, "CONF/template");
+	if (!modelo->GlobalVariables.Contains(GKDI_PATIENT_ID) && modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
+		throw IntegrationException(_Std("It has been read a \"patient\" tag without identifiers"), xpp, "CONF/template");
 	}
-	if(modelo->Paciente.listaIdentificadores.size() == 0 && modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
-		throw HL7XMLException(_Std("It has been read a \"paciente\" tag without identifiers"), xpp, "CONF/template");
-	}
-	/*
-	if(modelo->Paciente.numEpisodio.size() == 0) {
-		throw HL7Exception(_Std("It has been read a \"paciente\" tag without episode number"), "CONF/template");
-	}
-	*/
 	//se pone el codigo de aplicacion y el primer PACS de la configuracion si no nos ha venido  ninguno
-	modelo->CodigoAplicacion = codigoAplicacion;
+	modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_APPLICATION_CODE, codigoAplicacion);
 	if(servers.size() > 0) {
 		DicomServer* pServer = DicomServerList::Instance()->GetDefaultServer();
-		if (modelo->PACSObtencion.size() == 0 && pServer != NULL) {
-			modelo->PACSObtencion = pServer->ID;
+		if (!modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_STORE_SID) && pServer != NULL) {
+			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_STORE_SID, pServer->ID);
 		}
-		if (modelo->PACSAlmacenamiento.size() == 0 && pServer != NULL) {
-			modelo->PACSAlmacenamiento = pServer->ID;
+		if (!modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_RETRIEVE_SID) && pServer != NULL) {
+			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_RETRIEVE_SID, pServer->ID);
 		}
 	}
-	if ( (modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar && modelo->PACSAlmacenamiento.size() == 0) || 
-		(modelo->accion == GIL::IModeloIntegracion::TA_Obtener && modelo->PACSObtencion.size() == 0) ) 
+	if ( (modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar && !modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_STORE_SID)) || 
+		(modelo->accion == GIL::IModeloIntegracion::TA_Obtener && !modelo->GlobalVariables.Contains(GKDI_GLOBAL_PACS_RETRIEVE_SID)) ) 
 	{
-		throw HL7XMLException(_Std("You must define a default PACS in the integration XML or in the settings menu"), xpp, "CONF/template");
+		throw IntegrationException(_Std("You must define a default PACS in the integration XML or in the settings menu"), xpp, "CONF/template");
 	}
 	return modelo;
 }
