@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: streamingloader.cpp 4438 2011-11-22 14:24:34Z tovar $
+ *  $Id: streamingloader.cpp 4682 2012-02-09 14:25:47Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -594,6 +594,23 @@ void GNC::StreamingLoader::GetOutputDimensions(unsigned int currentDimensions[3]
 	}
 }
 
+bool GNC::StreamingLoader::GetDefaultWindowLevel(double &window, double &level)
+{
+	std::string windowTag, levelTag;
+	bool ok = m_IO->GetValueFromTag("0028|1050", levelTag) && m_IO->GetValueFromTag("0028|1051", windowTag);
+	if (ok) {
+		{
+			std::istringstream istr(levelTag);
+			istr >> level;	
+		}
+		{
+			std::istringstream istr(windowTag);
+			istr >> window;	
+		}		
+	}
+	return ok;	
+}
+
 void GNC::StreamingLoader::GetDirection(double cosines[9])
 {
 	for (int i = 0; i < 9; i++)
