@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: xmlrpccontroller.cpp 4477 2011-12-13 11:16:56Z tovar $
+*  $Id: xmlrpccontroller.cpp 4682 2012-02-09 14:25:47Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -16,6 +16,8 @@
 #include <wx/filename.h>
 #include <wx/dir.h>
 #include <main/controllers/configurationcontroller.h>
+#include <api/integration/dict.h>
+#include <main/controllers/integrationcontroller.h>
 #include <wx/wxsqlite3/wxsqlite3.h>
 
 #include "xmlrpccontroller.h"
@@ -32,8 +34,9 @@
 #include <main/gui/import/wxwizardimportacionginkgo.h>
 #include "controladorcomandos.h"
 #include "controladoreventos.h"
+#include <main/controllers/controladorhistorial.h>
 #include <eventos/eventosginkgo.h>
-#include "controladorhl7.h"
+#include "integrationcontroller.h"
 #include <xmlrpc/XmlRpc.h>
 #include <commands/comandopacs.h>
 #include <api/icontextoestudio.h>
@@ -174,7 +177,7 @@ namespace XmlRpc {
 
 		virtual void Update()
 		{
-			GNC::Entorno::Instance()->RefrescarDicomDir();
+			GNC::GCS::ControladorHistorial::Instance()->RecargarHistorial();
 			GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GUI::Eventos::EventoRecargarHistorial());
 		}
 	};
@@ -375,67 +378,57 @@ namespace XmlRpc {
 
 		void execute(XmlRpcValue& params, XmlRpcValue& result)
 		{
-			GnkPtr<GIL::IModeloIntegracion> pModelo(new GIL::IModeloIntegracion());
+			GnkPtr<GIL::IModeloIntegracion> integrationModel(new GIL::IModeloIntegracion());
 			//general info
-			pModelo->PACSAlmacenamiento = std::string(params[0]["pacsStoreSid"]);
-			pModelo->idPlantilla = std::string(params[0]["Pid"]);
-			pModelo->idPeticion = std::string(params[0]["PetitionId"]);
+			integrationModel->accion = GIL::IModeloIntegracion::TA_Dicomizar;
+			integrationModel->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_STORE_SID,  std::string(params[0]["pacsStoreSid"]));
+			integrationModel->idPlantilla = std::string(params[0]["Pid"]);
 			//patient info
-			pModelo->Paciente.nombre = std::string(params[0]["Patient"]["Name"]);
-			pModelo->Paciente.apellido1 = std::string(params[0]["Patient"]["FirstSurname"]);
-			pModelo->Paciente.apellido2 = std::string(params[0]["Patient"]["SecondSurname"]);
-			pModelo->Paciente.numEpisodio = std::string(params[0]["Patient"]["EpisodeNumber"]);
-			pModelo->Paciente.listaIdentificadores.push_back(GIL::IModeloIdentificador(std::string(params[0]["Patient"]["IdCode"]), std::string(params[0]["Patient"]["IdValue"])));
+			integrationModel->GlobalVariables.InsertVariable(GKDI_PATIENT_ID, std::string(params[0]["Patient"]["IdValue"]));
+			integrationModel->GlobalVariables.InsertVariable(GKDI_PATIENT_NAME, std::string(params[0]["Patient"]["Name"]));
+			integrationModel->GlobalVariables.InsertVariable(GKDI_PATIENT_FAMILY_NAME, std::string(params[0]["Patient"]["FirstSurname"]));
+			integrationModel->GlobalVariables.InsertVariable(GKDI_PATIENT_SECOND_FAMILY_NAME, std::string(params[0]["Patient"]["SecondSurname"]));
+			integrationModel->GlobalVariables.InsertVariable(GKDI_HCE_EPISODE_NUMBER, std::string(params[0]["Patient"]["EpisodeNumber"]));
 			//physician info
-			pModelo->Medico.nombre = std::string(params[0]["Physician"]["Name"]);
-			pModelo->Medico.apellido1 = std::string(params[0]["Physician"]["FirstSurname"]);
-			pModelo->Medico.apellido2 = std::string(params[0]["Physician"]["SecondSurname"]);
-			pModelo->Medico.idCentro = std::string(params[0]["Physician"]["IdCenter"]);
-			pModelo->Medico.nombreCentro = std::string(params[0]["Physician"]["CenterName"]);
-			pModelo->Medico.listaIdentificadores.push_back(GIL::IModeloIdentificador(std::string(params[0]["Physician"]["IdCode"]), std::string(params[0]["Physician"]["IdValue"])));
-			//HCE
-			pModelo->HCE.Sid = std::string(params[0]["HCE"]["AID"]);
+			integrationModel->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_ID, std::string(params[0]["Physician"]["IdValue"]));
+			integrationModel->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_NAME, std::string(params[0]["Physician"]["Name"]));
+			integrationModel->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_FAMILY_NAME, std::string(params[0]["Physician"]["FirstSurname"]));			
+			integrationModel->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_SECOND_FAMILY_NAME, std::string(params[0]["Physician"]["SecondSurname"]));
+			integrationModel->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_INSTITUTION_ID, std::string(params[0]["Physician"]["IdCenter"]));
+			integrationModel->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_INSTITUTION_NAME, std::string(params[0]["Physician"]["CenterName"]));
+			//hce
+			integrationModel->GlobalVariables.InsertVariable(GKDI_HCE_ID, std::string(params[0]["HCE"]["AID"]));
 
-			if(pModelo->HCE.Sid == "") {
-				LOG_ERROR(LOGGER,_Std("id_application expected"));
+			//insert dicom...
+			//insert tags dicom...
+			if (integrationModel->GlobalVariables.Contains(GKDI_PATIENT_ID)) {
+				integrationModel->TagsDICOMOverwrite.tags["0010|0020"] = integrationModel->GlobalVariables.GetValue(GKDI_PATIENT_ID);
 			}
-			if(pModelo->Medico.listaIdentificadores.size() == 0) {
-				LOG_ERROR(LOGGER,_Std("It has been read a \"medico\" tag without identifiers"));
-			}
-			if(pModelo->Paciente.listaIdentificadores.size() == 0 && pModelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
-				LOG_ERROR(LOGGER,_Std("It has been read a \"paciente\" tag without identifiers"));
-			}
-			std::string codigoAplicacion;
-			//se extrae de la configuracion el codigo de aplicacion
-			GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE","CodigoAplicacion", pModelo->CodigoAplicacion);
-
-			try {
-				GIL::HL7::ControladorHL7 controlador;
-				std::string uidModulo = controlador.GetUID(pModelo->idPlantilla);
-				pModelo->UIDModulo = uidModulo;
-				if (GNC::ControladorExtensiones::Instance()->ObtenerModulo(uidModulo) == NULL) {
-					LOG_ERROR(LOGGER,"No existe el modulo asociado");
-					result["error"] = -1;
-					return;
+			if (integrationModel->GlobalVariables.Contains(GKDI_PATIENT_NAME)) {
+				std::ostringstream ostr;
+				ostr << integrationModel->GlobalVariables.GetValue(GKDI_PATIENT_FAMILY_NAME);
+				if (integrationModel->GlobalVariables.Contains(GKDI_PATIENT_SECOND_FAMILY_NAME)) {
+					ostr << " " << integrationModel->GlobalVariables.GetValue(GKDI_PATIENT_SECOND_FAMILY_NAME);
 				}
-				GNC::GCS::ControladorComandos::Instance()->ProcessAsync(_Std("Closing windows..."), new LaunchDicomizationCommand(uidModulo,pModelo), NULL);
-			}catch(GIL::DICOM::I2DException& i){
-				LOG_ERROR("GIL/WF/Importar", (const std::string)i);
-				result["error"] = -1;
-				return;
+				ostr << "^" << integrationModel->GlobalVariables.GetValue(GKDI_PATIENT_NAME);
+				integrationModel->TagsDICOMOverwrite.tags["0010|0010"] = ostr.str();
 			}
-			catch(std::exception& ex1){
-				LOG_ERROR("GIL/WF/Importar", std::string("Error al importar: ") + ex1.what());
-				result["error"] = -1;
-				return;
+			if (integrationModel->GlobalVariables.Contains(GKDI_REFERRING_PHISICIAN_NAME)) {
+				std::ostringstream ostr;
+				ostr << integrationModel->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_FAMILY_NAME);
+				if (integrationModel->GlobalVariables.Contains(GKDI_REFERRING_PHISICIAN_SECOND_FAMILY_NAME)) {
+					ostr << " " << integrationModel->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_SECOND_FAMILY_NAME);
+				}
+				ostr << "^" << integrationModel->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_NAME);
+				integrationModel->TagsDICOMOverwrite.tags["0008|0090"] = ostr.str();
 			}
-			catch (...)
-			{
-				LOG_ERROR("GIL/WF/Importar", std::string("Error al importar: Error interno"));
-				result["error"] = -1;
-				return;
+			if (integrationModel->GlobalVariables.Contains(GKDI_REFERRING_PHISICIAN_INSTITUTION_NAME)) {
+				integrationModel->TagsDICOMOverwrite.tags["0008|0080"] = integrationModel->GlobalVariables.GetValue(GKDI_REFERRING_PHISICIAN_INSTITUTION_NAME);
 			}
 
+			GIL::IntegrationModelList list;
+			list.push_back(integrationModel);
+			GIL::IntegrationController::Instance()->Process(list);
 
 			result["error"] = 0;
 		}
