@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: entorno.cpp 4508 2012-01-11 12:53:39Z tovar $
+ *  $Id: entorno.cpp 4716 2012-02-17 09:20:53Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -21,7 +21,6 @@
 #include <main/licencia.h>
 
 #include <api/icontextoestudio.h>
-#include <api/imodelointegracion.h>
 #include <api/aetwildcards.h>
 
 #include <main/controllers/pacscontroller.h>
@@ -36,6 +35,7 @@
 #include <main/controllers/controladorhistorial.h>
 #include <main/controllers/controladoracciones.h>
 #include <main/controllers/controladorinternacionalizacion.h>
+#include <main/controllers/integrationcontroller.h>
 #include <main/managers/widgetsmanager.h>
 
 
@@ -48,6 +48,18 @@
 
 // Definicion de variables static
 #define GINKGO_LOCALAET    "GINKGO_%IP4"
+#define GINKGO_MENSAJE_LICENCIA "This is a open source Ginkgo CADx Framework build. MetaEmotion S.L does not provide support so eximes from all responsabilities derived from its usage.\n\nWARRANTY DISCLAIMER\n\n" \
+	"The software, procedures, information and data made available by MetaEmotion S.L. under current conditions are provided \"AS IS\", without warranties of any kind except for contracted services, in which cases the specific contract conditions will be applied.\n" \
+	"MetaEmotion S.L. expressly disclaims any representations and warranties, including without limitation, the implied warranties of merchantability and fitness for a particular purpose.\n\n" \
+	"MetaEmotion S.L. shall have no liability for:\n" \
+    " * Any loss or injury caused, in whole or in part, by its actions, omissions, or negligence, or for contingencies beyond its control, in procuring, compiling, or delivering the Information or\n" \
+    " * Any errors, omissions, or inaccuracies in the Information regardless of how caused, or delays or interruptions in delivery of the Information; or\n" \
+	" * Any decision made or action taken or not taken in reliance upon the Information furnished hereunder.\n\n" \
+	"Under no circumstances shall the authors be liable for direct, indirect, special, incidental, consequential damages or misdiagnosis\n" \
+    "resulting from the use, misuse, or inability to use the software, even if the authors have been advised of the possibility of such damages.\n" \
+	"This software musn't be sold without prior approval of the authors.\n" \
+	"\nThe user assumes the entire risk of using this program as well as conditions above."\
+	"\nGinkgo CADx is licensed under the LGPL v3 license. You can find the legal terms of the license at http://www.gnu.org/copyleft/lgpl.html"
 
 //helper
 bool RemoveTempDir(const wxString& dirPath)
@@ -68,6 +80,11 @@ bool RemoveTempDir(const wxString& dirPath)
 						cont = dir.GetNext(&fileName);
 					}
 				}else{
+					#ifdef _WIN32
+					_chmod(TOPATH(fileName), _S_IWRITE);
+					#else 
+					chmod(TOPATH(fileName), 0644);
+					#endif
 					if (wxRemoveFile(fileName)) {
 						cont = dir.GetFirst(&fileName);
 					} else {
@@ -102,6 +119,7 @@ GNC::Entorno::Entorno()
 	m_pPanelHerramientasSuperior = NULL;
 	m_pSizerHerramientas = NULL;
 	m_pSizerOpcionesHerramientas = NULL;
+	m_GinkgoLicenseMessage = GINKGO_MENSAJE_LICENCIA;
 	
 	m_isChildInstance = false;
 	
@@ -188,14 +206,12 @@ GNC::Entorno::Entorno()
 		m_Ubicaciones[title] = GIL::Ubicacion(title, path, descr, monitorize, cleanbefore, cleanafter);
 	}
 
-	// Refrescar Dicom dir
-
-	RefrescarDicomDir();
-
+	GIL::IntegrationController::Instance();
 }
 
 GNC::Entorno::~Entorno()
 {
+	GIL::IntegrationController::FreeInstance();
 	DJEncoderRegistration::cleanup();
 	DJDecoderRegistration::cleanup();
 
@@ -210,14 +226,12 @@ GNC::Entorno::~Entorno()
 		RemoveTempDir(FROMPATH(m_GinkgoTempDir));	
 	}
 
-	m_ModelosIntegracion.clear();
 	m_pApp = NULL;
 	m_pVentanaPrincipal = NULL;
 	m_pVentanaRaiz = NULL;
 	m_pPanelHerramientasSuperior = NULL;
 	m_pSizerHerramientas = NULL;
 	m_pSizerOpcionesHerramientas = NULL;
-
 }
 
 GNC::Entorno* GNC::Entorno::Instance()
@@ -236,16 +250,6 @@ void GNC::Entorno::FreeInstance()
 	m_pInstancia = NULL;
 }
 
-const std::string GNC::Entorno::GetGinkgoRegisteredUser()
-{
-	return GINKGO_REGISTERED_USER;
-}
-
-const std::string GNC::Entorno::GetGinkgoRegisteredOrganization()
-{
-	return GINKGO_REGISTERED_ORGANIZATION;
-}
-
 const std::string& GNC::Entorno::GetGinkgoVersion()
 {
 	return m_GinkgoVersion;
@@ -275,6 +279,16 @@ const std::string& GNC::Entorno::GetGinkgoCopyRight()
 	return m_GinkgoCopyRight;
 }
 
+const std::string& GNC::Entorno::GetLicenseMessage()
+{
+	return m_GinkgoLicenseMessage;
+}
+
+void GNC::Entorno::SetLicenseMessage(const std::string& license)
+{
+	m_GinkgoLicenseMessage = license;
+}
+
 int GNC::Entorno::ParseSVNBuild(const char* str)
 {
 	int num = -1;
@@ -285,44 +299,7 @@ int GNC::Entorno::ParseSVNBuild(const char* str)
 	return num;
 }
 
-std::string GNC::Entorno::GetGinkgoDicomDir(bool barraAlFinal)
-{
-	if(barraAlFinal) {
-		std::ostringstream out;
-		out << m_GinkgoDicomDir << (char) wxFileName::GetPathSeparator(wxPATH_NATIVE);
-		return out.str();
-	} else {
-		return m_GinkgoDicomDir;
-	}
-}
 
-void GNC::Entorno::RefrescarDicomDir()
-{
-	std::string value;
-	
-	if(!GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Estacion", "DicomDir", value))
-	{
-		std::ostringstream out;
-		out << GetGinkgoUserDir() << (char) wxFileName::GetPathSeparator(wxPATH_NATIVE) << "DICOMDIR";
-		m_GinkgoDicomDir = out.str();
-	} else {
-		m_GinkgoDicomDir = value;
-	}
-}
-
-std::string GNC::Entorno::GetPathAbsolutoFichero(const std::string& pathRelativo)
-{
-	std::ostringstream out;
-	out << GetGinkgoDicomDir(true) << pathRelativo;
-	return out.str();
-}
-
-std::string GNC::Entorno::GetPathRelativoFichero(const std::string& pathAbsoluto)
-{
-	wxFileName fileName(FROMPATH(pathAbsoluto));
-	fileName.MakeRelativeTo(FROMPATH(GetGinkgoDicomDir()));
-	return std::string(TOPATH(fileName.GetFullPath()));
-}
 
 const std::string& GNC::Entorno::GetGinkgoTempDir()
 {
@@ -348,7 +325,9 @@ std::string GNC::Entorno::CreateGinkgoTempDir()
 void GNC::Entorno::RemoveDirRecursive(const std::string& path)
 {
 	wxString pathWx = FROMPATH(path);
-	RemoveTempDir(pathWx);
+	if (wxDirExists(pathWx)) {
+		RemoveTempDir(pathWx);
+	}
 }
 
 std::string GNC::Entorno::CreateGinkgoTempFile()
