@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: entorno.h 4508 2012-01-11 12:53:39Z tovar $
+ *  $Id: entorno.h 4682 2012-02-09 14:25:47Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -62,19 +62,13 @@ namespace GNC {
 
 		// Miembros estaticos
 
-		virtual const std::string GetGinkgoRegisteredUser();
-		virtual const std::string GetGinkgoRegisteredOrganization();
 
 		virtual const std::string& GetGinkgoVersion();
 		virtual void GetGinkgoVersionAsTuple(int* version, int* subversion, int* release, int* build, std::string* codename);
+		virtual const std::string& GetLicenseMessage();
+		virtual void SetLicenseMessage(const std::string& license);
 		virtual const std::string& GetGinkgoCopyRight();
 		virtual int ParseSVNBuild(const char* str);
-		virtual std::string GetGinkgoDicomDir(bool barraAlFinal = false);
-		virtual void RefrescarDicomDir();
-
-		virtual std::string GetPathAbsolutoFichero(const std::string& pathRelativo);
-		virtual std::string GetPathRelativoFichero(const std::string& pathAbsoluto);
-
 		virtual const std::string& GetPluginsPath();
 		virtual const std::string& GetGinkgoUserDir();
 		virtual const std::string& GetGinkgoTempDir();
@@ -136,8 +130,6 @@ namespace GNC {
 		virtual GNC::GCS::IWidgetsManager* NewWidgetsManager(GNC::GCS::IVista* pVista);
 		virtual void FreeWidgetsManager(GNC::GCS::IWidgetsManager* pManager);
 
-		virtual GNC::GCS::IEntorno::ListaModelosIntegracion& GetModelosIntegracion() { return m_ModelosIntegracion; }
-
 		virtual GNC::GCS::IEntorno::MapaUbicaciones& GetUbicaciones() { return m_Ubicaciones; }
 
 	private:
@@ -146,11 +138,9 @@ namespace GNC {
 		std::string m_GinkgoPluginsDir;
 		std::string m_GinkgoUserDir;
 		std::string m_GinkgoTempDir;
-		std::string m_GinkgoDicomDir;
 		std::string m_GinkgoLanguageDir;
 		std::string m_GinkgoResourcesDir;
-
-		GNC::GCS::IEntorno::ListaModelosIntegracion m_pModelosIntegracion;
+		std::string m_GinkgoLicenseMessage;
 
 		wxApp* m_pApp;
 		VentanaPrincipal* m_pVentanaPrincipal;
