@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: dialogoadquisicion.cpp 4477 2011-12-13 11:16:56Z tovar $
+*  $Id: dialogoadquisicion.cpp 4639 2012-01-31 14:42:25Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -73,6 +73,7 @@ GNC::GUI::DialogoAdquisicion* GNC::GUI::DialogoAdquisicion::m_pInstance = NULL;
 
 GNC::GUI::DialogoAdquisicion::DialogoAdquisicion(wxWindow* pParent) : DialogoAdquisicionBase(pParent)
 {
+	m_reverseOrder = true;
 	m_pComandoPACS = NULL;
 	m_pImageList = new wxImageList(SIZE_ICONOS,SIZE_ICONOS,true);
 	m_Mode = TD_SERIES;
@@ -98,6 +99,7 @@ GNC::GUI::DialogoAdquisicion::DialogoAdquisicion(wxWindow* pParent) : DialogoAdq
 	m_pTreeListResultados->Connect(wxEVT_COMMAND_TREE_ITEM_MENU, wxTreeEventHandler( DialogoAdquisicion::OnTreeItemMenu ), NULL, this);
 	m_pTreeListResultados->Connect(wxEVT_COMMAND_TREE_ITEM_EXPANDED, wxTreeEventHandler( DialogoAdquisicion::OnTreeItemExpanded ), NULL, this);
 	m_pTreeListResultados->Connect(wxEVT_COMMAND_TREE_BEGIN_DRAG, wxTreeEventHandler( DialogoAdquisicion::OnTreeBeginDrag ), NULL, this);
+	m_pTreeListResultados->Connect(wxEVT_COMMAND_LIST_COL_CLICK, wxListEventHandler( DialogoAdquisicion::OnClickColumnHeader), NULL, this);
 
 	m_pDownloadPanel = new DownloadElementContainerPanel(m_pZonaDescargas);
 	m_pZonaDescargas->GetSizer()->Add(m_pDownloadPanel, 1, wxEXPAND|wxALL, 5);
@@ -637,6 +639,13 @@ void GNC::GUI::DialogoAdquisicion::OnTreeBeginDrag(wxTreeEvent& )
 	}
 }
 
+void GNC::GUI::DialogoAdquisicion::OnClickColumnHeader(wxListEvent& event)
+{
+	int column = event.GetColumn();
+	m_reverseOrder = !m_reverseOrder;
+	m_pTreeListResultados->SortChildren(m_pTreeListResultados->GetRootItem(), column, m_reverseOrder);
+}
+
 std::string GNC::GUI::DialogoAdquisicion::GetServerSeleccionado()
 {
 	std::string id;
