@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: dialogoadquisicion.h 4072 2011-08-10 13:45:52Z tovar $
+ *  $Id: dialogoadquisicion.h 4639 2012-01-31 14:42:25Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -44,8 +44,9 @@ namespace GNC {
 
 				DialogoAdquisicion(wxWindow* pParent);
 				~DialogoAdquisicion();
-
+				
 				virtual bool Show(bool show = true);
+				virtual bool Show(const std::string& idPatient, const std::string& idPACS);
 
 			//---------------------------------------------------------------------------
 			//region Eventos de interfaz
@@ -54,6 +55,7 @@ namespace GNC {
 				virtual void OnFechaDesdeDateChanged( wxDateEvent& event );
 				virtual void OnFechaHastaDateChanged( wxDateEvent& event );
 				virtual void OnBusquedaClick( wxCommandEvent& event );
+				virtual void Search();
 				virtual void OnCancelClick( wxCommandEvent& event);
 				std::string GetModalities();
 				virtual void OnLimpiarClick( wxCommandEvent& event );
@@ -65,6 +67,7 @@ namespace GNC {
 				virtual void OnTreeItemMenu(wxTreeEvent& event);
 				virtual void OnTreeItemExpanded(wxTreeEvent& event);
 				virtual void OnTreeBeginDrag(wxTreeEvent& event);
+				virtual void OnClickColumnHeader(wxListEvent& event);
 			
 			//---------------------------------------------------------------------------
 			//region Helpers
@@ -101,11 +104,9 @@ namespace GNC {
 
 				DownloadElementContainerPanel* m_pDownloadPanel;
 
-				std::string m_HardCodedPatientId;
-				bool        m_HardCodedPatientSearch;
-
 				bool        m_SizeRestriction;
 				bool        m_SizeOK;
+				bool			m_reverseOrder;
 
 				bool         m_AutoAddSeries;     // Indica que se auto-anyadiran a las descargas todas las series del proximo despliegue
 				wxTreeItemId m_AutoAddSeriesItem; // Elemento desplegado sobre el que se auto-anyadira
