@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: downloadelementcontainerpanel.h 4076 2011-08-11 06:37:52Z carlos $
+ *  $Id: downloadelementcontainerpanel.h 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -28,7 +28,7 @@ namespace GNC {
 			~DownloadElementContainerPanel();
 
 			bool FindDownload(const std::string& uid);
-			bool AddDownload(const std::string& s, const std::string& pd,const std::string& sd, const std::string& su, const std::string& sm, bool initIfStopped, bool seriesMode);
+			bool AddDownload(const std::string& s, const std::string& pd,const std::string& sd, const std::string& sm, bool initIfStopped, bool seriesMode, const std::string& studyUID, const std::string& seriesUID);
 			void RemoveDownload(DownloadElementPanel* de);
 
 		protected:
