@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguracionestacion.h 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: panelconfiguracionestacion.h 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -39,10 +39,6 @@ namespace GNC {
 
 				bool Guardar();
 
-				void Exportar(wxXmlNode* pNodo);
-
-				void Importar(wxXmlNode* pNodo);
-
 				//endregion
 
 
