@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguracionextensiones.cpp 4369 2011-11-04 11:55:00Z tovar $
+ *  $Id: panelconfiguracionextensiones.cpp 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -184,13 +184,6 @@ namespace GNC {
 			return true;
 		}
 
-		void PanelConfiguracionExtensiones::Exportar(wxXmlNode* /*pNodo*/)
-		{
-		}
-
-		void PanelConfiguracionExtensiones::Importar(wxXmlNode* /*pNodo*/)
-		{
-		}
 		//endregion
 
 		void PanelConfiguracionExtensiones::OnPropiedadCambiada(){
