@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguracionextensiones.h 4072 2011-08-10 13:45:52Z tovar $
+ *  $Id: panelconfiguracionextensiones.h 4477 2011-12-13 11:16:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -38,10 +38,6 @@ namespace GNC {
 				bool Validar();
 
 				bool Guardar();
-
-				void Exportar(wxXmlNode* pNodo);
-
-				void Importar(wxXmlNode* pNodo);
 				//endregion
 
 				virtual void OnPropiedadCambiada();
