@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguracionpacs.cpp 4477 2011-12-13 11:16:56Z tovar $
+ *  $Id: panelconfiguracionpacs.cpp 4803 2012-03-30 12:21:24Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -479,7 +479,7 @@ namespace GNC {
 							as.SetUserPass(std::string(m_pUser->GetValue().ToUTF8()), std::string(m_pPassword->GetValue().ToUTF8()));
 						}
 						CONDITION cond;
-						wxBusyInfo* info = new wxBusyInfo(_("Testing the connection to the server ..."));
+						wxBusyInfo* info = new wxBusyInfo(_("Testing the connection to the node ..."));
 						
 						std::string aet(m_pAET->GetValue().ToUTF8());
 						std::string host(m_pHost->GetValue().ToUTF8());
@@ -550,7 +550,7 @@ namespace GNC {
 		PanelConfiguracionPACS::PanelConfiguracionPACS(wxWindow* pParent,IDialogoConfiguracion* pDialogo): PanelConfiguracionPACSBase(pParent), IPasoConfiguracion(pDialogo)
 		{
 			this->m_pTreeListPACS->AddColumn(_("Name"), 200, wxALIGN_LEFT, -1, true, false);
-			this->m_pTreeListPACS->AddColumn(_("Default PACS"), 70, wxALIGN_LEFT, -1, true, false);
+			this->m_pTreeListPACS->AddColumn(_("Use by default"), 70, wxALIGN_LEFT, -1, true, false);
 			Recargar();
 			
 			m_pHelpBitmap->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoHelp());
@@ -650,12 +650,12 @@ namespace GNC {
 
 		std::string PanelConfiguracionPACS::GetTitle()
 		{
-			return _Std("PACS Servers");
+			return _Std("DICOM nodes");
 		}
 
 		std::string PanelConfiguracionPACS::GetCabecera()
 		{
-			return _Std("PACS Server Settings");
+			return _Std("DICOM nodes settings");
 		}
 
 		bool PanelConfiguracionPACS::Validar()
@@ -823,7 +823,7 @@ namespace GNC {
 			wxTreeItemId itemSeleccionado = m_pTreeListPACS->GetSelection();
 			if(itemSeleccionado.IsOk()){
 				std::string idSeleccionado(m_pTreeListPACS->GetItemText(itemSeleccionado).ToUTF8());
-				int answer = wxMessageBox(_("Confirm the removal of the server") + wxString::FromUTF8(idSeleccionado.c_str()), _("Data modified"), wxYES_NO | wxCANCEL, this);
+				int answer = wxMessageBox(_("Confirm the removal of the node") + wxString::FromUTF8(idSeleccionado.c_str()), _("Data modified"), wxYES_NO | wxCANCEL, this);
 				if(answer == wxYES){
 					for(TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); it++){
 						if((*it).id == idSeleccionado){
@@ -878,7 +878,7 @@ namespace GNC {
 			wxSize oldSize = m_staticTextExplicacion->GetSize();
 			Freeze();
 			m_staticTextExplicacion->Freeze();
-			m_staticTextExplicacion->SetLabel(_("You must configure the local AET, which is used to communicate with the PACS server. The specified port must be opened in the firewall, as it is essential for transfers."));
+			m_staticTextExplicacion->SetLabel(_("You must configure the local AET, which is used to communicate with the DICOM nodes. The specified port must be opened in the firewall, as it is essential for transfers."));
 			m_staticTextExplicacion->Wrap( event.GetSize().x-25 );
 			m_staticTextExplicacion->Thaw();
 			//Layout();
