@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelconfiguracionpermisos.cpp 4477 2011-12-13 11:16:56Z tovar $
+ *  $Id: panelconfiguracionpermisos.cpp 4782 2012-03-08 11:01:25Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -28,7 +28,9 @@
 #include <wx/log.h>
 #include <wx/busyinfo.h>
 #include <wx/xml/xml.h>
+#include <wx/sstream.h>
 #include <wx/log.h>
+#include <wx/menu.h>
 
 #include <wx/tokenzr.h>
 
@@ -40,9 +42,17 @@
 #include <main/controllers/controladorlog.h>
 #include <main/controllers/controladorpermisos.h>
 #include <main/entorno.h>
+#include <resources/ginkgoresourcemanager.h>
 
 #define SEPARADOR "|"
 
+#define COL_NAME			  0
+#define COL_VALUE			  1
+#define COL_DEFAULT_VALUE 2
+
+#define COLOUR_ACTIVE wxColour(10,174,10)
+#define COLOUR_INACTIVE wxColour(174,10,10)
+#define COLOUR_SET_BY_USER wxColour(229,137,39)
 
 namespace GNC {
 	namespace GUI {
@@ -96,16 +106,13 @@ namespace GNC {
 
 				const GNC::GCS::ControladorPermisos::TipoMapaDefiniciones& definiciones = GNC::GCS::ControladorPermisos::Instance()->GetMapaDefiniciones();
 
-				//bool defaultValue = GNC::GCS::ControladorPermisos::Instance()->GetDefaultPermiso();
 				//cargamos los permisos "publicos" definidos
 				std::string ultimaCategoria = "";
 				wxPGProperty* cat = NULL;
-				m_gridPermisos->SetColumnCount(4);
-				m_gridPermisos->MakeColumnEditable(2, true);
-				m_gridPermisos->SetColumnProportion(0, 3);
-				m_gridPermisos->SetColumnProportion(1, 1);
-				m_gridPermisos->SetColumnProportion(2, 2);
-				m_gridPermisos->SetColumnProportion(3, 2);
+				m_gridPermisos->SetColumnCount(3);
+				m_gridPermisos->SetColumnProportion(COL_NAME, 3);
+				m_gridPermisos->SetColumnProportion(COL_VALUE, 4);
+				m_gridPermisos->SetColumnProportion(COL_DEFAULT_VALUE, 2);
 				for(GNC::GCS::ControladorPermisos::TipoMapaDefiniciones::const_iterator it = definiciones.begin(); it != definiciones.end(); ++it)
 				{
 					if(!(*it).second.privado) {
@@ -114,11 +121,16 @@ namespace GNC {
 							cat = m_gridPermisos->Append(new wxPropertyCategory(wxString::FromUTF8((*it).second.descripcionNamespace.c_str()),wxString::FromUTF8(ultimaCategoria.c_str())));
 						}
 						std::string clave = (*it).second.espacioNombres + SEPARADOR + (*it).second.id;
-						wxPGProperty* prop = cat->AppendChild(new wxBoolProperty(wxString::FromUTF8((*it).second.descripcion.c_str()), wxString::FromUTF8(clave.c_str()), (*it).second.activoPorDefecto ) );
-						prop->SetCell(2, new wxPGCell( wxString::FromUTF8( ((*it).second.valorPorDefecto).c_str())) );
-						prop->SetCell(3, new wxPGCell( _("Default value") ));
+						wxLongStringProperty* propValue = new wxLongStringProperty(wxString::FromUTF8((*it).second.descripcion.c_str()), wxString::FromUTF8(clave.c_str()), wxString::FromUTF8((*it).second.valorPorDefecto.c_str()));
+						wxPGProperty* prop = cat->AppendChild(propValue);
+						prop->SetCell(COL_DEFAULT_VALUE, new wxPGCell( _("Default value") ));
+						SetPropertyActive(prop, (*it).second.activoPorDefecto);
 					}
 				}
+
+				m_gridPermisos->GetRoot()->SetFlagRecursively(wxPG_PROP_NO_ESCAPE, true);
+				m_gridPermisos->Connect(wxEVT_PG_DOUBLE_CLICK, wxPropertyGridEventHandler( ProfileDialog::OnPgDoubleClick ), NULL, this );
+				m_gridPermisos->Connect(wxEVT_PG_RIGHT_CLICK, wxPropertyGridEventHandler( ProfileDialog::OnPgMenu ), NULL, this );
 			}
 
 			~ProfileDialog()
@@ -130,14 +142,14 @@ namespace GNC {
 			{
 				nombre = std::string(m_pName->GetValue().ToUTF8());
 
-				//transformamos lo que esta viendo el usuario a un xml...
-				std::ostringstream ostr;
-				ostr << "<?xml version=\"1.0\"?>\n";
-				ostr << "<permisos>\n";
+				wxXmlDocument doc;
+				wxXmlNode* root = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("permisos"));
+				doc.SetRoot(root);
 
+				//transformamos lo que esta viendo el usuario a un xml...
 				for(wxPropertyGridIterator it = m_gridPermisos->GetIterator(); !it.AtEnd(); it.Next())
 				{
-					wxBoolProperty* pProperty = (wxBoolProperty*) it.GetProperty();
+					wxPGProperty* pProperty = it.GetProperty();
 
 					wxString clave = pProperty->GetName();
 
@@ -157,13 +169,15 @@ namespace GNC {
 						std::string stdclave( espacioNombres + "." + id );
 
 						std::string accion;
-						if (pProperty->GetValue()) {
+						
+						if (IsPropertyActive(pProperty)) {
 							accion = "activar";
 						} else {
 							accion = "desactivar";
 						}
 
-						std::string val(pProperty->GetCell(2)->GetText().ToUTF8());
+						std::string val(pProperty->GetValueAsString().ToUTF8());
+						
 						std::string activopordefecto = "true";
 
 						GNC::GCS::ControladorPermisos::TipoMapaDefiniciones mapa = GNC::GCS::ControladorPermisos::Instance()->GetMapaDefiniciones();
@@ -178,11 +192,126 @@ namespace GNC {
 							activopordefecto = "false";
 						}
 
-						ostr << "<permiso namespace=\"" << espacioNombres << "\" id=\"" << id << "\" valorpordefecto=\"" << def.valorPorDefecto << "\" activopordefecto=\"" << activopordefecto << "\" accion=\"" << accion << "\" valor=\"" << val << "\"/>" << std::endl;
+						wxXmlNode* permiso = new wxXmlNode(root, wxXML_ELEMENT_NODE, wxT("permiso"));
+						permiso->AddAttribute(wxT("id"), wxString::FromUTF8(id.c_str()));
+						permiso->AddAttribute(wxT("namespace"), wxString::FromUTF8(espacioNombres.c_str()));
+						permiso->AddAttribute(wxT("accion"), wxString::FromUTF8(accion.c_str()));
+						permiso->AddAttribute(wxT("activopordefecto"), wxString::FromUTF8(activopordefecto.c_str()));
+
+						
+						wxXmlNode* data = new wxXmlNode(permiso, wxXML_ELEMENT_NODE, wxT("default_value"));
+						data = new wxXmlNode(data, wxXML_CDATA_SECTION_NODE, wxT("default_value"));
+						data->SetContent(wxString::FromUTF8(def.valorPorDefecto.c_str()));
+
+						data = new wxXmlNode(permiso, wxXML_ELEMENT_NODE, wxT("value"));
+						data = new wxXmlNode(data, wxXML_CDATA_SECTION_NODE, wxT("value"));
+						data->SetContent(wxString::FromUTF8(val.c_str()));
+					}
+				}
+				wxMemoryOutputStream out;
+				doc.SetFileEncoding(wxT("UTF-8"));
+				doc.Save(out,0);
+				char* vectorWidgets = new char[out.GetLength()];
+				out.CopyTo(vectorWidgets,out.GetLength());
+				xml = std::string(vectorWidgets, out.GetLength());
+			}
+
+			virtual void OnPgDoubleClick(wxPropertyGridEvent &event) 
+			{
+				if (event.GetProperty() == NULL || event.GetProperty()->IsCategory()) 
+					return;
+				wxPGProperty* prop = event.GetProperty();
+				SetPropertyActive(prop, !IsPropertyActive(prop));
+			}
+
+			bool IsPropertyActive(wxPGProperty* pProp) 
+			{
+				wxColour col = pProp->GetCell(COL_NAME)->GetFgCol();
+				return col == COLOUR_ACTIVE;
+			}
+
+			void SetPropertyActive(wxPGProperty* pProp, bool value) 
+			{
+				if (value) {	
+					m_gridPermisos->SetPropertyCell(pProp->GetId(), COL_NAME, pProp->GetLabel(), GinkgoResourcesManager::IconosMenus::GetIcoTick(), COLOUR_ACTIVE);
+				} else {
+					m_gridPermisos->SetPropertyCell(pProp->GetId(), COL_NAME, pProp->GetLabel(), GinkgoResourcesManager::IconosMenus::GetIcoCross(), COLOUR_INACTIVE);
+				}
+				m_gridPermisos->RefreshProperty(pProp);
+			}
+
+			virtual void OnPgMenu(wxPropertyGridEvent &event) 
+			{
+				if (event.GetProperty() == NULL || event.GetProperty()->IsCategory()) 
+					return;
+				wxPGProperty* prop = event.GetProperty();
+				bool isActive = IsPropertyActive(prop);
+				wxMenu menu;
+				wxMenuItem* pActive = menu.Append(0, _("Active"), _("Set property active"), wxITEM_CHECK);
+				wxMenuItem* pInactive = menu.Append(1, _("Inactive"), _("Set property inactive"), wxITEM_CHECK);
+				wxMenuItem* pDefault = menu.Append(2, _("Default value"), _("Set default value"), wxITEM_NORMAL);
+				if (isActive) {
+					pActive->Check(true);
+					pInactive->Check(false);
+				} else {
+					pActive->Check(false);
+					pInactive->Check(true);
+				}
+				menu.Connect(pActive->GetId(),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ProfileDialog::OnActiveSelectedProperty ), NULL, this );
+				menu.Connect(pInactive->GetId(),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ProfileDialog::OnDesactiveSelectedProperty ), NULL, this );
+				menu.Connect(pDefault->GetId(),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ProfileDialog::OnSetDefaultSelected ), NULL, this );
+				m_gridPermisos->PopupMenu(&menu);
+			}
+
+			void OnActiveSelectedProperty(wxCommandEvent&) 
+			{
+				wxPGProperty* prop = m_gridPermisos->GetSelectedProperty();
+				if (prop != NULL) {
+					SetPropertyActive(prop, true);
+				}
+			}
+
+			void OnDesactiveSelectedProperty(wxCommandEvent&) 
+			{
+				wxPGProperty* prop = m_gridPermisos->GetSelectedProperty();
+				if (prop != NULL) {
+					SetPropertyActive(prop, false);
+				}
+			}
+
+			void OnSetDefaultSelected(wxCommandEvent&) 
+			{
+				wxPGProperty* prop = m_gridPermisos->GetSelectedProperty();
+				if (prop != NULL) {
+					wxString clave = prop->GetName();
+
+					wxStringTokenizer tkz(clave, wxString::FromUTF8(SEPARADOR));
+					std::string espacioNombres ="", id="";
+					if ( tkz.HasMoreTokens() )
+					{
+						espacioNombres = tkz.GetNextToken().ToUTF8();
+						if (tkz.HasMoreTokens()) {
+							id = tkz.GetNextToken().ToUTF8();
+						}
+					}
+					if (id != "" && espacioNombres != "") 
+					{
+						std::string stdclave( espacioNombres + "." + id );
+						std::string val(prop->GetValueAsString().ToUTF8());
+
+						GNC::GCS::ControladorPermisos::TipoMapaDefiniciones mapa = GNC::GCS::ControladorPermisos::Instance()->GetMapaDefiniciones();
+						GNC::GCS::ControladorPermisos::TipoMapaDefiniciones::iterator it = mapa.find(stdclave);
+						GNC::GCS::ControladorPermisos::TipoDefinicionPermiso def;
+
+						if (it != mapa.end()) {
+							def = (*it).second;
+						}
+
+						prop->SetValue(wxString::FromUTF8(def.valorPorDefecto.c_str()));
+						m_gridPermisos->SetPropertyCell(prop->GetId(), COL_DEFAULT_VALUE, _("Default value"), wxNullBitmap, wxNullColour);
+						SetPropertyActive(prop, def.activoPorDefecto);
 					}
 				}
-				ostr << "</permisos>\n";
-				xml = ostr.str();
 			}
 
 			void SetParametros(const std::string &nombre, const std::string &xml)
@@ -194,7 +323,7 @@ namespace GNC {
 
 				for(wxPropertyGridIterator it = m_gridPermisos->GetIterator(); !it.AtEnd(); it.Next())
 				{
-					wxBoolProperty* pProperty = dynamic_cast<wxBoolProperty*> (it.GetProperty());
+					wxPGProperty* pProperty = it.GetProperty();
 					if(pProperty != NULL) {
 
 						wxStringTokenizer tkz(pProperty->GetName(), wxString::FromUTF8(SEPARADOR));
@@ -207,20 +336,17 @@ namespace GNC {
 							}
 						}
 
-						/*
-						GNC::GCS::Permisos::EstadoPermiso perm = //GNC::GCS::ControladorPermisos::Instance()->Get(espacioNombres + "." + id);
-						pProperty->SetValue((bool)perm);
-						*/
 						TipoMapaPermisos::iterator itp = mapa.find(std::string(pProperty->GetName().ToUTF8()));
 						if (itp != mapa.end()) {
 							GNC::GCS::Permisos::EstadoPermiso& perm = (*itp).second;
-							pProperty->SetValue( (bool)perm );
-							pProperty->GetCell(2)->SetText( wxString::FromUTF8(perm.ObtenerValor<std::string>().c_str()));
+							SetPropertyActive(pProperty, perm);
+
+							pProperty->SetValue( wxString::FromUTF8(perm.GetRawValue().c_str()) );
 							if (perm.TieneValorPorDefecto()) {
-								pProperty->GetCell(3)->SetText(_("Default value"));
+								pProperty->GetCell(COL_DEFAULT_VALUE)->SetText(_("Default value"));
 							}
 							else {
-								pProperty->GetCell(3)->SetText(_("Set by user"));
+								m_gridPermisos->SetPropertyCell(pProperty->GetId(), COL_DEFAULT_VALUE, _("Set by user"), wxNullBitmap, COLOUR_SET_BY_USER);
 							}
 						}
 
@@ -244,7 +370,7 @@ namespace GNC {
 					}
 				} catch (GNC::GCS::ControladorPermisosException& ce)
 				{
-					LOG_WARN("GestionPermisos", "Existe en la configuracin un xml de permisos mal formado " << ce.GetCause());
+					LOG_WARN("GestionPermisos", "Existe en la configuración un xml de permisos mal formado " << ce.GetCause());
 				}
 				return permisos;
 			}
@@ -262,7 +388,7 @@ namespace GNC {
 
 			bool Validar() {
 				if(m_pName->GetValue() != wxEmptyString) {
-					//no puede duplicar un nombre que est en la lista y que no sea el mismo
+					//no puede duplicar un nombre que esté en la lista y que no sea el mismo
 					std::string nombre (m_pName->GetValue().ToUTF8());
 					if (nombre != m_nombreEditar) {
 						for (std::list<std::string>::iterator it = m_listaNombres.begin(); it != m_listaNombres.end(); ++it)
@@ -356,7 +482,7 @@ namespace GNC {
 		bool PanelConfiguracionPermisos::Validar()
 		{
 			bool ok = true;
-			//si modificado... los cambios se aplicarn al volver a reiniciar
+			//si modificado... los cambios se aplicarán al volver a reiniciar
 			if(m_permisosCambiados) {
 				wxMessageBox(_("Ginkgo CADx must restart for the permission changes to take effect"),_("Info"));
 			}
