@@ -268,16 +268,6 @@ namespace GNC {
 			return true;
 		}
 
-		void PanelConfiguracionSeguridad::Exportar(wxXmlNode* /*pNodo*/)
-		{
-			//no se exporta/importa nada de seguridad porque va en BBDD
-		}
-
-		void PanelConfiguracionSeguridad::Importar(wxXmlNode* /*pNodo*/)
-		{
-			//no se exporta/importa nada de seguridad porque va en BBDD
-		}
-
 		//endregion
 
 		void PanelConfiguracionSeguridad::OnSecTypeChoice(wxCommandEvent &/*event*/)
