@@ -40,10 +40,6 @@ namespace GNC {
 				bool Validar();
 
 				bool Guardar();
-
-				void Exportar(wxXmlNode* pNodo);
-
-				void Importar(wxXmlNode* pNodo);
 				//endregion
 
 
