@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: countdownmessage.h 4067 2011-08-08 08:35:48Z tovar $
+ *  $Id: countdownmessage.h 4719 2012-02-17 13:32:45Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -23,12 +23,13 @@ namespace GNC {
 		public:
 			CountdownMessage(wxWindow* pParent);
 			~CountdownMessage();
-			bool Cancel();
+			virtual bool Show(bool show=true);
 		protected:
 			virtual void OnCancel(wxCommandEvent &event);
+			virtual void OnCloseButton(wxCommandEvent &event);
+			virtual void OnClose(wxCloseEvent &event);
 			virtual void Notify();
 			int m_last;
-			bool m_cancelled;
 		};
 	}
 }
