@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: editordicom.h 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: editordicom.h 3830 2011-05-06 13:30:18Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -15,7 +15,7 @@
 #include "editordicombase.h"
 #include <api/iwizard.h>
 #include <api/ivista.h>
-#include <api/icontroladorimportacionpacs.h>
+#include <api/controllers/ipacscontroller.h>
 
 
 #include <string>
@@ -27,9 +27,9 @@ namespace GNC {
 		class EditorDICOM: public EditorDICOMBase
 		{
 			public:
-				EditorDICOM(wxWindow* pParent,std::string pathActivo, GIL::DICOM::IControladorImportacionPACS* pImportacion);
+				EditorDICOM(wxWindow* pParent,std::string pathActivo, GIL::DICOM::IPACSController* pImportacion);
 
-				EditorDICOM(wxWindow* pParent,GIL::DICOM::TipoJerarquia& base, GIL::DICOM::IControladorImportacionPACS* pImportacion);
+				EditorDICOM(wxWindow* pParent,GIL::DICOM::TipoJerarquia& base, GIL::DICOM::IPACSController* pImportacion);
 				~EditorDICOM();
 
 				void GetTagsEditados(GIL::DICOM::TipoJerarquia & base);
