@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wxwizardexportacionginkgo.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: wxwizardexportacionginkgo.cpp 4403 2011-11-14 10:59:24Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -71,13 +71,17 @@ namespace GNC {
 		{
 			IPasoWizard* currentPaso = m_ListaPasos[m_currentPasoIndex];
 			if(currentPaso->Validar()){
-				currentPaso->Detach(m_pSizerPrincipal);
-				++m_currentPasoIndex;
-				if(m_currentPasoIndex >= m_ListaPasos.size()) {
-					Close();
-					return;
-				} else {
-					CargarCurrent();
+				wxWindow* pCurrent = dynamic_cast<wxWindow*> (currentPaso);
+				if (pCurrent != NULL && (currentPaso)->Detach()) {
+					pCurrent->Hide();
+					m_pSizerPrincipal->Detach(pCurrent);
+						++m_currentPasoIndex;
+						if(m_currentPasoIndex >= m_ListaPasos.size()) {
+							Close();
+							return;
+						} else {
+							CargarCurrent();
+						}
 				}
 			}
 		}
@@ -85,23 +89,28 @@ namespace GNC {
 		void wxWidzardExportacionGinkgo::OnAnteriorClick(wxCommandEvent &)
 		{
 			if(m_currentPasoIndex!=0){
-				m_ListaPasos[m_currentPasoIndex]->Detach(m_pSizerPrincipal);
-				switch(m_currentPasoIndex){
-					case 1:
-						--m_currentPasoIndex;
-						break;
-					case 2:
-						m_currentPasoIndex=0;
-						break;
-					case 3:
-						if(m_pDatosPersistentes->m_formatoDestino == DICOM){
-							m_currentPasoIndex =1;
-						}else{
-							m_currentPasoIndex =2;
-						}
-				}
+				wxWindow* pCurrent = dynamic_cast<wxWindow*> (m_ListaPasos[m_currentPasoIndex]);
+				if (pCurrent != NULL && (m_ListaPasos[m_currentPasoIndex])->Detach()) 
+				{
+					pCurrent->Hide();
+					m_pSizerPrincipal->Detach(pCurrent);
+					switch(m_currentPasoIndex){
+						case 1:
+							--m_currentPasoIndex;
+							break;
+						case 2:
+							m_currentPasoIndex=0;
+							break;
+						case 3:
+							if(m_pDatosPersistentes->m_formatoDestino == DICOM){
+								m_currentPasoIndex =1;
+							}else{
+								m_currentPasoIndex =2;
+							}
+					}
 
-				CargarCurrent();
+					CargarCurrent();
+				}
 			}
 		}
 
@@ -112,19 +121,25 @@ namespace GNC {
 
 		void wxWidzardExportacionGinkgo::CargarCurrent(){
 			IPasoWizard* currentPaso = m_ListaPasos[m_currentPasoIndex];
-			currentPaso->Attach(m_pSizerPrincipal);
 
+			wxWindow* pCurrent = dynamic_cast<wxWindow*> (m_ListaPasos[m_currentPasoIndex]);
+			if (pCurrent != NULL && (m_ListaPasos[m_currentPasoIndex])->Attach()) 
+			{
+				pCurrent->Show(true);
+				m_pSizerPrincipal->Add(pCurrent, 10, wxEXPAND);
 
-			m_pHeader->SetTitle(wxString::FromUTF8(currentPaso->GetTitle().c_str()));
-			m_pHeader->SetSubtitle(wxString::FromUTF8(currentPaso->GetSubTitle().c_str()));
-			m_pBSiguiente->Enable(currentPaso->Siguiente());
-			m_pBAnterior->Enable(currentPaso->Anterior());
-			m_pBCerrar->Enable(currentPaso->Cancelar());
-			if(m_currentPasoIndex==m_ListaPasos.size()-1){
-				m_pBSiguiente->SetLabel(_("&Accept"));
-			}else{
-				m_pBSiguiente->SetLabel(_("&Next >"));
+				m_pHeader->SetTitle(wxString::FromUTF8(currentPaso->GetTitle().c_str()));
+				m_pHeader->SetSubtitle(wxString::FromUTF8(currentPaso->GetSubTitle().c_str()));
+				m_pBSiguiente->Enable(currentPaso->Siguiente());
+				m_pBAnterior->Enable(currentPaso->Anterior());
+				m_pBCerrar->Enable(currentPaso->Cancelar());
+				if(m_currentPasoIndex==m_ListaPasos.size()-1){
+					m_pBSiguiente->SetLabel(_("&Accept"));
+				}else{
+					m_pBSiguiente->SetLabel(_("&Next >"));
+				}
 			}
+			m_pPanelPrincipal->Layout();
 			Layout();
 		}
 	};
