@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: dialogoconfirmacioneliminar.h 3066 2010-12-21 10:10:14Z carlos $
+ *  $Id: dialogoconfirmacioneliminar.h 3995 2011-07-13 18:24:42Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -13,6 +13,7 @@
  */
 #pragma once
 #include "panelhistorial2base.h"
+#include <wx/ginkgostyle/ginkgostyle.h>
 
 //----------DIALOGO CONFIRMAR ELIMINAR...-------------
 namespace GNC {
@@ -27,8 +28,8 @@ namespace GNC {
 			DialogoConfirmacionEliminar(wxWindow* parent, const wxString& label):DialogoConfirmacionEliminarBase(parent){
 				m_pLabelEliminar->SetLabel(m_pLabelEliminar->GetLabel() + label + _(" from History?"));
 				m_resultado = TR_Cancelar;
-				Layout();
-				SetSize(GetBestSize());
+				m_pTitled->Layout();
+				m_body->Layout();
 				Layout();
 			};
 
