@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelestudio.cpp 4334 2011-10-26 07:00:01Z tovar $
+ *  $Id: panelestudio.cpp 4742 2012-02-23 10:57:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -32,6 +32,29 @@ namespace GNC {
 		PanelEstudio::PanelEstudio(INodoHistorial* pPadre, wxWindow* pParentWindow, const std::string& descripcion, const std::string& uidEstudio):
 			PanelEstudioBase(pParentWindow),INodoHistorial(pPadre,uidEstudio) {
 
+			InitFields(descripcion);
+			m_pLabelEstudio->Connect( wxEVT_MOUSEWHEEL, wxMouseEventHandler( PanelEstudio::OnMouseWheel ), NULL, this );
+			SetAutoLayout(true);
+
+			Layout();
+		}
+		PanelEstudio::~PanelEstudio()
+		{
+			if(EstaSeleccionado()){
+				GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GUI::Eventos::EventoSeleccionarHistorial(NULL));
+			}
+		}
+
+		void PanelEstudio::Seleccionar(bool seleccionar,bool force)
+		{
+			if(m_seleccionado!=seleccionar || force){
+				m_seleccionado = seleccionar;
+				Refresh();
+			}
+		}
+
+		void PanelEstudio::InitFields(const std::string& descripcion)
+		{
 			if(descripcion != "") {
 				m_pLabelEstudio->SetToolTip(wxString::FromUTF8(descripcion.c_str()));
 
@@ -57,24 +80,6 @@ namespace GNC {
 			} else {
 				m_pLabelEstudio->SetLabel(_("No description"));
 			}
-			m_pLabelEstudio->Connect( wxEVT_MOUSEWHEEL, wxMouseEventHandler( PanelEstudio::OnMouseWheel ), NULL, this );
-			SetAutoLayout(true);
-
-			Layout();
-		}
-		PanelEstudio::~PanelEstudio()
-		{
-			if(EstaSeleccionado()){
-				GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GUI::Eventos::EventoSeleccionarHistorial(NULL));
-			}
-		}
-
-		void PanelEstudio::Seleccionar(bool seleccionar,bool force)
-		{
-			if(m_seleccionado!=seleccionar || force){
-				m_seleccionado = seleccionar;
-				Refresh();
-			}
 		}
 
 		PanelSerie* PanelEstudio::GetSerie(const GNC::GCS::ControladorHistorial::ModeloSerie& modeloSerie){
@@ -136,29 +141,35 @@ namespace GNC {
 				pMenuSend->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoSendToPACS());
 				#endif
 				menu.Append(pMenuSend);
-				menu.AppendSeparator();
 			}
 
-			wxMenuItem* pMenuEliminar = new wxMenuItem(&menu, 3, wxString( _("&Delete from history") ), _("Delete"), wxITEM_NORMAL );
-			menu.Connect(3,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelEstudio::OnEliminar),NULL,this);
-			#ifdef __WXMSW__
-			pMenuEliminar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
-			#else
-			pMenuEliminar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
-			#endif
-			menu.Append(pMenuEliminar);
-			menu.AppendSeparator();
+			if (!GNC::GCS::ControladorHistorial::Instance()->IsReadOnly()) {
+				if (menu.GetMenuItemCount() > 0) {
+					menu.AppendSeparator();
+				}
+				wxMenuItem* pMenuEliminar = new wxMenuItem(&menu, 3, wxString( _("&Delete from history") ), _("Delete"), wxITEM_NORMAL );
+				menu.Connect(3,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelEstudio::OnEliminar),NULL,this);
+				#ifdef __WXMSW__
+				pMenuEliminar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
+				#else
+				pMenuEliminar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
+				#endif
+				menu.Append(pMenuEliminar);
+				menu.AppendSeparator();
 
-			wxMenuItem* pMenuLimpiar = new wxMenuItem(&menu, 4, wxString( _("&Clear History") ), _("Delete"), wxITEM_NORMAL );
-			menu.Connect(4,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelEstudio::OnLimpiarHistorial),NULL,this);
-			#ifdef __WXMSW__
-			pMenuLimpiar->SetBitmaps(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
-			#else
-			pMenuLimpiar->SetBitmap(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
-			#endif
-			menu.Append(pMenuLimpiar);
+				wxMenuItem* pMenuLimpiar = new wxMenuItem(&menu, 4, wxString( _("&Clear History") ), _("Delete"), wxITEM_NORMAL );
+				menu.Connect(4,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelEstudio::OnLimpiarHistorial),NULL,this);
+				#ifdef __WXMSW__
+				pMenuLimpiar->SetBitmaps(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
+				#else
+				pMenuLimpiar->SetBitmap(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
+				#endif
+				menu.Append(pMenuLimpiar);
+			}
 
-			GNC::Entorno::Instance()->GetVentanaRaiz()->PopupMenu(&menu);
+			if (menu.GetMenuItemCount() > 0) {
+				GNC::Entorno::Instance()->GetVentanaRaiz()->PopupMenu(&menu);
+			}
 			event.Skip(false);
 		}
 
