@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelhistorial2.cpp 4501 2011-12-20 11:13:41Z carlos $
+ *  $Id: panelhistorial2.cpp 4742 2012-02-23 10:57:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -131,6 +131,7 @@ namespace GNC {
 			GNC::Entorno::Instance()->GetControladorEventos()->Registrar(this, GNC::GCS::Eventos::EvtHandleDicom());			
 			GNC::Entorno::Instance()->GetControladorEventos()->Registrar(this, GNC::GCS::Eventos::EventView());
 			GNC::Entorno::Instance()->GetControladorEventos()->Registrar(this, GNC::GCS::Eventos::EventDeleteFileHistory());
+			GNC::Entorno::Instance()->GetControladorEventos()->Registrar(this, GNC::GCS::Eventos::EventUpdateFileHistory());
 
 			m_pSeleccionado = NULL;
 
@@ -952,34 +953,53 @@ namespace GNC {
 			pMenuSend->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoSendToPACS());
 			#endif
 
-			menu.Append(pMenuOpenFile);
-			menu.Append(pMenuOpenFolder);
-			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_acquisition")) {
-				menu.AppendSeparator();
-				menu.Append( pMenuAdquirir );
+			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.restrictions","acquire")) {
+				menu.Append(pMenuOpenFile);
+				menu.Append(pMenuOpenFolder);
+				if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_acquisition")) {
+					menu.AppendSeparator();
+					menu.Append( pMenuAdquirir );
+				} else {
+					delete pMenuAdquirir;
+				}
 			} else {
+				delete pMenuOpenFile;
 				delete pMenuAdquirir;
+				delete pMenuOpenFolder;
 			}
-			menu.AppendSeparator();
 			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_upload")) {
+				if (menu.GetMenuItemCount() > 0) {
+					menu.AppendSeparator();
+				}
 				menu.Append(pMenuSend);
 			} else {
 				delete pMenuSend;
 			}
-			menu.AppendSeparator();
-			menu.Append(pMenuImportar);
 
-			menu.AppendSeparator();
-			wxMenuItem* pMenuEliminar = new wxMenuItem(&menu, 1, wxString( _("&Clear History") ), _("Delete"), wxITEM_NORMAL );
-			menu.Connect(1,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelHistorial2::OnLimpiarHistorial),NULL,this);
-			#ifdef __WXMSW__
-			pMenuEliminar->SetBitmaps(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
-			#else
-			pMenuEliminar->SetBitmap(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
-			#endif
-			menu.Append(pMenuEliminar);
-			if(m_mapaHijos.size() == 0) {
-				pMenuEliminar->Enable(false);
+			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.restrictions","acquire")) {
+				if (menu.GetMenuItemCount() > 0) {
+					menu.AppendSeparator();
+				}
+				menu.Append(pMenuImportar);
+			} else {
+				delete pMenuImportar;
+			}
+
+			if (!GNC::GCS::ControladorHistorial::Instance()->IsReadOnly()) {
+				if (menu.GetMenuItemCount() > 0) {
+					menu.AppendSeparator();
+				}
+				wxMenuItem* pMenuEliminar = new wxMenuItem(&menu, 1, wxString( _("&Clear History") ), _("Delete"), wxITEM_NORMAL );
+				menu.Connect(1,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelHistorial2::OnLimpiarHistorial),NULL,this);
+				#ifdef __WXMSW__
+				pMenuEliminar->SetBitmaps(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
+				#else
+				pMenuEliminar->SetBitmap(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
+				#endif
+				menu.Append(pMenuEliminar);
+				if(m_mapaHijos.size() == 0) {
+					pMenuEliminar->Enable(false);
+				}
 			}
 			PopupMenu(&menu);
 			event.Skip(false);
@@ -1384,6 +1404,39 @@ namespace GNC {
 						}
 					}
 					break;
+				case ginkgoEVT_Core_UpdateFile:
+					{
+						GNC::GCS::Eventos::EventUpdateFileHistory* pEvt = dynamic_cast<GNC::GCS::Eventos::EventUpdateFileHistory*>(evt);
+						if (pEvt != NULL)
+						{
+							//update files from history
+							GNC::GCS::ControladorHistorial::ListaModelosDCM models;
+							GNC::GCS::ControladorHistorial::TAddErrorList errors;
+							//to update each serie only one time
+							std::set<std::string> setOfUpdatedSeries;
+							if (GNC::GCS::ControladorHistorial::Instance()->UpdateFiles(pEvt->GetIdList(), models, errors)) {
+								for (GNC::GCS::ControladorHistorial::ListaModelosDCM::iterator itModel = models.begin(); itModel != models.end(); ++itModel) {
+									GNC::GCS::ControladorHistorial::ModeloDCM& model = (*itModel);
+									if (setOfUpdatedSeries.find(model.m_uidSerie) == setOfUpdatedSeries.end()) {
+										setOfUpdatedSeries.insert(model.m_uidSerie);
+
+										//if serie has been rendered...
+										if (m_mapaUIDsAbribles.find(model.m_uidSerie) != m_mapaUIDsAbribles.end()) {
+											PanelEstudio* pStudyPanel = m_mapaUIDsAbribles[model.m_uidSerie]->GetEstudio(model.m_uidEstudio);
+											if (pStudyPanel) {
+												pStudyPanel->InitFields(model.m_descripcionEstudio);
+											}
+											PanelSerie* pPanel = m_mapaUIDsAbribles[model.m_uidSerie]->GetSeries(model.m_uidSerie);
+											if (pPanel) {
+												pPanel->InitFields(model.m_descripcionSerie, model.m_fechaSerie, model.m_horaSerie, model.m_uidImportador, model.m_modalidad, model.m_uidEstudio, model.m_uidTransferSyntax);
+											}
+										}
+									}
+								}
+							}
+						}
+					}
+					break;
 			}
 		}
 //endregion
