@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelpaciente.cpp 4334 2011-10-26 07:00:01Z tovar $
+ *  $Id: panelpaciente.cpp 4742 2012-02-23 10:57:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -184,6 +184,16 @@ namespace GNC {
 			}
 		}
 
+		PanelEstudio* PanelPaciente::GetEstudio(const std::string& studyUID)
+		{
+			TMapaHijos::iterator it=m_mapaHijos.find(studyUID);
+			if(it!=m_mapaHijos.end()){
+				return (PanelEstudio*)(*it).second;
+			}else{
+				return NULL;
+			}
+		}
+
 		void PanelPaciente::OnCabeceraClick(wxMouseEvent &)
 		{
 			//si el virtual size pasa de 16 bits (32000 pasan cosas malas)
@@ -235,41 +245,59 @@ namespace GNC {
 			pMenuSend->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoSendToPACS());
 			#endif
 
-			menu.Append(pMenuOpenFile);
-			menu.Append(pMenuOpenFolder);
-			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_acquisition")) {
-				menu.AppendSeparator();
-				menu.Append( pMenuAdquirir );
+			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.restrictions","acquire")) {
+				menu.Append(pMenuOpenFile);
+				menu.Append(pMenuOpenFolder);
+				if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_acquisition")) {
+					menu.AppendSeparator();
+					menu.Append( pMenuAdquirir );
+				} else {
+					delete pMenuAdquirir;
+				}
 			} else {
+				delete pMenuOpenFile;
 				delete pMenuAdquirir;
+				delete pMenuOpenFolder;
 			}
-			menu.AppendSeparator();
 			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","pacs_upload")) {
+				if (menu.GetMenuItemCount() > 0) {
+					menu.AppendSeparator();
+				}
 				menu.Append(pMenuSend);
 			} else {
 				delete pMenuSend;
 			}
-			menu.AppendSeparator();
-			menu.Append(pMenuImportar);
+			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.restrictions","import")) {
+				if (menu.GetMenuItemCount() > 0) {
+					menu.AppendSeparator();
+				}
+				menu.Append(pMenuImportar);
+			} else {
+				delete pMenuImportar;
+			}
 
-			menu.AppendSeparator();
-			wxMenuItem* pMenuEliminar = new wxMenuItem(&menu, 1, wxString( _("&Delete Patient from History") ), _("Delete"), wxITEM_NORMAL );
-			menu.Connect(1,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelPaciente::OnEliminar),NULL,this);
-			#ifdef __WXMSW__
-			pMenuEliminar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
-			#else
-			pMenuEliminar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
-			#endif
-			menu.Append(pMenuEliminar);
-			menu.AppendSeparator();
+			if (!GNC::GCS::ControladorHistorial::Instance()->IsReadOnly()) {
+				if (menu.GetMenuItemCount() > 0) {
+					menu.AppendSeparator();
+				}
+				wxMenuItem* pMenuEliminar = new wxMenuItem(&menu, 1, wxString( _("&Delete Patient from History") ), _("Delete"), wxITEM_NORMAL );
+				menu.Connect(1,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelPaciente::OnEliminar),NULL,this);
+				#ifdef __WXMSW__
+				pMenuEliminar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
+				#else
+				pMenuEliminar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
+				#endif
+				menu.Append(pMenuEliminar);
+				menu.AppendSeparator();
 
-			wxMenuItem* pMenuLimpiar = new wxMenuItem(&menu, 2, wxString( _("&Clear History") ), _("Delete"), wxITEM_NORMAL );
-			menu.Connect(2,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelPaciente::OnLimpiarHistorial),NULL,this);
-			#ifdef __WXMSW__
-			pMenuLimpiar->SetBitmaps(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
-			pMenuLimpiar->SetBitmap(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
-			#endif
-			menu.Append(pMenuLimpiar);
+				wxMenuItem* pMenuLimpiar = new wxMenuItem(&menu, 2, wxString( _("&Clear History") ), _("Delete"), wxITEM_NORMAL );
+				menu.Connect(2,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelPaciente::OnLimpiarHistorial),NULL,this);
+				#ifdef __WXMSW__
+				pMenuLimpiar->SetBitmaps(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
+				pMenuLimpiar->SetBitmap(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
+				#endif
+				menu.Append(pMenuLimpiar);
+			}
 			GNC::Entorno::Instance()->GetVentanaRaiz()->PopupMenu(&menu);
 			event.Skip(false);
 		}
