@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelserie.cpp 4501 2011-12-20 11:13:41Z carlos $
+ *  $Id: panelserie.cpp 4742 2012-02-23 10:57:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -22,9 +22,9 @@
 #include <main/controllers/controladorvistas.h>
 #include <main/controllers/controladorlog.h>
 #include <main/controllers/controladorcomandos.h>
+#include <main/controllers/integrationcontroller.h>
 #include <main/controllers/controladoreventos.h>
 #include <main/controllers/controladorpermisos.h>
-#include <main/controllers/controladorhl7.h>
 #include <main/controllers/controladorenviohl7.h>
 #include <main/entorno.h>
 #include <main/gui/pacsupload/wxwizarduploadpacs.h>
@@ -102,7 +102,49 @@ namespace GNC {
 			const std::string& uidSerie, const int numeroSlices, const std::string& uidEstudio, const std::string uidTransferSyntax):PanelSerieBase(pParentWindow),INodoHistorial(pPadre,uidSerie)
 		{
 			m_numeroSlices = numeroSlices;
-			m_uidSerie = uidSerie;
+			m_pNumeroCortes->SetLabel(wxString::Format(wxT("%d"),m_numeroSlices));
+			InitFields(descripcion, fecha, hora, id_importador, id_modalidad, uidEstudio, uidTransferSyntax);
+			m_pThumbnail->Hide();
+			m_modificado = false;
+			m_pNotificadorPreview = new NotificadorPreview(this);
+
+			m_pBWin = NULL;
+			m_pTimer = new TimerPanelSerie(this);
+			//random 50 y 300
+			m_dibujada = false;
+
+			Layout();
+		}
+		PanelSerie::~PanelSerie()
+		{
+			GNC::GCS::ControladorComandos::Instance()->AbortarComandosDeOwnerAsincrono(this);
+			delete m_pTimer;
+			m_pTimer = NULL;
+
+			if (m_pBWin != NULL) {
+				m_pBWin->Show();
+				m_pBWin = NULL;
+			}
+
+			if(EstaSeleccionado()){
+				GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GUI::Eventos::EventoSeleccionarHistorial(NULL));
+			}
+			m_pVistas.clear();
+			std::list< std::string > listaUIDs;
+			listaUIDs.push_back(m_clave);
+			GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GUI::Eventos::EventoAbribleEliminado(listaUIDs));
+			delete m_pNotificadorPreview;
+		}
+
+		void PanelSerie::SetModeloIntegracion (GnkPtr<GIL::IModeloIntegracion> pModeloIntegracion) {
+			m_pModeloIntegracion = pModeloIntegracion;
+		}
+
+		
+		void PanelSerie::InitFields(const std::string& descripcion, const std::string& fecha,
+			const std::string& hora, const std::string& id_importador, const std::string& id_modalidad,
+			const std::string& uidEstudio, const std::string uidTransferSyntax)
+		{
 			m_uidEstudio = uidEstudio;
 			m_uidTransferSyntax = uidTransferSyntax;
 			if(descripcion != "")
@@ -140,59 +182,22 @@ namespace GNC {
 				ostr << _Std("Date: ") << fecha << std::endl;
 				ostr << _Std("Time: ") << hora << std::endl;
 				ostr << _Std("Modality: ") << id_modalidad << std::endl;
-				ostr << _Std("Series UID: ") << uidSerie << std::endl;
+				ostr << _Std("Series UID: ") << m_clave << std::endl;
 				ostr << _Std("UID Importer: ") << id_importador;
 				wxString toolTip = wxString::FromUTF8(ostr.str().c_str());
 
 				SetToolTip(toolTip);
 				m_pThumbnail->SetToolTip(toolTip);
-				m_pThumbnail->Hide();
 			}
 
 			m_idImportador = id_importador;
 			m_idModalidad = id_modalidad;
 			m_pModalidad->SetLabel(wxString::FromUTF8(m_idModalidad.c_str()));
-			m_modificado= false;
-
-			m_pNumeroCortes->SetLabel(wxString::Format(wxT("%d"),m_numeroSlices));
-
-			m_pNotificadorPreview = new NotificadorPreview(this);
-
-			m_pBWin = NULL;
-			m_pTimer = new TimerPanelSerie(this);
-			//random 50 y 300
-			m_dibujada = false;
-
-			Layout();
-		}
-		PanelSerie::~PanelSerie()
-		{
-			GNC::GCS::ControladorComandos::Instance()->AbortarComandosDeOwnerAsincrono(this);
-			delete m_pTimer;
-			m_pTimer = NULL;
-
-			if (m_pBWin != NULL) {
-				m_pBWin->Show();
-				m_pBWin = NULL;
-			}
-
-			if(EstaSeleccionado()){
-				GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GUI::Eventos::EventoSeleccionarHistorial(NULL));
-			}
-			m_pVistas.clear();
-			std::list< std::string > listaUIDs;
-			listaUIDs.push_back(m_uidSerie);
-			GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GUI::Eventos::EventoAbribleEliminado(listaUIDs));
-			delete m_pNotificadorPreview;
-		}
-
-		void PanelSerie::SetModeloIntegracion (GnkPtr<GIL::IModeloIntegracion> pModeloIntegracion) {
-			m_pModeloIntegracion = pModeloIntegracion;
 		}
 
 		int PanelSerie::RefrescarNumeroSlices()
 		{
-			m_numeroSlices = GNC::GCS::ControladorHistorial::Instance()->GetSlicesCount(m_uidSerie);
+			m_numeroSlices = GNC::GCS::ControladorHistorial::Instance()->GetSlicesCount(m_clave);
 			m_pNumeroCortes->SetLabel(wxString::Format(wxT("%d"),m_numeroSlices));
 			Layout();
 			return m_numeroSlices;
@@ -257,7 +262,7 @@ namespace GNC {
 		void PanelSerie::GenerarThumbnail()
 		{
 			//generar el thumbnail!!!
-			GADAPI::ComandoGenerarThumbnails* pCmd = new GADAPI::ComandoGenerarThumbnails(GNC::GCS::ControladorHistorial::Instance()->GetPathFrameOfReference(m_uidSerie),m_pNotificadorPreview);
+			GADAPI::ComandoGenerarThumbnails* pCmd = new GADAPI::ComandoGenerarThumbnails(GNC::GCS::ControladorHistorial::Instance()->GetPathFrameOfReference(m_clave),m_pNotificadorPreview);
 			GNC::GCS::ControladorComandos::Instance()->ProcessAsync(_Std("Creating Thumbnail..."),pCmd,this);
 		}
 
@@ -292,7 +297,6 @@ namespace GNC {
 			menu.Connect(4,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnAbrir),NULL,this);
 			menu.Append(5, _("Open Series with .."));
 			menu.Connect(5,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnAbrirCon),NULL,this);
-			menu.AppendSeparator();
 				
 			
 			//Do you have to reprocess this series?
@@ -309,7 +313,7 @@ namespace GNC {
 
 			if(pModulo != NULL) {
 				//reprocess integration xml... read xml from first file..
-				std::vector<std::string> rutas = GNC::GCS::ControladorHistorial::Instance()->GetPathsSerieOrdenados(m_uidSerie);
+				std::vector<std::string> rutas = GNC::GCS::ControladorHistorial::Instance()->GetPathsSerieOrdenados(m_clave);
 				GIL::DICOM::IDICOMManager* pManager = GNC::Entorno::Instance()->GetPACSController()->CrearInstanciaDeDICOMManager();
 				GIL::DICOM::TipoPrivateTags tagsPrivados(UID_TAGS_PRIVADOS_COMUNES);
 				pManager->CargarFichero(rutas[0]);
@@ -323,8 +327,8 @@ namespace GNC {
 					#else
 					pMenuSend->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoReset());
 					#endif
-					menu.Append(pMenuSend);
 					menu.AppendSeparator();
+					menu.Append(pMenuSend);
 				}
 				GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pManager);				
 			}
@@ -338,31 +342,33 @@ namespace GNC {
 				#else
 				pMenuSend->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoSendToPACS());
 				#endif
-				menu.Append(pMenuSend);
 				menu.AppendSeparator();
+				menu.Append(pMenuSend);
 			}
 
-			wxMenuItem* pMenuEliminar = new wxMenuItem(&menu, 3, wxString( _("&Delete from history") ), _("Delete"), wxITEM_NORMAL );
-			menu.Connect(3,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnEliminar),NULL,this);
-			#ifdef __WXMSW__
-			pMenuEliminar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
-			#else
-			pMenuEliminar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
-			#endif
-			menu.Append(pMenuEliminar);
-			menu.AppendSeparator();
+			if (!GNC::GCS::ControladorHistorial::Instance()->IsReadOnly()) {
+				wxMenuItem* pMenuEliminar = new wxMenuItem(&menu, 3, wxString( _("&Delete from history") ), _("Delete"), wxITEM_NORMAL );
+				menu.Connect(3,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnEliminar),NULL,this);
+				#ifdef __WXMSW__
+				pMenuEliminar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
+				#else
+				pMenuEliminar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
+				#endif
+				menu.AppendSeparator();
+				menu.Append(pMenuEliminar);
 
-			wxMenuItem* pMenuLimpiar = new wxMenuItem(&menu, 6, wxString( _("&Clear History") ), _("Delete"), wxITEM_NORMAL );
-			menu.Connect(6,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnLimpiarHistorial),NULL,this);
-			#ifdef __WXMSW__
-			pMenuLimpiar->SetBitmaps(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
-			pMenuLimpiar->SetBitmap(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
-			#endif
-			menu.Append(pMenuLimpiar);
-
-
-			GNC::Entorno::Instance()->GetVentanaRaiz()->PopupMenu(&menu);
+				wxMenuItem* pMenuLimpiar = new wxMenuItem(&menu, 6, wxString( _("&Clear History") ), _("Delete"), wxITEM_NORMAL );
+				menu.Connect(6,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnLimpiarHistorial),NULL,this);
+				#ifdef __WXMSW__
+				pMenuLimpiar->SetBitmaps(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
+				pMenuLimpiar->SetBitmap(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
+				#endif
+				menu.Append(pMenuLimpiar);
+			}
 
+			if (menu.GetMenuItemCount() > 0) {
+				GNC::Entorno::Instance()->GetVentanaRaiz()->PopupMenu(&menu);
+			}
 			event.Skip(false);
 		}
 
@@ -439,7 +445,7 @@ namespace GNC {
 				GNC::GCS::IVista* pVista = GNC::Entorno::Instance()->GetControladorVistas()->GetVistaActiva();
 				if(pVista != NULL) {
 					m_pBWin = pVista->GetWindow();
-					pVista->ActivarRuta(GNC::GCS::ControladorHistorial::Instance()->GetPathFrameOfReference(m_uidSerie));
+					pVista->ActivarRuta(GNC::GCS::ControladorHistorial::Instance()->GetPathFrameOfReference(m_clave));
 					m_pBWin->Hide();
 					if (m_pTimer->IsRunning()) {
 						m_pTimer->Stop();
@@ -541,14 +547,14 @@ namespace GNC {
 
 			GNC::GCS::IControladorModulo::ListaDescriptoresSerie listaDescriptoresSerie;
 			if( pModulo->GetModo(idModo)->AbreSeriesSueltas() && !forzarEstudio ) {
-				listaDescriptoresSerie.push_back(GNC::GCS::IControladorModulo::DescriptorSerie(m_uidSerie, m_idModalidad, m_uidTransferSyntax, m_pModeloIntegracion));
+				listaDescriptoresSerie.push_back(GNC::GCS::IControladorModulo::DescriptorSerie(m_clave, m_idModalidad, m_uidTransferSyntax, m_pModeloIntegracion));
 			} else {
 				//pillamos todos los ficheros del estudio!!
 				GNC::GCS::ControladorHistorial::ListaModelosSeries seriesEstudio;
 				GNC::GCS::ControladorHistorial::Instance()->GetModelosSerieEstudio(m_uidEstudio, seriesEstudio);
 				for(GNC::GCS::ControladorHistorial::ListaModelosSeries::iterator it = seriesEstudio.begin(); it != seriesEstudio.end(); it++) {
 					//TODO FALTA RESOLVER EL TEMA MODELO DE INTEGRACION EN ESTE PUNTO
-					if((*it).m_uidSerie == m_uidSerie) {
+					if((*it).m_uidSerie == m_clave) {
 						listaDescriptoresSerie.push_front(GNC::GCS::IControladorModulo::DescriptorSerie((*it).m_uidSerie, (*it).m_modalidad, (*it).m_uidTransferSyntax , NULL));
 					} else {
 						listaDescriptoresSerie.push_back(GNC::GCS::IControladorModulo::DescriptorSerie((*it).m_uidSerie, (*it).m_modalidad, (*it).m_uidTransferSyntax , NULL));
@@ -618,7 +624,7 @@ namespace GNC {
 		void PanelSerie::OnUploadPACS(wxCommandEvent &)
 		{
 			wxWizardUploadPACSGinkgo::TListUIDs list;
-			list.push_back(m_uidSerie);
+			list.push_back(m_clave);
 			wxWizardUploadPACSGinkgo wiz(GNC::Entorno::Instance()->GetVentanaRaiz(), list);
 			wiz.ShowModal();
 		}
@@ -649,7 +655,7 @@ namespace GNC {
 			}
 
 			//reprocess integration xml... read xml from first file..
-			std::vector<std::string> rutas = GNC::GCS::ControladorHistorial::Instance()->GetPathsSerieOrdenados(m_uidSerie);
+			std::vector<std::string> rutas = GNC::GCS::ControladorHistorial::Instance()->GetPathsSerieOrdenados(m_clave);
 			GIL::DICOM::IDICOMManager* pManager = GNC::Entorno::Instance()->GetPACSController()->CrearInstanciaDeDICOMManager();
 			GIL::DICOM::TipoPrivateTags tagsPrivados(UID_TAGS_PRIVADOS_COMUNES);
 			pManager->CargarFichero(rutas[0]);
@@ -664,45 +670,14 @@ namespace GNC {
 			GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pManager);
 
 			try {
-				GIL::HL7::ControladorHL7 controlador;
-				GNC::GCS::IEntorno::ListaModelosIntegracion& listaModelos = GNC::Entorno::Instance()->GetModelosIntegracion();
-				controlador.ParsearModeloIntegracion(listaModelos,xmlString);
-
-				typedef GNC::GCS::IEntorno::ListaModelosIntegracion::iterator TIteradorModelos;
-				for (TIteradorModelos it = listaModelos.begin(); it != listaModelos.end(); it++) {
-					GnkPtr<GIL::IModeloIntegracion> modelo = (*it);
-					if (modelo->atendido)
-						continue;
-					else
-						modelo->atendido = true;
-					if(modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
-						//se busca el dicomizador del modulo indicado, habra un mapa que transformara sid en uids de modulo
-						std::string uidModulo("");
-						if (modelo->idPlantilla != "") {
-							uidModulo = controlador.GetUID(modelo->idPlantilla);
-							modelo->UIDModulo = uidModulo;
-							if (GNC::ControladorExtensiones::Instance()->ObtenerModulo(uidModulo) == NULL) {
-								throw GIL::HL7::HL7Exception("No existe el modulo asociado", "Modelo", true);
-							}
-						} else {
-							uidModulo = pModulo->GetUID();
-						}
-						modelo->UIDModulo = uidModulo;
-						if (GNC::ControladorExtensiones::Instance()->ObtenerModulo(uidModulo) == NULL) {
-							throw GIL::HL7::HL7Exception("No existe el modulo asociado", "Modelo", true);
-						}
-						pModulo->ReprocessIntegration(m_uidSerie, modelo);
-					}
-				}
+				GIL::IntegrationModelList listaModelos;
+				GIL::IntegrationController::Instance()->ParsearModeloIntegracion(listaModelos,xmlString);
+				GIL::IntegrationController::Instance()->ReProcess(pModulo, m_clave, listaModelos);
 			}
-			catch (GIL::HL7::HL7XMLException& ex) {
+			catch (GIL::IntegrationException& ex) {
 				LOG_ERROR("GIL/WF", "Semantic/Sintactic error parsing integration XML: " << ex.GetFullCause());
 				wxMessageBox(_("Semantic/Sintactic error parsing integration XML (see log for details):\n") + wxString::FromUTF8(ex.GetCause().c_str()),_("Error"),wxICON_INFORMATION);
 			}
-			catch (GIL::HL7::HL7Exception& ex1) {
-				LOG_ERROR("GIL/WF", "Error parsing integration XML: " << ex1.GetCause());
-				wxMessageBox(_("Error parsing integration XML:\n") + wxString::FromUTF8(ex1.GetCause().c_str()),_("Error"),wxICON_INFORMATION);
-			}
 			catch (std::exception& ex4) {
 				LOG_ERROR("GIL/WF", "Error executing WorkFlow: " << ex4.what());
 				wxMessageBox(_("Error executing WorkFlow\n") + wxString::FromUTF8(ex4.what()),_("Error"),wxICON_INFORMATION);
