@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: selectimagesimportation.cpp 4602 2012-01-26 07:23:02Z tovar $
+ *  $Id: selectimagesimportation.cpp 4706 2012-02-16 07:59:43Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -50,6 +50,8 @@
 #include <vtkPointData.h>
 #include <vtkginkgoimageviewer.h>
 
+#include <wx/mimetype.h>
+
 #define ID_BUTTON_HIDE 0
 #define ID_BUTTON_ROTATE_LEFT 1
 #define ID_BUTTON_ROTATE_RIGHT 2
@@ -178,9 +180,9 @@ namespace GNC {
 			m_fileSpecs = fileSpecs;
 			if (defaultFilter.IsEmpty()) {
 #if defined(_WIN32) || defined(__WXMAC__)
-				m_pDefaultFilter =_("Images (*.jpg;*.jpeg;*.bmp;*.png;*.tif;*.tiff)|*.jpg;*.jpeg;*.bmp;*.png;*.tif;*.tiff|JPEG Images (*.jpg;*.jpeg)|*.jpg;*.jpeg|BMP Images (*.bmp)|*.bmp|PNG Images (*.png)|*.png|TIFF Images (*.tif;*.tiff)|*.tif;*.tiff|All files(*.*)|*.*");
+				m_pDefaultFilter =_("Images (*.jpg;*.jpeg;*.bmp;*.png;*.tif;*.tiff;*.pdf)|*.jpg;*.jpeg;*.bmp;*.png;*.tif;*.tiff;*.pdf|JPEG Images (*.jpg;*.jpeg)|*.jpg;*.jpeg|BMP Images (*.bmp)|*.bmp|PNG Images (*.png)|*.png|TIFF Images (*.tif;*.tiff)|*.tif;*.tiff|PDF documents (*.pdf)|*.pdf|All files(*.*)|*.*");
 #else
-				m_pDefaultFilter =_("Images (*.jpg;*.jpeg;*.bmp;*.png;*.tif;*.tiff)|*.jpg;*.jpeg;*.bmp;*.png;*.tif;*.tiff;*.JPG;*.JPEG;*.BMP;*.PNG;*.TIF;*.TIFF|JPEG Images (*.jpg;*.jpeg)|*.jpg;*.jpeg;*.JPG;*.JPEG|BMP Images (*.bmp)|*.bmp;*BMP|PNG Images (*.png)|*.png;*PNG|TIFF Images (*.tif;*.tiff)|*.tif;*.tiff;*TIF;*TIFF|All files (*.*)|*.*");
+				m_pDefaultFilter =_("Images (*.jpg;*.jpeg;*.bmp;*.png;*.tif;*.tiff;*.pdf)|*.jpg;*.jpeg;*.bmp;*.png;*.tif;*.tiff;*.pdf;*.JPG;*.JPEG;*.BMP;*.PNG;*.TIF;*.TIFF;*.PDF|JPEG Images (*.jpg;*.jpeg)|*.jpg;*.jpeg;*.JPG;*.JPEG|BMP Images (*.bmp)|*.bmp;*BMP|PNG Images (*.png)|*.png;*PNG|TIFF Images (*.tif;*.tiff)|*.tif;*.tiff;*TIF;*TIFF|PDF documents (*.pdf;*.PDF)|*.PDF;*.pdf|All files (*.*)|*.*");
 #endif
 				m_fileSpecs.push_back("*.jpg");
 				m_fileSpecs.push_back("*.jpeg");
@@ -188,6 +190,7 @@ namespace GNC {
 				m_fileSpecs.push_back("*.png");
 				m_fileSpecs.push_back("*.tif");
 				m_fileSpecs.push_back("*.tiff");
+				m_fileSpecs.push_back("*.pdf");
 			} else {
 				m_pDefaultFilter = defaultFilter;
 			}
@@ -350,40 +353,51 @@ namespace GNC {
 				return;
 
 			Freeze();
-			m_pImagenes->Hide();
-			m_pPreviewPanel->Show();
-			m_pButtonsBar->Hide();
-			m_pPreview->SetFocus();
-			m_pButtonRemoveAll->Hide();
-			m_pButtonPreview->Hide();
-
 			//load preview...
 			wxString pathTmp = item->GetFilename();
-			m_pwxImagePreview->LoadFile(pathTmp);
+			if (m_pwxImagePreview->LoadFile(pathTmp)) 
+			{
+				m_pImagenes->Hide();
+				m_pPreviewPanel->Show();
+				m_pButtonsBar->Hide();
+				m_pPreview->SetFocus();
+				m_pButtonRemoveAll->Hide();
+				m_pButtonPreview->Hide();
 
-			vtkSmartPointer<vtkImageData> data = vtkSmartPointer<vtkImageData>::New();
-			double spacing[3] = {1.0f,1.0f,1.0f};
-			double origin[3] = {0.0f,0.0f,0.0f};
+				
 
-			data->SetDimensions(m_pwxImagePreview->GetWidth(), m_pwxImagePreview->GetHeight(), 1);
-			data->SetNumberOfScalarComponents(3);
-			data->SetScalarTypeToUnsignedChar();
-			data->SetSpacing(spacing[0],spacing[1],spacing[2]);
-			data->SetOrigin(origin[0],origin[1],origin[2]);
+				vtkSmartPointer<vtkImageData> data = vtkSmartPointer<vtkImageData>::New();
+				double spacing[3] = {1.0f,1.0f,1.0f};
+				double origin[3] = {0.0f,0.0f,0.0f};
 
-			vtkSmartPointer<vtkUnsignedCharArray> dataImagen = vtkSmartPointer<vtkUnsignedCharArray>::New();
-			dataImagen->SetNumberOfComponents(3);
-			unsigned int size = data->GetDimensions()[0] * data->GetDimensions()[1];
-			dataImagen->SetArray(m_pwxImagePreview->GetData(),size,1);
+				data->SetDimensions(m_pwxImagePreview->GetWidth(), m_pwxImagePreview->GetHeight(), 1);
+				data->SetNumberOfScalarComponents(3);
+				data->SetScalarTypeToUnsignedChar();
+				data->SetSpacing(spacing[0],spacing[1],spacing[2]);
+				data->SetOrigin(origin[0],origin[1],origin[2]);
 
-			data->GetPointData()->SetScalars(dataImagen);
+				vtkSmartPointer<vtkUnsignedCharArray> dataImagen = vtkSmartPointer<vtkUnsignedCharArray>::New();
+				dataImagen->SetNumberOfComponents(3);
+				unsigned int size = data->GetDimensions()[0] * data->GetDimensions()[1];
+				dataImagen->SetArray(m_pwxImagePreview->GetData(),size,1);
 
-			m_pPreview->SetInput(data);
-			m_pPreview->GetView()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION);
+				data->GetPointData()->SetScalars(dataImagen);
+
+				m_pPreview->SetInput(data);
+				m_pPreview->GetView()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION);
 
 
-			m_panelStep0->Layout();
-			m_panelStep0->Refresh();
+				m_panelStep0->Layout();
+				m_panelStep0->Refresh();
+			} else {
+				wxFileName fileName(pathTmp);
+				wxMimeTypesManager manager;
+				wxFileType* fileType = manager.GetFileTypeFromExtension(fileName.GetExt());
+				if (fileType != NULL) {
+					wxExecute(fileType->GetOpenCommand(pathTmp));
+					delete fileType;
+				}
+			}
 			Thaw();
 		}
 
