@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: selectimagesimportation.h 4303 2011-10-18 10:31:44Z tovar $
+ *  $Id: selectimagesimportation.h 4403 2011-11-14 10:59:24Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -79,9 +79,9 @@ namespace GNC {
 				GIL::Ubicacion* GetUbicacionSelected();
 
 			//region "Metodos heredados de IPasoWizard"
-				virtual void Attach(wxSizer *sizer);
+				virtual bool Attach();
 
-				virtual void Detach(wxSizer *sizer);
+				virtual bool Detach();
 
 				virtual std::string GetTitle();
 
