@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wxwizardimportacionginkgo.cpp 4403 2011-11-14 10:59:24Z tovar $
+ *  $Id: wxwizardimportacionginkgo.cpp 4784 2012-03-08 12:05:06Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -22,6 +22,10 @@
 
 #include <main/entorno.h>
 #include <main/controllers/controladorextensiones.h>
+#include <main/controllers/controladorpermisos.h>
+#include <main/gui/mainwindow/ventanaprincipal.h>
+#include <main/gui/progress/statusbarprogreso.h>
+#include <main/entorno.h>
 #include <resources/ginkgoresourcemanager.h>
 #include <eventos/eventosginkgo.h>
 #include <main/controllers/controladoreventos.h>
@@ -108,7 +112,7 @@ namespace GNC {
 
 				m_pControladorModulo->GetPasosImportacion(this,pasosModulo, m_pPanelPrincipal,dir_temp, m_pModeloIntegracion);
 				if (m_pModeloIntegracion.IsValid()) {
-					m_pModeloIntegracion->UIDModulo = m_pControladorModulo->GetUID();
+					//////////TODOm_pModeloIntegracion->UIDModulo = m_pControladorModulo->GetUID();
 				}
 
 				for(std::list<IPasoWizard*>::iterator it=pasosModulo.begin();it!=pasosModulo.end();++it){
@@ -203,7 +207,7 @@ namespace GNC {
 											
 						m_pControladorModulo->GetPasosImportacion(this,pasosModulo,m_pPanelPrincipal,dir_temp,m_pModeloIntegracion);
 						if (m_pModeloIntegracion.IsValid()) {
-							m_pModeloIntegracion->UIDModulo = m_pControladorModulo->GetUID();
+////////TODO				m_pModeloIntegracion->UIDModulo = m_pControladorModulo->GetUID();
 						}
 						
 						for(std::list<IPasoWizard*>::iterator it=pasosModulo.begin();it!=pasosModulo.end();++it){
@@ -220,6 +224,10 @@ namespace GNC {
 					
 					if(m_currentPaso==m_ListaPasos.end()){
 						m_OK=true;
+						if (GNC::GCS::ControladorPermisos::Instance()->Get("core.restrictions","auto_close")) {
+							GNC::GUI::StatusBarProgreso* statusBar = (GNC::GUI::StatusBarProgreso*)GNC::Entorno::Instance()->GetVentanaPrincipal()->GetStatusBar();
+							statusBar->ShowProgressDialog(true);
+						}
 						if(m_ListaFicheros.size() > 0) {
 							GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GCS::Eventos::EventoAddFicheroHistorial(m_ListaFicheros));
 						}
@@ -255,7 +263,8 @@ namespace GNC {
 				int answer = wxMessageBox(_("Are you sure you want to cancel the import process?"),_("Cancel"), wxYES_NO ,this);
 				if(answer == wxYES)
 				{
-					BorrarArchivosTemporales();
+					m_OK = false;
+					BorrarArchivosTemporales();					
 					event.Skip(true);
 				} else {
 					event.Skip(false);
