@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: acceptlicensedialog.cpp 3893 2011-06-21 13:01:56Z tovar $
+ *  $Id: acceptlicensedialog.cpp 4641 2012-02-01 13:04:38Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -13,6 +13,7 @@
  */
 #include "acceptlicensedialog.h"
 #include <main/controllers/configurationcontroller.h>
+#include <main/controllers/controladorpermisos.h>
 #include <main/entorno.h>
 #include <api/globals.h>
 #include <main/licencia.h>
@@ -25,7 +26,7 @@ GNC::GUI::AcceptLicenseDialog::AcceptLicenseDialog(wxWindow* pPadre):GNC::GUI::A
 	std::stringstream is;
 	is << _Std("Ginkgo CADx license agreement version  ") << GNC::Entorno::Instance()->GetGinkgoVersion() << std::endl;	
 	is << std::endl;	
-	is << GINKGO_MENSAJE_LICENCIA << std::endl;
+	is << GNC::Entorno::Instance()->GetLicenseMessage() << std::endl;
 	is << std::endl;
 	is << GNC::Entorno::Instance()->GetGinkgoCopyRight() << " MetaEmotion Healthcare " ;
 	is << "http://healthcare.metaemotion.com" << std::endl;
@@ -34,6 +35,9 @@ GNC::GUI::AcceptLicenseDialog::AcceptLicenseDialog(wxWindow* pPadre):GNC::GUI::A
 	m_pTextoLicencia->SetValue(wxString::FromUTF8(is.str().c_str()));
 	Layout();
 	m_buttonAceptar->SetFocus();
+	GNC::GCS::Permisos::EstadoPermiso updates = GNC::GCS::ControladorPermisos::Instance()->Get("core.update","check_updates");
+	m_pCheckForUpdates->Show(updates);
+	m_pCheckForUpdates->SetValue(updates);
 }
 
 GNC::GUI::AcceptLicenseDialog::~AcceptLicenseDialog()
