@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: abrir.h 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: abrir.h 4387 2011-11-08 08:49:01Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -14,7 +14,7 @@
 #pragma once
 #include <main/controllers/pacscontroller.h>
 #include <string>
-#include <vector>
+#include <list>
 
 
 namespace GNC {
@@ -27,7 +27,7 @@ namespace GNC {
 			Abrir();
 			~Abrir();
 
-			static void AbrirFichero(wxWindow* pParent);
+			static void AbrirFichero(wxWindow* pParent, const std::list<std::string>* directLoads = NULL);
 			static void AbrirDirectorio(wxWindow* pParent);
 
 		protected:
