@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wxwizarduploadpacs.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: wxwizarduploadpacs.cpp 4403 2011-11-14 10:59:24Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -73,14 +73,18 @@ namespace GNC {
 			void wxWizardUploadPACSGinkgo::OnSiguienteClick(wxCommandEvent& )
 			{
 				if((*m_currentPaso)->Validar()){
-					(*m_currentPaso)->Detach(m_pSizerPrincipal);
-					++m_currentPasoIndex;
-					++m_currentPaso;
-					if(m_currentPaso==m_ListaPasos.end()){
-						Hide();						
-						m_OK = true;
-					}else{
-						CargarCurrent();
+					wxWindow* pCurrent = dynamic_cast<wxWindow*> (*m_currentPaso);
+					if (pCurrent != NULL && (*m_currentPaso)->Detach()) {
+						pCurrent->Hide();
+						m_pSizerPrincipal->Detach(pCurrent);
+						++m_currentPasoIndex;
+						++m_currentPaso;
+						if(m_currentPaso==m_ListaPasos.end()){
+							Hide();						
+							m_OK = true;
+						}else{
+							CargarCurrent();
+						}
 					}
 				}
 			}
@@ -88,10 +92,15 @@ namespace GNC {
 			void wxWizardUploadPACSGinkgo::OnAnteriorClick(wxCommandEvent &)
 			{
 				if(m_currentPaso!=m_ListaPasos.begin()){
-					(*m_currentPaso)->Detach(m_pSizerPrincipal);
-					--m_currentPaso;
-					--m_currentPasoIndex;
-					CargarCurrent();
+					wxWindow* pCurrent = dynamic_cast<wxWindow*> (*m_currentPaso);
+					if (pCurrent != NULL && (*m_currentPaso)->Detach()) {
+						pCurrent->Hide();
+						m_pSizerPrincipal->Detach(pCurrent);
+
+						--m_currentPaso;
+						--m_currentPasoIndex;
+						CargarCurrent();
+					}
 				}
 			}
 
@@ -101,16 +110,23 @@ namespace GNC {
 			 }
 
 			 void wxWizardUploadPACSGinkgo::CargarCurrent(){
-				(*m_currentPaso)->Attach(m_pSizerPrincipal);
-				m_pHeader->SetTitle(wxString::FromUTF8((*m_currentPaso)->GetTitle().c_str()));
-				m_pBSiguiente->Enable((*m_currentPaso)->Siguiente());
-				m_pBAnterior->Enable((*m_currentPaso)->Anterior());
-				m_pBCerrar->Enable((*m_currentPaso)->Cancelar());
-				if(*(m_currentPaso)==m_ListaPasos.back()){
-					m_pBSiguiente->SetLabel(_("&Accept"));
-				}else{
-					m_pBSiguiente->SetLabel(_("&Next >"));
+				wxWindow* pCurrent = dynamic_cast<wxWindow*> (*m_currentPaso);
+				if (pCurrent != NULL && (*m_currentPaso)->Attach()) 
+				{
+					pCurrent->Show(true);
+				m_pSizerPrincipal->Add(pCurrent, 10, wxEXPAND);
+
+					m_pHeader->SetTitle(wxString::FromUTF8((*m_currentPaso)->GetTitle().c_str()));
+					m_pBSiguiente->Enable((*m_currentPaso)->Siguiente());
+					m_pBAnterior->Enable((*m_currentPaso)->Anterior());
+					m_pBCerrar->Enable((*m_currentPaso)->Cancelar());
+					if(*(m_currentPaso)==m_ListaPasos.back()){
+						m_pBSiguiente->SetLabel(_("&Accept"));
+					}else{
+						m_pBSiguiente->SetLabel(_("&Next >"));
+					}
 				}
+				m_pPanelPrincipal->Layout();
 				Layout();
 			 }
 
