@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wxwizarduploadpacs.h 3669 2011-04-11 10:59:33Z tovar $
+ *  $Id: wxwizarduploadpacs.h 3830 2011-05-06 13:30:18Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -15,7 +15,7 @@
 #include <api/iwizard.h>
 #include <wx/wizardginkgo/wxwizardginkgobase.h>
 #include <api/ientorno.h>
-#include <main/controllers/controladorimportacionpacs.h>
+#include <main/controllers/pacscontroller.h>
 #include <string>
 #include <vector>
 
