@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: paneltags.h 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: paneltags.h 4336 2011-10-26 11:57:07Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -20,7 +20,6 @@
 
 class PanelCustomPASI;
 
-
 namespace GNC {
 	namespace GUI {
 
@@ -36,9 +35,21 @@ namespace GNC {
 
 			void OnPropertyChanged(wxPropertyGridEvent& event) ;
 			void OnPropertyChanging(wxPropertyGridEvent& event) ;
+			virtual void OnClose(wxCloseEvent &event);
+
+			wxPGProperty* CreatePropertyGroup(const wxString& label);
+			void InsertTagInGroup(wxPGProperty* prop, const std::string& key, wxPGPropArg idPadre);
 
 		private:
 			void SetTags(GIL::DICOM::TipoJerarquia& base, wxPGPropArg idPadre, GIL::DICOM::IDICOMManager*	pDICOMManager) ;
+
+			wxPGProperty* identificationGroup;
+			wxPGProperty* patientGroup;
+			wxPGProperty* acquisitionGroup;
+			wxPGProperty* relationshipGroup;
+			wxPGProperty* imagePresentationGroup;
+			wxPGProperty* textGroup;
+			wxPGProperty* otherGroup;
 		};
 	}
 }
