@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: paneltarea.h 3066 2010-12-21 10:10:14Z carlos $
+ *  $Id: paneltarea.h 4359 2011-11-02 08:16:57Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -19,6 +19,10 @@ namespace GNC {
 		public:
 			PanelTarea( wxWindow* pPadre,long pidTarea);
 			~PanelTarea();
+
+			void SetProgress(const wxString& text, float progress);
+			wxString GetStatus();
+			float GetProgress();
 		protected:
 			void OnTareaCancelarClick(wxCommandEvent &event);
 			long m_PIDTarea;
