@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: statusbarprogreso.cpp 4366 2011-11-04 09:14:49Z tovar $
+ *  $Id: statusbarprogreso.cpp 4784 2012-03-08 12:05:06Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -200,11 +200,12 @@ void GNC::GUI::StatusBarProgreso::ActualizarInterfaz()
 	//Layout();
 }
 
-void GNC::GUI::StatusBarProgreso::OnMostrarOcultarDialogoProgreso(wxMouseEvent& )
+void GNC::GUI::StatusBarProgreso::ShowProgressDialog(bool show)
 {
-	if (GNC::GCS::ControladorVistas::Instance()->EsVisible(m_pPanelTareas)) {
+	bool isShown = GNC::GCS::ControladorVistas::Instance()->EsVisible(m_pPanelTareas);
+	if (!show && isShown) {
 		GNC::GCS::ControladorVistas::Instance()->OcultarPanel(m_pPanelTareas);
-	} else {
+	} else if (show && !isShown) {
 		wxPoint esquinaInferiorDerecha = GetParent()->GetPosition();
 		esquinaInferiorDerecha.x += GetParent()->GetSize().x;
 		esquinaInferiorDerecha.y += GetParent()->GetSize().y;
@@ -221,6 +222,11 @@ void GNC::GUI::StatusBarProgreso::OnMostrarOcultarDialogoProgreso(wxMouseEvent&
 	}
 }
 
+void GNC::GUI::StatusBarProgreso::OnMostrarOcultarDialogoProgreso(wxMouseEvent& )
+{
+	ShowProgressDialog(!GNC::GCS::ControladorVistas::Instance()->EsVisible(m_pPanelTareas));
+}
+
 
 void GNC::GUI::StatusBarProgreso::OnSize(wxSizeEvent& event)
 {
