@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: widgetsmanager.cpp 3754 2011-04-25 07:11:36Z tovar $
+ *  $Id: widgetsmanager.cpp 4534 2012-01-16 08:35:05Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -170,8 +170,8 @@ void GNC::WidgetsManager::RenderPrivate(GNC::GCS::Contexto3D* c)
 	}
 
 	if (c->GetRenderer() == m_pRendererActivo) {
-		if (m_pBuilder != NULL) {
-			m_pBuilder->Render(c);
+		for (GNC::GCS::ListaBuilders::iterator it = m_pBuilders.begin(); it != m_pBuilders.end(); it++) {
+			(*it)->Render(c);
 		}
 	}
 
@@ -189,10 +189,10 @@ void GNC::WidgetsManager::RenderPrivate(GNC::GCS::Contexto3D* c)
 			}
 		}
 
-		if (m_pBuilder != NULL) {
+		for (GNC::GCS::ListaBuilders::iterator it = m_pBuilders.begin(); it != m_pBuilders.end(); it++) {
 			if (!boundingBox.EsNulo()) {
 				if (m_pRendererActivo != NULL) {
-					m_pRendererActivo->ImprimirOverlay(m_pBuilder, c, boundingBox);
+					m_pRendererActivo->ImprimirOverlay(*it, c, boundingBox);
 				}
 			}
 		}
@@ -210,21 +210,36 @@ void GNC::WidgetsManager::RenderPrivate(GNC::GCS::Contexto3D* c)
 			//std::cout << "WIluminado !IZDown: Mano Abierta " << std::endl;
 		}
 	} else {
-		//si esta haciendo pam
-		if(m_mouseDerechoDown) {
-			//std::cout << "!WIluminado: DERDown: Mano Cerrada " << std::endl;
-			SetCursor(GNC::GCS::Widgets::CUR_MANO_CERRADA);
-		} else {
-			//si no se lo pedimos al builder
-			if(m_pBuilder != NULL && m_pBuilder->GetCursor() != GNC::GCS::Widgets::CUR_INVALIDO){
-				//std::cout << "!WIluminado: !DERDown: Builder cursor " << std::endl;
-				SetCursor(m_pBuilder->GetCursor());
-			} else {
-				//y si no pues si esta pulsando el derecho es que esta haciendo pan
-				//std::cout << "!WIluminado: !DERDown: Flecha" << std::endl;
-				SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
+		bool cursorNotFound = true;
+		if (m_mouseDerechoDown) {
+			//builder que atienda al boton derecho
+			for (GNC::GCS::ListaBuilders::iterator it = m_pBuilders.begin(); cursorNotFound && it != m_pBuilders.end(); it++) {
+				if ((*it)->GetButtonMask().IsRightEnabled()) {
+					if((*it)->GetCursor() != GNC::GCS::Widgets::CUR_INVALIDO){
+						//std::cout << "!WIluminado: !DERDown: Builder cursor " << std::endl;
+						SetCursor((*it)->GetCursor());
+						cursorNotFound = false;
+					}
+				}
 			}
 		}
+		if (m_mouseIzquierdoDown || cursorNotFound) {
+			//si no se lo pedimos al primer builder que encontremos		
+			for (GNC::GCS::ListaBuilders::iterator it = m_pBuilders.begin(); cursorNotFound && it != m_pBuilders.end(); it++) {
+				if ((*it)->GetButtonMask().IsLeftEnabled()) {
+					if((*it)->GetCursor() != GNC::GCS::Widgets::CUR_INVALIDO){
+						//std::cout << "!WIluminado: !DERDown: Builder cursor " << std::endl;
+						SetCursor((*it)->GetCursor());
+						cursorNotFound = false;
+					}
+				}
+			}
+		}
+		if (cursorNotFound) {
+			//y si no pues si esta pulsando el derecho es que esta haciendo pan
+			//std::cout << "!WIluminado: !DERDown: Flecha" << std::endl;
+			SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
+		}
 	}
 
 	c->GetRenderer()->Modificar(false);
@@ -375,8 +390,8 @@ void GNC::WidgetsManager::OnMouseEvents(GNC::GCS::Eventos::EventoRaton& evento)
 		}
 	}
 
-	if (m_pBuilder != NULL && evento.GetSkipped()) {
-		m_pBuilder->OnMouseEvents(evento);
+	for (GNC::GCS::ListaBuilders::iterator it = m_pBuilders.begin(); evento.GetSkipped() && it != m_pBuilders.end(); it++) {
+		(*it)->OnMouseEvents(evento);
 	}
 
 	if (evento.GetSkipped()) {
@@ -416,8 +431,8 @@ void GNC::WidgetsManager::OnKeyEvents(GNC::GCS::Eventos::EventoTeclado& evento)
 		}
 	}
 
-	if (m_pBuilder != NULL) {
-		m_pBuilder->OnKeyEvents(evento);
+	for (GNC::GCS::ListaBuilders::iterator it = m_pBuilders.begin(); it != m_pBuilders.end(); it++) {
+		(*it)->OnKeyEvents(evento);
 	}
 
 	// Primera pasada: widgets toplevel.
@@ -493,9 +508,14 @@ void GNC::WidgetsManager::DefaultMouseEventProcess(GNC::GCS::Eventos::EventoRato
 					GetMenuContextual(&menu);
 					//en este caso hay varios seleccionados pues se muestra el menu comun...
 					evento.c->pWindow->PopupMenu(&menu,wxPoint(evento.sX, evento.sY));
-					if(m_pBuilder != NULL && m_pBuilder->GetCursor() != GNC::GCS::Widgets::CUR_INVALIDO){
-						SetCursor(m_pBuilder->GetCursor());
-					} else {
+					bool cursorNotFound = true;
+					for (GNC::GCS::ListaBuilders::iterator it = m_pBuilders.begin(); cursorNotFound && it != m_pBuilders.end(); it++) {
+						if ((*it)->GetCursor() != GNC::GCS::Widgets::CUR_INVALIDO) {
+							SetCursor((*it)->GetCursor());
+							cursorNotFound = false;
+						}
+					}
+					if (cursorNotFound) {
 						//y si no pues si esta pulsando el derecho es que esta haciendo pan
 						SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
 					}
@@ -537,23 +557,8 @@ void GNC::WidgetsManager::DefaultMouseEventProcess(GNC::GCS::Eventos::EventoRato
 
 				//en este caso hay varios seleccionados pues se muestra el menu comun...
 				evento.c->pWindow->PopupMenu(&menu, wxPoint(evento.sX, evento.sY));
-				if(m_pBuilder != NULL && m_pBuilder->GetCursor() != GNC::GCS::Widgets::CUR_INVALIDO){
-					SetCursor(m_pBuilder->GetCursor());
-				} else {
-					//y si no pues si esta pulsando el derecho es que esta haciendo pan
-					SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
-				}
 				ConsumirEvento();
 			}
-			else {
-				if(m_pBuilder != NULL && m_pBuilder->GetCursor() != GNC::GCS::Widgets::CUR_INVALIDO){
-					SetCursor(m_pBuilder->GetCursor());
-				} else {
-					//y si no pues si esta pulsando el derecho es que esta haciendo pan
-					SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
-				}
-
-			}
 		}
 	} else {
 		evento.Skip(true);
