@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: herramientaelevacion.cpp 4478 2011-12-13 11:55:00Z carlos $
+ *  $Id: herramientaelevacion.cpp 4869 2012-04-19 11:47:15Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -237,13 +237,13 @@ void GNC::HerramientaElevacion::ConectarContratoFalso(bool activar) {
 			pC->GetManager()->EnableAnotacionDinamica(activar);
 			if (activar) {
 				GTRACE( "HerramientaElevacion: Conectando contrato falso de vista " << TContratableWidgets::m_pVistaActiva );
-				pC->GetViewer()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
+				pC->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
 				pC->GetManager()->SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
 				pC->GetManager()->Render();
 			}
 			else {
 				GTRACE( "HerramientaElevacion: Desconectando contrato falso de vista " << TContratableWidgets::m_pVistaActiva );
-				pC->GetViewer()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
+				pC->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
 				pC->GetManager()->SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
 			}
 		}
@@ -295,7 +295,7 @@ void GNC::HerramientaElevacion::ConectarContratos(bool activar)
 				}
 				//conectamos los observadores
 				m_pElevacionBuilder->SetObservador(this);
-				pCW->GetViewer()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
+				pCW->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
 				pCW->GetManager()->SetCursor(m_pElevacionBuilder->GetCursor());
 				pCW->GetManager()->Render();
 				if(pCE->m_modoMascara) {
@@ -317,7 +317,7 @@ void GNC::HerramientaElevacion::ConectarContratos(bool activar)
 						break;
 					}
 				}
-				pCW->GetViewer()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
+				pCW->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
 				pCW->GetManager()->SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
 			}
 		}
