@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: herramientainterpolate.cpp 4478 2011-12-13 11:55:00Z carlos $
+ *  $Id: herramientainterpolate.cpp 4869 2012-04-19 11:47:15Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -132,7 +132,7 @@ bool GNC::HerramientaInterpolate::IsSet()
 	if(TContratableWidgets::m_pVistaActiva != NULL && TContratableWidgets::m_pListaActiva != NULL) {
 		for (TContratableWidgets::IteradorListaContratos it1 = TContratableWidgets::m_pListaActiva->begin(); it1 != TContratableWidgets::m_pListaActiva->end(); it1++) {
 			TContratoWidgets* pCW = (*it1);
-			isSet = pCW->GetViewer()->GetInterpolationMode() == VTK_LINEAR_INTERPOLATION;
+			isSet = pCW->GetViewerActivo()->GetInterpolationMode() == VTK_LINEAR_INTERPOLATION;
 		}
 	}
 	return isSet;
@@ -145,10 +145,20 @@ void GNC::HerramientaInterpolate::SolicitarActivacion(const GNC::GCS::TriggerBut
 		TContratoWidgets* pCW = (*it1);
 		// Copio la lista
 		if (pCW->Inicializado()) {
-			if (pCW->GetViewer()->GetInterpolationMode() == VTK_LINEAR_INTERPOLATION) {
-				pCW->GetViewer()->SetInterpolationMode(VTK_NEAREST_INTERPOLATION);
-			} else {
-				pCW->GetViewer()->SetInterpolationMode(VTK_LINEAR_INTERPOLATION);
+			TContratoWidgets::TViewerList list;
+			pCW->GetAllViewers(list);
+			bool enable = false;
+			if (pCW->GetViewerActivo()->GetInterpolationMode() == VTK_LINEAR_INTERPOLATION) {
+				enable = true;
+			}
+			for (TContratoWidgets::TViewerList::iterator it = list.begin(); it != list.end(); it++) {
+				vtkGinkgoImageViewer* pW = (*it);
+				if (enable) {
+					pW->SetInterpolationMode(VTK_NEAREST_INTERPOLATION);
+				}
+				else {
+					pW->SetInterpolationMode(VTK_LINEAR_INTERPOLATION);
+				}
 			}
 			GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GCS::Eventos::EventoRender(TContratableWidgets::m_pVistaActiva));
 		}
