@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: herramientainterpolate.h 4090 2011-08-25 12:17:45Z tovar $
+ *  $Id: herramientainterpolate.h 4478 2011-12-13 11:55:00Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -41,7 +41,7 @@ namespace GNC {
 
 		bool IsSet();
 		//cuando hacen click en ella...
-		virtual void SolicitarActivacion();
+		virtual void SolicitarActivacion(const GNC::GCS::TriggerButton& buttonmask);
 
 		virtual void ConectarContratoFalso(bool activar);
 		virtual void SetVistaActiva(GNC::GCS::IVista* pVista);
