@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: herramientamarcado.cpp 4506 2012-01-11 11:21:21Z tovar $
+ *  $Id: herramientamarcado.cpp 4869 2012-04-19 11:47:15Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -280,12 +280,12 @@ void GNC::HerramientaMarcado::ConectarContratoFalso(bool activar) {
 		if (pC->Inicializado()) {
 			if (activar) {
 				GTRACE("HerramientaMarcado: Conectando contrato falso de vista " << ICConcreto::m_pVistaActiva);
-				pC->GetViewer()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
+				pC->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
 				pC->GetManager()->SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
 
 			} else {
 				GTRACE("HerramientaMarcado: Desconectando contrato falso de vista " << ICConcreto::m_pVistaActiva);
-				pC->GetViewer()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
+				pC->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
 				pC->GetManager()->SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
 			}
 		}
@@ -318,7 +318,7 @@ void GNC::HerramientaMarcado::ConectarContratos(bool activar) {
 				GTRACE("HerramientaMarcado: Conectando contratos de vista " << ICConcreto::m_pVistaActiva);
 				m_pContratoActivo = pC;
 				SetTipoMarcado(m_MarcadoActivo);
-				pC->GetViewer()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
+				pC->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
 				if (m_pBuilder != NULL) {
 					pC->GetManager()->SetCursor(m_pBuilder->GetCursor());
 				}
@@ -329,7 +329,7 @@ void GNC::HerramientaMarcado::ConectarContratos(bool activar) {
 			} else {
 				m_pContratoActivo = NULL;
 				GTRACE( "HerramientaMarcado: Desconectando contratos de vista " << ICConcreto::m_pVistaActiva );
-				pC->GetViewer()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
+				pC->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
 				pC->GetManager()->SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
 				if (m_pBuilder != NULL) {
 					delete m_pBuilder;
