@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: herramientapaneltags.h 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: herramientapaneltags.h 4478 2011-12-13 11:55:00Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -42,7 +42,7 @@ namespace GNC {
 
 		//cuando hacen click en ella...
 		bool IsVisible();
-		virtual void SolicitarActivacion();
+		virtual void SolicitarActivacion(const GNC::GCS::TriggerButton& buttonmask);
 
 		virtual void ConectarContratoFalso(bool activar);
 		virtual void SetVistaActiva(GNC::GCS::IVista* pVista);
