@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: toolpan.h 4490 2011-12-14 09:56:19Z carlos $
+ *  $Id: toolpan.h 4851 2012-04-18 11:59:41Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -14,13 +14,12 @@
 #pragma once
 #include <api/api.h>
 #include <export/itoolpan.h>
-#include <api/toolhandlers/ipanhandler.h>
 #include <widgets/wpan.h>
 
 
 namespace GNC {
 
-	class EXTAPI ToolPan : public GNC::GCS::IToolPan, public GNC::GCS::ToolHandlers::IPanHandler {
+	class EXTAPI ToolPan : public GNC::GCS::IToolPan {
 	public:
 		typedef GNC::GCS::Eventos::EventoRaton       TEventoRaton;
 		typedef GNC::GCS::Eventos::EventoTeclado     TEventoTeclado;
@@ -41,10 +40,6 @@ namespace GNC {
 
 //region "Eventos refinados desde los paneles"
 
-//endregion
-
-//region "Pan Handler realization"
-		virtual void Pan();
 //endregion
 		
 	protected:
