@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ginkgoresourcemanager.cpp 4511 2012-01-12 07:34:48Z tovar $
+ *  $Id: ginkgoresourcemanager.cpp 4706 2012-02-16 07:59:43Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -112,6 +112,8 @@ const wxBitmap GinkgoResourcesManager::PanelHistorial::GetIcoFicheroClave(){retu
 const wxBitmap GinkgoResourcesManager::PanelHistorial::GetIcoPlegar(){return wxMEMORY_BITMAP(ico_plegar); }
 const wxBitmap GinkgoResourcesManager::PanelHistorial::GetIcoDesplegar(){return wxMEMORY_BITMAP(ico_desplegar); }
 const wxBitmap GinkgoResourcesManager::PanelHistorial::GetMoviePreview(){return wxMEMORY_BITMAP(ico_movie_preview); }
+const wxBitmap GinkgoResourcesManager::PanelHistorial::GetPDFPreview(){return wxMEMORY_BITMAP(ico_pdf_preview); }
+const wxBitmap GinkgoResourcesManager::PanelHistorial::GetIcoUnknownFile(){return wxMEMORY_BITMAP(ico_unknown_file); }
 const wxBitmap GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll() {return wxMEMORY_BITMAP(ico_clean_all);}
 const wxBitmap GinkgoResourcesManager::PanelHistorial::GetIcoAllPatients() {return wxMEMORY_BITMAP(ico_all_patients);}
 // Iconos de herramientas
@@ -169,7 +171,8 @@ const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoUser(){return wxMEMORY
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoHelp(){return wxMEMORY_BITMAP(ico_help); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoSupport(){return wxMEMORY_BITMAP(ico_support); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoObtainExtensions(){return wxMEMORY_BITMAP(ico_obtain_extensions); }
-
+const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoTick(){return wxMEMORY_BITMAP(ico_tick); }
+const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoCross(){return wxMEMORY_BITMAP(ico_cross); }
 
 // Logos
 const wxBitmap GinkgoResourcesManager::Logos::GetLogoGinkgo48x48() {return wxMEMORY_BITMAP(ginkgo48x48); } // Not used
