@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ginkgoresourcemanager.h 4511 2012-01-12 07:34:48Z tovar $
+ *  $Id: ginkgoresourcemanager.h 4706 2012-02-16 07:59:43Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -95,6 +95,8 @@
 		static const wxBitmap GetIcoPlegar();
 		static const wxBitmap GetIcoDesplegar();
 		static const wxBitmap GetMoviePreview();
+		static const wxBitmap GetPDFPreview();
+		static const wxBitmap GetIcoUnknownFile();
 		static const wxBitmap GetIcoCleanAll();
 		static const wxBitmap GetIcoAllPatients();
  	};
@@ -157,6 +159,8 @@
 		static const wxBitmap GetIcoHelp();
 		static const wxBitmap GetIcoSupport();
 		static const wxBitmap GetIcoObtainExtensions();
+		static const wxBitmap GetIcoTick();
+		static const wxBitmap GetIcoCross();
  	};
 
  	class EXTAPI Logos {
