@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: iconos.h 4367 2011-11-04 10:58:44Z tovar $
+ *  $Id: iconos.h 4706 2012-02-16 07:59:43Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -27,3 +27,5 @@
 #include "ico_movie_preview.h"
 #include "ico_clean_all.h"
 #include "ico_all_patients.h"
+#include "ico_pdf_preview.h"
+#include "ico_unknown_file.h"
