@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: iconos.h 3756 2011-04-25 08:57:12Z tovar $
+ *  $Id: iconos.h 4511 2012-01-12 07:34:48Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -23,6 +23,9 @@
 #include "ico_lazo_chroma.h"
 #include "ico_wl.h"
 #include "ico_zoom.h"
+#include "ico_slider.h"
+#include "ico_pan.h"
+#include "ico_lupa.h"
 #include "ico_sin_opciones.h"
 #include "ico_debug.h"
 #include "ico_marcado.h"
@@ -31,3 +34,7 @@
 #include "ico_desencajar.h"
 #include "ico_corner_annotations.h"
 #include "ico_informe.h"
+#include "ico_mouse_r.h"
+#include "ico_mouse_l.h"
+#include "ico_mouse_rl.h"
+
