@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: iconos.h 4502 2012-01-09 12:19:39Z tovar $
+ *  $Id: iconos.h 4625 2012-01-30 09:27:26Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -40,3 +40,5 @@
 #include "ico_obtain_extensions.h"
 #include "ico_dicom_dir.h"
 #include "ico_open_disc.h"
+#include "ico_tick.h"
+#include "ico_cross.h"
