@@ -49,6 +49,7 @@ GinkgoInteractorStyleImage2D::GinkgoInteractorStyleImage2D()
 	this->ZSliceStep = 0;
 	this->LevelStep = 0.0;
 	this->WindowStep = 0.0;
+	this->PreviewMode = false;
 }
 
 //----------------------------------------------------------------------------
@@ -93,10 +94,10 @@ void GinkgoInteractorStyleImage2D::OnMouseMove()
 			break;
 
 		case VTKIS_PAN:
-			this->FindPokedRenderer(x, y);
-			this->Pan();
-			this->PropagateCameraFocalAndPosition();
-			this->InvokeEvent(vtkCommand::InteractionEvent, NULL);			
+			//this->FindPokedRenderer(x, y);
+			//this->Pan();
+			//this->PropagateCameraFocalAndPosition();
+			//this->InvokeEvent(vtkCommand::InteractionEvent, NULL);
 			break;
 		default:
 			break;
@@ -124,7 +125,7 @@ void GinkgoInteractorStyleImage2D::PropagateCameraFocalAndPosition()
 	this->GetView()->SyncSetCameraFocalAndPosition(focal, pos);
 	this->GetView()->SetLinkCameraFocalAndPosition(LinkCamera);
 
-	//this->GetView()->Render();
+	this->GetView()->Render();
 
 
 }
@@ -152,15 +153,15 @@ void GinkgoInteractorStyleImage2D::OnLeftButtonDown()
 			break;
 		*/
 		case vtkGinkgoImageViewer::SELECT_INTERACTION :
-			/*
-			this->StartPick();
-			*/
+			if (this->PreviewMode) {
+				this->StartPick();
+			}
 			break;
 		case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION :
-			/*
-			this->StartPick();
-			this->StopState();
-			*/
+			if (this->PreviewMode) {
+				this->StartPick();
+				this->StopState();
+			}
 			//this->StartPan();
 			break;
 		/*
@@ -206,11 +207,16 @@ void GinkgoInteractorStyleImage2D::OnMiddleButtonDown()
 			break;
 		*/
 		case vtkGinkgoImageViewer::SELECT_INTERACTION :
-			//this->StartPick();
+		if (this->PreviewMode) {
+			this->StartPick();
+		} else {
 			this->StartPan();
+		}
 			break;
 		case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION :
-			this->StartPan();
+			if (!this->PreviewMode) {
+				this->StartPan();
+			}
 			break;
 		/*
 		case vtkGinkgoImageViewer::FULL_PAGE_INTERACTION :
@@ -221,7 +227,9 @@ void GinkgoInteractorStyleImage2D::OnMiddleButtonDown()
 			break;
 		*/
 		case vtkGinkgoImageViewer::ZOOM_INTERACTION :
-			this->StartPan();
+			if (!this->PreviewMode) {
+				this->StartPan();
+			}
 			break;
 	}
 }
@@ -232,32 +240,28 @@ void GinkgoInteractorStyleImage2D::OnMiddleButtonUp()
 {
 	switch (this->State) {
 		case VTKIS_ZSLICE_MOVE:
-			/*
+		if (this->PreviewMode) {
 			this->EndZSliceMove();
-			*/
+}
 			break;
 		case VTKIS_WINDOW_LEVEL:
-			/*
-			this->EndWindowLevel();
-			*/
+			if (this->PreviewMode) {			this->EndWindowLevel();
+}
 			break;
 		case VTKIS_PICK:
-			/*
-			this->EndPick();
-			*/
+			if (this->PreviewMode) {			this->EndPick();
+}
 			break;
 		case VTKIS_MEASURE:
-			/*
-			this->EndMeasure();
-			*/
+			if (this->PreviewMode) {			this->EndMeasure();
+}
 			break;
 		case VTKIS_PAN:
 			this->EndPan();
 			break;
 		case VTKIS_DOLLY:
-			/*
-			this->EndDolly(); // continuous zoom
-			*/
+			if (this->PreviewMode) {			this->EndDolly(); // continuous zoom
+}
 			break;
 	}
 
@@ -269,34 +273,28 @@ void GinkgoInteractorStyleImage2D::OnLeftButtonUp()
 {
 	switch (this->State) {
 		case VTKIS_ZSLICE_MOVE:
-			/*
-			this->EndZSliceMove();
-			*/
+			if (this->PreviewMode) {			this->EndZSliceMove();
+}
 			break;
 		case VTKIS_WINDOW_LEVEL:
-			/*
-			this->EndWindowLevel();
-			*/
+			if (this->PreviewMode) {			this->EndWindowLevel();
+}
 			break;
 		case VTKIS_PICK:
-			/*
-			this->EndPick();
-			*/
+			if (this->PreviewMode) {			this->EndPick();
+}
 			break;
 		case VTKIS_MEASURE:
-			/*
-			this->EndMeasure();
-			*/
+			if (this->PreviewMode) {			this->EndMeasure();
+}
 			break;
 		case VTKIS_DOLLY: // continuous zoom
-			/*
-			this->EndDolly();
-			*/
+			if (this->PreviewMode) {			this->EndDolly();
+}
 			break;
 		case VTKIS_PAN: // continuous zoom
-			/*
-			this->EndPan();
-			*/
+			if (this->PreviewMode) {			this->EndPan();
+}
 			break;
 	}
 }
@@ -322,15 +320,13 @@ void GinkgoInteractorStyleImage2D::OnRightButtonDown()
 			this->StartWindowLevel();
 			break;
 		*/
-		case vtkGinkgoImageViewer::SELECT_INTERACTION:
-			/*
-			this->StartPick();
-			*/
+		case vtkGinkgoImageViewer::SELECT_INTERACTION :
+			if (this->PreviewMode) {			this->StartPick();
+}
 			break;
-		case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION:
-			/*
-			this->StartPan();
-			*/
+		case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION :
+			if (this->PreviewMode) {			this->StartPan();
+}
 			break;
 		/*
 		case vtkGinkgoImageViewer::FULL_PAGE_INTERACTION :
@@ -340,9 +336,10 @@ void GinkgoInteractorStyleImage2D::OnRightButtonDown()
 			this->StartMeasure();
 			break;
 		*/
-		case vtkGinkgoImageViewer::ZOOM_INTERACTION:
+		case vtkGinkgoImageViewer::ZOOM_INTERACTION :
 			/*
-			this->StartPan();
+			if (this->PreviewMode) {			this->StartPan();
+			}
 			*/
 			break;
 	}
@@ -354,33 +351,29 @@ void GinkgoInteractorStyleImage2D::OnRightButtonUp()
 {
 	switch (this->State) {
 		case VTKIS_ZSLICE_MOVE:
-			/*
-			this->EndZSliceMove();
-			*/
+			if (this->PreviewMode) {			this->EndZSliceMove();
+}
 			break;
 		case VTKIS_WINDOW_LEVEL:
-			/*
-			this->EndWindowLevel();
-			*/
+			if (this->PreviewMode) {			this->EndWindowLevel();
+}
 			break;
 		case VTKIS_PICK:
-			/*
-			this->EndPick();
-			*/
+			if (this->PreviewMode) {			this->EndPick();
+}
 			break;
 		case VTKIS_MEASURE:
-			/*
-			this->EndMeasure();
-			*/
+			if (this->PreviewMode) {			this->EndMeasure();
+}
 			break;
 		case VTKIS_DOLLY: // continuous zoom
-			/*
-			this->EndDolly();
-			*/
+			if (this->PreviewMode) {			this->EndDolly();
+}
 			break;
 		case VTKIS_PAN:
 			/*
-			this->EndPan();
+			if (this->PreviewMode) {			this->EndPan();
+			}
 			*/
 			break;
 	}
