@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: vtkginkgoimageviewer.h 4090 2011-08-25 12:17:45Z tovar $
+ *  $Id: vtkginkgoimageviewer.h 4335 2011-10-26 09:42:35Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -307,12 +307,15 @@ public:
 	void ResetToDefaultWindowLevel();
 
 	void SyncSetCameraFocalAndPosition(double* focal, double* pos);
+	void GetRelativePositionOfCamera(double focal[3], double pos[3]);
+	void SetRelativePositionOfCamera(const double focal[3], const double pos[3]);
 
 	void SetLookupTable(vtkSmartPointer<vtkScalarsToColors> lut, int idLookupTable);
 	vtkSmartPointer<vtkScalarsToColors> GetLookupTable();
 	int GetIdLookupTable();
 
 	//region Control: Zoom
+	void SetInitialParallelScale(double scale);
 	void ResetZoom(bool mantenerZoom = false);
 
 	/** Set the actual zoom factor of the view. */
