@@ -1,26 +1,26 @@
 
 /*
- *  
- *  $Id$
- *  Ginkgo CADx Project
- *
- *  Code adapted from VTK
- *
- *
+*  
+*  $Id$
+*  Ginkgo CADx Project
+*
+*  Code adapted from VTK
+*
+*
 =========================================================================
 
- Program:   Visualization Toolkit
- Module:    $RCSfile: vtkGinkgoOpenGLTexture.cxx,v $
+Program:   Visualization Toolkit
+Module:    $RCSfile: vtkGinkgoOpenGLTexture.cxx,v $
 
- Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
- All rights reserved.
- See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
+Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+All rights reserved.
+See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
 
- This software is distributed WITHOUT ANY WARRANTY; without even
- the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- PURPOSE.  See the above copyright notice for more information.
+This software is distributed WITHOUT ANY WARRANTY; without even
+the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+PURPOSE.  See the above copyright notice for more information.
 
- =========================================================================*/
+=========================================================================*/
 #if defined(__DEPRECATED)
 #undef __DEPRECATED
 #endif
@@ -52,6 +52,7 @@
 #include <limits>
 
 #include <main/controllers/controladorlog.h>
+#include <main/controllers/controladorpermisos.h>
 
 #ifndef VTK_IMPLEMENT_MESA_CXX
 vtkCxxRevisionMacro(vtkGinkgoOpenGLTexture, "$Revision: 1.81 $");
@@ -79,6 +80,7 @@ vtkGinkgoOpenGLTexture::vtkGinkgoOpenGLTexture()
 	this->zsize=0;
 	this->TIndex=0;
 	this->TIndexChanged=false;
+	this->LookupTableChanged = false;
 
 }
 
@@ -86,13 +88,13 @@ vtkGinkgoOpenGLTexture::vtkGinkgoOpenGLTexture()
 vtkGinkgoOpenGLTexture::~vtkGinkgoOpenGLTexture()
 {
 	if (this->RenderWindow)
-    {
+	{
 		this->ReleaseGraphicsResources(this->RenderWindow);
-    }
+	}
 	if(this->PBO!=0)
-    {
+	{
 		vtkErrorMacro(<< "PBO should have been deleted in ReleaseGraphicsResources()");
-    }
+	}
 	this->RenderWindow = NULL;
 }
 
@@ -101,12 +103,19 @@ void vtkGinkgoOpenGLTexture::Initialize(vtkRenderer * vtkNotUsed(ren))
 {
 }
 
+void vtkGinkgoOpenGLTexture::SetLookupTable(vtkScalarsToColors* table)
+{
+	vtkOpenGLTexture::SetLookupTable(table);
+	this->LookupTableChanged = true;
+
+}
+
 // ----------------------------------------------------------------------------
 // Release the graphics resources used by this texture.
 void vtkGinkgoOpenGLTexture::ReleaseGraphicsResources(vtkWindow *renWin)
 {
 	if (this->Index && renWin && renWin->GetMapped())
-    {
+	{
 		static_cast<vtkRenderWindow *>(renWin)->MakeCurrent();
 #ifdef GL_VERSION_1_1
 		// free any textures
@@ -115,7 +124,7 @@ void vtkGinkgoOpenGLTexture::ReleaseGraphicsResources(vtkWindow *renWin)
 			GLuint tempIndex;
 			tempIndex = this->Index;
 			// NOTE: Sun's OpenGL seems to require disabling of texture before delete
-			glDisable(GL_TEXTURE_2D);
+			//glDisable(GL_TEXTURE_2D);
 			glDeleteTextures(1, &tempIndex);
 		}
 #else
@@ -124,17 +133,17 @@ void vtkGinkgoOpenGLTexture::ReleaseGraphicsResources(vtkWindow *renWin)
 			glDeleteLists(this->Index,1);
 		}
 #endif
-    }
+	}
 	this->Index = 0;
 	this->RenderWindow = NULL;
 	this->CheckedHardwareSupport=false;
 	this->SupportsNonPowerOfTwoTextures=false;
 	this->SupportsPBO=false;
 	if(this->PBO!=0)
-    {
+	{
 		this->PBO->Delete();
 		this->PBO=0;
-    }
+	}
 	this->Modified();
 }
 
@@ -142,10 +151,14 @@ void vtkGinkgoOpenGLTexture::ReleaseGraphicsResources(vtkWindow *renWin)
 // Implement base class method.
 void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 {
-    this->Lock(GLOC());
-	GLenum format = GL_LUMINANCE;
+	this->Lock(GLOC());
 	vtkImageData *input = this->GetInput();
 
+	GLenum TexFormat         = GL_LUMINANCE;
+	GLenum TexInternalFormat = GL_LUMINANCE;
+	GLenum TexType           = GL_UNSIGNED_BYTE;
+
+
 	this->Initialize(ren);
 
 	// Need to reload the texture.
@@ -157,68 +170,68 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 	vtkOpenGLRenderWindow* renWin = static_cast<vtkOpenGLRenderWindow*>(ren->GetRenderWindow());
 
 	if(this->BlendingMode != VTK_TEXTURE_BLENDING_MODE_NONE && vtkgl::ActiveTexture)
-    {
+	{
 		glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, vtkgl::COMBINE);
 
 		switch(this->BlendingMode)
 		{
-			case VTK_TEXTURE_BLENDING_MODE_REPLACE:
+		case VTK_TEXTURE_BLENDING_MODE_REPLACE:
 			{
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_RGB, GL_REPLACE);
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_ALPHA, GL_REPLACE);
 				break;
 			}
-			case VTK_TEXTURE_BLENDING_MODE_MODULATE:
+		case VTK_TEXTURE_BLENDING_MODE_MODULATE:
 			{
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_RGB, GL_MODULATE);
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_ALPHA, GL_MODULATE);
 				break;
 			}
-			case VTK_TEXTURE_BLENDING_MODE_ADD:
+		case VTK_TEXTURE_BLENDING_MODE_ADD:
 			{
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_RGB, GL_ADD);
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_ALPHA, GL_ADD);
 				break;
 			}
-			case VTK_TEXTURE_BLENDING_MODE_ADD_SIGNED:
+		case VTK_TEXTURE_BLENDING_MODE_ADD_SIGNED:
 			{
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_RGB, vtkgl::ADD_SIGNED);
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_ALPHA, vtkgl::ADD_SIGNED);
 				break;
 			}
-			case VTK_TEXTURE_BLENDING_MODE_INTERPOLATE:
+		case VTK_TEXTURE_BLENDING_MODE_INTERPOLATE:
 			{
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_RGB, vtkgl::INTERPOLATE);
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_ALPHA, vtkgl::INTERPOLATE);
 				break;
 			}
-			case VTK_TEXTURE_BLENDING_MODE_SUBTRACT:
+		case VTK_TEXTURE_BLENDING_MODE_SUBTRACT:
 			{
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_RGB, vtkgl::SUBTRACT);
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_ALPHA, vtkgl::SUBTRACT);
 				break;
 			}
-			default:
+		default:
 			{
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_RGB, GL_ADD);
 				glTexEnvf (GL_TEXTURE_ENV, vtkgl::COMBINE_ALPHA, GL_ADD);
 			}
 		}
-    }
+	}
 
 	bool ImageDataChanged =
-		   ( this->GetMTime() > this->LoadTime.GetMTime() )
+		( this->GetMTime() > this->LoadTime.GetMTime() )
 		|| ( input->GetMTime() > this->LoadTime.GetMTime() )
-		|| ( this->GetLookupTable() && (this->GetLookupTable()->GetMTime () > this->LoadTime.GetMTime()) )
+		|| ( !UseShader && this->GetLookupTable() && (this->GetLookupTable()->GetMTime () > this->LoadTime.GetMTime()) )
 		|| ( renWin != this->RenderWindow.GetPointer() )
 		|| ( renWin->GetContextCreationTime() > this->LoadTime );
 
 	if (TIndexChanged || ImageDataChanged )
-    {
+	{
 		int bytesPerPixel;
 		int size[3];
 		vtkDataArray *scalars = NULL;
-		unsigned char *dataPtr;
+		unsigned char* vptr = NULL;
 		unsigned char *resultData=NULL;
 		int xsize, ysize;
 		unsigned int xs,ys;
@@ -235,7 +248,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 		if (!input || !scalars)
 		{
 			LOG_ERROR("OpenGLComponent", "NULL INPUT");
-		    this->UnLock(GLOC());
+			this->UnLock(GLOC());
 			return;
 		}
 
@@ -268,9 +281,28 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 		if (xsize == 0 || ysize == 0 || zsize == 0)
 		{
 			LOG_ERROR("OpenGLComponent", "Wrong size: " << xsize << "x" << ysize << "x" << zsize);
-		    this->UnLock(GLOC());
+			this->UnLock(GLOC());
 			return;
 		}
+		///CHECK HARDWARE SUPPORT
+		if(!this->CheckedHardwareSupport)
+		{
+			vtkOpenGLExtensionManager *m = renWin->GetExtensionManager();
+			this->CheckedHardwareSupport = true;
+			this->SupportsNonPowerOfTwoTextures = m->ExtensionSupported("GL_VERSION_2_0") || m->ExtensionSupported("GL_ARB_texture_non_power_of_two");
+			this->SupportsPBO=vtkPixelBufferObject::IsSupported(renWin);
+
+			int supports_GL_VERSION_2_0=m->ExtensionSupported("GL_VERSION_2_0");
+			if(supports_GL_VERSION_2_0)
+			{
+				m->LoadExtension("GL_ARB_multitexture");
+				m->LoadExtension("GL_VERSION_2_0");
+				//ENABLE/DISABLE SHADER!
+				if (GNC::GCS::ControladorPermisos::Instance()->Get("core.opengl", "enable_shaders").Activo()) {
+					this->UseShader = true;
+				}
+			}
+		}
 
 
 		TIndex = std::max<int>(0, std::min<int>(TIndex, zsize - 1));
@@ -279,30 +311,131 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 		//LOG_DEBUG("OpenGLComponent", "Fijado indice " << TIndex);
 
 		// make sure using unsigned char data of color scalars type
+		// IF MAP SCALARS
 		if (1 && (this->MapColorScalarsThroughLookupTable ||
 			scalars->GetDataType() != VTK_UNSIGNED_CHAR) )
 		{
-			void* vptr = scalars->GetVoidPointer(0);
-		    if (vptr == NULL) {
-				LOG_ERROR("OpenGLComponent", "Could not get pixel data pointer");
-		        this->UnLock(GLOC());
-		        return;
-		    }
 			const unsigned int wdh = size[0] * size[1];
 			const unsigned int numComponents = scalars->GetNumberOfComponents();
 
+			//IF THERE IS ONLY ONE COMPONENT COULD USE SHADERS...
+			if (numComponents == 1) {
+				if (UseShader) {
+					double range[2] = {0.0, 1.0};
+					scalars->GetRange(range);
 
-		    if (numComponents == 1) {
-				dataPtr = this->MapScalarsToColors (scalars);
-				if (dataPtr == NULL) {
-					LOG_DEBUG("OpenGLComponent", "Could not map pixel data");
-					this->UnLock(GLOC());
-					return;
+					TIndex = std::max<int>(0, std::min<int>(TIndex, zsize - 1));
+					TIndexChanged = false;
+					
+					LOG_DEBUG("OpenGLComponent", "Tipo de componente: " << scalars->GetDataTypeAsString());
+					if (scalars->GetDataType() == VTK_UNSIGNED_SHORT || scalars->GetDataType() == VTK_SHORT) 
+					{
+						//RESCALE TO UNSIGNED SHORT
+						bytesPerPixel         = 2;
+						TexInternalFormat = GL_LUMINANCE16;
+						TexType           = GL_UNSIGNED_SHORT;
+
+						unsigned short* resamplePixelData = new unsigned short[wdh];
+
+						const unsigned int psize = wdh;
+						double diff = range[1] - range[0];
+
+						if (diff < std::numeric_limits<double>::epsilon() ) {
+							range[0] = (scalars->GetDataType() == VTK_UNSIGNED_SHORT)?((double) std::numeric_limits<unsigned short>::min()):((double) std::numeric_limits<short>::min());
+							range[1] = (scalars->GetDataType() == VTK_UNSIGNED_SHORT)?((double) std::numeric_limits<unsigned short>::max()):((double) std::numeric_limits<short>::max());
+							diff = range[1] - range[0];
+						}
+
+						off = size[0] * size[1] * TIndex * bytesPerPixel;
+						unsigned char* dptr = (unsigned char*) scalars->GetVoidPointer(0);
+						if (dptr == NULL) {
+							LOG_ERROR("OpenGLComponent", "Could not get pixel data pointer");
+							this->UnLock(GLOC());
+							return;
+						}
+						vptr = (unsigned char*) (dptr + off);
+
+						double scale = 1 / diff;
+						unsigned short* dst = resamplePixelData;
+						short* src = (short*)vptr;
+
+						unsigned short v;
+						for (unsigned int i = 0; i < psize; i++) {
+							if (scalars->GetDataType() == VTK_UNSIGNED_SHORT) {
+								const unsigned short v1 = *((unsigned short*)src);
+								v = (unsigned short)(( scale * ( v1 - range[0]) )*std::numeric_limits<unsigned short>::max());
+								src++;
+							} else {
+								v = (unsigned short)(( scale * ((short) *(src++) - range[0]) )*std::numeric_limits<unsigned short>::max());
+							}
+							*(dst++) =  v;
+						}
+						pResampledPixelData = (unsigned char*) resamplePixelData;
+						vptr = pResampledPixelData;
+					} else if (scalars->GetDataType() == VTK_UNSIGNED_CHAR || scalars->GetDataType() == VTK_CHAR) {
+						//rescale to unsigned byte
+						bytesPerPixel         = 1;
+						TexInternalFormat = GL_LUMINANCE8;
+						TexType = GL_UNSIGNED_BYTE;	
+
+						unsigned char* resamplePixelData = new unsigned char[wdh];
+
+						const unsigned int psize = wdh;
+						double diff = range[1] - range[0];
+
+						if (diff < std::numeric_limits<double>::epsilon() ) {
+							range[0] = (scalars->GetDataType() == VTK_UNSIGNED_CHAR)?((double) std::numeric_limits<unsigned char>::min()):((double) std::numeric_limits<char>::min());
+							range[1] = (scalars->GetDataType() == VTK_UNSIGNED_CHAR)?((double) std::numeric_limits<unsigned char>::max()):((double) std::numeric_limits<char>::max());
+							diff = range[1] - range[0];
+						}
+
+						off = size[0] * size[1] * TIndex * bytesPerPixel;
+						unsigned char* dptr = (unsigned char*) scalars->GetVoidPointer(0);
+						if (dptr == NULL) {
+							LOG_ERROR("OpenGLComponent", "Could not get pixel data pointer");
+							this->UnLock(GLOC());
+							return;
+						}
+						vptr = (unsigned char*) (dptr + off);
+
+						double scale = 1 / diff;
+						unsigned char* dst = resamplePixelData;
+						char* src = (char*)vptr;
+
+						unsigned char v;
+						for (unsigned int i = 0; i < psize; i++) {
+							if (scalars->GetDataType() == VTK_UNSIGNED_CHAR) {
+								const unsigned char v1 = *((unsigned char*)src);
+								v = (unsigned char)(( scale * ( v1 - range[0]) )*std::numeric_limits<unsigned char>::max());
+								src++;
+							} else {
+								v = (unsigned char)(( scale * ((char) *(src++) - range[0]) )*std::numeric_limits<unsigned char>::max());
+							}
+							*(dst++) =  v;
+						}
+						pResampledPixelData = (unsigned char*) resamplePixelData;
+						vptr = pResampledPixelData;
+					} else {
+						LOG_WARN("OpenGLComponent", "Tipo de componente no soportado: Wrong size: " << scalars->GetDataTypeAsString());
+						this->UseShader = false;
+					}
+				} 
+				//if support shaders but scalar type isn't short or char, vtk makes the mapping
+				if (!this->UseShader)
+				{
+					vptr = this->MapScalarsToColors (scalars);
+					if (vptr == NULL) {
+						LOG_DEBUG("OpenGLComponent", "Could not map pixel data");
+						this->UnLock(GLOC());
+						return;
+					}
+					vptr += (wdh * TIndex * 4);
+					bytesPerPixel = 4;
 				}
-				dataPtr += (wdh * TIndex * 4);
-			}
+			}//end 1 component
 			else {
-
+				//lookup table with more than one component... extrange
+				this->UseShader = false;
 				pResampledPixelData = new unsigned char[wdh * 4];
 				const unsigned int psize = wdh;
 				double range[2] = {0.0, 1.0};
@@ -338,6 +471,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 							}
 
 						}
+						break;
 					case VTK_UNSIGNED_CHAR:
 						{
 							unsigned char *src = ((unsigned char*) vptr) + (wdh * TIndex * numComponents);
@@ -355,6 +489,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 							}
 
 						}
+						break;
 					case VTK_SHORT:
 						{
 
@@ -432,8 +567,8 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 					case VTK_UNSIGNED_INT:
 						{
 							if (diff < std::numeric_limits<double>::epsilon() ) {
-								range[0] = (double) std::numeric_limits<char>::min();
-								range[1] = (double) std::numeric_limits<char>::max();
+								range[0] = (double) std::numeric_limits<unsigned int>::min();
+								range[1] = (double) std::numeric_limits<unsigned int>::max();
 								diff = range[1] - range[0];
 							}
 
@@ -456,8 +591,8 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 					case VTK_FLOAT:
 						{
 							if (diff < std::numeric_limits<double>::epsilon() ) {
-								range[0] = (double) std::numeric_limits<char>::min();
-								range[1] = (double) std::numeric_limits<char>::max();
+								range[0] = (double) std::numeric_limits<float>::min();
+								range[1] = (double) std::numeric_limits<float>::max();
 								diff = range[1] - range[0];
 							}
 
@@ -480,8 +615,8 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 					case VTK_DOUBLE:
 						{
 							if (diff < std::numeric_limits<double>::epsilon() ) {
-								range[0] = (double) std::numeric_limits<char>::min();
-								range[1] = (double) std::numeric_limits<char>::max();
+								range[0] = (double) std::numeric_limits<double>::min();
+								range[1] = (double) std::numeric_limits<double>::max();
 								diff = range[1] - range[0];
 							}
 
@@ -507,39 +642,60 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 						return;
 				}
 
-				dataPtr = pResampledPixelData;
-		    }
-
-			bytesPerPixel = 4;
+				vptr = pResampledPixelData;
+				bytesPerPixel = 4;
+			}//end more than one component...
 		}
 		else
 		{
+			//RGB IMAGES
 			unsigned char *s_array = static_cast<vtkUnsignedCharArray *>(scalars)->GetPointer(0);
 			if (s_array != NULL) {
-				dataPtr = s_array + off;
+				vptr = s_array + off;
 			}
 			else {
 				LOG_DEBUG("OpenGLComponent", "Could not get pixel data pointer");
-			    this->UnLock(GLOC());
+				this->UnLock(GLOC());
 				return;
 			}
+
+			this->UseShader = false;
 		}
 
-
-		if(!this->CheckedHardwareSupport)
-		{
-			vtkOpenGLExtensionManager *m = renWin->GetExtensionManager();
-			this->CheckedHardwareSupport = true;
-			this->SupportsNonPowerOfTwoTextures = m->ExtensionSupported("GL_VERSION_2_0") || m->ExtensionSupported("GL_ARB_texture_non_power_of_two");
-			this->SupportsPBO=vtkPixelBufferObject::IsSupported(renWin);
-
-			int supports_GL_VERSION_2_0=m->ExtensionSupported("GL_VERSION_2_0");
-			if(supports_GL_VERSION_2_0)
+		//if no use pixel shader...
+		if (!this->UseShader) {
+			TexInternalFormat = bytesPerPixel;
+			TexType = GL_UNSIGNED_BYTE;
+			switch (bytesPerPixel)
 			{
-				m->LoadExtension("GL_ARB_multitexture");
-				m->LoadExtension("GL_VERSION_2_0");
-				this->UseShader = true;
+				case 1: TexFormat = GL_LUMINANCE; break;
+				case 2: TexFormat = GL_LUMINANCE_ALPHA; break;
+				case 3: TexFormat = GL_RGB; break;
+				case 4: TexFormat = GL_RGBA; break;
 			}
+			// if we are using OpenGL 1.1, you can force 32 or16 bit textures
+#ifdef GL_VERSION_1_1
+			if (this->Quality == VTK_TEXTURE_QUALITY_32BIT)
+			{
+				switch (bytesPerPixel)
+				{
+					case 1: TexInternalFormat = GL_LUMINANCE8; break;
+					case 2: TexInternalFormat = GL_LUMINANCE8_ALPHA8; break;
+					case 3: TexInternalFormat = GL_RGB8; break;
+					case 4: TexInternalFormat = GL_RGBA8; break;
+				}
+			}
+			else if (this->Quality == VTK_TEXTURE_QUALITY_16BIT)
+			{
+				switch (bytesPerPixel)
+				{
+					case 1: TexInternalFormat = GL_LUMINANCE4; break;
+					case 2: TexInternalFormat = GL_LUMINANCE4_ALPHA4; break;
+					case 3: TexInternalFormat = GL_RGB4; break;
+					case 4: TexInternalFormat = GL_RGBA4; break;
+				}
+			} 
+#endif
 		}
 
 		// -- decide whether the texture needs to be resampled --
@@ -573,16 +729,16 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 		if(resampleNeeded)
 		{
 			vtkDebugMacro(<< "Resampling texture to power of two for OpenGL");
-			resultData = this->ResampleToPowerOfTwo(xsize, ysize, dataPtr,
-													bytesPerPixel);
-            pNPOTPixelData = resultData;
+			resultData = this->ResampleToPowerOfTwo(xsize, ysize, vptr,
+				bytesPerPixel);
+			pNPOTPixelData = resultData;
 
 		}
 
 		if ( resultData == NULL )
-        {
-			resultData = dataPtr;
-        }
+		{
+			resultData = vptr;
+		}
 
 		// free any old display lists (from the old context)
 		if (this->RenderWindow) {
@@ -600,8 +756,6 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 			return;
 		}
 
-
-
 		// make the new context current before we mess with opengl
 		this->RenderWindow->MakeCurrent();
 
@@ -622,21 +776,23 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 		if(this->RenderWindow->IsA("vtkOpenGLRenderWindow"))
 		{
 			static_cast<vtkOpenGLRenderWindow *>(ren->GetRenderWindow())->
-			RegisterTextureResource( this->Index );
+				RegisterTextureResource( this->Index );
 		}
 
+		//pixel interpolate
 		if (this->Interpolate)
 		{
 			glTexParameterf( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER,
-							GL_LINEAR);
+				GL_LINEAR);
 			glTexParameterf( GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER,
-							GL_LINEAR );
+				GL_LINEAR );
 		}
 		else
 		{
 			glTexParameterf( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST );
 			glTexParameterf( GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST );
 		}
+		/////repeat texture??
 		if (this->Repeat)
 		{
 			glTexParameterf( GL_TEXTURE_2D, GL_TEXTURE_WRAP_S,     GL_REPEAT );
@@ -647,12 +803,12 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 			vtkOpenGLExtensionManager* manager = renWin->GetExtensionManager();
 			if (this->EdgeClamp &&
 				(manager->ExtensionSupported("GL_VERSION_1_2") ||
-				 manager->ExtensionSupported("GL_EXT_texture_edge_clamp")))
+				manager->ExtensionSupported("GL_EXT_texture_edge_clamp")))
 			{
 				glTexParameterf( GL_TEXTURE_2D, GL_TEXTURE_WRAP_S,
-								vtkgl::CLAMP_TO_EDGE );
+					vtkgl::CLAMP_TO_EDGE );
 				glTexParameterf( GL_TEXTURE_2D, GL_TEXTURE_WRAP_T,
-								vtkgl::CLAMP_TO_EDGE );
+					vtkgl::CLAMP_TO_EDGE );
 			}
 			else
 			{
@@ -660,181 +816,131 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 				glTexParameterf( GL_TEXTURE_2D, GL_TEXTURE_WRAP_T,     GL_CLAMP );
 			}
 		}
-		int internalFormat = bytesPerPixel;
-		switch (bytesPerPixel)
-		{
-			case 1: format = GL_LUMINANCE; break;
-			case 2: format = GL_LUMINANCE_ALPHA; break;
-			case 3: format = GL_RGB; break;
-			case 4: format = GL_RGBA; break;
-		}
-		// if we are using OpenGL 1.1, you can force 32 or16 bit textures
-#ifdef GL_VERSION_1_1
-		if (this->Quality == VTK_TEXTURE_QUALITY_32BIT)
-		{
-			switch (bytesPerPixel)
-			{
-				case 1: internalFormat = GL_LUMINANCE8; break;
-				case 2: internalFormat = GL_LUMINANCE8_ALPHA8; break;
-				case 3: internalFormat = GL_RGB8; break;
-				case 4: internalFormat = GL_RGBA8; break;
-			}
-		}
-		else if (this->Quality == VTK_TEXTURE_QUALITY_16BIT)
-		{
-			switch (bytesPerPixel)
-			{
-				case 1: internalFormat = GL_LUMINANCE4; break;
-				case 2: internalFormat = GL_LUMINANCE4_ALPHA4; break;
-				case 3: internalFormat = GL_RGB4; break;
-				case 4: internalFormat = GL_RGBA4; break;
-			}
-		}
-#endif
-		this->UseShader = false;
-		// =======================================
-		if( this->UseShader && this->ProgramObject == 0){
+
+		// =======================================UPLOAD SHADER ========
+		if( this->UseShader){
 			GLenum terror = 0;
 			GLint params = 0;
 
-			if (LUTIndex == 0)
-			{
-				glEnable(GL_TEXTURE_1D);
-				#if defined(_WINDOWS) || defined(__WXGTK__)
-				vtkgl::ActiveTexture(vtkgl::TEXTURE1_ARB);
-				#else
-				glActiveTexture(vtkgl::TEXTURE1_ARB);
-				#endif
-				glGenTextures(1, &this->LUTIndex);
-				glBindTexture(GL_TEXTURE_1D, this->LUTIndex);
-				glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_MIN_FILTER,
-								GL_LINEAR);
-				glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_MAG_FILTER,
-								GL_LINEAR );
-				glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_WRAP_S,     GL_CLAMP );
-				glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_WRAP_T,     GL_CLAMP );
+			//code of the shader
+			if (this->ProgramObject == 0) {
+				glEnable(vtkgl::FRAGMENT_PROGRAM_ARB);
+				//upload vertex program code...
+				this->ProgramObject = vtkgl::CreateProgram();
+				terror = glGetError();
 
-				unsigned char* data = new unsigned char[256 * 4];
-				unsigned char* ptr = data;
-				for (int i = 0; i < 256; i++) {
-					*(ptr++) = i;
-					*(ptr++) = i;
-					*(ptr++) = i;
-					*(ptr++) = 255;
-				}
-				glTexImage1D( GL_TEXTURE_1D, 0 , GL_RGBA,
-							 256, 0, GL_RGBA,
-							 GL_UNSIGNED_BYTE, data);
-				glDisable(GL_TEXTURE_1D);
-				#if defined(_WINDOWS) || defined(__WXGTK__)
-				vtkgl::ActiveTexture(vtkgl::TEXTURE0_ARB);
-				#else
-				glActiveTexture(vtkgl::TEXTURE0_ARB);
-				#endif
-			}
-			glEnable(vtkgl::FRAGMENT_PROGRAM_ARB);
+				this->VertexProgram = vtkgl::CreateShader(vtkgl::VERTEX_SHADER);
+				terror = glGetError();
 
-			this->ProgramObject = vtkgl::CreateProgram();
-			terror = glGetError();
+				std::string VertexProgramCode =
+					"void main (void)\n"
+					"{\n"
+					"gl_TexCoord[0] = gl_MultiTexCoord0;\n"
+					"gl_Position = ftransform();\n"
+					"}\n";
+				const char* ptr1 = (const char*)VertexProgramCode.c_str();
+				vtkgl::ShaderSource(this->VertexProgram, 1, &ptr1, NULL);
+				terror = glGetError();
+				vtkgl::CompileShader(this->VertexProgram);
+				terror = glGetError();
 
-			this->VertexProgram = vtkgl::CreateShader(vtkgl::VERTEX_SHADER);
-			terror = glGetError();
+				vtkgl::GetShaderiv(this->VertexProgram, vtkgl::COMPILE_STATUS, &params);
 
-			std::string VertexProgramCode =
-				"void main (void)\n"
-				"{\n"
-				"gl_TexCoord[0] = gl_TextureMatrix[0] * gl_MultiTexCoord0;\n"
-				"gl_Position = gl_ModelViewProjectionMatrix * gl_Vertex;\n"
-				"}\n";
-			const char* ptr1 = (const char*)VertexProgramCode.c_str();
-			vtkgl::ShaderSource(this->VertexProgram, 1, &ptr1, NULL);
-			terror = glGetError();
-			vtkgl::CompileShader(this->VertexProgram);
-			terror = glGetError();
-
-			vtkgl::GetShaderiv(this->VertexProgram, vtkgl::COMPILE_STATUS, &params);
-
-			if(params==GL_TRUE)
-			{
-				std::cout <<"vertex shader source compiled successfully" << std::endl;
-			}
-			else
-			{
-				std::cout << "vertex shader source compile error" << std::endl;
-				// include null terminator
-				vtkgl::GetShaderiv(this->VertexProgram, vtkgl::INFO_LOG_LENGTH, &params);
-				if(params>0)
+				if(params==GL_TRUE)
 				{
-					char *buffer=new char[params];
-					vtkgl::GetShaderInfoLog(this->VertexProgram, params, 0, buffer);
-					std::cout << "log: " << buffer << std::endl;
-					delete[] buffer;
+					//std::cout <<"vertex shader source compiled successfully" << std::endl;
 				}
 				else
 				{
-					std::cout << "NO Log: " << std::endl;
+					LOG_ERROR("Visualization", "vertex shader source compile error");
+					// include null terminator
+					vtkgl::GetShaderiv(this->VertexProgram, vtkgl::INFO_LOG_LENGTH, &params);
+					if(params>0)
+					{
+						char *buffer=new char[params];
+						vtkgl::GetShaderInfoLog(this->VertexProgram, params, 0, buffer);
+						LOG_ERROR("Visualization", buffer);
+						delete[] buffer;
+					}
+					else
+					{
+						LOG_ERROR("Visualization", "No error information available");
+					}
 				}
-			}
 
-			this->FragmentProgram = vtkgl::CreateShader(vtkgl::FRAGMENT_SHADER);
-			terror = glGetError();
-			std::string FragmenProgramCode =
-			"uniform sampler2D imagetexture;\n"
-			"uniform sampler1D lookuptable;\n"
-			"void main(void)\n"
-			"{\n"
-			"float color = texture2D(imagetexture, gl_TexCoord[0].st).r;\n"
-			"vec4 cr = TEXTURE1_ARBD(lookuptable, color);\n"
-			"cr.a = 1.0;"
-			"gl_FragColor = cr;\n"
-			"}\n";
-			const char* ptr2 = (const char*)FragmenProgramCode.c_str();
-			vtkgl::ShaderSource(this->FragmentProgram, 1, &ptr2, 0);
-			terror = glGetError();
-			vtkgl::CompileShader(this->FragmentProgram);
-			//terror = glGetError();
+				this->FragmentProgram = vtkgl::CreateShader(vtkgl::FRAGMENT_SHADER);
+				terror = glGetError();
+				std::string FragmenProgramCode =
+					"uniform sampler2D imagetexture;"
+					"uniform sampler1D lookuptable;"
+					"uniform float lutShift;"
+					"uniform float lutScale;"
+					"void main(void)"
+					"{"
+					"vec4 color = texture2D(imagetexture, gl_TexCoord[0].xy);"
+					"float lutColor = (color.r + lutShift) * lutScale;"
+					"if (lutColor > 1)"
+					"{"
+						"lutColor = 1;"
+					"}"
+					"if (lutColor <0)"
+					"{"
+						"lutColor = 0;"
+					"}"
+					"vec4 cr = texture1D(lookuptable, lutColor);"
+					//"cr.a = 1.0;"
+					"gl_FragColor = cr;"
+					"}";
+				const char* ptr2 = (const char*)FragmenProgramCode.c_str();
+				vtkgl::ShaderSource(this->FragmentProgram, 1, &ptr2, 0);
+				terror = glGetError();
+				vtkgl::CompileShader(this->FragmentProgram);
+				//terror = glGetError();
 
-			vtkgl::GetShaderiv(this->FragmentProgram, vtkgl::COMPILE_STATUS, &params);
+				vtkgl::GetShaderiv(this->FragmentProgram, vtkgl::COMPILE_STATUS, &params);
 
-			if(params==GL_TRUE)
-			{
-				std::cout <<"fragment shader source compiled successfully" << std::endl;
-			}
-			else
-			{
-				std::cout << "fragment shader source compile error" << std::endl;
-				// include null terminator
-				vtkgl::GetShaderiv(this->FragmentProgram, vtkgl::INFO_LOG_LENGTH, &params);
-				if(params>0)
+				if(params==GL_TRUE)
 				{
-					char *buffer=new char[params];
-					vtkgl::GetShaderInfoLog(this->FragmentProgram, params, 0, buffer);
-					std::cout << "log: " << buffer << std::endl;
-					delete[] buffer;
+					//std::cout <<"fragment shader source compiled successfully" << std::endl;
 				}
 				else
 				{
-					std::cout << "NO Log: " << std::endl;
+					LOG_ERROR("Visualization", "Fragment shader source compile error");
+					// include null terminator
+					vtkgl::GetShaderiv(this->FragmentProgram, vtkgl::INFO_LOG_LENGTH, &params);
+					if(params>0)
+					{
+						char *buffer=new char[params];
+						vtkgl::GetShaderInfoLog(this->FragmentProgram, params, 0, buffer);
+						LOG_ERROR("Visualization", buffer);
+						delete[] buffer;
+					}
+					else
+					{
+						LOG_ERROR("Visualization", "No error information available");
+					}
 				}
+
+				vtkgl::AttachShader(this->ProgramObject, this->VertexProgram);
+				terror = glGetError();
+				vtkgl::AttachShader(this->ProgramObject, this->FragmentProgram);
+				terror = glGetError();
+
+				vtkgl::LinkProgram(this->ProgramObject);
+				terror = glGetError();
+
+				GLint linked;
+				vtkgl::GetProgramiv(this->ProgramObject, vtkgl::LINK_STATUS, &linked);
+				if (linked)
+				{
+					//std::cout << "GPU Program enlazado" << std::endl;
+				}
+				glDisable(vtkgl::FRAGMENT_PROGRAM_ARB);
 			}
 
-			vtkgl::AttachShader(this->ProgramObject, this->VertexProgram);
-			terror = glGetError();
-			vtkgl::AttachShader(this->ProgramObject, this->FragmentProgram);
-			terror = glGetError();
-
-			vtkgl::LinkProgram(this->ProgramObject);
-			terror = glGetError();
-
-			GLint linked;
-			vtkgl::GetProgramiv(this->ProgramObject, vtkgl::LINK_STATUS, &linked);
-			if (linked)
-			{
-				std::cout << "GPU Program enlazado" << std::endl;
-			}
-
-		}
+		}//END PROGRAM SHADER
 
+		//UPLOAD TEXTURE...
 		if(this->SupportsPBO)
 		{
 			if(this->PBO==0)
@@ -845,30 +951,31 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 			//std::cout << ">> UpdatePBO" << std::endl;
 			unsigned int dims[2];
 			vtkIdType increments[2];
-			dims[0]=static_cast<unsigned int>(xsize);
-			dims[1]=static_cast<unsigned int>(ysize);
-			increments[0]=0;
-			increments[1]=0;
+			dims[0] = static_cast<unsigned int>(xsize);
+			dims[1] = static_cast<unsigned int>(ysize);
+			increments[0] = 0;
+			increments[1] = 0;
 
-			this->PBO->Upload2D(VTK_UNSIGNED_CHAR,resultData,dims,bytesPerPixel,
-								increments);
+			/*this->PBO->Upload2D(VTK_UNSIGNED_CHAR,resultData,dims,bytesPerPixel,
+			increments);*/
+			if (UseShader) { 
+				this->PBO->Upload2D(scalars->GetDataType(), resultData, dims, scalars->GetNumberOfComponents(), increments);
+			} else {
+				this->PBO->Upload2D(VTK_UNSIGNED_CHAR,resultData,dims,bytesPerPixel,
+					increments);
+			}
 			// non-blocking call
 			this->PBO->Bind(vtkPixelBufferObject::UNPACKED_BUFFER);
-			glTexImage2D( GL_TEXTURE_2D, 0 , internalFormat,
-						 xsize, ysize, 0, format,
-						 GL_UNSIGNED_BYTE,0);
+			glTexImage2D( GL_TEXTURE_2D, 0 , TexInternalFormat, xsize, ysize, 0, TexFormat, TexType, 0);
 			this->PBO->UnBind();
 			//std::cout << "<< UpdatePBO" << std::endl;
 		}
 		else
 		{
-		    //std::cout << ">> UpdateText(slow). ResultData = " << (void*)resultData << std::endl;
+			//std::cout << ">> UpdateText(slow). ResultData = " << (void*)resultData << std::endl;
 			// blocking call
-			glTexImage2D( GL_TEXTURE_2D, 0 , internalFormat,
-						 xsize, ysize, 0, format,
-						 GL_UNSIGNED_BYTE,
-						 static_cast<const GLvoid *>(resultData) );
-            //std::cout << "<< UpdateText(slow)" << std::endl;
+			glTexImage2D( GL_TEXTURE_2D, 0 , TexInternalFormat, xsize, ysize, 0, TexFormat, TexType, resultData);
+			//std::cout << "<< UpdateText(slow)" << std::endl;
 
 		}
 #ifndef GL_VERSION_1_1
@@ -884,9 +991,38 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 		if (pNPOTPixelData) {
 			delete[] pNPOTPixelData;
 		}
-    }
+	}// end if changes...
 
-    this->UnLock(GLOC());
+	//UPLOAD LOOKUP TABLE IF NEEDED
+	if (this->UseShader && (this->LUTIndex == 0 || LookupTableChanged)) {
+		LookupTableChanged = false;
+
+		//glEnable(GL_TEXTURE_1D);
+#if defined(_WINDOWS) || defined(__WXGTK__)
+		vtkgl::ActiveTextureARB(vtkgl::TEXTURE1_ARB);
+#else
+		glActiveTexture(vtkgl::TEXTURE1_ARB);
+#endif
+		glGenTextures(1, &this->LUTIndex);
+		glBindTexture(GL_TEXTURE_1D, this->LUTIndex);
+		glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_MIN_FILTER,
+			GL_NEAREST);
+		glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_MAG_FILTER,
+			GL_NEAREST );
+		glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_WRAP_S,     GL_CLAMP );
+		glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_WRAP_T,     GL_CLAMP );
+
+		glTexImage1D( GL_TEXTURE_1D, 0 , GL_RGBA,
+			static_cast<vtkLookupTable*>(LookupTable)->GetNumberOfTableValues(), 0, GL_RGBA,
+			GL_UNSIGNED_BYTE, static_cast<vtkLookupTable*>(LookupTable)->GetPointer(0));
+#if defined(_WINDOWS) || defined(__WXGTK__)
+		vtkgl::ActiveTextureARB(vtkgl::TEXTURE0_ARB);
+#else
+		glActiveTexture(vtkgl::TEXTURE0_ARB);
+#endif
+	}
+
+	this->UnLock(GLOC());
 
 	// execute the display list that uses creates the texture
 #ifdef GL_VERSION_1_1
@@ -901,41 +1037,26 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 	glEnable (GL_ALPHA_TEST);
 
 	if (this->PremultipliedAlpha)
-    {
+	{
 		// save the blend function.
 		glPushAttrib(GL_COLOR_BUFFER_BIT);
 
 		// make the blend function correct for textures premultiplied by alpha.
 		glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
-    }
+	}
 
 	// now bind it
 	if (this->UseShader) {
 		glEnable(GL_TEXTURE_1D);
-		#if defined(_WINDOWS) || defined(__WXGTK__)
-		vtkgl::ActiveTexture(vtkgl::TEXTURE1_ARB);
-		#else
-		glActiveTexture(vtkgl::TEXTURE1_ARB);
-		#endif
-		glMatrixMode(GL_TEXTURE);
-		glLoadIdentity();
 	}
-
 	glEnable(GL_TEXTURE_2D);
-	if (this->UseShader) {
-		#if defined(_WINDOWS) || defined(__WXGTK__)
-		vtkgl::ActiveTexture(vtkgl::TEXTURE0_ARB);
-		#else
-		glActiveTexture(vtkgl::TEXTURE0_ARB);
-		#endif
-	}
 	// clear any texture transform
 	glMatrixMode(GL_TEXTURE);
 	glLoadIdentity();
 
 	// build transformation
 	if (this->Transform)
-    {
+	{
 		double *mat = this->Transform->GetMatrix()->Element[0];
 		double mat2[16];
 		mat2[0] = mat[0];
@@ -957,19 +1078,15 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 
 		// insert texture transformation
 		glMultMatrixd(mat2);
-    }
+	}
 	glMatrixMode(GL_MODELVIEW);
 
 	vtkOpenGLRenderer *oRenderer=static_cast<vtkOpenGLRenderer *>(ren);
 
 	if(oRenderer->GetDepthPeelingHigherLayer())
-    {
-		std::cout << "DepthPeeling" << std::endl;
-		//uUseTexture=oRenderer->GetUseTextureUniformVariable();
-		//uTexture=oRenderer->GetTextureUniformVariable();
-		//vtkgl::Uniform1i(uUseTexture,1);
-		//vtkgl::Uniform1i(uTexture,0); // active texture 0
-    }
+	{
+		//std::cout << "DepthPeeling" << std::endl;
+	}
 
 	if (this->UseShader) {
 		GLenum error = 0;
@@ -988,7 +1105,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 		}
 		else
 		{
-			std::cout << "error: image is not a uniform." << std::endl;
+			LOG_ERROR("OpenGLComponent", "error: image is not a uniform");
 		}
 
 		loc = vtkgl::GetUniformLocation(this->ProgramObject,"lookuptable");
@@ -998,8 +1115,38 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 		}
 		else
 		{
-			std::cout << "error: lut is not a uniform." << std::endl;
+			LOG_ERROR("OpenGLComponent", "error: lut is not a uniform");
 		}
+
+		double normRange[2] = {0.0, 1.0};		
+		vtkDataArray *scalars = this->GetInputArrayToProcess(0, input);
+		scalars->GetRange(normRange);
+		double* drange = LookupTable->GetRange();
+		
+		float range[2] = { (drange[0]-normRange[0]) / (normRange[1]-normRange[0]), (drange[1]-normRange[0]) / (normRange[1]-normRange[0])};
+		float shift = -range[0];
+		float scale = (1.0f)/(range[1] - range[0]);
+
+		loc = vtkgl::GetUniformLocation(this->ProgramObject,"lutShift");
+		if(loc != -1)
+		{
+			vtkgl::Uniform1f(loc, shift);
+		}
+		else
+		{
+			LOG_ERROR("OpenGLComponent", "error: shift is not a uniform");
+		}
+
+		loc = vtkgl::GetUniformLocation(this->ProgramObject,"lutScale");
+		if(loc != -1)
+		{
+			vtkgl::Uniform1f(loc, scale);
+		}
+		else
+		{
+			LOG_ERROR("OpenGLComponent", "error: scale is not a uniform");
+		}
+		glDisable(vtkgl::FRAGMENT_PROGRAM_ARB);
 	}
 }
 
@@ -1009,9 +1156,10 @@ void vtkGinkgoOpenGLTexture::PostRender(vtkRenderer *vtkNotUsed(ren))
 
 	if (this->UseShader) {
 		vtkgl::UseProgram(0);
+		/*
 
 		#if defined(_WINDOWS) || defined(__WXGTK__)
-		vtkgl::ActiveTexture(vtkgl::TEXTURE1_ARB);
+		vtkgl::ActiveTextureARB(vtkgl::TEXTURE1_ARB);
 		#else
 		glActiveTexture(vtkgl::TEXTURE1_ARB);
 		#endif
@@ -1020,20 +1168,19 @@ void vtkGinkgoOpenGLTexture::PostRender(vtkRenderer *vtkNotUsed(ren))
 		glDisable(GL_TEXTURE_1D);
 
 		#if defined(_WINDOWS) || defined(__WXGTK__)
-		vtkgl::ActiveTexture(vtkgl::TEXTURE0_ARB);
+		vtkgl::ActiveTextureARB(vtkgl::TEXTURE0_ARB);
 		#else
 		glActiveTexture(vtkgl::TEXTURE0_ARB);
 		#endif
 
 		glBindTexture(GL_TEXTURE_2D, 0);
-
-		glDisable(vtkgl::FRAGMENT_PROGRAM_ARB);
+		*/
 	}
 	if (this->GetInput() && this->PremultipliedAlpha)
-    {
+	{
 		// restore the blend function
 		glPopAttrib();
-    }
+	}
 }
 
 // ----------------------------------------------------------------------------
@@ -1042,9 +1189,9 @@ static int FindPowerOfTwo(int i)
 	int size;
 
 	for ( i--, size=1; i > 0; size*=2 )
-    {
+	{
 		i /= 2;
-    }
+	}
 
 	// [these lines added by Tim Hutton (implementing Joris Vanden Wyngaerd's
 	// suggestions)]
@@ -1053,9 +1200,9 @@ static int FindPowerOfTwo(int i)
 	GLint maxDimGL;
 	glGetIntegerv(GL_MAX_TEXTURE_SIZE,&maxDimGL);
 	if ( size > maxDimGL )
-    {
-        size = maxDimGL ;
-    }
+	{
+		size = maxDimGL ;
+	}
 	// end of Tim's additions
 
 	return size;
@@ -1065,9 +1212,9 @@ static int FindPowerOfTwo(int i)
 // Creates resampled unsigned char texture map that is a power of two in both
 // x and y.
 unsigned char *vtkGinkgoOpenGLTexture::ResampleToPowerOfTwo(int &xs,
-															int &ys,
-															unsigned char *dptr,
-															int bpp)
+																				int &ys,
+																				unsigned char *dptr,
+																				int bpp)
 {
 	unsigned char *tptr, *p, *p1, *p2, *p3, *p4;
 	int xsize, ysize, i, j, k, jOffset, iIdx, jIdx;
@@ -1076,7 +1223,7 @@ unsigned char *vtkGinkgoOpenGLTexture::ResampleToPowerOfTwo(int &xs,
 	xsize = FindPowerOfTwo(xs);
 	ysize = FindPowerOfTwo(ys);
 	if (this->RestrictPowerOf2ImageSmaller)
-    {
+	{
 		if (xsize > xs)
 		{
 			xsize /= 2;
@@ -1085,7 +1232,7 @@ unsigned char *vtkGinkgoOpenGLTexture::ResampleToPowerOfTwo(int &xs,
 		{
 			ysize /= 2;
 		}
-    }
+	}
 	hx = (xs - 1.0) / (xsize - 1.0);
 	hy = (ys - 1.0) / (ysize - 1.0);
 
@@ -1094,7 +1241,7 @@ unsigned char *vtkGinkgoOpenGLTexture::ResampleToPowerOfTwo(int &xs,
 	// Resample from the previous image. Compute parametric coordinates and
 	// interpolate
 	for (j=0; j < ysize; j++)
-    {
+	{
 		pcoords[1] = j*hy;
 
 		jIdx = static_cast<int>(pcoords[1]);
@@ -1139,10 +1286,10 @@ unsigned char *vtkGinkgoOpenGLTexture::ResampleToPowerOfTwo(int &xs,
 			for (k=0; k < bpp; k++)
 			{
 				*p++ = static_cast<unsigned char>(p1[k]*w0 + p2[k]*w1 + p3[k]*w2
-												  + p4[k]*w3);
+					+ p4[k]*w3);
 			}
 		}
-    }
+	}
 
 	xs = xsize;
 	ys = ysize;
