@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wangulo.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: wangulo.cpp 4504 2012-01-11 07:46:45Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -29,7 +29,7 @@
 
 //region "Implementacion de WAnguloBuilder"
 
-GNC::GCS::Widgets::WAnguloBuilder::WAnguloBuilder(GNC::GCS::IWidgetsManager* pManager) : GNC::GCS::Widgets::IWidgetBuilder(pManager)
+GNC::GCS::Widgets::WAnguloBuilder::WAnguloBuilder(GNC::GCS::IWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask) : GNC::GCS::Widgets::IWidgetBuilder(pManager, buttonMask)
 {
 	m_Estado = WBS_Ninguno;
 	m_pAnguloTemp = NULL;
@@ -61,20 +61,38 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoR
 		return;
 	}
 	GTRACE("GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(wxMouseEvent&)");
-	if (m_Estado == WBS_Creando && evento.ButtonUp(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	if (m_Estado == WBS_Creando && evento.ButtonUp(m_ButtonMask)) {
 		if (m_pAnguloTemp != NULL) {
 			if (m_Modo == MA_Normal) { // Angulo normal
-				m_pAnguloTemp->m_Nodos[1] = evento.iP;
-				if ( (m_pAnguloTemp->m_Nodos[1] - m_pAnguloTemp->m_Nodos[0]).Norma2Cuadrado() < GNC::GCS::Vector::EpsilonDeReales() ) {
-					m_NodoActual = 0;
-					delete m_pAnguloTemp;
-					m_Estado = WBS_Ninguno;
-					m_pAnguloTemp = NULL;
-				}
-				else {
+				if (m_NodoActual == 1) {
+					m_pAnguloTemp->m_Nodos[1] = evento.iP;
+					if ( (m_pAnguloTemp->m_Nodos[1] - m_pAnguloTemp->m_Nodos[0]).Norma2Cuadrado() < GNC::GCS::Vector::EpsilonDeReales() ) {
+						m_NodoActual = 0;
+						delete m_pAnguloTemp;
+						m_Estado = WBS_Ninguno;
+						m_pAnguloTemp = NULL;
+					}
+					else {
+						m_pAnguloTemp->m_Nodos[2] = evento.iP;
+						m_NodoActual = 2;
+						m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
+					}
+				} else {
 					m_pAnguloTemp->m_Nodos[2] = evento.iP;
-					m_NodoActual = 2;
-					m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
+					if ( (m_pAnguloTemp->m_Nodos[2] - m_pAnguloTemp->m_Nodos[1]).Norma2Cuadrado() < GNC::GCS::Vector::EpsilonDeReales()) {
+						m_NodoActual = 0;
+						delete m_pAnguloTemp;
+						m_Estado = WBS_Ninguno;
+						m_pAnguloTemp = NULL;
+					}
+					else {
+						m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
+						m_pManager->InsertarWidget(m_pAnguloTemp);
+						LanzarEventoCreacion(m_pAnguloTemp);
+						m_pAnguloTemp = NULL;
+						m_Estado = WBS_Ninguno;
+						m_NodoActual = 0;
+					}
 				}
 			} else { // Angulo de Cobb
 				m_pAnguloTemp->m_Nodos[m_NodoActual] = evento.iP;
@@ -106,10 +124,9 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoR
 				}
 			}
 			m_pManager->Modificado();
+			ConsumirEvento();
 		}
-		evento.Skip(true);
-
-	} else if (evento.ButtonDown(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	} else if (evento.ButtonDown(m_ButtonMask)) {
 		if (m_Estado == WBS_Ninguno) {
 			m_Estado = WBS_Creando;
 			if (m_pAnguloTemp == NULL) {
@@ -120,56 +137,38 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoR
 				m_pAnguloTemp->m_Nodos[0] = m_pAnguloTemp->m_Nodos[1] = m_pAnguloTemp->m_Nodos[2] = evento.iP;
 				m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
 				m_NodoActual = 1;
+				ConsumirEvento();
 			}
 		} else {
 			if (m_pAnguloTemp != NULL) {
-				if (m_Modo == MA_Normal) { // Angulo normal
-					m_pAnguloTemp->m_Nodos[2] = evento.iP;
-					if ( (m_pAnguloTemp->m_Nodos[2] - m_pAnguloTemp->m_Nodos[1]).Norma2Cuadrado() < GNC::GCS::Vector::EpsilonDeReales()) {
-						m_NodoActual = 0;
-						delete m_pAnguloTemp;
-						m_Estado = WBS_Ninguno;
-						m_pAnguloTemp = NULL;
-					}
-					else {
-						m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
-						m_pManager->InsertarWidget(m_pAnguloTemp);
-						LanzarEventoCreacion(m_pAnguloTemp);
-						m_pAnguloTemp = NULL;
-						m_Estado = WBS_Ninguno;
-						m_NodoActual = 0;
-					}
-
-				} else { // Angulo de Cobb
+				if (m_Modo == MA_Cobb) {  // Angulo de Cobb
 					if (m_NodoActual == 2) {
 						m_pAnguloTemp->m_Nodos[2] = evento.iP;
 						m_NodoActual = 3;
 						m_pAnguloTemp->m_Nodos[3] = evento.iP;
 					}
 				}
+				ConsumirEvento();
 			} else {
 				m_Estado = WBS_Ninguno;
 			}
 		}
 		m_pManager->Modificado();
-		evento.Skip(true);
 	} else if (evento.Dragging() && m_Estado == WBS_Creando) {
 		if (m_pAnguloTemp != NULL) {
 			m_pAnguloTemp->m_Nodos[m_NodoActual] = evento.iP;
 			m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
 			m_pManager->Modificado();
+			ConsumirEvento();
 		}
-		evento.Skip(true);
 	} else if (evento.Moving() && m_Estado == WBS_Creando) {
 		if (m_pAnguloTemp != NULL) {
 			m_pAnguloTemp->m_Nodos[m_NodoActual] = evento.iP;
 			m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
 			m_pManager->Modificado();
+			ConsumirEvento();
 		}
-		evento.Skip(true);
 	}
-
-
 }
 
 void GNC::GCS::Widgets::WAnguloBuilder::OnKeyEvents(GNC::GCS::Eventos::EventoTeclado&)
