@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wanotacionesquina.cpp 3748 2011-04-20 10:38:38Z carlos $
+ *  $Id: wanotacionesquina.cpp 4067 2011-08-08 08:35:48Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -35,6 +35,7 @@
 
 #include <main/entorno.h>
 #include <main/controllers/controladoreventos.h>
+#include <main/controllers/configurationcontroller.h>
 
 #include "wanotacionesquina.h"
 
@@ -344,7 +345,7 @@ namespace GNC {
 
 GNC::GCS::Widgets::WAnotador::WAnotador(GNC::GCS::IAnotador* annotator, IWidgetsManager* pManager, long vid, const char* nombre, long gid) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre, gid)
 {
-	m_Oculto = false;
+	GNC::GCS::ConfigurationController::Instance()->readBoolUser("/GinkgoCore/Tools/CornerAnotations", "IsShown", m_Oculto, true);
 	m_TopLevel = true;
 	m_ReservaRecursos = true;
 	m_pAnnotator = annotator;
@@ -468,6 +469,7 @@ void GNC::GCS::Widgets::WAnotador::Ocultar(bool oculto)
 		m_Oculto = oculto;
 		Modificar(true);
 	}
+	GNC::GCS::ConfigurationController::Instance()->writeBoolUser("/GinkgoCore/Tools/CornerAnotations", "IsShown", m_Oculto);
 }
 
 void GNC::GCS::Widgets::WAnotador::RecalcularEstaticas(Anotaciones* pAnotaciones, GNC::GCS::Contexto3D* c)
