@@ -26,7 +26,7 @@
 
 //region "Implementacion de WElipseBuilder"
 
-GNC::GCS::Widgets::WElipseBuilder::WElipseBuilder(TWidgetsManager* pManager, long gid) : GNC::GCS::Widgets::IWidgetBuilder(pManager, gid)
+GNC::GCS::Widgets::WElipseBuilder::WElipseBuilder(TWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask, long gid) : GNC::GCS::Widgets::IWidgetBuilder(pManager, buttonMask, gid)
 {
 	m_MouseDown = false;
 	m_Estado = WBS_Ninguno;
@@ -42,7 +42,7 @@ void GNC::GCS::Widgets::WElipseBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoR
 	if (!m_pManager) {
 		return;
 	}
-	if (m_MouseDown && evento.ButtonUp(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	if (m_MouseDown && evento.ButtonUp(m_ButtonMask)) {
 		m_MouseDown = false;
 		if (m_Estado != WBS_Creando) {
 			m_Estado = WBS_Ninguno;
@@ -73,13 +73,13 @@ void GNC::GCS::Widgets::WElipseBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoR
 			WElipse* w = new WElipse(centro, radio1, radio2, m_pManager, evento.c->GetRenderer()->GetVID(), "Elipse", m_GID);
 			m_pManager->InsertarWidget(w);
 			m_pManager->LanzarEventoCreacion(w);
+			ConsumirEvento();
 		}
 
 		m_pManager->Modificado();
 		m_Estado = WBS_Ninguno;
-		evento.Skip(false);
 	}
-	else if (evento.ButtonDown(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	else if (evento.ButtonDown(m_ButtonMask)) {
 		if (m_Estado != WBS_Ninguno) {
 			return;
 		}
