@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wflecha.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: wflecha.cpp 4504 2012-01-11 07:46:45Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -33,7 +33,7 @@
 
 //region "Implementacion de WFlechaBuilder"
 
-GNC::GCS::Widgets::WFlechaBuilder::WFlechaBuilder(GNC::GCS::IWidgetsManager* pManager) : GNC::GCS::Widgets::IWidgetBuilder(pManager)
+GNC::GCS::Widgets::WFlechaBuilder::WFlechaBuilder(GNC::GCS::IWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask) : GNC::GCS::Widgets::IWidgetBuilder(pManager, buttonMask)
 {
 	m_MouseDown = false;
 	m_pFlechaTemp = NULL;
@@ -53,7 +53,7 @@ void GNC::GCS::Widgets::WFlechaBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoR
 		return;
 	}
 	GTRACE("GNC::GCS::Widgets::WFlechaBuilder::OnMouseEvents(wxMouseEvent&)");
-	if (m_MouseDown && evento.ButtonUp(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	if (m_MouseDown && evento.ButtonUp(m_ButtonMask)) {
 		m_MouseDown = false;
 		if (m_pFlechaTemp != NULL) {
 			m_pFlechaTemp->m_Vertices[1] = evento.iP;
@@ -67,11 +67,9 @@ void GNC::GCS::Widgets::WFlechaBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoR
 			}
 			m_pFlechaTemp = NULL;
 			m_pManager->Modificado();
+			ConsumirEvento();
 		}
-		evento.Skip(true);
-
-	} else if (evento.ButtonDown(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
-
+	} else if (evento.ButtonDown(m_ButtonMask)) {
 		m_MouseDown = true;
 		TNodo nodos[2];
 		nodos[0] = nodos[1] = evento.iP;
@@ -81,15 +79,15 @@ void GNC::GCS::Widgets::WFlechaBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoR
 		m_pFlechaTemp = new GNC::GCS::Widgets::WFlecha(m_pManager, evento.c->GetRenderer()->GetVID(), nodos, "Flecha");
 		//std::cout << "linea (leftdwn): " << m_Vertices[0].m_wX << ", " << m_Vertices[0].m_wY << " -> " << m_Vertices[1].m_wX << ", " << m_Vertices[1].m_wY << std::endl;
 		m_pManager->Modificado();
-		evento.Skip(true);
+		ConsumirEvento();
 	} else if (evento.Dragging() && m_MouseDown) {
 		if (m_pFlechaTemp != NULL) {
 			m_pFlechaTemp->m_Vertices[1] = evento.iP;
 			m_pFlechaTemp->Recalcular();
 			//std::cout << "linea (moving): " << m_Vertices[0].m_wX << ", " << m_Vertices[0].m_wY << " -> " << m_Vertices[1].m_wX << ", " << m_Vertices[1].m_wY << std::endl;
 			m_pManager->Modificado();
-		}
-		evento.Skip(true);
+			ConsumirEvento();
+		}		
 	}
 
 }
