@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wlupa.cpp 3535 2011-03-18 17:57:05Z carlos $
+ *  $Id: wlupa.cpp 4478 2011-12-13 11:55:00Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -38,7 +38,7 @@
 
 //region "Implementacion de WBuilder"
 
-GNC::GCS::Widgets::WLupaBuilder::WLupaBuilder(GNC::GCS::IWidgetsManager* pManager, GNC::GCS::Widgets::ModoLupa modo, long gid) : GNC::GCS::Widgets::IWidgetBuilder(pManager, gid), IObservadorWidget(-1, gid)
+GNC::GCS::Widgets::WLupaBuilder::WLupaBuilder(GNC::GCS::IWidgetsManager* pManager, GNC::GCS::Widgets::ModoLupa modo, const GNC::GCS::TriggerButton& buttonMask, long gid) : GNC::GCS::Widgets::IWidgetBuilder(pManager, buttonMask, gid), IObservadorWidget(-1, gid)
 {
 	m_ModoActivo = modo;
 	m_pLupaActiva = NULL;
@@ -86,7 +86,7 @@ void GNC::GCS::Widgets::WLupaBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoRat
 		return;
 	}
 
-	else if (evento.ButtonDown(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	else if (evento.ButtonDown(m_ButtonMask)) {
 		m_PosicionCursor= evento.iP;
 		if (m_pLupaActiva == NULL) {
 			const GNC::GCS::Vector::TComponente& factor = evento.c->RelacionImagenPantalla().NormaInfinito();
