@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wnota.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: wnota.cpp 4478 2011-12-13 11:55:00Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -46,7 +46,7 @@
 //====================================================================================================
 //= Builder de notas
 //====================================================================================================
-GNC::GCS::Widgets::WNotaBuilder::WNotaBuilder(GNC::GCS::IWidgetsManager* pManager) : IWidgetBuilder(pManager)
+GNC::GCS::Widgets::WNotaBuilder::WNotaBuilder(GNC::GCS::IWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask) : IWidgetBuilder(pManager, buttonMask)
 {
 	m_MouseDown = false;
 	m_Estado = WBS_Ninguno;
@@ -65,7 +65,7 @@ void GNC::GCS::Widgets::WNotaBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoRat
 	if (!m_pManager) {
 		return;
 	}
-	if (m_MouseDown && evento.ButtonUp(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	if (m_MouseDown && evento.ButtonUp(m_ButtonMask)) {
 		m_MouseDown = false;
 		if (m_Estado != WBS_Creando) {
 			m_Estado = WBS_Ninguno;
@@ -80,7 +80,7 @@ void GNC::GCS::Widgets::WNotaBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoRat
 		evento.Skip(false);
 		m_pManager->Modificado();
 
-	} else if (evento.ButtonDown(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	} else if (evento.ButtonDown(m_ButtonMask)) {
 		if (m_Estado != WBS_Ninguno) {
 			return;
 		}
