@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wpoligono.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: wpoligono.cpp 4504 2012-01-11 07:46:45Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -29,7 +29,7 @@
 
 //region "Implementacion de WPoligonoBuilder"
 
-GNC::GCS::Widgets::WPoligonoBuilder::WPoligonoBuilder(ModoPoligono modo, GNC::GCS::IWidgetsManager* pManager, GNC::GCS::Widgets::Observadores::IObservadorPoligono* pObservador) : GNC::GCS::Widgets::IWidgetBuilder(pManager), GNC::GCS::Widgets::Notificadores::INotificadorPoligono(pObservador)
+GNC::GCS::Widgets::WPoligonoBuilder::WPoligonoBuilder(ModoPoligono modo, GNC::GCS::IWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask, GNC::GCS::Widgets::Observadores::IObservadorPoligono* pObservador) : GNC::GCS::Widgets::IWidgetBuilder(pManager, buttonMask), GNC::GCS::Widgets::Notificadores::INotificadorPoligono(pObservador)
 {
 	m_NumNodos = 0;
 	m_MouseDown = false;
@@ -56,7 +56,7 @@ void GNC::GCS::Widgets::WPoligonoBuilder::OnMouseEvents(GNC::GCS::Eventos::Event
 	if (!m_pManager) {
 		return;
 	}
-	if (m_MouseDown && evento.ButtonUp(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	if (m_MouseDown && evento.ButtonUp(m_ButtonMask)) {
 		m_MouseDown = false;
 		if (m_Estado != WBS_Creando) {
 			m_Estado = WBS_Ninguno;
@@ -75,13 +75,13 @@ void GNC::GCS::Widgets::WPoligonoBuilder::OnMouseEvents(GNC::GCS::Eventos::Event
 			m_pManager->InsertarWidget(m_pPoligonoCreado);
 			NotificarCreacion(m_pPoligonoCreado);
 			m_pManager->LanzarEventoCreacion(m_pPoligonoCreado);
+			ConsumirEvento();
 		}
 		m_Vertices.clear();
-		evento.Skip(false);
 		m_pManager->Modificado();
 
 	}
-	else if (evento.ButtonDown(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	else if (evento.ButtonDown(m_ButtonMask)) {
 		if (m_Estado != WBS_Ninguno) {
 			return;
 		}
