@@ -27,7 +27,7 @@
 
 //region "Implementacion de WPuntoBuilder"
 
-GNC::GCS::Widgets::WPuntoBuilder::WPuntoBuilder(GNC::GCS::IWidgetsManager* pManager, long gid, vtkImageData* pImageData) : GNC::GCS::Widgets::IWidgetBuilder(pManager, gid)
+GNC::GCS::Widgets::WPuntoBuilder::WPuntoBuilder(GNC::GCS::IWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask, long gid, vtkImageData* pImageData) : GNC::GCS::Widgets::IWidgetBuilder(pManager, buttonMask, gid)
 {
 	m_MouseDown = false;
 	m_Estado = WBS_Creando;
@@ -46,14 +46,7 @@ void GNC::GCS::Widgets::WPuntoBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoRa
 		return;
 	}
 	GTRACE("GNC::GCS::Widgets::WPuntoBuilder::OnMouseEvents(wxMouseEvent&)");
-	if (m_MouseDown && evento.ButtonUp(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
-
-		m_MouseDown = false;
-		m_Estado = WBS_Creando;
-
-	}
-	else if (evento.ButtonDown(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
-
+	if (evento.ButtonUp(m_ButtonMask)) {
 		m_MouseDown = true;
 		m_Nodo= evento.iP;
 
@@ -63,8 +56,6 @@ void GNC::GCS::Widgets::WPuntoBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoRa
 		m_pManager->LanzarEventoCreacion(punto);
 		m_pManager->Modificado();
 		ConsumirEvento();
-		m_Estado = WBS_Moviendo;
-
 	}
 	else if (evento.Dragging() && m_MouseDown) {
 	}
