@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wregla.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: wregla.cpp 4500 2011-12-20 08:00:51Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -15,6 +15,8 @@
 #include <wx/xml/xml.h>
 #include <api/globals.h>
 #include <api/icontexto.h>
+#include <api/ivista.h>
+#include <api/icontextoestudio.h>
 #include <api/iwidgetsrenderer.h>
 #include <api/iwidgetsmanager.h>
 #include <api/westilo.h>
@@ -37,7 +39,7 @@
 
 //region "Implementacion de WReglaBuilder"
 
-GNC::GCS::Widgets::WReglaBuilder::WReglaBuilder(GNC::GCS::IWidgetsManager* pManager) : GNC::GCS::Widgets::IWidgetBuilder(pManager)
+GNC::GCS::Widgets::WReglaBuilder::WReglaBuilder(GNC::GCS::IWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask) : GNC::GCS::Widgets::IWidgetBuilder(pManager, buttonMask)
 {
 	m_MouseDown = false;
 	m_pReglaTemp = NULL;
@@ -59,7 +61,7 @@ void GNC::GCS::Widgets::WReglaBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoRa
 		return;
 	}
 	GTRACE("GNC::GCS::Widgets::WReglaBuilder::OnMouseEvents(wxMouseEvent&)");
-	if (m_MouseDown && evento.ButtonUp(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	if (m_MouseDown && evento.ButtonUp(m_ButtonMask)) {
 		m_MouseDown = false;
 		if (m_pReglaTemp != NULL) {
 			m_pReglaTemp->m_Vertices[1] = evento.iP;;
@@ -77,7 +79,7 @@ void GNC::GCS::Widgets::WReglaBuilder::OnMouseEvents(GNC::GCS::Eventos::EventoRa
 		}
 		ConsumirEvento();
 
-	} else if (evento.ButtonDown(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	} else if (evento.ButtonDown(m_ButtonMask)) {
 
 		m_MouseDown = true;
 		TNodo nodos[2];
@@ -641,20 +643,25 @@ void GNC::GCS::Widgets::WRegla::Recalcular(GNC::GCS::IWidgetsRenderer* renderer)
 	os.setf(ios::floatfield, ios::fixed );
 	os.precision(2);
 	os.fill('0');
-
 	float metricaDistancia = wDiff.Norma2();
 
-	if (metricaDistancia > 1000.0f) {
-		os << metricaDistancia / 1000.0f << " m.";
-	}
-	else if (metricaDistancia > 10.0f) {
-		os << metricaDistancia / 10.0f << " cm.";
-	}
-	else if (metricaDistancia < 1.0f) {
-			os << metricaDistancia * 1000.0f << " µm.";
+	double spacing[3] = {0.0, 0.0, 0.0};
+	bool hasSpacing = m_pManager->GetVista()->GetEstudio()->GetSpacingActiva(spacing[0], spacing[1], spacing[2]);
+	if (hasSpacing) {
+		if (metricaDistancia > 1000.0f) {
+			os << metricaDistancia / 1000.0f << " m.";
 		}
-	else {
-		os << metricaDistancia << " mm.";
+		else if (metricaDistancia > 10.0f) {
+			os << metricaDistancia / 10.0f << " cm.";
+		}
+		else if (metricaDistancia < 1.0f) {
+				os << metricaDistancia * 1000.0f << " µm.";
+			}
+		else {
+			os << metricaDistancia << " mm.";
+		}
+	} else {
+		os << metricaDistancia << " px.";
 	}
 
 	std::string medida = os.str();
@@ -725,21 +732,26 @@ void GNC::GCS::Widgets::WRegla::InsertarPropiedades(TListaMapasPropiedades &list
 		os.precision(2);
 		os.fill('0');
 
+		double spacing[3] = {0.0, 0.0, 0.0};
+		bool hasSpacing = m_pManager->GetVista()->GetEstudio()->GetSpacingActiva(spacing[0], spacing[1], spacing[2]);
 		float metricaDistancia = m_Distancia;
-
-		if (metricaDistancia > 1000.0f) {
-			os << metricaDistancia / 1000.0f << " m.";
+		if (hasSpacing) {
+			if (metricaDistancia > 1000.0f) {
+				os << metricaDistancia / 1000.0f << " m.";
+			}
+			else if (metricaDistancia > 10.0f) {
+				os << metricaDistancia / 10.0f << " cm.";
+			}
+			else if (metricaDistancia < 1.0f) {
+					os << metricaDistancia * 1000.0f << " µm.";
+				}
+			else {
+				os << metricaDistancia << " mm.";
+			}
+		} else {
+			os << metricaDistancia << " px.";
 		}
-		else if (metricaDistancia > 10.0f) {
-			os << metricaDistancia / 10.0f << " cm.";
-		}
-		else if (metricaDistancia < 1.0f) {
-			os << metricaDistancia * 1000.0f << " µm.";
-		}
-		else {
-			os << metricaDistancia << " mm.";
-		}
-
+		
 		std::string medida = os.str();
 		primerMapa[_Std("Length")] = medida;
 	 }
@@ -767,19 +779,24 @@ void GNC::GCS::Widgets::WRegla::OffscreenRender(GNC::GCS::Contexto3D* c)
 	os.precision(2);
 	os.fill('0');
 
+	double spacing[3] = {0.0, 0.0, 0.0};
+	bool hasSpacing = m_pManager->GetVista()->GetEstudio()->GetSpacingActiva(spacing[0], spacing[1], spacing[2]);
 	float metricaDistancia = m_Distancia;
-
-	if (metricaDistancia > 1000.0f) {
-		os << metricaDistancia / 1000.0f << " m.";
-	}
-	else if (metricaDistancia > 10.0f) {
-		os << metricaDistancia / 10.0f << " cm.";
-	}
-	else if (metricaDistancia < 1.0f) {
-		os << metricaDistancia * 1000.0f << " µm.";
-	}
-	else {
-		os << metricaDistancia << " mm.";
+	if (hasSpacing) {
+		if (metricaDistancia > 1000.0f) {
+			os << metricaDistancia / 1000.0f << " m.";
+		}
+		else if (metricaDistancia > 10.0f) {
+			os << metricaDistancia / 10.0f << " cm.";
+		}
+		else if (metricaDistancia < 1.0f) {
+				os << metricaDistancia * 1000.0f << " µm.";
+			}
+		else {
+			os << metricaDistancia << " mm.";
+		}
+	} else {
+		os << metricaDistancia << " px.";
 	}
 
 	std::string medida = os.str();
