@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wtrapezoide.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: wtrapezoide.cpp 4504 2012-01-11 07:46:45Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -26,7 +26,7 @@
 
 //region "Implementacion de WTrapezoideBuilder , se construye exactamente igual a un rectangulo"
 
-GNC::GCS::Widgets::WTrapezoideBuilder::WTrapezoideBuilder(TWidgetsManager* pManager, long gid,  int numMaxTrapezoides) : GNC::GCS::Widgets::IWidgetBuilder(pManager, gid)
+GNC::GCS::Widgets::WTrapezoideBuilder::WTrapezoideBuilder(TWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask, long gid,  int numMaxTrapezoides) : GNC::GCS::Widgets::IWidgetBuilder(pManager, buttonMask, gid)
 {
 	m_MouseDown = false;
 	m_Estado = WBS_Ninguno;
@@ -43,7 +43,7 @@ void GNC::GCS::Widgets::WTrapezoideBuilder::OnMouseEvents(GNC::GCS::Eventos::Eve
 	if (!m_pManager) {
 		return;
 	}
-	if (m_MouseDown && evento.ButtonUp(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	if (m_MouseDown && evento.ButtonUp(m_ButtonMask)) {
 		m_MouseDown = false;
 		if (m_Estado != WBS_Creando) {
 			m_Estado = WBS_Ninguno;
@@ -58,19 +58,16 @@ void GNC::GCS::Widgets::WTrapezoideBuilder::OnMouseEvents(GNC::GCS::Eventos::Eve
 		m_Vertices[2].Asignar(m_Stop.x, m_Stop.y);
 		m_Vertices[3].Asignar(m_Start.x, m_Stop.y);
 
+		m_pManager->Modificado();
 		TVector diff = m_Stop - m_Start;
 		if (std::abs(diff.x) > evento.c->RelacionImagenPantalla().NormaInfinito() && std::abs(diff.y) > evento.c->RelacionImagenPantalla().NormaInfinito()) {
 			WTrapezoide* w = new WTrapezoide(m_pManager, m_Vertices, evento.c->GetRenderer()->GetVID(), "Trapezoide", m_GID);
 			m_pManager->InsertarWidget(w);
+			ConsumirEvento();
 			m_pManager->LanzarEventoCreacion(w);
-			return;
 		}
-
-		m_pManager->Modificado();
-		m_Estado = WBS_Ninguno;
-		ConsumirEvento();
 	}
-	else if (evento.ButtonDown(GNC::GCS::Eventos::EventoRaton::EB_IZQUIERDO)) {
+	else if (evento.ButtonDown(m_ButtonMask)) {
 		if (m_Estado != WBS_Ninguno) {
 			return;
 		}
