@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: thumbnailctrl.cpp 4437 2011-11-21 14:03:22Z tovar $
+ *  $Id: thumbnailctrl.cpp 4706 2012-02-16 07:59:43Z tovar $
  *  Ginkgo CADx Project
  *
  *
@@ -46,6 +46,7 @@
 #include "wx/image.h"
 #include "wx/filename.h"
 #include "wx/dcbuffer.h"
+#include <resources/ginkgoresourcemanager.h>
 
 #include "tick.xpm"
 
@@ -1674,22 +1675,27 @@ class LoadThread: public wxThread {
 		 if (wxFileExists(m_filename))
 		 {
 			  wxImage image;
-			  if (image.LoadFile(m_filename, wxBITMAP_TYPE_ANY))
-			  {
-					wxSize thumbnailSize = ctrl->GetThumbnailImageSize();
-					double scaleX = ((double) thumbnailSize.x)/((double) image.GetWidth());
-					double scaleY = ((double) thumbnailSize.y)/((double) image.GetHeight());
-
-					if (scaleX < 1.0 || scaleY < 1.0)
-					{
-						 double scale = wxMin(scaleX, scaleY);
-						int newWidth = std::max<int>(1, (int) (scale * image.GetWidth()));
-						int newHeight = std::max<int>(1, (int) (scale * image.GetHeight()));
-						 image.Rescale(newWidth, newHeight);
-					}
-					m_cachedBitmap = wxBitmap(image);
-					ctrl->Refresh(true);
+			  if (!image.LoadFile(m_filename, wxBITMAP_TYPE_ANY)) {
+				  wxFileName fileName(m_filename);
+				  if (fileName.GetExt().CompareTo(wxT("PDF"), wxString::ignoreCase) == 0) {
+					  image = GinkgoResourcesManager::PanelHistorial::GetPDFPreview().ConvertToImage();
+				  } else {
+					  image = GinkgoResourcesManager::PanelHistorial::GetIcoUnknownFile().ConvertToImage();
+				  }
 			  }
+				wxSize thumbnailSize = ctrl->GetThumbnailImageSize();
+				double scaleX = ((double) thumbnailSize.x)/((double) image.GetWidth());
+				double scaleY = ((double) thumbnailSize.y)/((double) image.GetHeight());
+
+				if (scaleX < 1.0 || scaleY < 1.0)
+				{
+					double scale = wxMin(scaleX, scaleY);
+					int newWidth = std::max<int>(1, (int) (scale * image.GetWidth()));
+					int newHeight = std::max<int>(1, (int) (scale * image.GetHeight()));
+					image.Rescale(newWidth, newHeight);
+				}
+				m_cachedBitmap = wxBitmap(image);
+				ctrl->Refresh(true);
 		 }
 		 return NULL;
 	 }
