@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: thumbnailctrl.h 3822 2011-05-04 08:34:50Z carlos $
+ *  $Id: thumbnailctrl.h 4437 2011-11-21 14:03:22Z tovar $
  *  Ginkgo CADx Project
  *
  *
@@ -138,6 +138,7 @@ protected:
  * wxImageThumbnailItem class declaration
  */
 
+class LoadThread;
 class EXTAPI wxImageThumbnailItem: public wxThumbnailItem
 {
 	DECLARE_DYNAMIC_CLASS(wxImageThumbnailItem)
@@ -145,7 +146,8 @@ public:
 // Constructors
 
     wxImageThumbnailItem(const wxString& filename = wxEmptyString):
-        wxThumbnailItem(filename) {}
+        wxThumbnailItem(filename) {pThread = NULL;}
+	  ~wxImageThumbnailItem();
 
 // Overrideables
 
@@ -159,6 +161,7 @@ public:
 
 protected:
     wxBitmap    m_cachedBitmap;
+	 LoadThread* pThread;
 };
 
 /*!
