@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wxwizardginkgobase.cpp 3066 2010-12-21 10:10:14Z carlos $
+ *  $Id: wxwizardginkgobase.cpp 4711 2012-02-16 08:43:55Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -13,13 +13,22 @@
  */
 #include "wxwizardginkgobase.h"
 #include <resources/ginkgoresourcemanager.h>
+#include <main/controllers/inactivitycontroller.h>
 
 wxWizardGinkgoBase::wxWizardGinkgoBase( wxWindow* parent):
 wxWizardGinkgoBaseWx(parent)
 {
+	//stops inactivity monitor
+	GNC::GCS::InactivityController::Instance()->StopsMonitoring();
+	//
 }
 
-wxWizardGinkgoBase::~wxWizardGinkgoBase(){};
+wxWizardGinkgoBase::~wxWizardGinkgoBase()
+{
+	//starts inactivity monitor
+	GNC::GCS::InactivityController::Instance()->RestartMonitoring();
+	//
+}
 
 void wxWizardGinkgoBase::SiguientePaso(){
 	wxCommandEvent evt;
