@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wxwizardginkgobase.h 3535 2011-03-18 17:57:05Z carlos $
+ *  $Id: wxwizardginkgobase.h 4445 2011-11-25 08:25:25Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -14,8 +14,9 @@
 #pragma once
 #include "wxwizardginkgobasewx.h"
 #include <api/iwizard.h>
+#include <api/api.h>
 
-class wxWizardGinkgoBase: public wxWizardGinkgoBaseWx, public IWizard{
+class EXTAPI wxWizardGinkgoBase: public wxWizardGinkgoBaseWx, public IWizard{
 public:
 	wxWizardGinkgoBase( wxWindow* parent);
 	~wxWizardGinkgoBase();
