@@ -42,6 +42,8 @@
 #include <iostream>
 #include <exception>
 #include <string>
+#include <api/iexception.h>
+#include <api/internacionalization/internacionalization.h>
 
 #define GLOC() (__FILE__ ":" TOSTRING(__LINE__))
 #define STRINGIFY(x) #x
@@ -445,15 +447,10 @@ inline void GLockable::AutoUnLock(GLocker* pLocker)
 
 //endregion
 
-struct GnkNullPointerException : public std::exception
+struct GnkNullPointerException : public GNC::GCS::IException
 {
-    GnkNullPointerException() throw() {}
+	GnkNullPointerException() throw() : GNC::GCS::IException(_Std("Attempted to dereference null pointer")) {}
     ~GnkNullPointerException() throw() {}
-
-    const char* what() const throw()
-    {
-        return "[Yasper Exception] Attempted to dereference null pointer";
-    }
 };
 
 class GnkCounter : public GLockable
