@@ -21,7 +21,7 @@ IMPLEMENT_PrivateExtension(GnkFooExtension)
 
 //parameters are related with provider, version... sid is the extension id, it's used to know if a file has been imported by this extension
 //this information will be used in viewer open preference
-GnkFooExtension::GnkFooExtension(): PrivateExtension(FOO_EXTENSION_SID, FOO_EXTENSION_PROVIDER, FOO_EXTENSION_DESCRIPTION, FOO_EXTENSION_VERSION, FOO_EXTENSION_SUB_VERSION, FOO_EXTENSION_SUB_RELEASE, FOO_EXTENSION_BUILD, FOO_EXTENSION_CODENAME, FOO_EXTENSION_UPDATEURL)
+GnkFooExtension::GnkFooExtension(): PrivateExtension(EXT_SID, EXT_PROVIDER, EXT_DESCRIPTION, EXT_VERSION, EXT_SUBVERSION, EXT_RELEASE, EXT_BUILD, EXT_CODENAME, EXT_UPDATEURL)
 {
 }
 
@@ -30,9 +30,11 @@ GnkFooExtension::~GnkFooExtension()
 }
 
 //returns extension controller module
-GNC::GCS::IControladorModulo* GnkFooExtension::InitializeLibrary(GNC::GCS::IEntorno* pEntorno)
+PrivateExtension::TListControllers GnkFooExtension::InitializeLibrary(GNC::GCS::IEntorno* pEntorno)
 {
-	return new FooExtension::FooExtensionController(pEntorno);
+	TListControllers list;
+	list.push_back(new FooExtension::FooExtensionController(pEntorno));
+	return list;
 }
 
 //here you can implement your own security policy
