@@ -20,7 +20,7 @@ public :
 	GnkFooExtension();
 	~GnkFooExtension();
 	//here you have to return module controller of this extension
-	virtual GNC::GCS::IControladorModulo* InitializeLibrary(GNC::GCS::IEntorno* pEntorno);
+	virtual TListControllers InitializeLibrary(GNC::GCS::IEntorno* pEntorno);
 	//it's used by Ginkgo CADx core to know if extension is activated or not, extension can implement it's own security policies
 	virtual bool IsActivated();
 	//it's used by Ginkgo CADx core to show library activation dialog
