@@ -55,20 +55,12 @@ namespace FooExtension {
 
 		//region "IPasoWizard"
 
-		void GeneralData::Attach(wxSizer *sizer){
+		bool GeneralData::Attach(){
 			m_pPatientId->SetFocus();
 
-			Show(true);
-
-			sizer->Add(this,10, wxEXPAND);
-			this->GetParent()->Layout();
+			return true;
 		}
 
-		void GeneralData::Detach(wxSizer *sizer){
-			Hide();
-			sizer->Detach(this);
-			sizer->GetContainingWindow()->Layout();
-		}
 
 		std::string GeneralData::GetTitle(){
 			return _Std("Title of this step");
@@ -184,10 +176,10 @@ namespace FooExtension {
 			base.tags[std::string("0008|0070")] = std::string("Metaemotion S.L.");
 
 			//description of the extension
-			base.tags[std::string("0008|1090")] = FOO_EXTENSION_DESCRIPTION;
+			base.tags[std::string("0008|1090")] = EXT_DESCRIPTION;
 
 			//uid of the extension, used to open imported files with this extension
-			base.tags[std::string("0018|1030")] = FOO_EXTENSION_UID;
+			base.tags[std::string("0018|1030")] = EXT_IMPORTER_SID;
 
 			base.tags[std::string("0008|0020")] = m_pPersistentData->StudyDate;
 
