@@ -36,9 +36,8 @@ namespace FooExtension {
 				~GeneralData();
 
 				//this method tells importation step that it has to attach to the wizard (attach and show)
-				virtual void Attach(wxSizer *sizer);
-				//this method tells importation step that it has to be dettached from the wizard
-				virtual void Detach(wxSizer *sizer);
+				virtual bool Attach();
+				
 				//returns step title
 				virtual std::string GetTitle();
 				//returns step subtitle
