@@ -19,7 +19,7 @@
 #include <api/imodelointegracion.h>
 #include <sstream>
 
-#include <api/icontroladorimportacionpacs.h>
+#include <api/controllers/ipacscontroller.h>
 
 namespace FooExtension {
 	namespace GUI {
