@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: toolwindowlevellight.cpp 4530 2012-01-16 07:23:33Z tovar $
+ *  $Id: toolwindowlevellight.cpp 4869 2012-04-19 11:47:15Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -317,14 +317,14 @@ void LightVisualizator::ToolWindowLevelLight::ConectarContratos(bool activar)
 	for (; itWindowLevel != TContratableWindowLevel::m_pListaActiva->end(); itWindowLevel++) {
 		TContratoWindowLevel* pCWL = (*itWindowLevel);
 		if (activar) {
-			GTRACE("ToolWindowLevelLight: Conectando contratos de vista " << pCW->GetViewer() );
+			GTRACE("ToolWindowLevelLight: Conectando contratos de vista " << pCW->GetViewerActivo() );
 			// Subscribimos los eventos de la ventana a un metodo especifico del panel de esta herramienta
 			// Usamos de Id de grupo el valor del puntero de la herramienta, que es unico y no cambia
 			((LightVisualizator::GUI::HerramientaOpcionesWindowLevelGUI*)m_pAbstractPanelHerramientaOpciones)->ConfigurarCombo(&pCWL->m_listaWindowLevels, pCWL->m_labelCurrent, pCWL->CurrentWindow, pCWL->CurrentLevel);
 			GNC::GCS::ControladorEventos::Instance()->Registrar(this, GNC::GCS::Eventos::EventoModificacionImagen(TContratableWindowLevel::m_pVistaActiva));
 		}
 		else {
-			GTRACE( "ToolWindowLevelLight: Desconectando contratos de vista " << pCW->GetViewer() );
+			GTRACE( "ToolWindowLevelLight: Desconectando contratos de vista " << pCW->GetViewerActivo() );
 			GNC::GCS::ControladorEventos::Instance()->DesRegistrar(this);
 		}
 	}
