@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: toolwindowlevellight.h 3905 2011-06-30 08:47:47Z tovar $
+ *  $Id: toolwindowlevellight.h 4468 2011-12-09 10:02:00Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -23,7 +23,7 @@ namespace LightVisualizator {
 	class ToolWindowLevelLight : public IToolWindowLevelLight, public GNC::GCS::IObservador {
 
 	public:
-		typedef std::map<TContratoWindowLevel*, GNC::GCS::IContratoWindowLevel::WindowLevel> ListaWindowLevelsIniciales;
+		typedef std::map<TContratoWindowLevel*, GNC::GCS::IContractWindowLevel::WindowLevel> ListaWindowLevelsIniciales;
 
 		ToolWindowLevelLight();
 		virtual ~ToolWindowLevelLight();
@@ -44,7 +44,7 @@ namespace LightVisualizator {
 		//region "metodos propios de la herramienta window/level"
 		virtual void ClampWindowLevel(double window, double level, double& clampedWindow, double& clampedLevel);
 
-		virtual void SetWindowLevel(const GNC::GCS::IContratoWindowLevel::WindowLevel& wl);
+		virtual void SetWindowLevel(const GNC::GCS::IContractWindowLevel::WindowLevel& wl);
 		void Resetear();
 		//endregion
 
