@@ -1,5 +1,5 @@
 /*
- *  $Id: glightvisualizatorview.cpp 4468 2011-12-09 10:02:00Z carlos $
+ *  $Id: glightvisualizatorview.cpp 4690 2012-02-13 07:12:10Z carlos $
  *  Proyecto Ginkgo
  *
  *  Copyright 2008 MetaEmotion S.L. All rights reserved.
@@ -157,7 +157,7 @@ namespace LightVisualizator {
 				}
 			}
 			catch (GNC::GCS::ControladorHerramientasException& ex) {
-				std::cerr << "Error al obtener la herramienta: No se pudo subscribir la herramienta: " << ex.getCause() << std::endl;
+				std::cerr << "Error al obtener la herramienta: No se pudo subscribir la herramienta: " << ex << std::endl;
 			}
 
 			View->Lock(GLOC());
@@ -237,7 +237,7 @@ namespace LightVisualizator {
 					}
 				}
 				catch (GNC::GCS::ControladorHerramientasException& ex) {
-					std::cerr << "Error al obtener la herramienta: No se pudo subscribir la herramienta: " << ex.getCause() << std::endl;
+					std::cerr << "Error al obtener la herramienta: No se pudo subscribir la herramienta: " << ex << std::endl;
 				}
 			}
 
