@@ -1,5 +1,5 @@
 /*
- *  $Id: lightvisualizatorextension.h 3900 2011-06-24 13:47:22Z tovar $
+ *  $Id: lightvisualizatorextension.h 4555 2012-01-17 10:03:03Z tovar $
  *  Proyecto Ginkgo
  *
  *  Copyright 2008 MetaEmotion S.L. All rights reserved.
@@ -20,7 +20,7 @@ public :
 	LightVisualizatorExtension();
 	~LightVisualizatorExtension();
 	//here you have to return module controller of this extension
-	virtual GNC::GCS::IControladorModulo* InitializeLibrary(GNC::GCS::IEntorno* pEntorno);
+	virtual TListControllers InitializeLibrary(GNC::GCS::IEntorno* pEntorno);
 	//it's used by Ginkgo CADx core to know if extension is activated or not, extension can implement it's own security policies
 	virtual bool IsActivated();
 	//it's used by Ginkgo CADx core to show library activation dialog
