@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: visualizator.cpp 4365 2011-11-03 14:01:58Z carlos $
+ *  $Id: visualizator.cpp 4555 2012-01-17 10:03:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -33,9 +33,11 @@ GNKVisualizatorExtension::GNKVisualizatorExtension():PrivateExtension(EXT_SID, E
 GNKVisualizatorExtension::~GNKVisualizatorExtension()
 {
 }
-GNC::GCS::IControladorModulo* GNKVisualizatorExtension::InitializeLibrary(GNC::GCS::IEntorno* pEntorno)
+PrivateExtension::TListControllers GNKVisualizatorExtension::InitializeLibrary(GNC::GCS::IEntorno* pEntorno)
 {
-	return new GNKVisualizator::ControladorAtencionPrimaria(pEntorno);
+	PrivateExtension::TListControllers list;
+	list.push_back(new GNKVisualizator::ControladorAtencionPrimaria(pEntorno));
+	return list;
 }
 bool GNKVisualizatorExtension::IsActivated()
 {
