@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: visualizator.h 3558 2011-03-20 20:02:22Z carlos $
+ *  $Id: visualizator.h 4555 2012-01-17 10:03:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -22,7 +22,7 @@ class GNKVisualizatorExtension : public PrivateExtension
 public :
 	GNKVisualizatorExtension();
 	~GNKVisualizatorExtension();
-	virtual GNC::GCS::IControladorModulo* InitializeLibrary(GNC::GCS::IEntorno* pEntorno);
+	virtual PrivateExtension::TListControllers InitializeLibrary(GNC::GCS::IEntorno* pEntorno);
 	virtual bool IsActivated();
 	virtual void ShowActivationDialog(wxWindow* pParent);
 };
\ No newline at end of file
