@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: visualizatorcontroller.cpp 4555 2012-01-17 10:03:03Z tovar $
+ *  $Id: visualizatorcontroller.cpp 4706 2012-02-16 07:59:43Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -22,10 +22,10 @@
 #include "../herramientas/herramientaoverlays.h"
 #include "../herramientas/reconstructiontool.h"
 
-#include "../dialogos/contenedorherramientas.h"
-#include "../dialogos/importacion/pasodatosgenerales.h"
-#include "../dialogos/importacion/datospersistentesimportacion.h"
-#include "../dialogos/seleccionardiagnostico/seleccionardiagnostico.h"
+#include <visualizator/dialogos/contenedorherramientas.h>
+#include <main/gui/import/generaldata.h>
+#include <main/gui/import/importationdata.h>
+#include <visualizator/dialogos/seleccionardiagnostico/seleccionardiagnostico.h>
 #include "../vistas/vista2d.h"
 #include "../vistas/waveformview.h"
 #include <visualizator/estudios/visualizatorstudy.h>
@@ -34,6 +34,7 @@
 #include <api/ientorno.h>
 #include <api/ivista.h>
 #include <api/dicom/imodelodicom.h>
+#include <api/integration/dict.h>
 #include <api/icontroladorcarga.h>
 #include <main/controllers/controladorhistorial.h>
 #include <visualizator/dialogos/importacion/selectimagesimportationvisualizator.h>
@@ -48,6 +49,7 @@
 #include <api/icontroladorcarga.h>
 #include <main/controllers/controladorcarga.h>
 #include <main/controllers/controladorcomandos.h>
+#include <visualizator/commands/pdfextractercommand.h>
 #include <commands/comandopacs.h>
 
 #include <vector>
@@ -59,6 +61,8 @@
 #include <visualizator/resources/aprimresourcemanager.h>
 #include "../exportacion/tagsprivados.h"
 
+#define UID_EncapsulatedPDFStorage  "1.2.840.10008.5.1.4.1.1.104.1"
+
 namespace GNKVisualizator {
 	class GNKVisualizatorControllerMode: public GNC::GCS::ModoControlador
 	{
@@ -115,16 +119,6 @@ GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::G
 	// Codigos LOINC de los informes de A. Primaria.
 	m_ListaInformes.push_back(GNC::GCS::IdHL7("TUID" + m_UID, "0", _Std("Ginkgo CADx Image Report"), "LN", "", "","v1.0"));
 
-
-	// Codigos LOINC de los Estudios que genera A. Primaria
-	m_ListaEstudios["EstudioOriginal"]= GNC::GCS::IdHL7("EstudioOriginal", "121018", "Study Instance UID", "DCM", "HD", "","v1.0");
-	
-	// Codigos LOINC de los registros HL7 que genera A. Primaria
-	m_ListaRegistros["SerieOriginal"] = GNC::GCS::IdHL7("SerieOriginal", "112002", "Series Instance UID", "DCM", "HD", "","v1.0");
-	m_ListaRegistros["IDPacs"] = GNC::GCS::IdHL7("IDPacs", "ARCHIVE", "IDPACS", "DCM", "HD", "","v1.0");
-	m_ListaRegistros["Imagen"] = GNC::GCS::IdHL7("Imagen", "121126", "SOP Instance UID", "DCM", "HD", "","v1.0");
-	m_ListaRegistros["SOPClass"] = GNC::GCS::IdHL7("SOPClass", "121127", "SOP Class ID", "DCM", "HD", "","v1.0");
-
 	m_pPanelContenedorCustom = NULL;
 
 	//registrar herramientas
@@ -160,7 +154,7 @@ GNKVisualizator::ControladorAtencionPrimaria::~ControladorAtencionPrimaria()
 		}
 	}
 	catch (GNC::GCS::ControladorHerramientasException& ex) {
-		std::cerr << "Error al registrar herramientas de Oftal: No se pudo subscribir la herramienta: " << ex.getCause() << std::endl;
+		std::cerr << "Error al registrar herramientas de Oftal: No se pudo subscribir la herramienta: " << ex << std::endl;
 	}
 
 
@@ -280,42 +274,30 @@ GNC::GCS::IVista* GNKVisualizator::ControladorAtencionPrimaria::AbrirVista(int m
 			}
 		}
 	}
-	//
-
-	/*ESTO SIRVE PARA NO SEPARAR POR SERIES...
-	std::list<std::string> listaUIDSerie;
-	std::vector<std::string> rutas;
-	GnkPtr<GIL::IModeloIntegracion> pModeloIntegracion = NULL;
-	for(ListaDescriptoresSerie::iterator it = series.begin(); it!=series.end(); it++){
-		listaUIDSerie.push_back((*it).m_uidSerie);
-		if(!m_ListaModos[modo]->SoportaModalidad((*it).m_modalidad)){
-			//mensaje de error!!
-			wxMessageBox(_("Derma view does not support modality studies") + wxString::FromUTF8((*it).m_modalidad.c_str()), _("Error"), wxICON_ERROR);
-			return NULL;
-		}
-		if((*it).m_pModeloIntegracion.IsValid()) {
-			pModeloIntegracion = (*it).m_pModeloIntegracion;
-		}
-		std::vector<std::string> rutasSerie = m_pEntorno->GetControladorHistorial()->GetPathsSerieOrdenados((*it).m_uidSerie);
-		for (std::vector<std::string>::iterator it = rutasSerie.begin(); it != rutasSerie.end(); ++it) {
-			rutas.push_back((*it));
-		}
-	}
-	{
-	*/
 
 	for(std::set<std::string>::iterator it = uidsSeries.begin(); it!= uidsSeries.end(); it++)
 	{
 		std::vector<std::string> rutas = m_pEntorno->GetControladorHistorial()->GetPathsSerieOrdenados((*it));
-
-		GNC::GCS::IControladorVistas* pCtrlVistas = m_pEntorno->GetControladorVistas();
-		wxWindow* pVentanaPadre = NULL;
-
 		if (rutas.size() == 0)
 		{
 			return NULL;
 		}
 
+		//if it's pdf...
+		GNC::GCS::ControladorHistorial::ListaModelosDCM dcmModels;
+		GNC::GCS::ControladorHistorial::Instance()->GetAllModelosDCMSeries((*it), dcmModels);
+		if (dcmModels.size() > 0 && dcmModels.front().m_sopClassUID == UID_EncapsulatedPDFStorage) 
+		{			
+			GNKVisualizator::GADAPI::PDFExtracterCommandParameters* pParams = new GNKVisualizator::GADAPI::PDFExtracterCommandParameters(rutas);
+			GNKVisualizator::GADAPI::PDFExtracterCommand* pCmd = new GNKVisualizator::GADAPI::PDFExtracterCommand(pParams);
+			m_pEntorno->GetControladorComandos()->ProcessAsync("Extracting...", pCmd, NULL);
+			
+			continue;
+		}
+
+		GNC::GCS::IControladorVistas* pCtrlVistas = m_pEntorno->GetControladorVistas();
+		wxWindow* pVentanaPadre = NULL;
+
 		//primero de todo seleccionar diagnostico
 		std::string uidDiagnosticoSeleccionado = uidEstudioDiagnostico;
 		if(!SeleccionarDiagnostico(rutas[0],uidDiagnosticoSeleccionado))
@@ -418,10 +400,11 @@ bool GNKVisualizator::ControladorAtencionPrimaria::SoportaImportacion() const
 	return m_pEntorno->GetControladorPermisos()->Get("atencionprimaria", "dicomizador");
 }
 
-void GNKVisualizator::ControladorAtencionPrimaria::GetPasosImportacion(IWizard* pWizard,std::list<IPasoWizard*> &listaPasos, wxWindow* pParent, std::string &dirTemporal, GnkPtr<GIL::IModeloIntegracion> pModeloIntegracion){
-	GnkPtr<GNKVisualizator::GUI::TipoWizardImportacion> datosPersistentes(new GNKVisualizator::GUI::TipoWizardImportacion(pModeloIntegracion));
+void GNKVisualizator::ControladorAtencionPrimaria::GetPasosImportacion(IWizard* pWizard,std::list<IPasoWizard*> &listaPasos, wxWindow* pParent, std::string &dirTemporal, GnkPtr<GIL::IModeloIntegracion> pModeloIntegracion)
+{
+	GnkPtr<GNC::GUI::ImportationData> datosPersistentes(new GNC::GUI::ImportationData(pModeloIntegracion));
 
-	IPasoWizard* paso=new GNKVisualizator::GUI::PasoDatosGenerales(pParent,pWizard,datosPersistentes,dirTemporal,m_pEntorno);
+	IPasoWizard* paso=new GNC::GUI::GeneralData(pParent,pWizard,datosPersistentes, true);
 	listaPasos.push_back(paso);
 
 	paso = new GNKVisualizator::GUI::SelectImagesImportationVisualizator(pParent,pWizard,datosPersistentes,dirTemporal);
@@ -475,6 +458,7 @@ void GNKVisualizator::ControladorAtencionPrimaria::OcultarPaneles(bool izquierdo
 void GNKVisualizator::ControladorAtencionPrimaria::ReprocessIntegration(const std::string& uidSeries, GnkPtr<GIL::IModeloIntegracion> pIntegrationModel)
 {	
 	//reprocess integration flow...
+
 	std::vector<std::string> rutas = m_pEntorno->GetControladorHistorial()->GetPathsSerieOrdenados(uidSeries);
 	GnkPtr<GNKVisualizator::VisualizatorStudy> estudio = new GNKVisualizator::VisualizatorStudy();
 	estudio->ListaUIDsSerie.push_back(uidSeries);
@@ -483,32 +467,36 @@ void GNKVisualizator::ControladorAtencionPrimaria::ReprocessIntegration(const st
 	estudio->VentanaPadre = NULL;
 	estudio->InicializarContextoEstudio(rutas, "", GNC::GCS::IContextoEstudio::TMF_UNDiagnostico);
 
-	
+	GIL::IStudyModel studyModel;
+	GIL::ISeriesModel seriesModel;
 	//recreate evidences...
 	std::string strTmp0, strTmp1;
-	pIntegrationModel->Evidencias.clear();
+
 	estudio->SetIndiceActivo(0);
 	estudio->GetTagImagenActiva("0020|000d", strTmp0);//uid study
+	studyModel.MapOfVars.InsertVariable(GKDI_STUDY_INSTANCE_UID, strTmp1);
 	estudio->GetTagImagenActiva("0008|0050", strTmp1);//accession
-	GIL::IModeloEvidenciaEstudio evidenciaEstudioDicomizado("EstudioOriginal", strTmp0, strTmp1);
+	studyModel.MapOfVars.InsertVariable(GKDI_STUDY_ACCESSION_NUMBER, strTmp1);
 
 	estudio->GetTagImagenActiva("0020|000e", strTmp0);//uid series
-	GIL::IModeloEvidenciaSerie evidenciaSerie("SerieOriginal", strTmp0);
+	seriesModel.MapOfVars.InsertVariable(GKDI_SERIE_INSTANCE_UID, strTmp0);
 	for (int i = 0; i < estudio->GetNumeroCortes(); ++i) {
+		GIL::IImageModel imageModel;
 		estudio->SetIndiceActivo(i);
 		estudio->GetTagImagenActiva("0008|0018", strTmp0);//sop instance
 		estudio->GetTagImagenActiva("0008|0016", strTmp1);//sop class
-
-		GIL::IModeloEvidenciaImagen evidenciaImagen("Imagen", strTmp0, strTmp1);
-		evidenciaSerie.ListaImagenes.push_back(evidenciaImagen);
+		imageModel.MapOfVars.InsertVariable(GKDI_IMAGE_SOP_INSTANCE_UID, strTmp0);
+		imageModel.MapOfVars.InsertVariable(GKDI_IMAGE_SOP_CLASS_UID, strTmp1);
+		seriesModel.Images.push_back(imageModel);
 	}
 
-	evidenciaEstudioDicomizado.ListaSeries.push_back(evidenciaSerie);
-	pIntegrationModel->Evidencias.push_back(evidenciaEstudioDicomizado);
+	studyModel.Series.push_back(seriesModel);
+
+	pIntegrationModel->Studies.push_back(studyModel);
 	//
-	GADAPI::ComandoPACSParams * pParams = new ::GADAPI::ComandoPACSParams(pIntegrationModel->PACSAlmacenamiento, rutas, pIntegrationModel);
+	::GADAPI::ComandoPACSParams * pParams = new ::GADAPI::ComandoPACSParams(pIntegrationModel->GlobalVariables.GetValue(GKDI_GLOBAL_PACS_STORE_SID), rutas, pIntegrationModel);
 	pParams->m_informar = false;
-	GADAPI::ComandoPACS * pCmd = new ::GADAPI::ComandoPACS(pParams);
+	::GADAPI::ComandoPACS * pCmd = new ::GADAPI::ComandoPACS(pParams);
 	GNC::GCS::ControladorComandos::Instance()->ProcessAsync(_Std("Uploading..."), pCmd, NULL);	
 	//
 }
