@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: selectimagesimportationvisualizator.h 4303 2011-10-18 10:31:44Z tovar $
+ *  $Id: selectimagesimportationvisualizator.h 4589 2012-01-24 12:59:14Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -15,7 +15,7 @@
 #include <api/iwizard.h>
 #include <string>
 #include <vector>
-#include "datospersistentesimportacion.h"
+#include <main/gui/import/importationdata.h>
 #include <api/dicom/idicomizador.h>
 #include <wx/ginkgostyle/ginkgostyle.h>
 #include <main/gui/import/selectimagesimportation.h>
@@ -32,7 +32,7 @@ namespace GNKVisualizator {
 		class SelectImagesImportationVisualizator: public GNC::GUI::SelectImagesImportation
 		{
 			public:
-				SelectImagesImportationVisualizator(wxWindow* pParent,IWizard* pWizard,const GnkPtr<TipoWizardImportacion>& datosPersistentes,const std::string &dirTemporal);
+				SelectImagesImportationVisualizator(wxWindow* pParent,IWizard* pWizard,const GnkPtr<GNC::GUI::ImportationData>& importationData,const std::string &dirTemporal);
 				~SelectImagesImportationVisualizator();
 
 				virtual bool Validar();
@@ -41,7 +41,7 @@ namespace GNKVisualizator {
 
 				void RellenarTagsComunes(GIL::DICOM::TipoJerarquia& base);
 
-				GnkPtr<TipoWizardImportacion> m_pDatosPersistentes;
+				GnkPtr<GNC::GUI::ImportationData> m_pImportationData;
 				std::string m_dirTemporal;
 				bool m_dicomizado;
 		};
