@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: eventosvisualizator.h -1   $
+ *  $Id: visualizatorevents.h 4335 2011-10-26 09:42:35Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -18,7 +18,9 @@
 #define ginkgoEVT_GNKVisualizator_EventoRefrescarListaOverlays	 3002
 #define ginkgoEVT_GNKVisualizator_EventoMostrarOverlay			 3003
 #define ginkgoEVT_GNKVisualizator_EventoZoom							 3004
+#define ginkgoEVT_GNKVisualizator_ChangePositionEvent				 3005
 
 #include "sincronizacion.h"
 #include "overlays.h"
 #include "zoom.h"
+#include "changeposition.h"
