@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: vista2d.cpp 4501 2011-12-20 11:13:41Z carlos $
+ *  $Id: vista2d.cpp 4842 2012-04-17 13:34:25Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -58,8 +58,7 @@
 #include "../dialogos/contenedorherramientas.h"
 
 
-
-#define TAG_WIDGETS					    0xb;
+#define TAG_WIDGETS 0xb;
 
 #ifdef __DEPRECATED
 #undef __DEPRECATED
@@ -195,10 +194,10 @@ GNKVisualizator::Vista2D::Vista2D(const GnkPtr<GNKVisualizator::VisualizatorStud
 		hMapa = cH->ObtenerHerramientaConcreta<GNKVisualizator::IHerramientaMapaColor>(GNKVisualizator::IHerramientaMapaColor::ID);
 		if (hMapa != NULL) {
 			hMapa->Subscribir(this, GVista);
-		}		
+		}
 	}
 	catch (GNC::GCS::ControladorHerramientasException& ex) {
-		std::cerr << "Error al obtener la herramienta puntero: No se pudo subscribir la herramienta: " << ex.getCause() << std::endl;
+		std::cerr << "Error al obtener la herramienta puntero: No se pudo subscribir la herramienta: " << ex << std::endl;
 	}
 }
 
@@ -344,10 +343,10 @@ GNKVisualizator::Vista2D::~Vista2D()
 		hMapa = cH->ObtenerHerramientaConcreta<GNKVisualizator::IHerramientaMapaColor>(GNKVisualizator::IHerramientaMapaColor::ID);
 		if (hMapa != NULL) {
 			hMapa->DesSubscribirsLosDeLaVista(this);
-		}		
+		}
 	}
 	catch (GNC::GCS::ControladorHerramientasException& ex) {
-		std::cerr << "Error al obtener la herramienta puntero. No se pudo des-subscribir la herramienta: " << ex.getCause() << std::endl;
+		std::cerr << "Error al obtener la herramienta puntero. No se pudo des-subscribir la herramienta: " << ex << std::endl;
 	}
 
 	/*
