@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: gvistacompleja.cpp 4492 2011-12-14 11:14:13Z tovar $
+ *  $Id: gvistacompleja.cpp 4869 2012-04-19 11:47:15Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -383,7 +383,7 @@ void GVistaCompleja::IniciarPipeline()
 		}
 	}
 	catch (GNC::GCS::ControladorHerramientasException& ex) {
-		std::cerr << "Error al obtener la herramienta puntero: No se pudo subscribir la herramienta: " << ex.getCause() << std::endl;
+		std::cerr << "Error al obtener la herramienta puntero: No se pudo subscribir la herramienta: " << ex << std::endl;
 	}
 
 	GNKVisualizator::IReconstructionTool* hReconstruction = cH->ObtenerHerramientaConcreta<GNKVisualizator::IReconstructionTool>(GNKVisualizator::IReconstructionTool::ID);
@@ -550,7 +550,7 @@ void GVistaCompleja::OnMenuVerClick(wxCommandEvent& )
 		pMenuVer->Connect(ID_FLIP_H, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( GVistaCompleja::OnFlipHorizontal),NULL,this);
 	}
 	catch (GNC::GCS::ControladorHerramientasException& ex) {
-		std::cerr << "Error al obtener la herramienta puntero: No se pudo subscribir la herramienta: " << ex.getCause() << std::endl;
+		std::cerr << "Error al obtener la herramienta puntero: No se pudo subscribir la herramienta: " << ex << std::endl;
 	}
 	m_pBarraIzquierda->PopupMenu(pMenuVer);
 	delete pMenuVer;
@@ -642,7 +642,7 @@ void GVistaCompleja::OnMenuLayout(wxCommandEvent &event)
 		}
 	}
 	catch (GNC::GCS::ControladorHerramientasException& ex) {
-		std::cerr << "Error al obtener la herramienta puntero: No se pudo subscribir la herramienta: " << ex.getCause() << std::endl;
+		std::cerr << "Error al obtener la herramienta puntero: No se pudo subscribir la herramienta: " << ex << std::endl;
 	}
 }
 
@@ -663,7 +663,7 @@ void GVistaCompleja::OnDesencajar(wxCommandEvent &event)
 		}
 	}
 	catch (GNC::GCS::ControladorHerramientasException& ex) {
-		std::cerr << "Error al obtener la herramienta puntero: No se pudo subscribir la herramienta: " << ex.getCause() << std::endl;
+		std::cerr << "Error al obtener la herramienta puntero: No se pudo subscribir la herramienta: " << ex << std::endl;
 	}
 }
 void GVistaCompleja::OnRotateLeft(wxCommandEvent &event)
@@ -792,11 +792,11 @@ void GVistaCompleja::OnMouseWheel(wxMouseEvent& event)
 			for (TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); it++) {
 				if(event.GetWheelRotation() > 0)
 				{
-					(*it)->GoToTSlice(1);
+					(*it)->GoToTSlice(-1);
 				}
 				else
 				{
-					(*it)->GoToTSlice(-1);
+					(*it)->GoToTSlice(1);
 				}
 			}
 		} else {
@@ -864,7 +864,7 @@ void GVistaCompleja::OnTimer()
 }
 
 //contrato widgets
-vtkGinkgoImageViewer* GVistaCompleja::GetViewer()
+vtkGinkgoImageViewer* GVistaCompleja::GetViewerActivo()
 {
 	// TODO Excepciones
 	vtkGinkgoImageViewer* viewer = m_VistasSimples[0]->ViewImage2D;
@@ -878,6 +878,12 @@ vtkGinkgoImageViewer* GVistaCompleja::GetViewer()
 	return viewer;
 }
 
+void GVistaCompleja::GetAllViewers(std::list<vtkGinkgoImageViewer*>& viewerList)
+{
+	for (TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); it++) {
+		viewerList.push_back((*it)->ViewImage2D);
+	}
+}
 
 //region "Realizacion de la interfaz IAnnotator"
 std::string GVistaCompleja::GetTopLeftAnnotation(GNC::GCS::Contexto3D* c)
@@ -1126,7 +1132,7 @@ void GVistaCompleja::GoToSlice(int pos, bool relativa, bool propagar, bool rende
 	m_posicion = posicion;
 
 	//se reestablece el window/level antes del evento de modificación porque ese evento lo escucha la herramienta
-	GNC::GCS::IContractWindowLevel::Setup(*IVista->GetEstudio()->GetTagsImagenDeImagenActiva());
+	GNC::GCS::IContractWindowLevel::Setup(*IVista->GetEstudio()->GetTagsImagen(m_posicion));
 
 	//se le indica al manager el vid
 	IVista->GetEstudio()->IndiceFicheroActivo = posicion;
@@ -1306,21 +1312,28 @@ void GVistaCompleja::ProcesarEvento(GNC::GCS::Eventos::IEvento *evt)
 					case GNC::GCS::Eventos::EventoModificacionImagen::VisualizacionImagenModificada:
 						//para que pille bien el window/level
 						for(TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); it++) {
-							if(pEvt->ResetWindowLevel()) {
-								if (HasDefaultWindowLevel()) {
-									GNC::GCS::IContractWindowLevel::WindowLevel wl = GetAndSetDefaultWindowLevel();
-									(*it)->ViewImage2D->SetDefaultWindowLevel(wl.m_window, wl.m_level);			
-								} else {
-									(*it)->ViewImage2D->SetAutoDefaultWindowLevel();
-								}
+							if (pEvt->AutoCalculeWindowLevel()) {
+								(*it)->ViewImage2D->SetAutoDefaultWindowLevel();
 								(*it)->ViewImage2D->ResetToDefaultWindowLevel();
+								SetUserDefinedWindowLevel((*it)->ViewImage2D->GetWindow(), (*it)->ViewImage2D->GetLevel());
 							} else {
-								(*it)->ViewImage2D->SetWindow(pEvt->GetWindow());
-								(*it)->ViewImage2D->SetLevel(pEvt->GetLevel());
-								//(*it)->ViewImage2D->UpdateImage();
-								for(TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); it++) {
-                                                                    //(*it)->ViewInteractor2D->Refresh(false);
-                                                                    //(*it)->ViewInteractor2D->Render();
+								if(pEvt->ResetWindowLevel()) {
+									if (HasDefaultWindowLevel()) {
+										GNC::GCS::IContractWindowLevel::WindowLevel wl = GetAndSetDefaultWindowLevel();
+										(*it)->ViewImage2D->SetDefaultWindowLevel(wl.m_window, wl.m_level);			
+									} else {
+										(*it)->ViewImage2D->SetAutoDefaultWindowLevel();
+									}
+
+									(*it)->ViewImage2D->ResetToDefaultWindowLevel();
+								} else {
+									(*it)->ViewImage2D->SetWindow(pEvt->GetWindow());
+									(*it)->ViewImage2D->SetLevel(pEvt->GetLevel());
+									//(*it)->ViewImage2D->UpdateImage();
+									for(TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); it++) {
+																							  //(*it)->ViewInteractor2D->Refresh(false);
+																							  //(*it)->ViewInteractor2D->Render();
+									}
 								}
 							}
 							if(pEvt->ResetCurrentPoint())
@@ -1429,7 +1442,11 @@ void GVistaCompleja::SetLayoutVentana(int filas, int columnas)
 			m_VistasSimples.erase(pVista);
 		}
 	} else {
+		int interpolationMode = VTK_NEAREST_INTERPOLATION;
 		for (unsigned int i = 0; i < m_VistasSimples.size(); ++i) {
+			if (i == 0) {				
+				interpolationMode = m_VistasSimples[i]->ViewImage2D->GetInterpolationMode();
+			}
 			m_VistasSimples[i]->ViewImage2D->ResetZoom();
 		}
 
@@ -1438,6 +1455,9 @@ void GVistaCompleja::SetLayoutVentana(int filas, int columnas)
 			incrementado = true;
 			AddVistaSimple();
 		}
+		for (unsigned int i = 1; i < m_VistasSimples.size(); ++i) {
+			m_VistasSimples[i]->ViewImage2D->SetInterpolationMode(interpolationMode);
+		}
 		//por si la posicion actual es invalida
 		m_posicion = 0;
 	}
@@ -1464,6 +1484,7 @@ void GVistaCompleja::SetLayoutVentana(int filas, int columnas)
 			return;
 		}
 	}
+	m_pEntorno->GetControladorHerramientas()->RefrescarHerramientas();
 }
 
 int GVistaCompleja::GetFilas()
@@ -1516,7 +1537,7 @@ void GVistaCompleja::SetReconstructionMode(GNKVisualizator::Reconstruction::Reco
 		case GNKVisualizator::Reconstruction::RM_VolumeRendering:
 			{
 				typedef MedicalViewer::Reconstruction::GUI::wxVolumeRendering TReconstructionWin;
-				TReconstructionWin* win = new TReconstructionWin(this, GNKVisualizator::IReconstructionContract::Estudio, GetViewer()->GetWindow(), GetViewer()->GetLevel());
+				TReconstructionWin* win = new TReconstructionWin(this, GNKVisualizator::IReconstructionContract::Estudio, GetViewerActivo()->GetWindow(), GetViewerActivo()->GetLevel());
 				win->Show(true);
 			}
 			break;
