@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: gvistacompleja.h 4486 2011-12-14 08:32:24Z carlos $
+ *  $Id: gvistacompleja.h 4869 2012-04-19 11:47:15Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -115,7 +115,8 @@ public:
 	//endregion
 
 	//contrato widgets
-	virtual vtkGinkgoImageViewer* GetViewer();
+	virtual vtkGinkgoImageViewer* GetViewerActivo();
+	virtual void GetAllViewers(std::list<vtkGinkgoImageViewer*>& viewerList);
 
 	//region "Realizacion de la interfaz IAnnotator"
 	virtual std::string GetTopLeftAnnotation(GNC::GCS::Contexto3D* c);
