@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: gvistasimple.cpp 4500 2011-12-20 08:00:51Z carlos $
+ *  $Id: gvistasimple.cpp 4849 2012-04-18 10:42:04Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -419,9 +419,6 @@ std::string GVistaSimple::GetTopRightAnnotation(GNC::GCS::Contexto3D*) {
 
 	tag = "0010|1010"; // Patient's Age
 	str = IVista->GetDICOMTagOriginal(tag);
-	if(str.size() > 0) {
-		os << str.c_str() << "Y" << std::endl;
-	}
 
 	tag = "0008|0060"; // Modalidad
 	os << _Std("Modality: ") << IVista->GetDICOMTagOriginal(tag).c_str() << std::endl;
@@ -453,6 +450,10 @@ std::string GVistaSimple::GetBottomLeftAnnotation(GNC::GCS::Contexto3D* c) {
 		return "";
 
 	std::ostringstream os;
+	std::string tmp = IVista->GetDICOMTagOriginal("0020|4000");// Image description
+	if (!tmp.empty()) {
+		os << _Std("Comment:") << tmp << std::endl;
+	}
 	int dims[3] = {0, 0, 0};
 	this->ViewImage2D->GetDimensions(dims);
 	int nc = this->ViewImage2D->GetNumberOfComponents();
@@ -464,6 +465,18 @@ std::string GVistaSimple::GetBottomLeftAnnotation(GNC::GCS::Contexto3D* c) {
 	if(nc == 1){
 		os << "W/L: "  << ViewImage2D->GetWindow() << "/" << ViewImage2D->GetLevel() << std::endl;
 	}
+	
+	
+	//esto es una secuencia no sta mu bien
+	tmp = IVista->GetDICOMTagOriginal(std::string("0020|0062"));
+	if(tmp != "") {
+		if(tmp=="R"){
+			os << _Std("Right") << ";" ;
+		}else if(tmp=="L"){
+			os << _Std("Left") << ";";
+		}
+	}
+
 	if (c->offscreenCreado) {
 		os << _Std("Slice: ") <<  c->OVID + 1;
 		if (dims[2] > 1) {
@@ -479,7 +492,6 @@ std::string GVistaSimple::GetBottomLeftAnnotation(GNC::GCS::Contexto3D* c) {
 		os << std::endl;
 	}
 
-	std::string tmp;
 	double spacing[3] = {0.0, 0.0, 0.0};
 	bool hasSpacing = EstudioReferido->GetSpacingActiva(spacing[0], spacing[1], spacing[2]);
 	if (hasSpacing) {
