@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: gwaveformview.cpp 4444 2011-11-24 11:48:53Z tovar $
+*  $Id: gwaveformview.cpp 4869 2012-04-19 11:47:15Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -204,7 +204,7 @@ namespace GNKVisualizator
 			m_pManager->Render();
 		}
 
-		vtkGinkgoImageViewer* GWaveformView::GetViewer()
+		vtkGinkgoImageViewer* GWaveformView::GetViewerActivo()
 		{
 			return ViewImage2D;
 		}
